Class Account

  • All Implemented Interfaces:

    
    public final class Account
    
                        
    • Constructor Detail

    • Method Detail

      • token

         final String token()

        Globally unique identifier for the account. This is the same as the account_token returned by the enroll endpoint. If using this parameter, do not include pagination.

      • created

         final Optional<OffsetDateTime> created()

        Timestamp of when the account was created. For accounts created before 2023-05-11, this field will be null.

      • spendLimit

         final Account.SpendLimit spendLimit()

        Spend limit information for the user containing the daily, monthly, and lifetime spend limit of the account. Any charges to a card owned by this account will be declined once their transaction volume has surpassed the value in the applicable time limit (rolling). A lifetime limit of 0 indicates that the lifetime limit feature is disabled.

      • state

         final Account.State state()

        Account state:

        • ACTIVE - Account is able to transact and create new cards.

        • PAUSED - Account will not be able to transact or create new cards. It can be set back to ACTIVE.

        • CLOSED - Account will not be able to transact or create new cards. CLOSED accounts are also unable to be transitioned to ACTIVE or PAUSED states. CLOSED accounts result from failing to pass KYB/KYC or Lithic closing for risk/compliance reasons. Please contact [email protected] if you believe this was in error.

      • authRuleTokens

        @Deprecated(message = "deprecated") final Optional<List<String>> authRuleTokens()

        List of identifiers for the Auth Rule(s) that are applied on the account. This field is deprecated and will no longer be populated in the account_holder object. The key will be removed from the schema in a future release. Use the /auth_rules endpoints to fetch Auth Rule information instead.

      • _token

         final JsonField<String> _token()

        Globally unique identifier for the account. This is the same as the account_token returned by the enroll endpoint. If using this parameter, do not include pagination.

      • _created

         final JsonField<OffsetDateTime> _created()

        Timestamp of when the account was created. For accounts created before 2023-05-11, this field will be null.

      • _spendLimit

         final JsonField<Account.SpendLimit> _spendLimit()

        Spend limit information for the user containing the daily, monthly, and lifetime spend limit of the account. Any charges to a card owned by this account will be declined once their transaction volume has surpassed the value in the applicable time limit (rolling). A lifetime limit of 0 indicates that the lifetime limit feature is disabled.

      • _state

         final JsonField<Account.State> _state()

        Account state:

        • ACTIVE - Account is able to transact and create new cards.

        • PAUSED - Account will not be able to transact or create new cards. It can be set back to ACTIVE.

        • CLOSED - Account will not be able to transact or create new cards. CLOSED accounts are also unable to be transitioned to ACTIVE or PAUSED states. CLOSED accounts result from failing to pass KYB/KYC or Lithic closing for risk/compliance reasons. Please contact [email protected] if you believe this was in error.

      • _authRuleTokens

        @Deprecated(message = "deprecated") final JsonField<List<String>> _authRuleTokens()

        List of identifiers for the Auth Rule(s) that are applied on the account. This field is deprecated and will no longer be populated in the account_holder object. The key will be removed from the schema in a future release. Use the /auth_rules endpoints to fetch Auth Rule information instead.

      • builder

         final static Account.Builder builder()

        Returns a mutable builder for constructing an instance of Account.

        The following fields are required:

        .token()
        .created()
        .spendLimit()
        .state()