Class Account.SpendLimit

  • All Implemented Interfaces:

    
    public final class Account.SpendLimit
    
                        

    Spend limit information for the user containing the daily, monthly, and lifetime spend limit of the account. Any charges to a card owned by this account will be declined once their transaction volume has surpassed the value in the applicable time limit (rolling). A lifetime limit of 0 indicates that the lifetime limit feature is disabled.