Class Account.SpendLimit.Builder
-
- All Implemented Interfaces:
public final class Account.SpendLimit.BuilderA builder for SpendLimit.
-
-
Method Summary
-
-
Method Detail
-
daily
final Account.SpendLimit.Builder daily(Long daily)
Daily spend limit (in cents).
-
daily
final Account.SpendLimit.Builder daily(JsonField<Long> daily)
Sets Builder.daily to an arbitrary JSON value.
You should usually call Builder.daily with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lifetime
final Account.SpendLimit.Builder lifetime(Long lifetime)
Total spend limit over account lifetime (in cents).
-
lifetime
final Account.SpendLimit.Builder lifetime(JsonField<Long> lifetime)
Sets Builder.lifetime to an arbitrary JSON value.
You should usually call Builder.lifetime with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
monthly
final Account.SpendLimit.Builder monthly(Long monthly)
Monthly spend limit (in cents).
-
monthly
final Account.SpendLimit.Builder monthly(JsonField<Long> monthly)
Sets Builder.monthly to an arbitrary JSON value.
You should usually call Builder.monthly with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Account.SpendLimit.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Account.SpendLimit.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Account.SpendLimit.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Account.SpendLimit.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Account.SpendLimit.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Account.SpendLimit build()
Returns an immutable instance of SpendLimit.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.daily() .lifetime() .monthly()
-
-
-
-