Package com.lithic.api.models
Class AccountActivityListPage.Builder
-
- All Implemented Interfaces:
public final class AccountActivityListPage.BuilderA builder for AccountActivityListPage.
-
-
Method Summary
Modifier and Type Method Description final AccountActivityListPage.Builderservice(AccountActivityService service)final AccountActivityListPage.Builderparams(AccountActivityListParams params)The parameters that were used to request this page. final AccountActivityListPage.Builderresponse(AccountActivityListPageResponse response)The response that this page was parsed from. final AccountActivityListPagebuild()Returns an immutable instance of AccountActivityListPage. -
-
Method Detail
-
service
final AccountActivityListPage.Builder service(AccountActivityService service)
-
params
final AccountActivityListPage.Builder params(AccountActivityListParams params)
The parameters that were used to request this page.
-
response
final AccountActivityListPage.Builder response(AccountActivityListPageResponse response)
The response that this page was parsed from.
-
build
final AccountActivityListPage build()
Returns an immutable instance of AccountActivityListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-