Package com.lithic.api.models
Class AccountActivityRetrieveTransactionResponse.PaymentTransaction.RelatedAccountTokens
-
- All Implemented Interfaces:
public final class AccountActivityRetrieveTransactionResponse.PaymentTransaction.RelatedAccountTokensRelated account tokens for the transaction
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountActivityRetrieveTransactionResponse.PaymentTransaction.RelatedAccountTokens.BuilderA builder for RelatedAccountTokens.
-
Method Summary
Modifier and Type Method Description final Optional<String>accountToken()Globally unique identifier for the account final Optional<String>businessAccountToken()Globally unique identifier for the business account final JsonField<String>_accountToken()Returns the raw JSON value of accountToken. final JsonField<String>_businessAccountToken()Returns the raw JSON value of businessAccountToken. final Map<String, JsonValue>_additionalProperties()final AccountActivityRetrieveTransactionResponse.PaymentTransaction.RelatedAccountTokens.BuildertoBuilder()final AccountActivityRetrieveTransactionResponse.PaymentTransaction.RelatedAccountTokensvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountActivityRetrieveTransactionResponse.PaymentTransaction.RelatedAccountTokens.Builderbuilder()Returns a mutable builder for constructing an instance of RelatedAccountTokens. -
-
Method Detail
-
accountToken
final Optional<String> accountToken()
Globally unique identifier for the account
-
businessAccountToken
final Optional<String> businessAccountToken()
Globally unique identifier for the business account
-
_accountToken
final JsonField<String> _accountToken()
Returns the raw JSON value of accountToken.
Unlike accountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_businessAccountToken
final JsonField<String> _businessAccountToken()
Returns the raw JSON value of businessAccountToken.
Unlike businessAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountActivityRetrieveTransactionResponse.PaymentTransaction.RelatedAccountTokens.Builder toBuilder()
-
validate
final AccountActivityRetrieveTransactionResponse.PaymentTransaction.RelatedAccountTokens validate()
-
builder
final static AccountActivityRetrieveTransactionResponse.PaymentTransaction.RelatedAccountTokens.Builder builder()
Returns a mutable builder for constructing an instance of RelatedAccountTokens.
The following fields are required:
.accountToken() .businessAccountToken()
-
-
-
-