Enum AccountHolder.StatusReason.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum AccountHolder.StatusReason.Value extends Enum<AccountHolder.StatusReason.Value>
An enum containing StatusReason's known values, as well as an _UNKNOWN member.
An instance of StatusReason can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<AccountHolder.StatusReason.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description ADDRESS_VERIFICATION_FAILUREAGE_THRESHOLD_FAILURECOMPLETE_VERIFICATION_FAILUREDOB_VERIFICATION_FAILUREID_VERIFICATION_FAILUREMAX_DOCUMENT_ATTEMPTSMAX_RESUBMISSION_ATTEMPTSNAME_VERIFICATION_FAILUREOTHER_VERIFICATION_FAILURERISK_THRESHOLD_FAILUREWATCHLIST_ALERT_FAILURE_UNKNOWNAn enum member indicating that StatusReason was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final AccountHolder.StatusReason.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<AccountHolder.StatusReason.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<AccountHolder.StatusReason.Value>getEntries()An enum containing StatusReason's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final AccountHolder.StatusReason.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<AccountHolder.StatusReason.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<AccountHolder.StatusReason.Value> getEntries()
An enum containing StatusReason's known values, as well as an _UNKNOWN member.
An instance of StatusReason can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-