Class AccountHolderCreateResponse
-
- All Implemented Interfaces:
public final class AccountHolderCreateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountHolderCreateResponse.BuilderA builder for AccountHolderCreateResponse.
public final classAccountHolderCreateResponse.StatusKYC and KYB evaluation states.
Note:
PENDING_REVIEWis only applicable for theKYB_BASICworkflow.
public final classAccountHolderCreateResponse.StatusReasonsStatus Reasons for KYC/KYB enrollment states
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier for the account holder. final StringaccountToken()Globally unique identifier for the account. final AccountHolderCreateResponse.Statusstatus()KYC and KYB evaluation states. final List<AccountHolderCreateResponse.StatusReasons>statusReasons()Reason for the evaluation status. final Optional<OffsetDateTime>created()Timestamp of when the account holder was created. final Optional<String>externalId()Customer-provided token that indicates a relationship with an object outside of the Lithic ecosystem. final Optional<List<RequiredDocument>>requiredDocuments()Only present for "KYB_BASIC" workflow. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<String>_accountToken()Returns the raw JSON value of accountToken. final JsonField<AccountHolderCreateResponse.Status>_status()Returns the raw JSON value of status. final JsonField<List<AccountHolderCreateResponse.StatusReasons>>_statusReasons()Returns the raw JSON value of statusReasons. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<String>_externalId()Returns the raw JSON value of externalId. final JsonField<List<RequiredDocument>>_requiredDocuments()Returns the raw JSON value of requiredDocuments. final Map<String, JsonValue>_additionalProperties()final AccountHolderCreateResponse.BuildertoBuilder()final AccountHolderCreateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountHolderCreateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of AccountHolderCreateResponse. -
-
Method Detail
-
accountToken
final String accountToken()
Globally unique identifier for the account.
-
status
final AccountHolderCreateResponse.Status status()
KYC and KYB evaluation states.
Note:
PENDING_REVIEWis only applicable for theKYB_BASICworkflow.
-
statusReasons
final List<AccountHolderCreateResponse.StatusReasons> statusReasons()
Reason for the evaluation status.
-
created
final Optional<OffsetDateTime> created()
Timestamp of when the account holder was created.
-
externalId
final Optional<String> externalId()
Customer-provided token that indicates a relationship with an object outside of the Lithic ecosystem.
-
requiredDocuments
final Optional<List<RequiredDocument>> requiredDocuments()
Only present for "KYB_BASIC" workflow. A list of documents required for the account holder to be approved.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_accountToken
final JsonField<String> _accountToken()
Returns the raw JSON value of accountToken.
Unlike accountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<AccountHolderCreateResponse.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_statusReasons
final JsonField<List<AccountHolderCreateResponse.StatusReasons>> _statusReasons()
Returns the raw JSON value of statusReasons.
Unlike statusReasons, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_externalId
final JsonField<String> _externalId()
Returns the raw JSON value of externalId.
Unlike externalId, this method doesn't throw if the JSON field has an unexpected type.
-
_requiredDocuments
final JsonField<List<RequiredDocument>> _requiredDocuments()
Returns the raw JSON value of requiredDocuments.
Unlike requiredDocuments, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountHolderCreateResponse.Builder toBuilder()
-
validate
final AccountHolderCreateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccountHolderCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of AccountHolderCreateResponse.
The following fields are required:
.token() .accountToken() .status() .statusReasons()
-
-
-
-