Class AccountHolderEntity
-
- All Implemented Interfaces:
public final class AccountHolderEntityInformation about an entity associated with an account holder
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountHolderEntity.BuilderA builder for AccountHolderEntity.
public final classAccountHolderEntity.AddressIndividual's current address
public final classAccountHolderEntity.EntityStatusThe status of the entity
public final classAccountHolderEntity.EntityTypeThe type of entity
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier for the entity final StringaccountHolderToken()Globally unique identifier for the account holder final AccountHolderEntity.Addressaddress()Individual's current address final Optional<String>dob()Individual's date of birth, as an RFC 3339 date final Optional<String>email()Individual's email address final Optional<String>firstName()Individual's first name, as it appears on government-issued identity documents final Optional<String>lastName()Individual's last name, as it appears on government-issued identity documents final Optional<String>phoneNumber()Individual's phone number, entered in E. final AccountHolderEntity.EntityStatusstatus()The status of the entity final AccountHolderEntity.EntityTypetype()The type of entity final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<String>_accountHolderToken()Returns the raw JSON value of accountHolderToken. final JsonField<AccountHolderEntity.Address>_address()Returns the raw JSON value of address. final JsonField<String>_dob()Returns the raw JSON value of dob. final JsonField<String>_email()Returns the raw JSON value of email. final JsonField<String>_firstName()Returns the raw JSON value of firstName. final JsonField<String>_lastName()Returns the raw JSON value of lastName. final JsonField<String>_phoneNumber()Returns the raw JSON value of phoneNumber. final JsonField<AccountHolderEntity.EntityStatus>_status()Returns the raw JSON value of status. final JsonField<AccountHolderEntity.EntityType>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final AccountHolderEntity.BuildertoBuilder()final AccountHolderEntityvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountHolderEntity.Builderbuilder()Returns a mutable builder for constructing an instance of AccountHolderEntity. -
-
Method Detail
-
accountHolderToken
final String accountHolderToken()
Globally unique identifier for the account holder
-
address
final AccountHolderEntity.Address address()
Individual's current address
-
firstName
final Optional<String> firstName()
Individual's first name, as it appears on government-issued identity documents
-
lastName
final Optional<String> lastName()
Individual's last name, as it appears on government-issued identity documents
-
phoneNumber
final Optional<String> phoneNumber()
Individual's phone number, entered in E.164 format
-
status
final AccountHolderEntity.EntityStatus status()
The status of the entity
-
type
final AccountHolderEntity.EntityType type()
The type of entity
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_accountHolderToken
final JsonField<String> _accountHolderToken()
Returns the raw JSON value of accountHolderToken.
Unlike accountHolderToken, this method doesn't throw if the JSON field has an unexpected type.
-
_address
final JsonField<AccountHolderEntity.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_dob
final JsonField<String> _dob()
Returns the raw JSON value of dob.
Unlike dob, this method doesn't throw if the JSON field has an unexpected type.
-
_email
final JsonField<String> _email()
Returns the raw JSON value of email.
Unlike email, this method doesn't throw if the JSON field has an unexpected type.
-
_firstName
final JsonField<String> _firstName()
Returns the raw JSON value of firstName.
Unlike firstName, this method doesn't throw if the JSON field has an unexpected type.
-
_lastName
final JsonField<String> _lastName()
Returns the raw JSON value of lastName.
Unlike lastName, this method doesn't throw if the JSON field has an unexpected type.
-
_phoneNumber
final JsonField<String> _phoneNumber()
Returns the raw JSON value of phoneNumber.
Unlike phoneNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<AccountHolderEntity.EntityStatus> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<AccountHolderEntity.EntityType> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountHolderEntity.Builder toBuilder()
-
validate
final AccountHolderEntity validate()
-
builder
final static AccountHolderEntity.Builder builder()
Returns a mutable builder for constructing an instance of AccountHolderEntity.
The following fields are required:
.token() .accountHolderToken() .address() .dob() .email() .firstName() .lastName() .phoneNumber() .status() .type()
-
-
-
-