Class AccountHolderListPageAsync
-
- All Implemented Interfaces:
-
com.lithic.api.core.PageAsync
public final class AccountHolderListPageAsync implements PageAsync<AccountHolder>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountHolderListPageAsync.BuilderA builder for AccountHolderListPageAsync.
-
Method Summary
Modifier and Type Method Description final List<AccountHolder>data()Delegates to AccountHolderListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to AccountHolderListPageResponse, but gracefully handles missing data. List<AccountHolder>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final AccountHolderListParamsnextPageParams()CompletableFuture<AccountHolderListPageAsync>nextPage()Returns the page after this one by making another request. final AutoPagerAsync<AccountHolder>autoPager()final AccountHolderListParamsparams()The parameters that were used to request this page. final AccountHolderListPageResponseresponse()The response that this page was parsed from. final AccountHolderListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountHolderListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of AccountHolderListPageAsync. -
-
Method Detail
-
data
final List<AccountHolder> data()
Delegates to AccountHolderListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to AccountHolderListPageResponse, but gracefully handles missing data.
-
items
List<AccountHolder> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final AccountHolderListParams nextPageParams()
-
nextPage
CompletableFuture<AccountHolderListPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<AccountHolder> autoPager()
-
params
final AccountHolderListParams params()
The parameters that were used to request this page.
-
response
final AccountHolderListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final AccountHolderListPageAsync.Builder toBuilder()
-
builder
final static AccountHolderListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of AccountHolderListPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-