Class AccountHolderUpdateParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class AccountHolderUpdateParams implements Params
Update the information associated with a particular account holder (including business owners and control persons associated to a business account). If Lithic is performing KYB or KYC and additional verification is required we will run the individual's or business's updated information again and return whether the status is accepted or pending (i.e., further action required). All calls to this endpoint will return a synchronous response. The response time will depend on the workflow. In some cases, the response may indicate the workflow is under review or further action will be needed to complete the account creation process. This endpoint can only be used on existing accounts that are part of the program that the calling API key manages.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountHolderUpdateParams.BuilderA builder for AccountHolderUpdateParams.
public final classAccountHolderUpdateParams.BodyThe KYB request payload for updating a business.
-
Method Summary
Modifier and Type Method Description final Optional<String>accountHolderToken()final AccountHolderUpdateParams.Bodybody()The KYB request payload for updating a business. final Headers_additionalHeaders()final QueryParams_additionalQueryParams()final AccountHolderUpdateParams.BuildertoBuilder()final AccountHolderUpdateParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountHolderUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of AccountHolderUpdateParams. -
-
Method Detail
-
accountHolderToken
final Optional<String> accountHolderToken()
-
body
final AccountHolderUpdateParams.Body body()
The KYB request payload for updating a business.
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
toBuilder
final AccountHolderUpdateParams.Builder toBuilder()
-
_body
final AccountHolderUpdateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static AccountHolderUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of AccountHolderUpdateParams.
The following fields are required:
.body()
-
-
-
-