Class AccountHolderUpdateParams.Body.PatchRequest
-
- All Implemented Interfaces:
public final class AccountHolderUpdateParams.Body.PatchRequestThe legacy request for updating an account holder.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountHolderUpdateParams.Body.PatchRequest.BuilderA builder for PatchRequest.
-
Method Summary
Modifier and Type Method Description final Optional<AddressUpdate>address()Allowed for: KYC-Exempt, BYO-KYC, BYO-KYB. final Optional<String>businessAccountToken()Allowed for: KYC-Exempt, BYO-KYC. final Optional<String>email()Allowed for all Account Holders. final Optional<String>firstName()Allowed for KYC-Exempt, BYO-KYC. final Optional<String>lastName()Allowed for KYC-Exempt, BYO-KYC. final Optional<String>legalBusinessName()Allowed for BYO-KYB. final Optional<String>phoneNumber()Allowed for all Account Holders. final JsonField<AddressUpdate>_address()Returns the raw JSON value of address. final JsonField<String>_businessAccountToken()Returns the raw JSON value of businessAccountToken. final JsonField<String>_email()Returns the raw JSON value of email. final JsonField<String>_firstName()Returns the raw JSON value of firstName. final JsonField<String>_lastName()Returns the raw JSON value of lastName. final JsonField<String>_legalBusinessName()Returns the raw JSON value of legalBusinessName. final JsonField<String>_phoneNumber()Returns the raw JSON value of phoneNumber. final Map<String, JsonValue>_additionalProperties()final AccountHolderUpdateParams.Body.PatchRequest.BuildertoBuilder()final AccountHolderUpdateParams.Body.PatchRequestvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountHolderUpdateParams.Body.PatchRequest.Builderbuilder()Returns a mutable builder for constructing an instance of PatchRequest. -
-
Method Detail
-
address
final Optional<AddressUpdate> address()
Allowed for: KYC-Exempt, BYO-KYC, BYO-KYB.
-
businessAccountToken
final Optional<String> businessAccountToken()
Allowed for: KYC-Exempt, BYO-KYC. The token of the business account to which the account holder is associated.
-
email
final Optional<String> email()
Allowed for all Account Holders. Account holder's email address. The primary purpose of this field is for cardholder identification and verification during the digital wallet tokenization process.
-
firstName
final Optional<String> firstName()
Allowed for KYC-Exempt, BYO-KYC. Account holder's first name.
-
lastName
final Optional<String> lastName()
Allowed for KYC-Exempt, BYO-KYC. Account holder's last name.
-
legalBusinessName
final Optional<String> legalBusinessName()
Allowed for BYO-KYB. Legal business name of the account holder.
-
phoneNumber
final Optional<String> phoneNumber()
Allowed for all Account Holders. Account holder's phone number, entered in E.164 format. The primary purpose of this field is for cardholder identification and verification during the digital wallet tokenization process.
-
_address
final JsonField<AddressUpdate> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_businessAccountToken
final JsonField<String> _businessAccountToken()
Returns the raw JSON value of businessAccountToken.
Unlike businessAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_email
final JsonField<String> _email()
Returns the raw JSON value of email.
Unlike email, this method doesn't throw if the JSON field has an unexpected type.
-
_firstName
final JsonField<String> _firstName()
Returns the raw JSON value of firstName.
Unlike firstName, this method doesn't throw if the JSON field has an unexpected type.
-
_lastName
final JsonField<String> _lastName()
Returns the raw JSON value of lastName.
Unlike lastName, this method doesn't throw if the JSON field has an unexpected type.
-
_legalBusinessName
final JsonField<String> _legalBusinessName()
Returns the raw JSON value of legalBusinessName.
Unlike legalBusinessName, this method doesn't throw if the JSON field has an unexpected type.
-
_phoneNumber
final JsonField<String> _phoneNumber()
Returns the raw JSON value of phoneNumber.
Unlike phoneNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountHolderUpdateParams.Body.PatchRequest.Builder toBuilder()
-
validate
final AccountHolderUpdateParams.Body.PatchRequest validate()
-
builder
final static AccountHolderUpdateParams.Body.PatchRequest.Builder builder()
Returns a mutable builder for constructing an instance of PatchRequest.
-
-
-
-