Package com.lithic.api.models
Class AccountHolderUpdateResponse
-
- All Implemented Interfaces:
public final class AccountHolderUpdateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAccountHolderUpdateResponse.VisitorAn interface that defines how to map each variant of AccountHolderUpdateResponse to a value of type T.
public final classAccountHolderUpdateResponse.KybKycPatchResponsepublic final classAccountHolderUpdateResponse.PatchResponse
-
Method Summary
Modifier and Type Method Description final Optional<AccountHolderUpdateResponse.KybKycPatchResponse>kybKycPatch()final Optional<AccountHolderUpdateResponse.PatchResponse>patch()final BooleanisKybKycPatch()final BooleanisPatch()final AccountHolderUpdateResponse.KybKycPatchResponseasKybKycPatch()final AccountHolderUpdateResponse.PatchResponseasPatch()final Optional<JsonValue>_json()final <T extends Any> Taccept(AccountHolderUpdateResponse.Visitor<T> visitor)final AccountHolderUpdateResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountHolderUpdateResponseofKybKycPatch(AccountHolderUpdateResponse.KybKycPatchResponse kybKycPatch)final static AccountHolderUpdateResponseofPatch(AccountHolderUpdateResponse.PatchResponse patch)-
-
Method Detail
-
kybKycPatch
final Optional<AccountHolderUpdateResponse.KybKycPatchResponse> kybKycPatch()
-
patch
final Optional<AccountHolderUpdateResponse.PatchResponse> patch()
-
isKybKycPatch
final Boolean isKybKycPatch()
-
asKybKycPatch
final AccountHolderUpdateResponse.KybKycPatchResponse asKybKycPatch()
-
asPatch
final AccountHolderUpdateResponse.PatchResponse asPatch()
-
accept
final <T extends Any> T accept(AccountHolderUpdateResponse.Visitor<T> visitor)
-
validate
final AccountHolderUpdateResponse validate()
-
ofKybKycPatch
final static AccountHolderUpdateResponse ofKybKycPatch(AccountHolderUpdateResponse.KybKycPatchResponse kybKycPatch)
-
ofPatch
final static AccountHolderUpdateResponse ofPatch(AccountHolderUpdateResponse.PatchResponse patch)
-
-
-
-