Class AccountHolderUpdateResponse.PatchResponse
-
- All Implemented Interfaces:
public final class AccountHolderUpdateResponse.PatchResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountHolderUpdateResponse.PatchResponse.BuilderA builder for PatchResponse.
public final classAccountHolderUpdateResponse.PatchResponse.AddressThe address for the account holder
-
Method Summary
Modifier and Type Method Description final Optional<String>token()The token for the account holder that was updated final Optional<AccountHolderUpdateResponse.PatchResponse.Address>address()The address for the account holder final Optional<String>businessAccountToken()The token for the business account that the account holder is associated with final Optional<String>email()The email for the account holder final Optional<String>firstName()The first name for the account holder final Optional<String>lastName()The last name for the account holder final Optional<String>legalBusinessName()The legal business name for the account holder final Optional<String>phoneNumber()The phone_number for the account holder final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<AccountHolderUpdateResponse.PatchResponse.Address>_address()Returns the raw JSON value of address. final JsonField<String>_businessAccountToken()Returns the raw JSON value of businessAccountToken. final JsonField<String>_email()Returns the raw JSON value of email. final JsonField<String>_firstName()Returns the raw JSON value of firstName. final JsonField<String>_lastName()Returns the raw JSON value of lastName. final JsonField<String>_legalBusinessName()Returns the raw JSON value of legalBusinessName. final JsonField<String>_phoneNumber()Returns the raw JSON value of phoneNumber. final Map<String, JsonValue>_additionalProperties()final AccountHolderUpdateResponse.PatchResponse.BuildertoBuilder()final AccountHolderUpdateResponse.PatchResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountHolderUpdateResponse.PatchResponse.Builderbuilder()Returns a mutable builder for constructing an instance of PatchResponse. -
-
Method Detail
-
address
final Optional<AccountHolderUpdateResponse.PatchResponse.Address> address()
The address for the account holder
-
businessAccountToken
final Optional<String> businessAccountToken()
The token for the business account that the account holder is associated with
-
legalBusinessName
final Optional<String> legalBusinessName()
The legal business name for the account holder
-
phoneNumber
final Optional<String> phoneNumber()
The phone_number for the account holder
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_address
final JsonField<AccountHolderUpdateResponse.PatchResponse.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_businessAccountToken
final JsonField<String> _businessAccountToken()
Returns the raw JSON value of businessAccountToken.
Unlike businessAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_email
final JsonField<String> _email()
Returns the raw JSON value of email.
Unlike email, this method doesn't throw if the JSON field has an unexpected type.
-
_firstName
final JsonField<String> _firstName()
Returns the raw JSON value of firstName.
Unlike firstName, this method doesn't throw if the JSON field has an unexpected type.
-
_lastName
final JsonField<String> _lastName()
Returns the raw JSON value of lastName.
Unlike lastName, this method doesn't throw if the JSON field has an unexpected type.
-
_legalBusinessName
final JsonField<String> _legalBusinessName()
Returns the raw JSON value of legalBusinessName.
Unlike legalBusinessName, this method doesn't throw if the JSON field has an unexpected type.
-
_phoneNumber
final JsonField<String> _phoneNumber()
Returns the raw JSON value of phoneNumber.
Unlike phoneNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountHolderUpdateResponse.PatchResponse.Builder toBuilder()
-
validate
final AccountHolderUpdateResponse.PatchResponse validate()
-
builder
final static AccountHolderUpdateResponse.PatchResponse.Builder builder()
Returns a mutable builder for constructing an instance of PatchResponse.
-
-
-
-