Package com.lithic.api.models
Interface AccountHolderUpdateResponse.Visitor
-
- All Implemented Interfaces:
public interface AccountHolderUpdateResponse.Visitor<T extends Object>An interface that defines how to map each variant of AccountHolderUpdateResponse to a value of type T.
-
-
Method Summary
Modifier and Type Method Description abstract TvisitKybKycPatch(AccountHolderUpdateResponse.KybKycPatchResponse kybKycPatch)abstract TvisitPatch(AccountHolderUpdateResponse.PatchResponse patch)Tunknown(JsonValue json)Maps an unknown variant of AccountHolderUpdateResponse to a value of type T. -
-
Method Detail
-
visitKybKycPatch
abstract T visitKybKycPatch(AccountHolderUpdateResponse.KybKycPatchResponse kybKycPatch)
-
visitPatch
abstract T visitPatch(AccountHolderUpdateResponse.PatchResponse patch)
-
unknown
T unknown(JsonValue json)
Maps an unknown variant of AccountHolderUpdateResponse to a value of type T.
An instance of AccountHolderUpdateResponse can contain an unknown variant if it was deserialized from data that doesn't match any known variant. For example, if the SDK is on an older version than the API, then the API may respond with new variants that the SDK is unaware of.
-
-
-
-