Class AccountHolderUpdatedWebhookEvent.KybPayload.UpdateRequest
-
- All Implemented Interfaces:
public final class AccountHolderUpdatedWebhookEvent.KybPayload.UpdateRequestOriginal request to update the account holder.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountHolderUpdatedWebhookEvent.KybPayload.UpdateRequest.BuilderA builder for UpdateRequest.
public final classAccountHolderUpdatedWebhookEvent.KybPayload.UpdateRequest.Individual
-
Method Summary
-
-
Method Detail
-
beneficialOwnerIndividuals
final Optional<List<AccountHolderUpdatedWebhookEvent.KybPayload.UpdateRequest.Individual>> beneficialOwnerIndividuals()
You must submit a list of all direct and indirect individuals with 25% or more ownership in the company. A maximum of 4 beneficial owners can be submitted. If no individual owns 25% of the company you do not need to send beneficial owner information. See FinCEN requirements (Section I) for more background on individuals that should be included.
-
businessEntity
final Optional<KybBusinessEntity> businessEntity()
Information for business for which the account is being opened and KYB is being run.
-
controlPerson
final Optional<AccountHolderUpdatedWebhookEvent.KybPayload.UpdateRequest.Individual> controlPerson()
An individual with significant responsibility for managing the legal entity (e.g., a Chief Executive Officer, Chief Financial Officer, Chief Operating Officer, Managing Member, General Partner, President, Vice President, or Treasurer). This can be an executive, or someone who will have program-wide access to the cards that Lithic will provide. In some cases, this individual could also be a beneficial owner listed above. See FinCEN requirements (Section II) for more background.
-
_beneficialOwnerIndividuals
final JsonField<List<AccountHolderUpdatedWebhookEvent.KybPayload.UpdateRequest.Individual>> _beneficialOwnerIndividuals()
Returns the raw JSON value of beneficialOwnerIndividuals.
Unlike beneficialOwnerIndividuals, this method doesn't throw if the JSON field has an unexpected type.
-
_businessEntity
final JsonField<KybBusinessEntity> _businessEntity()
Returns the raw JSON value of businessEntity.
Unlike businessEntity, this method doesn't throw if the JSON field has an unexpected type.
-
_controlPerson
final JsonField<AccountHolderUpdatedWebhookEvent.KybPayload.UpdateRequest.Individual> _controlPerson()
Returns the raw JSON value of controlPerson.
Unlike controlPerson, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountHolderUpdatedWebhookEvent.KybPayload.UpdateRequest.Builder toBuilder()
-
validate
final AccountHolderUpdatedWebhookEvent.KybPayload.UpdateRequest validate()
-
builder
final static AccountHolderUpdatedWebhookEvent.KybPayload.UpdateRequest.Builder builder()
Returns a mutable builder for constructing an instance of UpdateRequest.
-
-
-
-