Class AccountHolderUpdatedWebhookEvent.KycPayload
-
- All Implemented Interfaces:
public final class AccountHolderUpdatedWebhookEvent.KycPayloadKYC payload for an updated account holder.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountHolderUpdatedWebhookEvent.KycPayload.BuilderA builder for KycPayload.
public final classAccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequestOriginal request to update the account holder.
public final classAccountHolderUpdatedWebhookEvent.KycPayload.EventTypeThe type of event that occurred.
-
Method Summary
-
-
Method Detail
-
updateRequest
final AccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequest updateRequest()
Original request to update the account holder.
-
eventType
final Optional<AccountHolderUpdatedWebhookEvent.KycPayload.EventType> eventType()
The type of event that occurred.
-
externalId
final Optional<String> externalId()
A user provided id that can be used to link an account holder with an external system
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_updateRequest
final JsonField<AccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequest> _updateRequest()
Returns the raw JSON value of updateRequest.
Unlike updateRequest, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<AccountHolderUpdatedWebhookEvent.KycPayload.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_externalId
final JsonField<String> _externalId()
Returns the raw JSON value of externalId.
Unlike externalId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountHolderUpdatedWebhookEvent.KycPayload.Builder toBuilder()
-
validate
final AccountHolderUpdatedWebhookEvent.KycPayload validate()
-
builder
final static AccountHolderUpdatedWebhookEvent.KycPayload.Builder builder()
Returns a mutable builder for constructing an instance of KycPayload.
The following fields are required:
.token() .updateRequest()
-
-
-
-