Class AccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequest.Individual
-
- All Implemented Interfaces:
public final class AccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequest.IndividualInformation on the individual for whom the account is being opened and KYC is being run.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequest.Individual.BuilderA builder for Individual.
public final classAccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequest.Individual.AddressIndividual's current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable. Only USA addresses are currently supported.
-
Method Summary
Modifier and Type Method Description final Optional<AccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequest.Individual.Address>address()Individual's current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable. final Optional<String>dob()Individual's date of birth, as an RFC 3339 date. final Optional<String>email()Individual's email address. final Optional<String>firstName()Individual's first name, as it appears on government-issued identity documents. final Optional<String>governmentId()Government-issued identification number (required for identity verification and compliance with banking regulations). final Optional<String>lastName()Individual's last name, as it appears on government-issued identity documents. final Optional<String>phoneNumber()Individual's phone number, entered in E.164 format. final JsonField<AccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequest.Individual.Address>_address()Returns the raw JSON value of address. final JsonField<String>_dob()Returns the raw JSON value of dob. final JsonField<String>_email()Returns the raw JSON value of email. final JsonField<String>_firstName()Returns the raw JSON value of firstName. final JsonField<String>_governmentId()Returns the raw JSON value of governmentId. final JsonField<String>_lastName()Returns the raw JSON value of lastName. final JsonField<String>_phoneNumber()Returns the raw JSON value of phoneNumber. final Map<String, JsonValue>_additionalProperties()final AccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequest.Individual.BuildertoBuilder()final AccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequest.Individualvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequest.Individual.Builderbuilder()Returns a mutable builder for constructing an instance of Individual. -
-
Method Detail
-
address
final Optional<AccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequest.Individual.Address> address()
Individual's current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable. Only USA addresses are currently supported.
-
email
final Optional<String> email()
Individual's email address. If utilizing Lithic for chargeback processing, this customer email address may be used to communicate dispute status and resolution.
-
firstName
final Optional<String> firstName()
Individual's first name, as it appears on government-issued identity documents.
-
governmentId
final Optional<String> governmentId()
Government-issued identification number (required for identity verification and compliance with banking regulations). Social Security Numbers (SSN) and Individual Taxpayer Identification Numbers (ITIN) are currently supported, entered as full nine-digits, with or without hyphens
-
lastName
final Optional<String> lastName()
Individual's last name, as it appears on government-issued identity documents.
-
phoneNumber
final Optional<String> phoneNumber()
Individual's phone number, entered in E.164 format.
-
_address
final JsonField<AccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequest.Individual.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_dob
final JsonField<String> _dob()
Returns the raw JSON value of dob.
Unlike dob, this method doesn't throw if the JSON field has an unexpected type.
-
_email
final JsonField<String> _email()
Returns the raw JSON value of email.
Unlike email, this method doesn't throw if the JSON field has an unexpected type.
-
_firstName
final JsonField<String> _firstName()
Returns the raw JSON value of firstName.
Unlike firstName, this method doesn't throw if the JSON field has an unexpected type.
-
_governmentId
final JsonField<String> _governmentId()
Returns the raw JSON value of governmentId.
Unlike governmentId, this method doesn't throw if the JSON field has an unexpected type.
-
_lastName
final JsonField<String> _lastName()
Returns the raw JSON value of lastName.
Unlike lastName, this method doesn't throw if the JSON field has an unexpected type.
-
_phoneNumber
final JsonField<String> _phoneNumber()
Returns the raw JSON value of phoneNumber.
Unlike phoneNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequest.Individual.Builder toBuilder()
-
validate
final AccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequest.Individual validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequest.Individual.Builder builder()
Returns a mutable builder for constructing an instance of Individual.
-
-
-
-