Package com.lithic.api.models
Class AccountListPage
-
- All Implemented Interfaces:
public final class AccountListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountListPage.BuilderA builder for AccountListPage.
public final classAccountListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<Account>data()Delegates to AccountListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to AccountListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<AccountListParams>getNextPageParams()final Optional<AccountListPage>getNextPage()final AccountListPage.AutoPagerautoPager()final AccountListParamsparams()The parameters that were used to request this page. final AccountListPageResponseresponse()The response that this page was parsed from. final AccountListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountListPage.Builderbuilder()Returns a mutable builder for constructing an instance of AccountListPage. -
-
Method Detail
-
data
final List<Account> data()
Delegates to AccountListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to AccountListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<AccountListParams> getNextPageParams()
-
getNextPage
final Optional<AccountListPage> getNextPage()
-
autoPager
final AccountListPage.AutoPager autoPager()
-
params
final AccountListParams params()
The parameters that were used to request this page.
-
response
final AccountListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final AccountListPage.Builder toBuilder()
-
builder
final static AccountListPage.Builder builder()
Returns a mutable builder for constructing an instance of AccountListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-