Package com.lithic.api.models
Class AccountListPageAsync
-
- All Implemented Interfaces:
-
com.lithic.api.core.PageAsync
public final class AccountListPageAsync implements PageAsync<Account>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountListPageAsync.BuilderA builder for AccountListPageAsync.
-
Method Summary
Modifier and Type Method Description final List<Account>data()Delegates to AccountListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to AccountListPageResponse, but gracefully handles missing data. List<Account>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final AccountListParamsnextPageParams()CompletableFuture<AccountListPageAsync>nextPage()Returns the page after this one by making another request. final AutoPagerAsync<Account>autoPager()final AccountListParamsparams()The parameters that were used to request this page. final AccountListPageResponseresponse()The response that this page was parsed from. final AccountListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of AccountListPageAsync. -
-
Method Detail
-
data
final List<Account> data()
Delegates to AccountListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to AccountListPageResponse, but gracefully handles missing data.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final AccountListParams nextPageParams()
-
nextPage
CompletableFuture<AccountListPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<Account> autoPager()
-
params
final AccountListParams params()
The parameters that were used to request this page.
-
response
final AccountListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final AccountListPageAsync.Builder toBuilder()
-
builder
final static AccountListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of AccountListPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-