Package com.lithic.api.models
Class AccountListPageAsync.Response
-
- All Implemented Interfaces:
public final class AccountListPageAsync.Response
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountListPageAsync.Response.Builder
-
Method Summary
Modifier and Type Method Description final List<Account>data()final BooleanhasMore()final Optional<JsonField<List<Account>>>_data()final Optional<JsonField<Boolean>>_hasMore()final Map<String, JsonValue>_additionalProperties()final AccountListPageAsync.Responsevalidate()final AccountListPageAsync.Response.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountListPageAsync.Response.Builderbuilder()Returns a mutable builder for constructing an instance of AccountListPageAsync. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final AccountListPageAsync.Response validate()
-
toBuilder
final AccountListPageAsync.Response.Builder toBuilder()
-
builder
final static AccountListPageAsync.Response.Builder builder()
Returns a mutable builder for constructing an instance of AccountListPageAsync.
-
-
-
-