Class AccountSpendLimits.Builder
-
- All Implemented Interfaces:
public final class AccountSpendLimits.BuilderA builder for AccountSpendLimits.
-
-
Method Summary
-
-
Method Detail
-
availableSpendLimit
final AccountSpendLimits.Builder availableSpendLimit(AccountSpendLimits.AvailableSpendLimit availableSpendLimit)
-
availableSpendLimit
final AccountSpendLimits.Builder availableSpendLimit(JsonField<AccountSpendLimits.AvailableSpendLimit> availableSpendLimit)
Sets Builder.availableSpendLimit to an arbitrary JSON value.
You should usually call Builder.availableSpendLimit with a well-typed AvailableSpendLimit value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
spendLimit
final AccountSpendLimits.Builder spendLimit(AccountSpendLimits.SpendLimit spendLimit)
-
spendLimit
final AccountSpendLimits.Builder spendLimit(JsonField<AccountSpendLimits.SpendLimit> spendLimit)
Sets Builder.spendLimit to an arbitrary JSON value.
You should usually call Builder.spendLimit with a well-typed SpendLimit value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
spendVelocity
final AccountSpendLimits.Builder spendVelocity(AccountSpendLimits.SpendVelocity spendVelocity)
-
spendVelocity
final AccountSpendLimits.Builder spendVelocity(JsonField<AccountSpendLimits.SpendVelocity> spendVelocity)
Sets Builder.spendVelocity to an arbitrary JSON value.
You should usually call Builder.spendVelocity with a well-typed SpendVelocity value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountSpendLimits.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountSpendLimits.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountSpendLimits.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountSpendLimits.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountSpendLimits.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountSpendLimits build()
Returns an immutable instance of AccountSpendLimits.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.availableSpendLimit()
-
-
-
-