Class AccountSpendLimits.SpendLimit
-
- All Implemented Interfaces:
public final class AccountSpendLimits.SpendLimit
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountSpendLimits.SpendLimit.BuilderA builder for SpendLimit.
-
Method Summary
Modifier and Type Method Description final Optional<Long>daily()The configured daily spend limit (in cents) on the Account. final Optional<Long>lifetime()The configured lifetime spend limit (in cents) on the Account. final Optional<Long>monthly()The configured monthly spend limit (in cents) on the Account. final JsonField<Long>_daily()Returns the raw JSON value of daily. final JsonField<Long>_lifetime()Returns the raw JSON value of lifetime. final JsonField<Long>_monthly()Returns the raw JSON value of monthly. final Map<String, JsonValue>_additionalProperties()final AccountSpendLimits.SpendLimit.BuildertoBuilder()final AccountSpendLimits.SpendLimitvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountSpendLimits.SpendLimit.Builderbuilder()Returns a mutable builder for constructing an instance of SpendLimit. -
-
Method Detail
-
lifetime
final Optional<Long> lifetime()
The configured lifetime spend limit (in cents) on the Account.
-
monthly
final Optional<Long> monthly()
The configured monthly spend limit (in cents) on the Account.
-
_daily
final JsonField<Long> _daily()
Returns the raw JSON value of daily.
Unlike daily, this method doesn't throw if the JSON field has an unexpected type.
-
_lifetime
final JsonField<Long> _lifetime()
Returns the raw JSON value of lifetime.
Unlike lifetime, this method doesn't throw if the JSON field has an unexpected type.
-
_monthly
final JsonField<Long> _monthly()
Returns the raw JSON value of monthly.
Unlike monthly, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountSpendLimits.SpendLimit.Builder toBuilder()
-
validate
final AccountSpendLimits.SpendLimit validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccountSpendLimits.SpendLimit.Builder builder()
Returns a mutable builder for constructing an instance of SpendLimit.
-
-
-
-