Class AccountUpdateParams.Body.Builder
-
- All Implemented Interfaces:
public final class AccountUpdateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
dailySpendLimit
final AccountUpdateParams.Body.Builder dailySpendLimit(Long dailySpendLimit)
Amount (in cents) for the account's daily spend limit (e.g. 100000 would be a
$1,000 limit). By default the daily spend limit is set to $
1,250.
-
dailySpendLimit
final AccountUpdateParams.Body.Builder dailySpendLimit(JsonField<Long> dailySpendLimit)
Sets Builder.dailySpendLimit to an arbitrary JSON value.
You should usually call Builder.dailySpendLimit with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lifetimeSpendLimit
final AccountUpdateParams.Body.Builder lifetimeSpendLimit(Long lifetimeSpendLimit)
Amount (in cents) for the account's lifetime spend limit (e.g. 100000 would be a $1,000 limit). Once this limit is reached, no transactions will be accepted on any card created for this account until the limit is updated. Note that a spend limit of 0 is effectively no limit, and should only be used to reset or remove a prior limit. Only a limit of 1 or above will result in declined transactions due to checks against the account limit. This behavior differs from the daily spend limit and the monthly spend limit.
-
lifetimeSpendLimit
final AccountUpdateParams.Body.Builder lifetimeSpendLimit(JsonField<Long> lifetimeSpendLimit)
Sets Builder.lifetimeSpendLimit to an arbitrary JSON value.
You should usually call Builder.lifetimeSpendLimit with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
monthlySpendLimit
final AccountUpdateParams.Body.Builder monthlySpendLimit(Long monthlySpendLimit)
Amount (in cents) for the account's monthly spend limit (e.g. 100000 would be a
$1,000 limit). By default the monthly spend limit is set to $
5,000.
-
monthlySpendLimit
final AccountUpdateParams.Body.Builder monthlySpendLimit(JsonField<Long> monthlySpendLimit)
Sets Builder.monthlySpendLimit to an arbitrary JSON value.
You should usually call Builder.monthlySpendLimit with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
state
final AccountUpdateParams.Body.Builder state(AccountUpdateParams.State state)
Account states.
-
state
final AccountUpdateParams.Body.Builder state(JsonField<AccountUpdateParams.State> state)
Sets Builder.state to an arbitrary JSON value.
You should usually call Builder.state with a well-typed State value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
verificationAddress
@Deprecated(message = "deprecated") final AccountUpdateParams.Body.Builder verificationAddress(AccountUpdateParams.VerificationAddress verificationAddress)
Address used during Address Verification Service (AVS) checks during transactions if enabled via Auth Rules. This field is deprecated as AVS checks are no longer supported by Authorization Rules. The field will be removed from the schema in a future release.
-
verificationAddress
@Deprecated(message = "deprecated") final AccountUpdateParams.Body.Builder verificationAddress(JsonField<AccountUpdateParams.VerificationAddress> verificationAddress)
Sets Builder.verificationAddress to an arbitrary JSON value.
You should usually call Builder.verificationAddress with a well-typed VerificationAddress value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountUpdateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountUpdateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountUpdateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountUpdateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountUpdateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountUpdateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-