Class AccountUpdateParams.VerificationAddress
-
- All Implemented Interfaces:
@Deprecated(message = "deprecated") public final class AccountUpdateParams.VerificationAddress
Address used during Address Verification Service (AVS) checks during transactions if enabled via Auth Rules. This field is deprecated as AVS checks are no longer supported by Auth Rules. The field will be removed from the schema in a future release.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountUpdateParams.VerificationAddress.BuilderA builder for VerificationAddress.
-
Method Summary
Modifier and Type Method Description final Optional<String>address1()final Optional<String>address2()final Optional<String>city()final Optional<String>country()final Optional<String>postalCode()final Optional<String>state()final JsonField<String>_address1()Returns the raw JSON value of address1. final JsonField<String>_address2()Returns the raw JSON value of address2. final JsonField<String>_city()Returns the raw JSON value of city. final JsonField<String>_country()Returns the raw JSON value of country. final JsonField<String>_postalCode()Returns the raw JSON value of postalCode. final JsonField<String>_state()Returns the raw JSON value of state. final Map<String, JsonValue>_additionalProperties()final AccountUpdateParams.VerificationAddress.BuildertoBuilder()final AccountUpdateParams.VerificationAddressvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountUpdateParams.VerificationAddress.Builderbuilder()Returns a mutable builder for constructing an instance of VerificationAddress. -
-
Method Detail
-
postalCode
final Optional<String> postalCode()
-
_address1
final JsonField<String> _address1()
Returns the raw JSON value of address1.
Unlike address1, this method doesn't throw if the JSON field has an unexpected type.
-
_address2
final JsonField<String> _address2()
Returns the raw JSON value of address2.
Unlike address2, this method doesn't throw if the JSON field has an unexpected type.
-
_city
final JsonField<String> _city()
Returns the raw JSON value of city.
Unlike city, this method doesn't throw if the JSON field has an unexpected type.
-
_country
final JsonField<String> _country()
Returns the raw JSON value of country.
Unlike country, this method doesn't throw if the JSON field has an unexpected type.
-
_postalCode
final JsonField<String> _postalCode()
Returns the raw JSON value of postalCode.
Unlike postalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<String> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountUpdateParams.VerificationAddress.Builder toBuilder()
-
validate
final AccountUpdateParams.VerificationAddress validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccountUpdateParams.VerificationAddress.Builder builder()
Returns a mutable builder for constructing an instance of VerificationAddress.
-
-
-
-