Package com.lithic.api.models
Class AchPaymentUpdateAction
-
- All Implemented Interfaces:
public final class AchPaymentUpdateAction
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAchPaymentUpdateAction.VisitorAn interface that defines how to map each variant of AchPaymentUpdateAction to a value of type T.
public final classAchPaymentUpdateAction.TagActionpublic final classAchPaymentUpdateAction.CreateCaseAction
-
Method Summary
Modifier and Type Method Description final Optional<AchPaymentUpdateAction.TagAction>tag()final Optional<AchPaymentUpdateAction.CreateCaseAction>createCase()final BooleanisTag()final BooleanisCreateCase()final AchPaymentUpdateAction.TagActionasTag()final AchPaymentUpdateAction.CreateCaseActionasCreateCase()final Optional<JsonValue>_json()final <T extends Any> Taccept(AchPaymentUpdateAction.Visitor<T> visitor)Maps this instance's current variant to a value of type T using the given visitor. final AchPaymentUpdateActionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AchPaymentUpdateActionofTag(AchPaymentUpdateAction.TagAction tag)final static AchPaymentUpdateActionofCreateCase(AchPaymentUpdateAction.CreateCaseAction createCase)-
-
Method Detail
-
tag
final Optional<AchPaymentUpdateAction.TagAction> tag()
-
createCase
final Optional<AchPaymentUpdateAction.CreateCaseAction> createCase()
-
isCreateCase
final Boolean isCreateCase()
-
asTag
final AchPaymentUpdateAction.TagAction asTag()
-
asCreateCase
final AchPaymentUpdateAction.CreateCaseAction asCreateCase()
-
accept
final <T extends Any> T accept(AchPaymentUpdateAction.Visitor<T> visitor)
Maps this instance's current variant to a value of type T using the given visitor.
Note that this method is not forwards compatible with new variants from the API, unless visitor overrides Visitor.unknown. To handle variants not known to this version of the SDK gracefully, consider overriding Visitor.unknown:
import com.lithic.api.core.JsonValue; import java.util.Optional; Optional<String> result = achPaymentUpdateAction.accept(new AchPaymentUpdateAction.Visitor<Optional<String>>() { @Override public Optional<String> visitTag(TagAction tag) { return Optional.of(tag.toString()); } // ... @Override public Optional<String> unknown(JsonValue json) { // Or inspect the `json`. return Optional.empty(); } });
-
validate
final AchPaymentUpdateAction validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
ofTag
final static AchPaymentUpdateAction ofTag(AchPaymentUpdateAction.TagAction tag)
-
ofCreateCase
final static AchPaymentUpdateAction ofCreateCase(AchPaymentUpdateAction.CreateCaseAction createCase)
-
-
-
-