Class AddressUpdate
-
- All Implemented Interfaces:
public final class AddressUpdate
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAddressUpdate.BuilderA builder for AddressUpdate.
-
Method Summary
Modifier and Type Method Description final Optional<String>address1()Valid deliverable address (no PO boxes). final Optional<String>address2()Unit or apartment number (if applicable). final Optional<String>city()Name of city. final Optional<String>country()Valid country code. final Optional<String>postalCode()Valid postal code. final Optional<String>state()Valid state code. final JsonField<String>_address1()Returns the raw JSON value of address1. final JsonField<String>_address2()Returns the raw JSON value of address2. final JsonField<String>_city()Returns the raw JSON value of city. final JsonField<String>_country()Returns the raw JSON value of country. final JsonField<String>_postalCode()Returns the raw JSON value of postalCode. final JsonField<String>_state()Returns the raw JSON value of state. final Map<String, JsonValue>_additionalProperties()final AddressUpdate.BuildertoBuilder()final AddressUpdatevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AddressUpdate.Builderbuilder()Returns a mutable builder for constructing an instance of AddressUpdate. -
-
Method Detail
-
country
final Optional<String> country()
Valid country code. Only USA is currently supported, entered in uppercase ISO 3166-1 alpha-3 three-character format.
-
postalCode
final Optional<String> postalCode()
Valid postal code. Only USA ZIP codes are currently supported, entered as a five-digit ZIP or nine-digit ZIP+4.
-
state
final Optional<String> state()
Valid state code. Only USA state codes are currently supported, entered in uppercase ISO 3166-2 two-character format.
-
_address1
final JsonField<String> _address1()
Returns the raw JSON value of address1.
Unlike address1, this method doesn't throw if the JSON field has an unexpected type.
-
_address2
final JsonField<String> _address2()
Returns the raw JSON value of address2.
Unlike address2, this method doesn't throw if the JSON field has an unexpected type.
-
_city
final JsonField<String> _city()
Returns the raw JSON value of city.
Unlike city, this method doesn't throw if the JSON field has an unexpected type.
-
_country
final JsonField<String> _country()
Returns the raw JSON value of country.
Unlike country, this method doesn't throw if the JSON field has an unexpected type.
-
_postalCode
final JsonField<String> _postalCode()
Returns the raw JSON value of postalCode.
Unlike postalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<String> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AddressUpdate.Builder toBuilder()
-
validate
final AddressUpdate validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AddressUpdate.Builder builder()
Returns a mutable builder for constructing an instance of AddressUpdate.
-
-
-
-