Package com.lithic.api.models
Class AggregateBalanceListPage
-
- All Implemented Interfaces:
public final class AggregateBalanceListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAggregateBalanceListPage.BuilderA builder for AggregateBalanceListPage.
public final classAggregateBalanceListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<AggregateBalance>data()Delegates to AggregateBalanceListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to AggregateBalanceListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<AggregateBalanceListParams>getNextPageParams()final Optional<AggregateBalanceListPage>getNextPage()final AggregateBalanceListPage.AutoPagerautoPager()final AggregateBalanceListParamsparams()The parameters that were used to request this page. final AggregateBalanceListPageResponseresponse()The response that this page was parsed from. final AggregateBalanceListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AggregateBalanceListPage.Builderbuilder()Returns a mutable builder for constructing an instance of AggregateBalanceListPage. -
-
Method Detail
-
data
final List<AggregateBalance> data()
Delegates to AggregateBalanceListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to AggregateBalanceListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<AggregateBalanceListParams> getNextPageParams()
-
getNextPage
final Optional<AggregateBalanceListPage> getNextPage()
-
autoPager
final AggregateBalanceListPage.AutoPager autoPager()
-
params
final AggregateBalanceListParams params()
The parameters that were used to request this page.
-
response
final AggregateBalanceListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final AggregateBalanceListPage.Builder toBuilder()
-
builder
final static AggregateBalanceListPage.Builder builder()
Returns a mutable builder for constructing an instance of AggregateBalanceListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-