Package com.lithic.api.models
Class AggregateBalanceListPage.Builder
-
- All Implemented Interfaces:
public final class AggregateBalanceListPage.BuilderA builder for AggregateBalanceListPage.
-
-
Method Summary
Modifier and Type Method Description final AggregateBalanceListPage.Builderservice(AggregateBalanceService service)final AggregateBalanceListPage.Builderparams(AggregateBalanceListParams params)The parameters that were used to request this page. final AggregateBalanceListPage.Builderresponse(AggregateBalanceListPageResponse response)The response that this page was parsed from. final AggregateBalanceListPagebuild()Returns an immutable instance of AggregateBalanceListPage. -
-
Method Detail
-
service
final AggregateBalanceListPage.Builder service(AggregateBalanceService service)
-
params
final AggregateBalanceListPage.Builder params(AggregateBalanceListParams params)
The parameters that were used to request this page.
-
response
final AggregateBalanceListPage.Builder response(AggregateBalanceListPageResponse response)
The response that this page was parsed from.
-
build
final AggregateBalanceListPage build()
Returns an immutable instance of AggregateBalanceListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-