Package com.lithic.api.models
Class AggregateBalanceListPageAsync
-
- All Implemented Interfaces:
public final class AggregateBalanceListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAggregateBalanceListPageAsync.BuilderA builder for AggregateBalanceListPageAsync.
public final classAggregateBalanceListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<AggregateBalance>data()Delegates to AggregateBalanceListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to AggregateBalanceListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<AggregateBalanceListParams>getNextPageParams()final CompletableFuture<Optional<AggregateBalanceListPageAsync>>getNextPage()final AggregateBalanceListPageAsync.AutoPagerautoPager()final AggregateBalanceListParamsparams()The parameters that were used to request this page. final AggregateBalanceListPageResponseresponse()The response that this page was parsed from. final AggregateBalanceListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AggregateBalanceListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of AggregateBalanceListPageAsync. -
-
Method Detail
-
data
final List<AggregateBalance> data()
Delegates to AggregateBalanceListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to AggregateBalanceListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<AggregateBalanceListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<AggregateBalanceListPageAsync>> getNextPage()
-
autoPager
final AggregateBalanceListPageAsync.AutoPager autoPager()
-
params
final AggregateBalanceListParams params()
The parameters that were used to request this page.
-
response
final AggregateBalanceListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final AggregateBalanceListPageAsync.Builder toBuilder()
-
builder
final static AggregateBalanceListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of AggregateBalanceListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-