Package com.lithic.api.models
Class AggregateBalanceListPageAsync.Builder
-
- All Implemented Interfaces:
public final class AggregateBalanceListPageAsync.BuilderA builder for AggregateBalanceListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final AggregateBalanceListPageAsync.Builderservice(AggregateBalanceServiceAsync service)final AggregateBalanceListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final AggregateBalanceListPageAsync.Builderparams(AggregateBalanceListParams params)The parameters that were used to request this page. final AggregateBalanceListPageAsync.Builderresponse(AggregateBalanceListPageResponse response)The response that this page was parsed from. final AggregateBalanceListPageAsyncbuild()Returns an immutable instance of AggregateBalanceListPageAsync. -
-
Method Detail
-
service
final AggregateBalanceListPageAsync.Builder service(AggregateBalanceServiceAsync service)
-
streamHandlerExecutor
final AggregateBalanceListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final AggregateBalanceListPageAsync.Builder params(AggregateBalanceListParams params)
The parameters that were used to request this page.
-
response
final AggregateBalanceListPageAsync.Builder response(AggregateBalanceListPageResponse response)
The response that this page was parsed from.
-
build
final AggregateBalanceListPageAsync build()
Returns an immutable instance of AggregateBalanceListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-