Package com.lithic.api.models
Class AggregateBalanceListPageResponse.Builder
-
- All Implemented Interfaces:
public final class AggregateBalanceListPageResponse.BuilderA builder for AggregateBalanceListPageResponse.
-
-
Method Summary
-
-
Method Detail
-
data
final AggregateBalanceListPageResponse.Builder data(List<AggregateBalance> data)
-
data
final AggregateBalanceListPageResponse.Builder data(JsonField<List<AggregateBalance>> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed
List<AggregateBalance>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addData
final AggregateBalanceListPageResponse.Builder addData(AggregateBalance data)
Adds a single AggregateBalance to Builder.data.
-
hasMore
final AggregateBalanceListPageResponse.Builder hasMore(Boolean hasMore)
More data exists.
-
hasMore
final AggregateBalanceListPageResponse.Builder hasMore(JsonField<Boolean> hasMore)
Sets Builder.hasMore to an arbitrary JSON value.
You should usually call Builder.hasMore with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AggregateBalanceListPageResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AggregateBalanceListPageResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AggregateBalanceListPageResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AggregateBalanceListPageResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AggregateBalanceListPageResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AggregateBalanceListPageResponse build()
Returns an immutable instance of AggregateBalanceListPageResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.data() .hasMore()
-
-
-
-