Class AggregateBalanceListResponse.Builder
-
- All Implemented Interfaces:
public final class AggregateBalanceListResponse.BuilderA builder for AggregateBalanceListResponse.
-
-
Method Summary
-
-
Method Detail
-
availableAmount
final AggregateBalanceListResponse.Builder availableAmount(Long availableAmount)
Funds available for spend in the currency's smallest unit (e.g., cents for USD)
-
availableAmount
final AggregateBalanceListResponse.Builder availableAmount(JsonField<Long> availableAmount)
Sets Builder.availableAmount to an arbitrary JSON value.
You should usually call Builder.availableAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final AggregateBalanceListResponse.Builder created(OffsetDateTime created)
Date and time for when the balance was first created.
-
created
final AggregateBalanceListResponse.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final AggregateBalanceListResponse.Builder currency(String currency)
3-character alphabetic ISO 4217 code for the local currency of the balance.
-
currency
final AggregateBalanceListResponse.Builder currency(JsonField<String> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastCardToken
final AggregateBalanceListResponse.Builder lastCardToken(String lastCardToken)
Globally unique identifier for the card that had its balance updated most recently
-
lastCardToken
final AggregateBalanceListResponse.Builder lastCardToken(JsonField<String> lastCardToken)
Sets Builder.lastCardToken to an arbitrary JSON value.
You should usually call Builder.lastCardToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastTransactionEventToken
final AggregateBalanceListResponse.Builder lastTransactionEventToken(String lastTransactionEventToken)
Globally unique identifier for the last transaction event that impacted this balance
-
lastTransactionEventToken
final AggregateBalanceListResponse.Builder lastTransactionEventToken(JsonField<String> lastTransactionEventToken)
Sets Builder.lastTransactionEventToken to an arbitrary JSON value.
You should usually call Builder.lastTransactionEventToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastTransactionToken
final AggregateBalanceListResponse.Builder lastTransactionToken(String lastTransactionToken)
Globally unique identifier for the last transaction that impacted this balance
-
lastTransactionToken
final AggregateBalanceListResponse.Builder lastTransactionToken(JsonField<String> lastTransactionToken)
Sets Builder.lastTransactionToken to an arbitrary JSON value.
You should usually call Builder.lastTransactionToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pendingAmount
final AggregateBalanceListResponse.Builder pendingAmount(Long pendingAmount)
Funds not available for spend due to card authorizations or pending ACH release. Shown in the currency's smallest unit (e.g., cents for USD)
-
pendingAmount
final AggregateBalanceListResponse.Builder pendingAmount(JsonField<Long> pendingAmount)
Sets Builder.pendingAmount to an arbitrary JSON value.
You should usually call Builder.pendingAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalAmount
final AggregateBalanceListResponse.Builder totalAmount(Long totalAmount)
The sum of available and pending balance in the currency's smallest unit (e.g., cents for USD)
-
totalAmount
final AggregateBalanceListResponse.Builder totalAmount(JsonField<Long> totalAmount)
Sets Builder.totalAmount to an arbitrary JSON value.
You should usually call Builder.totalAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updated
final AggregateBalanceListResponse.Builder updated(OffsetDateTime updated)
Date and time for when the balance was last updated.
-
updated
final AggregateBalanceListResponse.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AggregateBalanceListResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AggregateBalanceListResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AggregateBalanceListResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AggregateBalanceListResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AggregateBalanceListResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AggregateBalanceListResponse build()
Returns an immutable instance of AggregateBalanceListResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.availableAmount() .created() .currency() .lastCardToken() .lastTransactionEventToken() .lastTransactionToken() .pendingAmount() .totalAmount() .updated()
-
-
-
-