Class AsaRequestWebhookEvent
-
- All Implemented Interfaces:
public final class AsaRequestWebhookEventThe Auth Stream Access request payload that was sent to the ASA responder.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAsaRequestWebhookEvent.BuilderA builder for AsaRequestWebhookEvent.
public final classAsaRequestWebhookEvent.Avspublic final classAsaRequestWebhookEvent.AsaRequestCardCard object in ASA
public final classAsaRequestWebhookEvent.AsaRequestStatusThe type of authorization request that this request is for. Note that
CREDIT_AUTHORIZATIONandFINANCIAL_CREDIT_AUTHORIZATIONis only available to users with credit decisioning via ASA enabled.public final classAsaRequestWebhookEvent.TransactionInitiatorThe entity that initiated the transaction.
public final classAsaRequestWebhookEvent.AccountTypepublic final classAsaRequestWebhookEvent.AsaRequestFleetInfoOptional Object containing information if the Card is a part of a Fleet managed program
public final classAsaRequestWebhookEvent.LatestChallengeThe latest Authorization Challenge that was issued to the cardholder for this merchant.
public final classAsaRequestWebhookEvent.NetworkCard network of the authorization.
public final classAsaRequestWebhookEvent.AsaNetworkSpecificDataContains raw data provided by the card network, including attributes that provide further context about the authorization. If populated by the network, data is organized by Lithic and passed through without further modification. Please consult the official network documentation for more details about these values and how to use them. This object is only available to certain programs- contact your Customer Success Manager to discuss enabling access.
public final classAsaRequestWebhookEvent.Pos
-
Method Summary
Modifier and Type Method Description final Stringtoken()The provisional transaction group uuid associated with the authorization final LongacquirerFee()Fee (in cents) assessed by the merchant and paid for by the cardholder. final Longamount()Authorization amount of the transaction (in cents), including any acquirer fees. final LongauthorizationAmount()The base transaction amount (in cents) plus the acquirer fee field. final AsaRequestWebhookEvent.Avsavs()final AsaRequestWebhookEvent.AsaRequestCardcard()Card object in ASA final StringcardholderCurrency()3-character alphabetic ISO 4217 code for cardholder's billing currency. final LongcashAmount()The portion of the transaction requested as cash back by the cardholder, and does not include any acquirer fees. final OffsetDateTimecreated()Date and time when the transaction first occurred in UTC. final Merchantmerchant()final LongmerchantAmount()The amount that the merchant will receive, denominated in merchant_currencyand in the smallest currency unit.final StringmerchantCurrency()3-character alphabetic ISO 4217 code for the local currency of the transaction. final LongsettledAmount()Amount (in cents) of the transaction that has been settled, including any acquirer fees final AsaRequestWebhookEvent.AsaRequestStatusstatus()The type of authorization request that this request is for. final AsaRequestWebhookEvent.TransactionInitiatortransactionInitiator()The entity that initiated the transaction. final Optional<AsaRequestWebhookEvent.AccountType>accountType()final Optional<CardholderAuthentication>cardholderAuthentication()final Optional<Long>cashback()Deprecated, use cash_amount.final Optional<Double>conversionRate()If the transaction was requested in a currency other than the settlement currency, this field will be populated to indicate the rate used to translate the merchant_amount to the amount (i.e. final Optional<String>eventToken()The event token associated with the authorization. final Optional<AsaRequestWebhookEvent.AsaRequestFleetInfo>fleetInfo()Optional Object containing information if the Card is a part of a Fleet managed program final Optional<AsaRequestWebhookEvent.LatestChallenge>latestChallenge()The latest Authorization Challenge that was issued to the cardholder for this merchant. final Optional<AsaRequestWebhookEvent.Network>network()Card network of the authorization. final Optional<Long>networkRiskScore()Network-provided score assessing risk level associated with a given authorization. final Optional<AsaRequestWebhookEvent.AsaNetworkSpecificData>networkSpecificData()Contains raw data provided by the card network, including attributes that provide further context about the authorization. final Optional<AsaRequestWebhookEvent.Pos>pos()final Optional<TokenInfo>tokenInfo()final Optional<OffsetDateTime>ttl()Deprecated: approximate time-to-live for the authorization. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<Long>_acquirerFee()Returns the raw JSON value of acquirerFee. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<Long>_authorizationAmount()Returns the raw JSON value of authorizationAmount. final JsonField<AsaRequestWebhookEvent.Avs>_avs()Returns the raw JSON value of avs. final JsonField<AsaRequestWebhookEvent.AsaRequestCard>_card()Returns the raw JSON value of card. final JsonField<String>_cardholderCurrency()Returns the raw JSON value of cardholderCurrency. final JsonField<Long>_cashAmount()Returns the raw JSON value of cashAmount. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<Merchant>_merchant()Returns the raw JSON value of merchant. final JsonField<Long>_merchantAmount()Returns the raw JSON value of merchantAmount. final JsonField<String>_merchantCurrency()Returns the raw JSON value of merchantCurrency. final JsonField<Long>_settledAmount()Returns the raw JSON value of settledAmount. final JsonField<AsaRequestWebhookEvent.AsaRequestStatus>_status()Returns the raw JSON value of status. final JsonField<AsaRequestWebhookEvent.TransactionInitiator>_transactionInitiator()Returns the raw JSON value of transactionInitiator. final JsonField<AsaRequestWebhookEvent.AccountType>_accountType()Returns the raw JSON value of accountType. final JsonField<CardholderAuthentication>_cardholderAuthentication()Returns the raw JSON value of cardholderAuthentication. final JsonField<Long>_cashback()Returns the raw JSON value of cashback. final JsonField<Double>_conversionRate()Returns the raw JSON value of conversionRate. final JsonField<String>_eventToken()Returns the raw JSON value of eventToken. final JsonField<AsaRequestWebhookEvent.AsaRequestFleetInfo>_fleetInfo()Returns the raw JSON value of fleetInfo. final JsonField<AsaRequestWebhookEvent.LatestChallenge>_latestChallenge()Returns the raw JSON value of latestChallenge. final JsonField<AsaRequestWebhookEvent.Network>_network()Returns the raw JSON value of network. final JsonField<Long>_networkRiskScore()Returns the raw JSON value of networkRiskScore. final JsonField<AsaRequestWebhookEvent.AsaNetworkSpecificData>_networkSpecificData()Returns the raw JSON value of networkSpecificData. final JsonField<AsaRequestWebhookEvent.Pos>_pos()Returns the raw JSON value of pos. final JsonField<TokenInfo>_tokenInfo()Returns the raw JSON value of tokenInfo. final JsonField<OffsetDateTime>_ttl()Returns the raw JSON value of ttl. final Map<String, JsonValue>_additionalProperties()final AsaRequestWebhookEvent.BuildertoBuilder()final AsaRequestWebhookEventvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AsaRequestWebhookEvent.Builderbuilder()Returns a mutable builder for constructing an instance of AsaRequestWebhookEvent. -
-
Method Detail
-
acquirerFee
final Long acquirerFee()
Fee (in cents) assessed by the merchant and paid for by the cardholder. Will be zero if no fee is assessed. Rebates may be transmitted as a negative value to indicate credited fees.
-
amount
final Long amount()
Authorization amount of the transaction (in cents), including any acquirer fees. The contents of this field are identical to
authorization_amount.
-
authorizationAmount
final Long authorizationAmount()
The base transaction amount (in cents) plus the acquirer fee field. This is the amount the issuer should authorize against unless the issuer is paying the acquirer fee on behalf of the cardholder.
-
avs
final AsaRequestWebhookEvent.Avs avs()
-
card
final AsaRequestWebhookEvent.AsaRequestCard card()
Card object in ASA
-
cardholderCurrency
final String cardholderCurrency()
3-character alphabetic ISO 4217 code for cardholder's billing currency.
-
cashAmount
final Long cashAmount()
The portion of the transaction requested as cash back by the cardholder, and does not include any acquirer fees. The amount field includes the purchase amount, the requested cash back amount, and any acquirer fees.
If no cash back was requested, the value of this field will be 0, and the field will always be present.
-
created
final OffsetDateTime created()
Date and time when the transaction first occurred in UTC.
-
merchantAmount
final Long merchantAmount()
The amount that the merchant will receive, denominated in
merchant_currencyand in the smallest currency unit. Note the amount includesacquirer_fee, similar toauthorization_amount. It will be different fromauthorization_amountif the merchant is taking payment in a different currency.
-
merchantCurrency
final String merchantCurrency()
3-character alphabetic ISO 4217 code for the local currency of the transaction.
-
settledAmount
final Long settledAmount()
Amount (in cents) of the transaction that has been settled, including any acquirer fees
-
status
final AsaRequestWebhookEvent.AsaRequestStatus status()
The type of authorization request that this request is for. Note that
CREDIT_AUTHORIZATIONandFINANCIAL_CREDIT_AUTHORIZATIONis only available to users with credit decisioning via ASA enabled.
-
transactionInitiator
final AsaRequestWebhookEvent.TransactionInitiator transactionInitiator()
The entity that initiated the transaction.
-
accountType
final Optional<AsaRequestWebhookEvent.AccountType> accountType()
-
cardholderAuthentication
final Optional<CardholderAuthentication> cardholderAuthentication()
-
conversionRate
final Optional<Double> conversionRate()
If the transaction was requested in a currency other than the settlement currency, this field will be populated to indicate the rate used to translate the merchant_amount to the amount (i.e.,
merchant_amountxconversion_rate=amount). Note that themerchant_amountis in the local currency and the amount is in the settlement currency.
-
eventToken
final Optional<String> eventToken()
The event token associated with the authorization. This field is only set for programs enrolled into the beta.
-
fleetInfo
final Optional<AsaRequestWebhookEvent.AsaRequestFleetInfo> fleetInfo()
Optional Object containing information if the Card is a part of a Fleet managed program
-
latestChallenge
final Optional<AsaRequestWebhookEvent.LatestChallenge> latestChallenge()
The latest Authorization Challenge that was issued to the cardholder for this merchant.
-
network
final Optional<AsaRequestWebhookEvent.Network> network()
Card network of the authorization.
-
networkRiskScore
final Optional<Long> networkRiskScore()
Network-provided score assessing risk level associated with a given authorization. Scores are on a range of 0-999, with 0 representing the lowest risk and 999 representing the highest risk. For Visa transactions, where the raw score has a range of 0-99, Lithic will normalize the score by multiplying the raw score by 10x.
-
networkSpecificData
final Optional<AsaRequestWebhookEvent.AsaNetworkSpecificData> networkSpecificData()
Contains raw data provided by the card network, including attributes that provide further context about the authorization. If populated by the network, data is organized by Lithic and passed through without further modification. Please consult the official network documentation for more details about these values and how to use them. This object is only available to certain programs- contact your Customer Success Manager to discuss enabling access.
-
pos
final Optional<AsaRequestWebhookEvent.Pos> pos()
-
ttl
final Optional<OffsetDateTime> ttl()
Deprecated: approximate time-to-live for the authorization.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_acquirerFee
final JsonField<Long> _acquirerFee()
Returns the raw JSON value of acquirerFee.
Unlike acquirerFee, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_authorizationAmount
final JsonField<Long> _authorizationAmount()
Returns the raw JSON value of authorizationAmount.
Unlike authorizationAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_avs
final JsonField<AsaRequestWebhookEvent.Avs> _avs()
Returns the raw JSON value of avs.
Unlike avs, this method doesn't throw if the JSON field has an unexpected type.
-
_card
final JsonField<AsaRequestWebhookEvent.AsaRequestCard> _card()
Returns the raw JSON value of card.
Unlike card, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholderCurrency
final JsonField<String> _cardholderCurrency()
Returns the raw JSON value of cardholderCurrency.
Unlike cardholderCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_cashAmount
final JsonField<Long> _cashAmount()
Returns the raw JSON value of cashAmount.
Unlike cashAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_merchant
final JsonField<Merchant> _merchant()
Returns the raw JSON value of merchant.
Unlike merchant, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantAmount
final JsonField<Long> _merchantAmount()
Returns the raw JSON value of merchantAmount.
Unlike merchantAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCurrency
final JsonField<String> _merchantCurrency()
Returns the raw JSON value of merchantCurrency.
Unlike merchantCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_settledAmount
final JsonField<Long> _settledAmount()
Returns the raw JSON value of settledAmount.
Unlike settledAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<AsaRequestWebhookEvent.AsaRequestStatus> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionInitiator
final JsonField<AsaRequestWebhookEvent.TransactionInitiator> _transactionInitiator()
Returns the raw JSON value of transactionInitiator.
Unlike transactionInitiator, this method doesn't throw if the JSON field has an unexpected type.
-
_accountType
final JsonField<AsaRequestWebhookEvent.AccountType> _accountType()
Returns the raw JSON value of accountType.
Unlike accountType, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholderAuthentication
final JsonField<CardholderAuthentication> _cardholderAuthentication()
Returns the raw JSON value of cardholderAuthentication.
Unlike cardholderAuthentication, this method doesn't throw if the JSON field has an unexpected type.
-
_cashback
final JsonField<Long> _cashback()
Returns the raw JSON value of cashback.
Unlike cashback, this method doesn't throw if the JSON field has an unexpected type.
-
_conversionRate
final JsonField<Double> _conversionRate()
Returns the raw JSON value of conversionRate.
Unlike conversionRate, this method doesn't throw if the JSON field has an unexpected type.
-
_eventToken
final JsonField<String> _eventToken()
Returns the raw JSON value of eventToken.
Unlike eventToken, this method doesn't throw if the JSON field has an unexpected type.
-
_fleetInfo
final JsonField<AsaRequestWebhookEvent.AsaRequestFleetInfo> _fleetInfo()
Returns the raw JSON value of fleetInfo.
Unlike fleetInfo, this method doesn't throw if the JSON field has an unexpected type.
-
_latestChallenge
final JsonField<AsaRequestWebhookEvent.LatestChallenge> _latestChallenge()
Returns the raw JSON value of latestChallenge.
Unlike latestChallenge, this method doesn't throw if the JSON field has an unexpected type.
-
_network
final JsonField<AsaRequestWebhookEvent.Network> _network()
Returns the raw JSON value of network.
Unlike network, this method doesn't throw if the JSON field has an unexpected type.
-
_networkRiskScore
final JsonField<Long> _networkRiskScore()
Returns the raw JSON value of networkRiskScore.
Unlike networkRiskScore, this method doesn't throw if the JSON field has an unexpected type.
-
_networkSpecificData
final JsonField<AsaRequestWebhookEvent.AsaNetworkSpecificData> _networkSpecificData()
Returns the raw JSON value of networkSpecificData.
Unlike networkSpecificData, this method doesn't throw if the JSON field has an unexpected type.
-
_pos
final JsonField<AsaRequestWebhookEvent.Pos> _pos()
Returns the raw JSON value of pos.
Unlike pos, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenInfo
final JsonField<TokenInfo> _tokenInfo()
Returns the raw JSON value of tokenInfo.
Unlike tokenInfo, this method doesn't throw if the JSON field has an unexpected type.
-
_ttl
final JsonField<OffsetDateTime> _ttl()
Returns the raw JSON value of ttl.
Unlike ttl, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AsaRequestWebhookEvent.Builder toBuilder()
-
validate
final AsaRequestWebhookEvent validate()
-
builder
final static AsaRequestWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of AsaRequestWebhookEvent.
The following fields are required:
.token() .acquirerFee() .amount() .authorizationAmount() .avs() .card() .cardholderCurrency() .cashAmount() .created() .merchant() .merchantAmount() .merchantCurrency() .settledAmount() .status() .transactionInitiator()
-
-
-
-