Class AsaRequestWebhookEvent.AsaNetworkSpecificData
-
- All Implemented Interfaces:
public final class AsaRequestWebhookEvent.AsaNetworkSpecificDataContains raw data provided by the card network, including attributes that provide further context about the authorization. If populated by the network, data is organized by Lithic and passed through without further modification. Please consult the official network documentation for more details about these values and how to use them. This object is only available to certain programs- contact your Customer Success Manager to discuss enabling access.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAsaRequestWebhookEvent.AsaNetworkSpecificData.BuilderA builder for AsaNetworkSpecificData.
public final classAsaRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercardpublic final classAsaRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataVisa
-
Method Summary
Modifier and Type Method Description final Optional<AsaRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard>mastercard()final Optional<AsaRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataVisa>visa()final JsonField<AsaRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard>_mastercard()Returns the raw JSON value of mastercard. final JsonField<AsaRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataVisa>_visa()Returns the raw JSON value of visa. final Map<String, JsonValue>_additionalProperties()final AsaRequestWebhookEvent.AsaNetworkSpecificData.BuildertoBuilder()final AsaRequestWebhookEvent.AsaNetworkSpecificDatavalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AsaRequestWebhookEvent.AsaNetworkSpecificData.Builderbuilder()Returns a mutable builder for constructing an instance of AsaNetworkSpecificData. -
-
Method Detail
-
mastercard
final Optional<AsaRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard> mastercard()
-
visa
final Optional<AsaRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataVisa> visa()
-
_mastercard
final JsonField<AsaRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard> _mastercard()
Returns the raw JSON value of mastercard.
Unlike mastercard, this method doesn't throw if the JSON field has an unexpected type.
-
_visa
final JsonField<AsaRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataVisa> _visa()
Returns the raw JSON value of visa.
Unlike visa, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AsaRequestWebhookEvent.AsaNetworkSpecificData.Builder toBuilder()
-
validate
final AsaRequestWebhookEvent.AsaNetworkSpecificData validate()
-
builder
final static AsaRequestWebhookEvent.AsaNetworkSpecificData.Builder builder()
Returns a mutable builder for constructing an instance of AsaNetworkSpecificData.
-
-
-
-