Class AsaRequestWebhookEvent.AsaNetworkSpecificData.Builder
-
- All Implemented Interfaces:
public final class AsaRequestWebhookEvent.AsaNetworkSpecificData.BuilderA builder for AsaNetworkSpecificData.
-
-
Method Summary
-
-
Method Detail
-
mastercard
final AsaRequestWebhookEvent.AsaNetworkSpecificData.Builder mastercard(AsaRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard mastercard)
-
mastercard
final AsaRequestWebhookEvent.AsaNetworkSpecificData.Builder mastercard(Optional<AsaRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard> mastercard)
Alias for calling Builder.mastercard with
mastercard.orElse(null).
-
mastercard
final AsaRequestWebhookEvent.AsaNetworkSpecificData.Builder mastercard(JsonField<AsaRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard> mastercard)
Sets Builder.mastercard to an arbitrary JSON value.
You should usually call Builder.mastercard with a well-typed AsaNetworkSpecificDataMastercard value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
visa
final AsaRequestWebhookEvent.AsaNetworkSpecificData.Builder visa(AsaRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataVisa visa)
-
visa
final AsaRequestWebhookEvent.AsaNetworkSpecificData.Builder visa(Optional<AsaRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataVisa> visa)
Alias for calling Builder.visa with
visa.orElse(null).
-
visa
final AsaRequestWebhookEvent.AsaNetworkSpecificData.Builder visa(JsonField<AsaRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataVisa> visa)
Sets Builder.visa to an arbitrary JSON value.
You should usually call Builder.visa with a well-typed AsaNetworkSpecificDataVisa value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AsaRequestWebhookEvent.AsaNetworkSpecificData.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AsaRequestWebhookEvent.AsaNetworkSpecificData.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AsaRequestWebhookEvent.AsaNetworkSpecificData.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AsaRequestWebhookEvent.AsaNetworkSpecificData.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AsaRequestWebhookEvent.AsaNetworkSpecificData.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AsaRequestWebhookEvent.AsaNetworkSpecificData build()
Returns an immutable instance of AsaNetworkSpecificData.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-