Class AsaRequestWebhookEvent.AsaRequestCard
-
- All Implemented Interfaces:
public final class AsaRequestWebhookEvent.AsaRequestCardCard object in ASA
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAsaRequestWebhookEvent.AsaRequestCard.BuilderA builder for AsaRequestCard.
public final classAsaRequestWebhookEvent.AsaRequestCard.SpendLimitDurationNote that to support recurring monthly payments, which can occur on different day every month, the time window we consider for MONTHLY velocity starts 6 days after the current calendar date one month prior.
public final classAsaRequestWebhookEvent.AsaRequestCard.Statepublic final classAsaRequestWebhookEvent.AsaRequestCard.CardType
-
Method Summary
Modifier and Type Method Description final Optional<String>token()Globally unique identifier for the card. final Optional<String>hostname()Hostname of card’s locked merchant (will be empty if not applicable) final Optional<String>lastFour()Last four digits of the card number final Optional<String>memo()Customizable name to identify the card. final Optional<Long>spendLimit()Amount (in cents) to limit approved authorizations. final Optional<AsaRequestWebhookEvent.AsaRequestCard.SpendLimitDuration>spendLimitDuration()Note that to support recurring monthly payments, which can occur on different day every month, the time window we consider for MONTHLY velocity starts 6 days after the current calendar date one month prior. final Optional<AsaRequestWebhookEvent.AsaRequestCard.State>state()final Optional<AsaRequestWebhookEvent.AsaRequestCard.CardType>type()final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<String>_hostname()Returns the raw JSON value of hostname. final JsonField<String>_lastFour()Returns the raw JSON value of lastFour. final JsonField<String>_memo()Returns the raw JSON value of memo. final JsonField<Long>_spendLimit()Returns the raw JSON value of spendLimit. final JsonField<AsaRequestWebhookEvent.AsaRequestCard.SpendLimitDuration>_spendLimitDuration()Returns the raw JSON value of spendLimitDuration. final JsonField<AsaRequestWebhookEvent.AsaRequestCard.State>_state()Returns the raw JSON value of state. final JsonField<AsaRequestWebhookEvent.AsaRequestCard.CardType>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final AsaRequestWebhookEvent.AsaRequestCard.BuildertoBuilder()final AsaRequestWebhookEvent.AsaRequestCardvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AsaRequestWebhookEvent.AsaRequestCard.Builderbuilder()Returns a mutable builder for constructing an instance of AsaRequestCard. -
-
Method Detail
-
hostname
final Optional<String> hostname()
Hostname of card’s locked merchant (will be empty if not applicable)
-
memo
final Optional<String> memo()
Customizable name to identify the card. We recommend against using this field to store JSON data as it can cause unexpected behavior.
-
spendLimit
final Optional<Long> spendLimit()
Amount (in cents) to limit approved authorizations. Purchase requests above the spend limit will be declined (refunds and credits will be approved).
Note that while spend limits are enforced based on authorized and settled volume on a card, they are not recommended to be used for balance or reconciliation-level accuracy. Spend limits also cannot block force posted charges (i.e., when a merchant sends a clearing message without a prior authorization).
-
spendLimitDuration
final Optional<AsaRequestWebhookEvent.AsaRequestCard.SpendLimitDuration> spendLimitDuration()
Note that to support recurring monthly payments, which can occur on different day every month, the time window we consider for MONTHLY velocity starts 6 days after the current calendar date one month prior.
-
state
final Optional<AsaRequestWebhookEvent.AsaRequestCard.State> state()
-
type
final Optional<AsaRequestWebhookEvent.AsaRequestCard.CardType> type()
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_hostname
final JsonField<String> _hostname()
Returns the raw JSON value of hostname.
Unlike hostname, this method doesn't throw if the JSON field has an unexpected type.
-
_lastFour
final JsonField<String> _lastFour()
Returns the raw JSON value of lastFour.
Unlike lastFour, this method doesn't throw if the JSON field has an unexpected type.
-
_memo
final JsonField<String> _memo()
Returns the raw JSON value of memo.
Unlike memo, this method doesn't throw if the JSON field has an unexpected type.
-
_spendLimit
final JsonField<Long> _spendLimit()
Returns the raw JSON value of spendLimit.
Unlike spendLimit, this method doesn't throw if the JSON field has an unexpected type.
-
_spendLimitDuration
final JsonField<AsaRequestWebhookEvent.AsaRequestCard.SpendLimitDuration> _spendLimitDuration()
Returns the raw JSON value of spendLimitDuration.
Unlike spendLimitDuration, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<AsaRequestWebhookEvent.AsaRequestCard.State> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<AsaRequestWebhookEvent.AsaRequestCard.CardType> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AsaRequestWebhookEvent.AsaRequestCard.Builder toBuilder()
-
validate
final AsaRequestWebhookEvent.AsaRequestCard validate()
-
builder
final static AsaRequestWebhookEvent.AsaRequestCard.Builder builder()
Returns a mutable builder for constructing an instance of AsaRequestCard.
-
-
-
-