Class AsaRequestWebhookEvent.AsaRequestCard.SpendLimitDuration

  • All Implemented Interfaces:
    com.lithic.api.core.Enum

    
    public final class AsaRequestWebhookEvent.AsaRequestCard.SpendLimitDuration
     implements Enum
                        

    Note that to support recurring monthly payments, which can occur on different day every month, the time window we consider for MONTHLY velocity starts 6 days after the current calendar date one month prior.