Class AsaRequestWebhookEvent.Avs
-
- All Implemented Interfaces:
public final class AsaRequestWebhookEvent.Avs
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAsaRequestWebhookEvent.Avs.BuilderA builder for Avs.
public final classAsaRequestWebhookEvent.Avs.AddressMatchResultLithic's evaluation result comparing the transaction's address data with the cardholder KYC data if it exists. In the event Lithic does not have any Cardholder KYC data, or the transaction does not contain any address data, NOT_PRESENT will be returned
-
Method Summary
Modifier and Type Method Description final Stringaddress()Cardholder address final AsaRequestWebhookEvent.Avs.AddressMatchResultaddressOnFileMatch()Lithic's evaluation result comparing the transaction's address data with the cardholder KYC data if it exists. final Stringzipcode()Cardholder ZIP code final JsonField<String>_address()Returns the raw JSON value of address. final JsonField<AsaRequestWebhookEvent.Avs.AddressMatchResult>_addressOnFileMatch()Returns the raw JSON value of addressOnFileMatch. final JsonField<String>_zipcode()Returns the raw JSON value of zipcode. final Map<String, JsonValue>_additionalProperties()final AsaRequestWebhookEvent.Avs.BuildertoBuilder()final AsaRequestWebhookEvent.Avsvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AsaRequestWebhookEvent.Avs.Builderbuilder()Returns a mutable builder for constructing an instance of Avs. -
-
Method Detail
-
addressOnFileMatch
final AsaRequestWebhookEvent.Avs.AddressMatchResult addressOnFileMatch()
Lithic's evaluation result comparing the transaction's address data with the cardholder KYC data if it exists. In the event Lithic does not have any Cardholder KYC data, or the transaction does not contain any address data, NOT_PRESENT will be returned
-
_address
final JsonField<String> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_addressOnFileMatch
final JsonField<AsaRequestWebhookEvent.Avs.AddressMatchResult> _addressOnFileMatch()
Returns the raw JSON value of addressOnFileMatch.
Unlike addressOnFileMatch, this method doesn't throw if the JSON field has an unexpected type.
-
_zipcode
final JsonField<String> _zipcode()
Returns the raw JSON value of zipcode.
Unlike zipcode, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AsaRequestWebhookEvent.Avs.Builder toBuilder()
-
validate
final AsaRequestWebhookEvent.Avs validate()
-
builder
final static AsaRequestWebhookEvent.Avs.Builder builder()
Returns a mutable builder for constructing an instance of Avs.
The following fields are required:
.address() .addressOnFileMatch() .zipcode()
-
-
-
-