Class AsaRequestWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class AsaRequestWebhookEvent.BuilderA builder for AsaRequestWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
token
final AsaRequestWebhookEvent.Builder token(String token)
The provisional transaction group uuid associated with the authorization
-
token
final AsaRequestWebhookEvent.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
acquirerFee
final AsaRequestWebhookEvent.Builder acquirerFee(Long acquirerFee)
Fee (in cents) assessed by the merchant and paid for by the cardholder. Will be zero if no fee is assessed. Rebates may be transmitted as a negative value to indicate credited fees.
-
acquirerFee
final AsaRequestWebhookEvent.Builder acquirerFee(JsonField<Long> acquirerFee)
Sets Builder.acquirerFee to an arbitrary JSON value.
You should usually call Builder.acquirerFee with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final AsaRequestWebhookEvent.Builder amount(Long amount)
Authorization amount of the transaction (in cents), including any acquirer fees. The contents of this field are identical to
authorization_amount.
-
amount
final AsaRequestWebhookEvent.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
authorizationAmount
final AsaRequestWebhookEvent.Builder authorizationAmount(Long authorizationAmount)
The base transaction amount (in cents) plus the acquirer fee field. This is the amount the issuer should authorize against unless the issuer is paying the acquirer fee on behalf of the cardholder.
-
authorizationAmount
final AsaRequestWebhookEvent.Builder authorizationAmount(JsonField<Long> authorizationAmount)
Sets Builder.authorizationAmount to an arbitrary JSON value.
You should usually call Builder.authorizationAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
avs
final AsaRequestWebhookEvent.Builder avs(AsaRequestWebhookEvent.Avs avs)
-
avs
final AsaRequestWebhookEvent.Builder avs(JsonField<AsaRequestWebhookEvent.Avs> avs)
Sets Builder.avs to an arbitrary JSON value.
You should usually call Builder.avs with a well-typed Avs value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
card
final AsaRequestWebhookEvent.Builder card(AsaRequestWebhookEvent.AsaRequestCard card)
Card object in ASA
-
card
final AsaRequestWebhookEvent.Builder card(JsonField<AsaRequestWebhookEvent.AsaRequestCard> card)
Sets Builder.card to an arbitrary JSON value.
You should usually call Builder.card with a well-typed AsaRequestCard value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardholderCurrency
final AsaRequestWebhookEvent.Builder cardholderCurrency(String cardholderCurrency)
3-character alphabetic ISO 4217 code for cardholder's billing currency.
-
cardholderCurrency
final AsaRequestWebhookEvent.Builder cardholderCurrency(JsonField<String> cardholderCurrency)
Sets Builder.cardholderCurrency to an arbitrary JSON value.
You should usually call Builder.cardholderCurrency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cashAmount
final AsaRequestWebhookEvent.Builder cashAmount(Long cashAmount)
The portion of the transaction requested as cash back by the cardholder, and does not include any acquirer fees. The amount field includes the purchase amount, the requested cash back amount, and any acquirer fees.
If no cash back was requested, the value of this field will be 0, and the field will always be present.
-
cashAmount
final AsaRequestWebhookEvent.Builder cashAmount(JsonField<Long> cashAmount)
Sets Builder.cashAmount to an arbitrary JSON value.
You should usually call Builder.cashAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final AsaRequestWebhookEvent.Builder created(OffsetDateTime created)
Date and time when the transaction first occurred in UTC.
-
created
final AsaRequestWebhookEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchant
final AsaRequestWebhookEvent.Builder merchant(Merchant merchant)
-
merchant
final AsaRequestWebhookEvent.Builder merchant(JsonField<Merchant> merchant)
Sets Builder.merchant to an arbitrary JSON value.
You should usually call Builder.merchant with a well-typed Merchant value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantAmount
final AsaRequestWebhookEvent.Builder merchantAmount(Long merchantAmount)
The amount that the merchant will receive, denominated in
merchant_currencyand in the smallest currency unit. Note the amount includesacquirer_fee, similar toauthorization_amount. It will be different fromauthorization_amountif the merchant is taking payment in a different currency.
-
merchantAmount
final AsaRequestWebhookEvent.Builder merchantAmount(JsonField<Long> merchantAmount)
Sets Builder.merchantAmount to an arbitrary JSON value.
You should usually call Builder.merchantAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCurrency
final AsaRequestWebhookEvent.Builder merchantCurrency(String merchantCurrency)
3-character alphabetic ISO 4217 code for the local currency of the transaction.
-
merchantCurrency
final AsaRequestWebhookEvent.Builder merchantCurrency(JsonField<String> merchantCurrency)
Sets Builder.merchantCurrency to an arbitrary JSON value.
You should usually call Builder.merchantCurrency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
settledAmount
final AsaRequestWebhookEvent.Builder settledAmount(Long settledAmount)
Amount (in cents) of the transaction that has been settled, including any acquirer fees
-
settledAmount
final AsaRequestWebhookEvent.Builder settledAmount(JsonField<Long> settledAmount)
Sets Builder.settledAmount to an arbitrary JSON value.
You should usually call Builder.settledAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final AsaRequestWebhookEvent.Builder status(AsaRequestWebhookEvent.AsaRequestStatus status)
The type of authorization request that this request is for. Note that
CREDIT_AUTHORIZATIONandFINANCIAL_CREDIT_AUTHORIZATIONis only available to users with credit decisioning via ASA enabled.
-
status
final AsaRequestWebhookEvent.Builder status(JsonField<AsaRequestWebhookEvent.AsaRequestStatus> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed AsaRequestStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionInitiator
final AsaRequestWebhookEvent.Builder transactionInitiator(AsaRequestWebhookEvent.TransactionInitiator transactionInitiator)
The entity that initiated the transaction.
-
transactionInitiator
final AsaRequestWebhookEvent.Builder transactionInitiator(JsonField<AsaRequestWebhookEvent.TransactionInitiator> transactionInitiator)
Sets Builder.transactionInitiator to an arbitrary JSON value.
You should usually call Builder.transactionInitiator with a well-typed TransactionInitiator value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountType
final AsaRequestWebhookEvent.Builder accountType(AsaRequestWebhookEvent.AccountType accountType)
-
accountType
final AsaRequestWebhookEvent.Builder accountType(JsonField<AsaRequestWebhookEvent.AccountType> accountType)
Sets Builder.accountType to an arbitrary JSON value.
You should usually call Builder.accountType with a well-typed AccountType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardholderAuthentication
final AsaRequestWebhookEvent.Builder cardholderAuthentication(CardholderAuthentication cardholderAuthentication)
-
cardholderAuthentication
final AsaRequestWebhookEvent.Builder cardholderAuthentication(JsonField<CardholderAuthentication> cardholderAuthentication)
Sets Builder.cardholderAuthentication to an arbitrary JSON value.
You should usually call Builder.cardholderAuthentication with a well-typed CardholderAuthentication value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cashback
final AsaRequestWebhookEvent.Builder cashback(Long cashback)
Deprecated, use
cash_amount.
-
cashback
final AsaRequestWebhookEvent.Builder cashback(JsonField<Long> cashback)
Sets Builder.cashback to an arbitrary JSON value.
You should usually call Builder.cashback with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
conversionRate
final AsaRequestWebhookEvent.Builder conversionRate(Double conversionRate)
If the transaction was requested in a currency other than the settlement currency, this field will be populated to indicate the rate used to translate the merchant_amount to the amount (i.e.,
merchant_amountxconversion_rate=amount). Note that themerchant_amountis in the local currency and the amount is in the settlement currency.
-
conversionRate
final AsaRequestWebhookEvent.Builder conversionRate(JsonField<Double> conversionRate)
Sets Builder.conversionRate to an arbitrary JSON value.
You should usually call Builder.conversionRate with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventToken
final AsaRequestWebhookEvent.Builder eventToken(String eventToken)
The event token associated with the authorization. This field is only set for programs enrolled into the beta.
-
eventToken
final AsaRequestWebhookEvent.Builder eventToken(JsonField<String> eventToken)
Sets Builder.eventToken to an arbitrary JSON value.
You should usually call Builder.eventToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fleetInfo
final AsaRequestWebhookEvent.Builder fleetInfo(AsaRequestWebhookEvent.AsaRequestFleetInfo fleetInfo)
Optional Object containing information if the Card is a part of a Fleet managed program
-
fleetInfo
final AsaRequestWebhookEvent.Builder fleetInfo(Optional<AsaRequestWebhookEvent.AsaRequestFleetInfo> fleetInfo)
Alias for calling Builder.fleetInfo with
fleetInfo.orElse(null).
-
fleetInfo
final AsaRequestWebhookEvent.Builder fleetInfo(JsonField<AsaRequestWebhookEvent.AsaRequestFleetInfo> fleetInfo)
Sets Builder.fleetInfo to an arbitrary JSON value.
You should usually call Builder.fleetInfo with a well-typed AsaRequestFleetInfo value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
latestChallenge
final AsaRequestWebhookEvent.Builder latestChallenge(AsaRequestWebhookEvent.LatestChallenge latestChallenge)
The latest Authorization Challenge that was issued to the cardholder for this merchant.
-
latestChallenge
final AsaRequestWebhookEvent.Builder latestChallenge(JsonField<AsaRequestWebhookEvent.LatestChallenge> latestChallenge)
Sets Builder.latestChallenge to an arbitrary JSON value.
You should usually call Builder.latestChallenge with a well-typed LatestChallenge value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
network
final AsaRequestWebhookEvent.Builder network(AsaRequestWebhookEvent.Network network)
Card network of the authorization.
-
network
final AsaRequestWebhookEvent.Builder network(JsonField<AsaRequestWebhookEvent.Network> network)
Sets Builder.network to an arbitrary JSON value.
You should usually call Builder.network with a well-typed Network value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
networkRiskScore
final AsaRequestWebhookEvent.Builder networkRiskScore(Long networkRiskScore)
Network-provided score assessing risk level associated with a given authorization. Scores are on a range of 0-999, with 0 representing the lowest risk and 999 representing the highest risk. For Visa transactions, where the raw score has a range of 0-99, Lithic will normalize the score by multiplying the raw score by 10x.
-
networkRiskScore
final AsaRequestWebhookEvent.Builder networkRiskScore(Long networkRiskScore)
Alias for Builder.networkRiskScore.
This unboxed primitive overload exists for backwards compatibility.
-
networkRiskScore
final AsaRequestWebhookEvent.Builder networkRiskScore(Optional<Long> networkRiskScore)
Alias for calling Builder.networkRiskScore with
networkRiskScore.orElse(null).
-
networkRiskScore
final AsaRequestWebhookEvent.Builder networkRiskScore(JsonField<Long> networkRiskScore)
Sets Builder.networkRiskScore to an arbitrary JSON value.
You should usually call Builder.networkRiskScore with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
networkSpecificData
final AsaRequestWebhookEvent.Builder networkSpecificData(AsaRequestWebhookEvent.AsaNetworkSpecificData networkSpecificData)
Contains raw data provided by the card network, including attributes that provide further context about the authorization. If populated by the network, data is organized by Lithic and passed through without further modification. Please consult the official network documentation for more details about these values and how to use them. This object is only available to certain programs- contact your Customer Success Manager to discuss enabling access.
-
networkSpecificData
final AsaRequestWebhookEvent.Builder networkSpecificData(Optional<AsaRequestWebhookEvent.AsaNetworkSpecificData> networkSpecificData)
Alias for calling Builder.networkSpecificData with
networkSpecificData.orElse(null).
-
networkSpecificData
final AsaRequestWebhookEvent.Builder networkSpecificData(JsonField<AsaRequestWebhookEvent.AsaNetworkSpecificData> networkSpecificData)
Sets Builder.networkSpecificData to an arbitrary JSON value.
You should usually call Builder.networkSpecificData with a well-typed AsaNetworkSpecificData value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pos
final AsaRequestWebhookEvent.Builder pos(AsaRequestWebhookEvent.Pos pos)
-
pos
final AsaRequestWebhookEvent.Builder pos(JsonField<AsaRequestWebhookEvent.Pos> pos)
Sets Builder.pos to an arbitrary JSON value.
You should usually call Builder.pos with a well-typed Pos value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tokenInfo
final AsaRequestWebhookEvent.Builder tokenInfo(TokenInfo tokenInfo)
-
tokenInfo
final AsaRequestWebhookEvent.Builder tokenInfo(Optional<TokenInfo> tokenInfo)
Alias for calling Builder.tokenInfo with
tokenInfo.orElse(null).
-
tokenInfo
final AsaRequestWebhookEvent.Builder tokenInfo(JsonField<TokenInfo> tokenInfo)
Sets Builder.tokenInfo to an arbitrary JSON value.
You should usually call Builder.tokenInfo with a well-typed TokenInfo value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ttl
final AsaRequestWebhookEvent.Builder ttl(OffsetDateTime ttl)
Deprecated: approximate time-to-live for the authorization.
-
ttl
final AsaRequestWebhookEvent.Builder ttl(JsonField<OffsetDateTime> ttl)
Sets Builder.ttl to an arbitrary JSON value.
You should usually call Builder.ttl with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AsaRequestWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AsaRequestWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AsaRequestWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AsaRequestWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AsaRequestWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AsaRequestWebhookEvent build()
Returns an immutable instance of AsaRequestWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .acquirerFee() .amount() .authorizationAmount() .avs() .card() .cardholderCurrency() .cashAmount() .created() .merchant() .merchantAmount() .merchantCurrency() .settledAmount() .status() .transactionInitiator()
-
-
-
-