Class AuthRule
-
- All Implemented Interfaces:
public final class AuthRule
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAuthRule.BuilderA builder for AuthRule.
public final classAuthRule.StateIndicates whether the Auth Rule is ACTIVE or INACTIVE
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier. final AuthRule.Statestate()Indicates whether the Auth Rule is ACTIVE or INACTIVE final Optional<List<String>>accountTokens()Array of account_token(s) identifying the accounts that the Auth Rule applies to. final Optional<List<String>>allowedCountries()Countries in which the Auth Rule permits transactions. final Optional<List<String>>allowedMcc()Merchant category codes for which the Auth Rule permits transactions. final Optional<List<String>>blockedCountries()Countries in which the Auth Rule automatically declines transactions. final Optional<List<String>>blockedMcc()Merchant category codes for which the Auth Rule automatically declines transactions. final Optional<List<String>>cardTokens()Array of card_token(s) identifying the cards that the Auth Rule applies to. final Optional<Boolean>programLevel()Boolean indicating whether the Auth Rule is applied at the program level. final JsonField<String>_token()Globally unique identifier. final JsonField<AuthRule.State>_state()Indicates whether the Auth Rule is ACTIVE or INACTIVE final JsonField<List<String>>_accountTokens()Array of account_token(s) identifying the accounts that the Auth Rule applies to. final JsonField<List<String>>_allowedCountries()Countries in which the Auth Rule permits transactions. final JsonField<List<String>>_allowedMcc()Merchant category codes for which the Auth Rule permits transactions. final JsonField<List<String>>_blockedCountries()Countries in which the Auth Rule automatically declines transactions. final JsonField<List<String>>_blockedMcc()Merchant category codes for which the Auth Rule automatically declines transactions. final JsonField<List<String>>_cardTokens()Array of card_token(s) identifying the cards that the Auth Rule applies to. final JsonField<Boolean>_programLevel()Boolean indicating whether the Auth Rule is applied at the program level. final Map<String, JsonValue>_additionalProperties()final AuthRulevalidate()final AuthRule.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AuthRule.Builderbuilder()Returns a mutable builder for constructing an instance of AuthRule. -
-
Method Detail
-
state
final AuthRule.State state()
Indicates whether the Auth Rule is ACTIVE or INACTIVE
-
accountTokens
final Optional<List<String>> accountTokens()
Array of account_token(s) identifying the accounts that the Auth Rule applies to. Note that only this field or
card_tokenscan be provided for a given Auth Rule.
-
allowedCountries
final Optional<List<String>> allowedCountries()
Countries in which the Auth Rule permits transactions. Note that Lithic maintains a list of countries in which all transactions are blocked; "allowing" those countries in an Auth Rule does not override the Lithic-wide restrictions.
-
allowedMcc
final Optional<List<String>> allowedMcc()
Merchant category codes for which the Auth Rule permits transactions.
-
blockedCountries
final Optional<List<String>> blockedCountries()
Countries in which the Auth Rule automatically declines transactions.
-
blockedMcc
final Optional<List<String>> blockedMcc()
Merchant category codes for which the Auth Rule automatically declines transactions.
-
cardTokens
final Optional<List<String>> cardTokens()
Array of card_token(s) identifying the cards that the Auth Rule applies to. Note that only this field or
account_tokenscan be provided for a given Auth Rule.
-
programLevel
final Optional<Boolean> programLevel()
Boolean indicating whether the Auth Rule is applied at the program level.
-
_state
final JsonField<AuthRule.State> _state()
Indicates whether the Auth Rule is ACTIVE or INACTIVE
-
_accountTokens
final JsonField<List<String>> _accountTokens()
Array of account_token(s) identifying the accounts that the Auth Rule applies to. Note that only this field or
card_tokenscan be provided for a given Auth Rule.
-
_allowedCountries
final JsonField<List<String>> _allowedCountries()
Countries in which the Auth Rule permits transactions. Note that Lithic maintains a list of countries in which all transactions are blocked; "allowing" those countries in an Auth Rule does not override the Lithic-wide restrictions.
-
_allowedMcc
final JsonField<List<String>> _allowedMcc()
Merchant category codes for which the Auth Rule permits transactions.
-
_blockedCountries
final JsonField<List<String>> _blockedCountries()
Countries in which the Auth Rule automatically declines transactions.
-
_blockedMcc
final JsonField<List<String>> _blockedMcc()
Merchant category codes for which the Auth Rule automatically declines transactions.
-
_cardTokens
final JsonField<List<String>> _cardTokens()
Array of card_token(s) identifying the cards that the Auth Rule applies to. Note that only this field or
account_tokenscan be provided for a given Auth Rule.
-
_programLevel
final JsonField<Boolean> _programLevel()
Boolean indicating whether the Auth Rule is applied at the program level.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AuthRule.Builder toBuilder()
-
builder
final static AuthRule.Builder builder()
Returns a mutable builder for constructing an instance of AuthRule.
The following fields are required:
.token() .state()
-
-
-
-