Class AuthRule.Builder
-
- All Implemented Interfaces:
public final class AuthRule.BuilderA builder for AuthRule.
-
-
Method Summary
Modifier and Type Method Description final AuthRule.Buildertoken(String token)Globally unique identifier. final AuthRule.Buildertoken(JsonField<String> token)Globally unique identifier. final AuthRule.Builderstate(AuthRule.State state)Indicates whether the Auth Rule is ACTIVE or INACTIVE final AuthRule.Builderstate(JsonField<AuthRule.State> state)Indicates whether the Auth Rule is ACTIVE or INACTIVE final AuthRule.BuilderaccountTokens(List<String> accountTokens)Array of account_token(s) identifying the accounts that the Auth Rule applies to. final AuthRule.BuilderaccountTokens(JsonField<List<String>> accountTokens)Array of account_token(s) identifying the accounts that the Auth Rule applies to. final AuthRule.BuilderaddAccountToken(String accountToken)Array of account_token(s) identifying the accounts that the Auth Rule applies to. final AuthRule.BuilderallowedCountries(List<String> allowedCountries)Countries in which the Auth Rule permits transactions. final AuthRule.BuilderallowedCountries(JsonField<List<String>> allowedCountries)Countries in which the Auth Rule permits transactions. final AuthRule.BuilderaddAllowedCountry(String allowedCountry)Countries in which the Auth Rule permits transactions. final AuthRule.BuilderallowedMcc(List<String> allowedMcc)Merchant category codes for which the Auth Rule permits transactions. final AuthRule.BuilderallowedMcc(JsonField<List<String>> allowedMcc)Merchant category codes for which the Auth Rule permits transactions. final AuthRule.BuilderaddAllowedMcc(String allowedMcc)Merchant category codes for which the Auth Rule permits transactions. final AuthRule.BuilderblockedCountries(List<String> blockedCountries)Countries in which the Auth Rule automatically declines transactions. final AuthRule.BuilderblockedCountries(JsonField<List<String>> blockedCountries)Countries in which the Auth Rule automatically declines transactions. final AuthRule.BuilderaddBlockedCountry(String blockedCountry)Countries in which the Auth Rule automatically declines transactions. final AuthRule.BuilderblockedMcc(List<String> blockedMcc)Merchant category codes for which the Auth Rule automatically declines transactions. final AuthRule.BuilderblockedMcc(JsonField<List<String>> blockedMcc)Merchant category codes for which the Auth Rule automatically declines transactions. final AuthRule.BuilderaddBlockedMcc(String blockedMcc)Merchant category codes for which the Auth Rule automatically declines transactions. final AuthRule.BuildercardTokens(List<String> cardTokens)Array of card_token(s) identifying the cards that the Auth Rule applies to. final AuthRule.BuildercardTokens(JsonField<List<String>> cardTokens)Array of card_token(s) identifying the cards that the Auth Rule applies to. final AuthRule.BuilderaddCardToken(String cardToken)Array of card_token(s) identifying the cards that the Auth Rule applies to. final AuthRule.BuilderprogramLevel(Boolean programLevel)Boolean indicating whether the Auth Rule is applied at the program level. final AuthRule.BuilderprogramLevel(JsonField<Boolean> programLevel)Boolean indicating whether the Auth Rule is applied at the program level. final AuthRule.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final AuthRule.BuilderputAdditionalProperty(String key, JsonValue value)final AuthRule.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final AuthRule.BuilderremoveAdditionalProperty(String key)final AuthRule.BuilderremoveAllAdditionalProperties(Set<String> keys)final AuthRulebuild()-
-
Method Detail
-
token
final AuthRule.Builder token(String token)
Globally unique identifier.
-
token
final AuthRule.Builder token(JsonField<String> token)
Globally unique identifier.
-
state
final AuthRule.Builder state(AuthRule.State state)
Indicates whether the Auth Rule is ACTIVE or INACTIVE
-
state
final AuthRule.Builder state(JsonField<AuthRule.State> state)
Indicates whether the Auth Rule is ACTIVE or INACTIVE
-
accountTokens
final AuthRule.Builder accountTokens(List<String> accountTokens)
Array of account_token(s) identifying the accounts that the Auth Rule applies to. Note that only this field or
card_tokenscan be provided for a given Auth Rule.
-
accountTokens
final AuthRule.Builder accountTokens(JsonField<List<String>> accountTokens)
Array of account_token(s) identifying the accounts that the Auth Rule applies to. Note that only this field or
card_tokenscan be provided for a given Auth Rule.
-
addAccountToken
final AuthRule.Builder addAccountToken(String accountToken)
Array of account_token(s) identifying the accounts that the Auth Rule applies to. Note that only this field or
card_tokenscan be provided for a given Auth Rule.
-
allowedCountries
final AuthRule.Builder allowedCountries(List<String> allowedCountries)
Countries in which the Auth Rule permits transactions. Note that Lithic maintains a list of countries in which all transactions are blocked; "allowing" those countries in an Auth Rule does not override the Lithic-wide restrictions.
-
allowedCountries
final AuthRule.Builder allowedCountries(JsonField<List<String>> allowedCountries)
Countries in which the Auth Rule permits transactions. Note that Lithic maintains a list of countries in which all transactions are blocked; "allowing" those countries in an Auth Rule does not override the Lithic-wide restrictions.
-
addAllowedCountry
final AuthRule.Builder addAllowedCountry(String allowedCountry)
Countries in which the Auth Rule permits transactions. Note that Lithic maintains a list of countries in which all transactions are blocked; "allowing" those countries in an Auth Rule does not override the Lithic-wide restrictions.
-
allowedMcc
final AuthRule.Builder allowedMcc(List<String> allowedMcc)
Merchant category codes for which the Auth Rule permits transactions.
-
allowedMcc
final AuthRule.Builder allowedMcc(JsonField<List<String>> allowedMcc)
Merchant category codes for which the Auth Rule permits transactions.
-
addAllowedMcc
final AuthRule.Builder addAllowedMcc(String allowedMcc)
Merchant category codes for which the Auth Rule permits transactions.
-
blockedCountries
final AuthRule.Builder blockedCountries(List<String> blockedCountries)
Countries in which the Auth Rule automatically declines transactions.
-
blockedCountries
final AuthRule.Builder blockedCountries(JsonField<List<String>> blockedCountries)
Countries in which the Auth Rule automatically declines transactions.
-
addBlockedCountry
final AuthRule.Builder addBlockedCountry(String blockedCountry)
Countries in which the Auth Rule automatically declines transactions.
-
blockedMcc
final AuthRule.Builder blockedMcc(List<String> blockedMcc)
Merchant category codes for which the Auth Rule automatically declines transactions.
-
blockedMcc
final AuthRule.Builder blockedMcc(JsonField<List<String>> blockedMcc)
Merchant category codes for which the Auth Rule automatically declines transactions.
-
addBlockedMcc
final AuthRule.Builder addBlockedMcc(String blockedMcc)
Merchant category codes for which the Auth Rule automatically declines transactions.
-
cardTokens
final AuthRule.Builder cardTokens(List<String> cardTokens)
Array of card_token(s) identifying the cards that the Auth Rule applies to. Note that only this field or
account_tokenscan be provided for a given Auth Rule.
-
cardTokens
final AuthRule.Builder cardTokens(JsonField<List<String>> cardTokens)
Array of card_token(s) identifying the cards that the Auth Rule applies to. Note that only this field or
account_tokenscan be provided for a given Auth Rule.
-
addCardToken
final AuthRule.Builder addCardToken(String cardToken)
Array of card_token(s) identifying the cards that the Auth Rule applies to. Note that only this field or
account_tokenscan be provided for a given Auth Rule.
-
programLevel
final AuthRule.Builder programLevel(Boolean programLevel)
Boolean indicating whether the Auth Rule is applied at the program level.
-
programLevel
final AuthRule.Builder programLevel(JsonField<Boolean> programLevel)
Boolean indicating whether the Auth Rule is applied at the program level.
-
additionalProperties
final AuthRule.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AuthRule.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AuthRule.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AuthRule.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AuthRule.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-