Class AuthRule.DraftVersion.State

  • All Implemented Interfaces:
    com.lithic.api.core.Enum

    
    public final class AuthRule.DraftVersion.State
     implements Enum
                        

    The state of the draft version. Most rules are created synchronously and the state is immediately SHADOWING. Rules backed by TypeScript code are compiled asynchronously — the state starts as PENDING and transitions to SHADOWING on success or ERROR on failure.

    • PENDING: Compilation of the rule is in progress (TypeScript rules only).

    • SHADOWING: The draft version is ready and evaluating in shadow mode alongside the current active version. It can be promoted to the active version.

    • ERROR: Compilation of the rule failed. Check the error field for details.

    • Constructor Detail

    • Method Detail

      • _value

         final JsonField<String> _value()

        Returns this class instance's raw value.

        This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.

      • value

         final AuthRule.DraftVersion.State.Value value()

        Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.

        Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.

      • known

         final AuthRule.DraftVersion.State.Known known()

        Returns an enum member corresponding to this class instance's value.

        Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.

      • asString

         final String asString()

        Returns this class instance's primitive wire representation.

        This differs from the toString method because that method is primarily for debugging and generally doesn't throw.

      • validate

         final AuthRule.DraftVersion.State validate()

        Validates that the types of all values in this object match their expected types recursively.

        This method is not forwards compatible with new types from the API for existing fields.