Package com.lithic.api.models
Class AuthRuleV2ListPage.Builder
-
- All Implemented Interfaces:
public final class AuthRuleV2ListPage.BuilderA builder for AuthRuleV2ListPage.
-
-
Method Summary
Modifier and Type Method Description final AuthRuleV2ListPage.Builderservice(V2Service service)final AuthRuleV2ListPage.Builderparams(AuthRuleV2ListParams params)The parameters that were used to request this page. final AuthRuleV2ListPage.Builderresponse(AuthRuleV2ListPageResponse response)The response that this page was parsed from. final AuthRuleV2ListPagebuild()Returns an immutable instance of AuthRuleV2ListPage. -
-
Method Detail
-
service
final AuthRuleV2ListPage.Builder service(V2Service service)
-
params
final AuthRuleV2ListPage.Builder params(AuthRuleV2ListParams params)
The parameters that were used to request this page.
-
response
final AuthRuleV2ListPage.Builder response(AuthRuleV2ListPageResponse response)
The response that this page was parsed from.
-
build
final AuthRuleV2ListPage build()
Returns an immutable instance of AuthRuleV2ListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-