Package com.lithic.api.models
Class AuthRuleV2ListPageAsync
-
- All Implemented Interfaces:
public final class AuthRuleV2ListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAuthRuleV2ListPageAsync.BuilderA builder for AuthRuleV2ListPageAsync.
public final classAuthRuleV2ListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<V2ListResponse>data()Delegates to AuthRuleV2ListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to AuthRuleV2ListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<AuthRuleV2ListParams>getNextPageParams()final CompletableFuture<Optional<AuthRuleV2ListPageAsync>>getNextPage()final AuthRuleV2ListPageAsync.AutoPagerautoPager()final AuthRuleV2ListParamsparams()The parameters that were used to request this page. final AuthRuleV2ListPageResponseresponse()The response that this page was parsed from. final AuthRuleV2ListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AuthRuleV2ListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of AuthRuleV2ListPageAsync. -
-
Method Detail
-
data
final List<V2ListResponse> data()
Delegates to AuthRuleV2ListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to AuthRuleV2ListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<AuthRuleV2ListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<AuthRuleV2ListPageAsync>> getNextPage()
-
autoPager
final AuthRuleV2ListPageAsync.AutoPager autoPager()
-
params
final AuthRuleV2ListParams params()
The parameters that were used to request this page.
-
response
final AuthRuleV2ListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final AuthRuleV2ListPageAsync.Builder toBuilder()
-
builder
final static AuthRuleV2ListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of AuthRuleV2ListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-