Class AuthRuleV2ListPageResponse.Builder
-
- All Implemented Interfaces:
public final class AuthRuleV2ListPageResponse.BuilderA builder for AuthRuleV2ListPageResponse.
-
-
Method Summary
-
-
Method Detail
-
data
final AuthRuleV2ListPageResponse.Builder data(List<V2ListResponse> data)
-
data
final AuthRuleV2ListPageResponse.Builder data(JsonField<List<V2ListResponse>> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed
List<V2ListResponse>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addData
final AuthRuleV2ListPageResponse.Builder addData(V2ListResponse data)
Adds a single V2ListResponse to Builder.data.
-
hasMore
final AuthRuleV2ListPageResponse.Builder hasMore(Boolean hasMore)
Indicates whether there are more Auth Rules to be retrieved by paging through the results.
-
hasMore
final AuthRuleV2ListPageResponse.Builder hasMore(JsonField<Boolean> hasMore)
Sets Builder.hasMore to an arbitrary JSON value.
You should usually call Builder.hasMore with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AuthRuleV2ListPageResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AuthRuleV2ListPageResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AuthRuleV2ListPageResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AuthRuleV2ListPageResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AuthRuleV2ListPageResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AuthRuleV2ListPageResponse build()
Returns an immutable instance of AuthRuleV2ListPageResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.data() .hasMore()
-
-
-
-