Class AuthRuleV2ListParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class AuthRuleV2ListParams implements Params
Lists V2 authorization rules
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAuthRuleV2ListParams.BuilderA builder for AuthRuleV2ListParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>accountToken()Only return Authorization Rules that are bound to the provided account token. final Optional<String>cardToken()Only return Authorization Rules that are bound to the provided card token. final Optional<String>endingBefore()A cursor representing an item's token before which a page of results should end. final Optional<Long>pageSize()Page size (for pagination). final Optional<String>startingAfter()A cursor representing an item's token after which a page of results should begin. final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final AuthRuleV2ListParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AuthRuleV2ListParamsnone()final static AuthRuleV2ListParams.Builderbuilder()Returns a mutable builder for constructing an instance of AuthRuleV2ListParams. -
-
Method Detail
-
accountToken
final Optional<String> accountToken()
Only return Authorization Rules that are bound to the provided account token.
-
cardToken
final Optional<String> cardToken()
Only return Authorization Rules that are bound to the provided card token.
-
endingBefore
final Optional<String> endingBefore()
A cursor representing an item's token before which a page of results should end. Used to retrieve the previous page of results before this item.
-
startingAfter
final Optional<String> startingAfter()
A cursor representing an item's token after which a page of results should begin. Used to retrieve the next page of results after this item.
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final AuthRuleV2ListParams.Builder toBuilder()
-
none
final static AuthRuleV2ListParams none()
-
builder
final static AuthRuleV2ListParams.Builder builder()
Returns a mutable builder for constructing an instance of AuthRuleV2ListParams.
-
-
-
-