Class AuthRuleV2ListResultsPageAsync
-
- All Implemented Interfaces:
-
com.lithic.api.core.PageAsync
public final class AuthRuleV2ListResultsPageAsync implements PageAsync<V2ListResultsResponse>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAuthRuleV2ListResultsPageAsync.BuilderA builder for AuthRuleV2ListResultsPageAsync.
-
Method Summary
Modifier and Type Method Description final List<V2ListResultsResponse>data()Delegates to AuthRuleV2ListResultsPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to AuthRuleV2ListResultsPageResponse, but gracefully handles missing data. List<V2ListResultsResponse>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final AuthRuleV2ListResultsParamsnextPageParams()CompletableFuture<AuthRuleV2ListResultsPageAsync>nextPage()Returns the page after this one by making another request. final AutoPagerAsync<V2ListResultsResponse>autoPager()final AuthRuleV2ListResultsParamsparams()The parameters that were used to request this page. final AuthRuleV2ListResultsPageResponseresponse()The response that this page was parsed from. final AuthRuleV2ListResultsPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AuthRuleV2ListResultsPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of AuthRuleV2ListResultsPageAsync. -
-
Method Detail
-
data
final List<V2ListResultsResponse> data()
Delegates to AuthRuleV2ListResultsPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to AuthRuleV2ListResultsPageResponse, but gracefully handles missing data.
-
items
List<V2ListResultsResponse> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final AuthRuleV2ListResultsParams nextPageParams()
-
nextPage
CompletableFuture<AuthRuleV2ListResultsPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<V2ListResultsResponse> autoPager()
-
params
final AuthRuleV2ListResultsParams params()
The parameters that were used to request this page.
-
response
final AuthRuleV2ListResultsPageResponse response()
The response that this page was parsed from.
-
toBuilder
final AuthRuleV2ListResultsPageAsync.Builder toBuilder()
-
builder
final static AuthRuleV2ListResultsPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of AuthRuleV2ListResultsPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-