Package com.lithic.api.models
Class AuthRuleV2ListVersionsParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class AuthRuleV2ListVersionsParams implements Params
Returns all versions of an auth rule, sorted by version number descending (newest first).
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAuthRuleV2ListVersionsParams.BuilderA builder for AuthRuleV2ListVersionsParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>authRuleToken()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final AuthRuleV2ListVersionsParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static AuthRuleV2ListVersionsParamsnone()final static AuthRuleV2ListVersionsParams.Builderbuilder()Returns a mutable builder for constructing an instance of AuthRuleV2ListVersionsParams. -
-
Method Detail
-
authRuleToken
final Optional<String> authRuleToken()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final AuthRuleV2ListVersionsParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static AuthRuleV2ListVersionsParams none()
-
builder
final static AuthRuleV2ListVersionsParams.Builder builder()
Returns a mutable builder for constructing an instance of AuthRuleV2ListVersionsParams.
-
-
-
-