Class AuthRuleV2UpdateParams.Body.UnionMember1
-
- All Implemented Interfaces:
public final class AuthRuleV2UpdateParams.Body.UnionMember1
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAuthRuleV2UpdateParams.Body.UnionMember1.BuilderA builder for UnionMember1.
public final classAuthRuleV2UpdateParams.Body.UnionMember1.StateThe desired state of the Auth Rule.
Note that only deactivating an Auth Rule through this endpoint is supported at this time. If you need to (re-)activate an Auth Rule the /promote endpoint should be used to promote a draft to the currently active version.
-
Method Summary
Modifier and Type Method Description final Optional<String>name()Auth Rule Name final Optional<AuthRuleV2UpdateParams.Body.UnionMember1.State>state()The desired state of the Auth Rule. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<AuthRuleV2UpdateParams.Body.UnionMember1.State>_state()Returns the raw JSON value of state. final Map<String, JsonValue>_additionalProperties()final AuthRuleV2UpdateParams.Body.UnionMember1.BuildertoBuilder()final AuthRuleV2UpdateParams.Body.UnionMember1validate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AuthRuleV2UpdateParams.Body.UnionMember1.Builderbuilder()Returns a mutable builder for constructing an instance of UnionMember1. -
-
Method Detail
-
state
final Optional<AuthRuleV2UpdateParams.Body.UnionMember1.State> state()
The desired state of the Auth Rule.
Note that only deactivating an Auth Rule through this endpoint is supported at this time. If you need to (re-)activate an Auth Rule the /promote endpoint should be used to promote a draft to the currently active version.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<AuthRuleV2UpdateParams.Body.UnionMember1.State> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AuthRuleV2UpdateParams.Body.UnionMember1.Builder toBuilder()
-
validate
final AuthRuleV2UpdateParams.Body.UnionMember1 validate()
-
builder
final static AuthRuleV2UpdateParams.Body.UnionMember1.Builder builder()
Returns a mutable builder for constructing an instance of UnionMember1.
-
-
-
-