Class AuthenticationRetrieveResponse.Cardholder
-
- All Implemented Interfaces:
public final class AuthenticationRetrieveResponse.CardholderObject containing data about the cardholder provided during the transaction.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAuthenticationRetrieveResponse.Cardholder.BuilderA builder for Cardholder.
public final classAuthenticationRetrieveResponse.Cardholder.AddressMatchResultLithic's evaluation result comparing the transaction's address data with the cardholder KYC data if it exists. In the event Lithic does not have any Cardholder KYC data, or the transaction does not contain any address data, NOT_PRESENT will be returned
public final classAuthenticationRetrieveResponse.Cardholder.BillingAddressObject containing data on the billing address provided during the transaction.
public final classAuthenticationRetrieveResponse.Cardholder.ShippingAddressObject containing data on the shipping address provided during the transaction.
-
Method Summary
Modifier and Type Method Description final Optional<Boolean>addressMatch()Indicates whether the shipping address and billing address provided by the cardholder are the same. final Optional<AuthenticationRetrieveResponse.Cardholder.AddressMatchResult>addressOnFileMatch()Lithic's evaluation result comparing the transaction's address data with the cardholder KYC data if it exists. final Optional<AuthenticationRetrieveResponse.Cardholder.BillingAddress>billingAddress()Object containing data on the billing address provided during the transaction. final Optional<String>email()Email address that is either provided by the cardholder or is on file with the merchant in a 3RI request. final Optional<String>name()Name of the cardholder. final Optional<String>phoneNumberHome()Home phone number provided by the cardholder. final Optional<String>phoneNumberMobile()Mobile/cell phone number provided by the cardholder. final Optional<String>phoneNumberWork()Work phone number provided by the cardholder. final Optional<AuthenticationRetrieveResponse.Cardholder.ShippingAddress>shippingAddress()Object containing data on the shipping address provided during the transaction. final JsonField<Boolean>_addressMatch()Returns the raw JSON value of addressMatch. final JsonField<AuthenticationRetrieveResponse.Cardholder.AddressMatchResult>_addressOnFileMatch()Returns the raw JSON value of addressOnFileMatch. final JsonField<AuthenticationRetrieveResponse.Cardholder.BillingAddress>_billingAddress()Returns the raw JSON value of billingAddress. final JsonField<String>_email()Returns the raw JSON value of email. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_phoneNumberHome()Returns the raw JSON value of phoneNumberHome. final JsonField<String>_phoneNumberMobile()Returns the raw JSON value of phoneNumberMobile. final JsonField<String>_phoneNumberWork()Returns the raw JSON value of phoneNumberWork. final JsonField<AuthenticationRetrieveResponse.Cardholder.ShippingAddress>_shippingAddress()Returns the raw JSON value of shippingAddress. final Map<String, JsonValue>_additionalProperties()final AuthenticationRetrieveResponse.Cardholder.BuildertoBuilder()final AuthenticationRetrieveResponse.Cardholdervalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AuthenticationRetrieveResponse.Cardholder.Builderbuilder()Returns a mutable builder for constructing an instance of Cardholder. -
-
Method Detail
-
addressMatch
final Optional<Boolean> addressMatch()
Indicates whether the shipping address and billing address provided by the cardholder are the same. This value - and assessment of whether the addresses match - is provided directly in the 3DS request and is not determined by Lithic. Maps to EMV 3DS field
addrMatch.
-
addressOnFileMatch
final Optional<AuthenticationRetrieveResponse.Cardholder.AddressMatchResult> addressOnFileMatch()
Lithic's evaluation result comparing the transaction's address data with the cardholder KYC data if it exists. In the event Lithic does not have any Cardholder KYC data, or the transaction does not contain any address data, NOT_PRESENT will be returned
-
billingAddress
final Optional<AuthenticationRetrieveResponse.Cardholder.BillingAddress> billingAddress()
Object containing data on the billing address provided during the transaction.
-
email
final Optional<String> email()
Email address that is either provided by the cardholder or is on file with the merchant in a 3RI request. Maps to EMV 3DS field
email.
-
phoneNumberHome
final Optional<String> phoneNumberHome()
Home phone number provided by the cardholder. Maps to EMV 3DS fields
homePhone.ccandhomePhone.subscriber.
-
phoneNumberMobile
final Optional<String> phoneNumberMobile()
Mobile/cell phone number provided by the cardholder. Maps to EMV 3DS fields
mobilePhone.ccandmobilePhone.subscriber.
-
phoneNumberWork
final Optional<String> phoneNumberWork()
Work phone number provided by the cardholder. Maps to EMV 3DS fields
workPhone.ccandworkPhone.subscriber.
-
shippingAddress
final Optional<AuthenticationRetrieveResponse.Cardholder.ShippingAddress> shippingAddress()
Object containing data on the shipping address provided during the transaction.
-
_addressMatch
final JsonField<Boolean> _addressMatch()
Returns the raw JSON value of addressMatch.
Unlike addressMatch, this method doesn't throw if the JSON field has an unexpected type.
-
_addressOnFileMatch
final JsonField<AuthenticationRetrieveResponse.Cardholder.AddressMatchResult> _addressOnFileMatch()
Returns the raw JSON value of addressOnFileMatch.
Unlike addressOnFileMatch, this method doesn't throw if the JSON field has an unexpected type.
-
_billingAddress
final JsonField<AuthenticationRetrieveResponse.Cardholder.BillingAddress> _billingAddress()
Returns the raw JSON value of billingAddress.
Unlike billingAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_email
final JsonField<String> _email()
Returns the raw JSON value of email.
Unlike email, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_phoneNumberHome
final JsonField<String> _phoneNumberHome()
Returns the raw JSON value of phoneNumberHome.
Unlike phoneNumberHome, this method doesn't throw if the JSON field has an unexpected type.
-
_phoneNumberMobile
final JsonField<String> _phoneNumberMobile()
Returns the raw JSON value of phoneNumberMobile.
Unlike phoneNumberMobile, this method doesn't throw if the JSON field has an unexpected type.
-
_phoneNumberWork
final JsonField<String> _phoneNumberWork()
Returns the raw JSON value of phoneNumberWork.
Unlike phoneNumberWork, this method doesn't throw if the JSON field has an unexpected type.
-
_shippingAddress
final JsonField<AuthenticationRetrieveResponse.Cardholder.ShippingAddress> _shippingAddress()
Returns the raw JSON value of shippingAddress.
Unlike shippingAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AuthenticationRetrieveResponse.Cardholder.Builder toBuilder()
-
validate
final AuthenticationRetrieveResponse.Cardholder validate()
-
builder
final static AuthenticationRetrieveResponse.Cardholder.Builder builder()
Returns a mutable builder for constructing an instance of Cardholder.
-
-
-
-