Class AuthenticationRetrieveResponse.Cardholder.Builder
-
- All Implemented Interfaces:
public final class AuthenticationRetrieveResponse.Cardholder.BuilderA builder for Cardholder.
-
-
Method Summary
-
-
Method Detail
-
addressMatch
final AuthenticationRetrieveResponse.Cardholder.Builder addressMatch(Boolean addressMatch)
Indicates whether the shipping address and billing address provided by the cardholder are the same. This value - and assessment of whether the addresses match - is provided directly in the 3DS request and is not determined by Lithic. Maps to EMV 3DS field
addrMatch.
-
addressMatch
final AuthenticationRetrieveResponse.Cardholder.Builder addressMatch(Boolean addressMatch)
Alias for Builder.addressMatch.
This unboxed primitive overload exists for backwards compatibility.
-
addressMatch
final AuthenticationRetrieveResponse.Cardholder.Builder addressMatch(Optional<Boolean> addressMatch)
Alias for calling Builder.addressMatch with
addressMatch.orElse(null).
-
addressMatch
final AuthenticationRetrieveResponse.Cardholder.Builder addressMatch(JsonField<Boolean> addressMatch)
Sets Builder.addressMatch to an arbitrary JSON value.
You should usually call Builder.addressMatch with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addressOnFileMatch
final AuthenticationRetrieveResponse.Cardholder.Builder addressOnFileMatch(AuthenticationRetrieveResponse.Cardholder.AddressMatchResult addressOnFileMatch)
Lithic's evaluation result comparing the transaction's address data with the cardholder KYC data if it exists. In the event Lithic does not have any Cardholder KYC data, or the transaction does not contain any address data, NOT_PRESENT will be returned
-
addressOnFileMatch
final AuthenticationRetrieveResponse.Cardholder.Builder addressOnFileMatch(JsonField<AuthenticationRetrieveResponse.Cardholder.AddressMatchResult> addressOnFileMatch)
Sets Builder.addressOnFileMatch to an arbitrary JSON value.
You should usually call Builder.addressOnFileMatch with a well-typed AddressMatchResult value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
billingAddress
final AuthenticationRetrieveResponse.Cardholder.Builder billingAddress(AuthenticationRetrieveResponse.Cardholder.BillingAddress billingAddress)
Object containing data on the billing address provided during the transaction.
-
billingAddress
final AuthenticationRetrieveResponse.Cardholder.Builder billingAddress(JsonField<AuthenticationRetrieveResponse.Cardholder.BillingAddress> billingAddress)
Sets Builder.billingAddress to an arbitrary JSON value.
You should usually call Builder.billingAddress with a well-typed BillingAddress value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
email
final AuthenticationRetrieveResponse.Cardholder.Builder email(String email)
Email address that is either provided by the cardholder or is on file with the merchant in a 3RI request. Maps to EMV 3DS field
email.
-
email
final AuthenticationRetrieveResponse.Cardholder.Builder email(Optional<String> email)
Alias for calling Builder.email with
email.orElse(null).
-
email
final AuthenticationRetrieveResponse.Cardholder.Builder email(JsonField<String> email)
Sets Builder.email to an arbitrary JSON value.
You should usually call Builder.email with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final AuthenticationRetrieveResponse.Cardholder.Builder name(String name)
Name of the cardholder. Maps to EMV 3DS field
cardholderName.
-
name
final AuthenticationRetrieveResponse.Cardholder.Builder name(Optional<String> name)
Alias for calling Builder.name with
name.orElse(null).
-
name
final AuthenticationRetrieveResponse.Cardholder.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
phoneNumberHome
final AuthenticationRetrieveResponse.Cardholder.Builder phoneNumberHome(String phoneNumberHome)
Home phone number provided by the cardholder. Maps to EMV 3DS fields
homePhone.ccandhomePhone.subscriber.
-
phoneNumberHome
final AuthenticationRetrieveResponse.Cardholder.Builder phoneNumberHome(Optional<String> phoneNumberHome)
Alias for calling Builder.phoneNumberHome with
phoneNumberHome.orElse(null).
-
phoneNumberHome
final AuthenticationRetrieveResponse.Cardholder.Builder phoneNumberHome(JsonField<String> phoneNumberHome)
Sets Builder.phoneNumberHome to an arbitrary JSON value.
You should usually call Builder.phoneNumberHome with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
phoneNumberMobile
final AuthenticationRetrieveResponse.Cardholder.Builder phoneNumberMobile(String phoneNumberMobile)
Mobile/cell phone number provided by the cardholder. Maps to EMV 3DS fields
mobilePhone.ccandmobilePhone.subscriber.
-
phoneNumberMobile
final AuthenticationRetrieveResponse.Cardholder.Builder phoneNumberMobile(Optional<String> phoneNumberMobile)
Alias for calling Builder.phoneNumberMobile with
phoneNumberMobile.orElse(null).
-
phoneNumberMobile
final AuthenticationRetrieveResponse.Cardholder.Builder phoneNumberMobile(JsonField<String> phoneNumberMobile)
Sets Builder.phoneNumberMobile to an arbitrary JSON value.
You should usually call Builder.phoneNumberMobile with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
phoneNumberWork
final AuthenticationRetrieveResponse.Cardholder.Builder phoneNumberWork(String phoneNumberWork)
Work phone number provided by the cardholder. Maps to EMV 3DS fields
workPhone.ccandworkPhone.subscriber.
-
phoneNumberWork
final AuthenticationRetrieveResponse.Cardholder.Builder phoneNumberWork(Optional<String> phoneNumberWork)
Alias for calling Builder.phoneNumberWork with
phoneNumberWork.orElse(null).
-
phoneNumberWork
final AuthenticationRetrieveResponse.Cardholder.Builder phoneNumberWork(JsonField<String> phoneNumberWork)
Sets Builder.phoneNumberWork to an arbitrary JSON value.
You should usually call Builder.phoneNumberWork with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
shippingAddress
final AuthenticationRetrieveResponse.Cardholder.Builder shippingAddress(AuthenticationRetrieveResponse.Cardholder.ShippingAddress shippingAddress)
Object containing data on the shipping address provided during the transaction.
-
shippingAddress
final AuthenticationRetrieveResponse.Cardholder.Builder shippingAddress(JsonField<AuthenticationRetrieveResponse.Cardholder.ShippingAddress> shippingAddress)
Sets Builder.shippingAddress to an arbitrary JSON value.
You should usually call Builder.shippingAddress with a well-typed ShippingAddress value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AuthenticationRetrieveResponse.Cardholder.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AuthenticationRetrieveResponse.Cardholder.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AuthenticationRetrieveResponse.Cardholder.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AuthenticationRetrieveResponse.Cardholder.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AuthenticationRetrieveResponse.Cardholder.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AuthenticationRetrieveResponse.Cardholder build()
Returns an immutable instance of Cardholder.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-