Package com.lithic.api.models
Class AuthenticationSimulateResponse
-
- All Implemented Interfaces:
public final class AuthenticationSimulateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAuthenticationSimulateResponse.BuilderA builder for AuthenticationSimulateResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>token()Globally unique identifier for the 3DS authentication. final JsonField<String>_token()Returns the raw JSON value of token. final Map<String, JsonValue>_additionalProperties()final AuthenticationSimulateResponse.BuildertoBuilder()final AuthenticationSimulateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AuthenticationSimulateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of AuthenticationSimulateResponse. -
-
Method Detail
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AuthenticationSimulateResponse.Builder toBuilder()
-
validate
final AuthenticationSimulateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AuthenticationSimulateResponse.Builder builder()
Returns a mutable builder for constructing an instance of AuthenticationSimulateResponse.
-
-
-
-