Package com.lithic.api.models
Class BacktestCreateResponse
-
- All Implemented Interfaces:
public final class BacktestCreateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBacktestCreateResponse.BuilderA builder for BacktestCreateResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>backtestToken()Auth Rule Backtest Token final JsonField<String>_backtestToken()Returns the raw JSON value of backtestToken. final Map<String, JsonValue>_additionalProperties()final BacktestCreateResponse.BuildertoBuilder()final BacktestCreateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BacktestCreateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of BacktestCreateResponse. -
-
Method Detail
-
backtestToken
final Optional<String> backtestToken()
Auth Rule Backtest Token
-
_backtestToken
final JsonField<String> _backtestToken()
Returns the raw JSON value of backtestToken.
Unlike backtestToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BacktestCreateResponse.Builder toBuilder()
-
validate
final BacktestCreateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BacktestCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of BacktestCreateResponse.
-
-
-
-