Package com.lithic.api.models
Class BacktestResults.Results.RuleStats.Example
-
- All Implemented Interfaces:
public final class BacktestResults.Results.RuleStats.Example
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBacktestResults.Results.RuleStats.Example.BuilderA builder for Example.
public final classBacktestResults.Results.RuleStats.Example.DecisionThe decision made by the rule for this event.
-
Method Summary
-
-
Method Detail
-
decision
final Optional<BacktestResults.Results.RuleStats.Example.Decision> decision()
The decision made by the rule for this event.
-
eventToken
final Optional<String> eventToken()
The event token.
-
timestamp
final Optional<OffsetDateTime> timestamp()
The timestamp of the event.
-
_approved
final JsonField<Boolean> _approved()
Returns the raw JSON value of approved.
Unlike approved, this method doesn't throw if the JSON field has an unexpected type.
-
_decision
final JsonField<BacktestResults.Results.RuleStats.Example.Decision> _decision()
Returns the raw JSON value of decision.
Unlike decision, this method doesn't throw if the JSON field has an unexpected type.
-
_eventToken
final JsonField<String> _eventToken()
Returns the raw JSON value of eventToken.
Unlike eventToken, this method doesn't throw if the JSON field has an unexpected type.
-
_timestamp
final JsonField<OffsetDateTime> _timestamp()
Returns the raw JSON value of timestamp.
Unlike timestamp, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BacktestResults.Results.RuleStats.Example.Builder toBuilder()
-
validate
final BacktestResults.Results.RuleStats.Example validate()
-
builder
final static BacktestResults.Results.RuleStats.Example.Builder builder()
Returns a mutable builder for constructing an instance of Example.
-
-
-
-