Class BacktestResults.Results.RuleStats.Example.Builder
-
- All Implemented Interfaces:
public final class BacktestResults.Results.RuleStats.Example.BuilderA builder for Example.
-
-
Method Summary
-
-
Method Detail
-
approved
final BacktestResults.Results.RuleStats.Example.Builder approved(Boolean approved)
Whether the rule would have approved the authorization request.
-
approved
final BacktestResults.Results.RuleStats.Example.Builder approved(JsonField<Boolean> approved)
Sets Builder.approved to an arbitrary JSON value.
You should usually call Builder.approved with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventToken
final BacktestResults.Results.RuleStats.Example.Builder eventToken(String eventToken)
The authorization request event token.
-
eventToken
final BacktestResults.Results.RuleStats.Example.Builder eventToken(JsonField<String> eventToken)
Sets Builder.eventToken to an arbitrary JSON value.
You should usually call Builder.eventToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
timestamp
final BacktestResults.Results.RuleStats.Example.Builder timestamp(OffsetDateTime timestamp)
The timestamp of the authorization request event.
-
timestamp
final BacktestResults.Results.RuleStats.Example.Builder timestamp(JsonField<OffsetDateTime> timestamp)
Sets Builder.timestamp to an arbitrary JSON value.
You should usually call Builder.timestamp with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final BacktestResults.Results.RuleStats.Example.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BacktestResults.Results.RuleStats.Example.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BacktestResults.Results.RuleStats.Example.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BacktestResults.Results.RuleStats.Example.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BacktestResults.Results.RuleStats.Example.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BacktestResults.Results.RuleStats.Example build()
Returns an immutable instance of Example.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-