Class Balance
-
- All Implemented Interfaces:
public final class BalanceBalance
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBalance.BuilderA builder for Balance.
public final classBalance.FinancialAccountTypeType of financial account.
-
Method Summary
Modifier and Type Method Description final LongavailableAmount()Funds available for spend in the currency's smallest unit (e.g. final OffsetDateTimecreated()Date and time for when the balance was first created. final Stringcurrency()3-character alphabetic ISO 4217 code for the local currency of the balance. final StringfinancialAccountToken()Globally unique identifier for the financial account that holds this balance. final Balance.FinancialAccountTypefinancialAccountType()Type of financial account. final StringlastTransactionEventToken()Globally unique identifier for the last financial transaction event that impacted this balance. final StringlastTransactionToken()Globally unique identifier for the last financial transaction that impacted this balance. final LongpendingAmount()Funds not available for spend due to card authorizations or pending ACH release. final LongtotalAmount()The sum of available and pending balance in the currency's smallest unit (e.g., cents for USD). final OffsetDateTimeupdated()Date and time for when the balance was last updated. final JsonField<Long>_availableAmount()Funds available for spend in the currency's smallest unit (e.g. final JsonField<OffsetDateTime>_created()Date and time for when the balance was first created. final JsonField<String>_currency()3-character alphabetic ISO 4217 code for the local currency of the balance. final JsonField<String>_financialAccountToken()Globally unique identifier for the financial account that holds this balance. final JsonField<Balance.FinancialAccountType>_financialAccountType()Type of financial account. final JsonField<String>_lastTransactionEventToken()Globally unique identifier for the last financial transaction event that impacted this balance. final JsonField<String>_lastTransactionToken()Globally unique identifier for the last financial transaction that impacted this balance. final JsonField<Long>_pendingAmount()Funds not available for spend due to card authorizations or pending ACH release. final JsonField<Long>_totalAmount()The sum of available and pending balance in the currency's smallest unit (e.g., cents for USD). final JsonField<OffsetDateTime>_updated()Date and time for when the balance was last updated. final Map<String, JsonValue>_additionalProperties()final Balancevalidate()final Balance.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Balance.Builderbuilder()Returns a mutable builder for constructing an instance of Balance. -
-
Method Detail
-
availableAmount
final Long availableAmount()
Funds available for spend in the currency's smallest unit (e.g., cents for USD)
-
created
final OffsetDateTime created()
Date and time for when the balance was first created.
-
currency
final String currency()
3-character alphabetic ISO 4217 code for the local currency of the balance.
-
financialAccountToken
final String financialAccountToken()
Globally unique identifier for the financial account that holds this balance.
-
financialAccountType
final Balance.FinancialAccountType financialAccountType()
Type of financial account.
-
lastTransactionEventToken
final String lastTransactionEventToken()
Globally unique identifier for the last financial transaction event that impacted this balance.
-
lastTransactionToken
final String lastTransactionToken()
Globally unique identifier for the last financial transaction that impacted this balance.
-
pendingAmount
final Long pendingAmount()
Funds not available for spend due to card authorizations or pending ACH release. Shown in the currency's smallest unit (e.g., cents for USD).
-
totalAmount
final Long totalAmount()
The sum of available and pending balance in the currency's smallest unit (e.g., cents for USD).
-
updated
final OffsetDateTime updated()
Date and time for when the balance was last updated.
-
_availableAmount
final JsonField<Long> _availableAmount()
Funds available for spend in the currency's smallest unit (e.g., cents for USD)
-
_created
final JsonField<OffsetDateTime> _created()
Date and time for when the balance was first created.
-
_currency
final JsonField<String> _currency()
3-character alphabetic ISO 4217 code for the local currency of the balance.
-
_financialAccountToken
final JsonField<String> _financialAccountToken()
Globally unique identifier for the financial account that holds this balance.
-
_financialAccountType
final JsonField<Balance.FinancialAccountType> _financialAccountType()
Type of financial account.
-
_lastTransactionEventToken
final JsonField<String> _lastTransactionEventToken()
Globally unique identifier for the last financial transaction event that impacted this balance.
-
_lastTransactionToken
final JsonField<String> _lastTransactionToken()
Globally unique identifier for the last financial transaction that impacted this balance.
-
_pendingAmount
final JsonField<Long> _pendingAmount()
Funds not available for spend due to card authorizations or pending ACH release. Shown in the currency's smallest unit (e.g., cents for USD).
-
_totalAmount
final JsonField<Long> _totalAmount()
The sum of available and pending balance in the currency's smallest unit (e.g., cents for USD).
-
_updated
final JsonField<OffsetDateTime> _updated()
Date and time for when the balance was last updated.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Balance.Builder toBuilder()
-
builder
final static Balance.Builder builder()
Returns a mutable builder for constructing an instance of Balance.
The following fields are required:
.availableAmount() .created() .currency() .financialAccountToken() .financialAccountType() .lastTransactionEventToken() .lastTransactionToken() .pendingAmount() .totalAmount() .updated()
-
-
-
-