Class Balance.Builder
-
- All Implemented Interfaces:
public final class Balance.BuilderA builder for Balance.
-
-
Method Summary
Modifier and Type Method Description final Balance.BuilderavailableAmount(Long availableAmount)Funds available for spend in the currency's smallest unit (e.g. final Balance.BuilderavailableAmount(JsonField<Long> availableAmount)Sets Builder.availableAmount to an arbitrary JSON value. final Balance.Buildercreated(OffsetDateTime created)Date and time for when the balance was first created. final Balance.Buildercreated(JsonField<OffsetDateTime> created)Sets Builder.created to an arbitrary JSON value. final Balance.Buildercurrency(String currency)3-character alphabetic ISO 4217 code for the local currency of the balance. final Balance.Buildercurrency(JsonField<String> currency)Sets Builder.currency to an arbitrary JSON value. final Balance.BuilderfinancialAccountToken(String financialAccountToken)Globally unique identifier for the financial account that holds this balance. final Balance.BuilderfinancialAccountToken(JsonField<String> financialAccountToken)Sets Builder.financialAccountToken to an arbitrary JSON value. final Balance.BuilderfinancialAccountType(Balance.FinancialAccountType financialAccountType)Type of financial account. final Balance.BuilderfinancialAccountType(JsonField<Balance.FinancialAccountType> financialAccountType)Sets Builder.financialAccountType to an arbitrary JSON value. final Balance.BuilderlastTransactionEventToken(String lastTransactionEventToken)Globally unique identifier for the last financial transaction event that impacted this balance. final Balance.BuilderlastTransactionEventToken(JsonField<String> lastTransactionEventToken)Sets Builder.lastTransactionEventToken to an arbitrary JSON value. final Balance.BuilderlastTransactionToken(String lastTransactionToken)Globally unique identifier for the last financial transaction that impacted this balance. final Balance.BuilderlastTransactionToken(JsonField<String> lastTransactionToken)Sets Builder.lastTransactionToken to an arbitrary JSON value. final Balance.BuilderpendingAmount(Long pendingAmount)Funds not available for spend due to card authorizations or pending ACH release. final Balance.BuilderpendingAmount(JsonField<Long> pendingAmount)Sets Builder.pendingAmount to an arbitrary JSON value. final Balance.BuildertotalAmount(Long totalAmount)The sum of available and pending balance in the currency's smallest unit (e.g., cents for USD). final Balance.BuildertotalAmount(JsonField<Long> totalAmount)Sets Builder.totalAmount to an arbitrary JSON value. final Balance.Builderupdated(OffsetDateTime updated)Date and time for when the balance was last updated. final Balance.Builderupdated(JsonField<OffsetDateTime> updated)Sets Builder.updated to an arbitrary JSON value. final Balance.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Balance.BuilderputAdditionalProperty(String key, JsonValue value)final Balance.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Balance.BuilderremoveAdditionalProperty(String key)final Balance.BuilderremoveAllAdditionalProperties(Set<String> keys)final Balancebuild()Returns an immutable instance of Balance. -
-
Method Detail
-
availableAmount
final Balance.Builder availableAmount(Long availableAmount)
Funds available for spend in the currency's smallest unit (e.g., cents for USD)
-
availableAmount
final Balance.Builder availableAmount(JsonField<Long> availableAmount)
Sets Builder.availableAmount to an arbitrary JSON value.
You should usually call Builder.availableAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final Balance.Builder created(OffsetDateTime created)
Date and time for when the balance was first created.
-
created
final Balance.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final Balance.Builder currency(String currency)
3-character alphabetic ISO 4217 code for the local currency of the balance.
-
currency
final Balance.Builder currency(JsonField<String> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
financialAccountToken
final Balance.Builder financialAccountToken(String financialAccountToken)
Globally unique identifier for the financial account that holds this balance.
-
financialAccountToken
final Balance.Builder financialAccountToken(JsonField<String> financialAccountToken)
Sets Builder.financialAccountToken to an arbitrary JSON value.
You should usually call Builder.financialAccountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
financialAccountType
final Balance.Builder financialAccountType(Balance.FinancialAccountType financialAccountType)
Type of financial account.
-
financialAccountType
final Balance.Builder financialAccountType(JsonField<Balance.FinancialAccountType> financialAccountType)
Sets Builder.financialAccountType to an arbitrary JSON value.
You should usually call Builder.financialAccountType with a well-typed FinancialAccountType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastTransactionEventToken
final Balance.Builder lastTransactionEventToken(String lastTransactionEventToken)
Globally unique identifier for the last financial transaction event that impacted this balance.
-
lastTransactionEventToken
final Balance.Builder lastTransactionEventToken(JsonField<String> lastTransactionEventToken)
Sets Builder.lastTransactionEventToken to an arbitrary JSON value.
You should usually call Builder.lastTransactionEventToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastTransactionToken
final Balance.Builder lastTransactionToken(String lastTransactionToken)
Globally unique identifier for the last financial transaction that impacted this balance.
-
lastTransactionToken
final Balance.Builder lastTransactionToken(JsonField<String> lastTransactionToken)
Sets Builder.lastTransactionToken to an arbitrary JSON value.
You should usually call Builder.lastTransactionToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pendingAmount
final Balance.Builder pendingAmount(Long pendingAmount)
Funds not available for spend due to card authorizations or pending ACH release. Shown in the currency's smallest unit (e.g., cents for USD).
-
pendingAmount
final Balance.Builder pendingAmount(JsonField<Long> pendingAmount)
Sets Builder.pendingAmount to an arbitrary JSON value.
You should usually call Builder.pendingAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalAmount
final Balance.Builder totalAmount(Long totalAmount)
The sum of available and pending balance in the currency's smallest unit (e.g., cents for USD).
-
totalAmount
final Balance.Builder totalAmount(JsonField<Long> totalAmount)
Sets Builder.totalAmount to an arbitrary JSON value.
You should usually call Builder.totalAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updated
final Balance.Builder updated(OffsetDateTime updated)
Date and time for when the balance was last updated.
-
updated
final Balance.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Balance.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Balance.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Balance.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Balance.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Balance.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Balance build()
Returns an immutable instance of Balance.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.availableAmount() .created() .currency() .financialAccountToken() .financialAccountType() .lastTransactionEventToken() .lastTransactionToken() .pendingAmount() .totalAmount() .updated()
-
-
-
-