Package com.lithic.api.models
Class BalanceListPage
-
- All Implemented Interfaces:
public final class BalanceListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBalanceListPage.BuilderA builder for BalanceListPage.
public final classBalanceListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<Balance>data()Delegates to BalanceListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to BalanceListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<BalanceListParams>getNextPageParams()final Optional<BalanceListPage>getNextPage()final BalanceListPage.AutoPagerautoPager()final BalanceListParamsparams()The parameters that were used to request this page. final BalanceListPageResponseresponse()The response that this page was parsed from. final BalanceListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BalanceListPage.Builderbuilder()Returns a mutable builder for constructing an instance of BalanceListPage. -
-
Method Detail
-
data
final List<Balance> data()
Delegates to BalanceListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to BalanceListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<BalanceListParams> getNextPageParams()
-
getNextPage
final Optional<BalanceListPage> getNextPage()
-
autoPager
final BalanceListPage.AutoPager autoPager()
-
params
final BalanceListParams params()
The parameters that were used to request this page.
-
response
final BalanceListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final BalanceListPage.Builder toBuilder()
-
builder
final static BalanceListPage.Builder builder()
Returns a mutable builder for constructing an instance of BalanceListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-