Package com.lithic.api.models
Class BalanceListPage.Builder
-
- All Implemented Interfaces:
public final class BalanceListPage.BuilderA builder for BalanceListPage.
-
-
Method Summary
Modifier and Type Method Description final BalanceListPage.Builderservice(BalanceService service)final BalanceListPage.Builderparams(BalanceListParams params)The parameters that were used to request this page. final BalanceListPage.Builderresponse(BalanceListPageResponse response)The response that this page was parsed from. final BalanceListPagebuild()Returns an immutable instance of BalanceListPage. -
-
Method Detail
-
service
final BalanceListPage.Builder service(BalanceService service)
-
params
final BalanceListPage.Builder params(BalanceListParams params)
The parameters that were used to request this page.
-
response
final BalanceListPage.Builder response(BalanceListPageResponse response)
The response that this page was parsed from.
-
build
final BalanceListPage build()
Returns an immutable instance of BalanceListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-