Package com.lithic.api.models
Class BalanceListPageAsync
-
- All Implemented Interfaces:
public final class BalanceListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBalanceListPageAsync.BuilderA builder for BalanceListPageAsync.
public final classBalanceListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<Balance>data()Delegates to BalanceListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to BalanceListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<BalanceListParams>getNextPageParams()final CompletableFuture<Optional<BalanceListPageAsync>>getNextPage()final BalanceListPageAsync.AutoPagerautoPager()final BalanceListParamsparams()The parameters that were used to request this page. final BalanceListPageResponseresponse()The response that this page was parsed from. final BalanceListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BalanceListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of BalanceListPageAsync. -
-
Method Detail
-
data
final List<Balance> data()
Delegates to BalanceListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to BalanceListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<BalanceListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<BalanceListPageAsync>> getNextPage()
-
autoPager
final BalanceListPageAsync.AutoPager autoPager()
-
params
final BalanceListParams params()
The parameters that were used to request this page.
-
response
final BalanceListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final BalanceListPageAsync.Builder toBuilder()
-
builder
final static BalanceListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of BalanceListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-