Package com.lithic.api.models
Class BalanceListPageResponse.Builder
-
- All Implemented Interfaces:
public final class BalanceListPageResponse.BuilderA builder for BalanceListPageResponse.
-
-
Method Summary
-
-
Method Detail
-
data
final BalanceListPageResponse.Builder data(List<Balance> data)
-
data
final BalanceListPageResponse.Builder data(JsonField<List<Balance>> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed
List<Balance>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addData
final BalanceListPageResponse.Builder addData(Balance data)
Adds a single Balance to Builder.data.
-
hasMore
final BalanceListPageResponse.Builder hasMore(Boolean hasMore)
More data exists.
-
hasMore
final BalanceListPageResponse.Builder hasMore(JsonField<Boolean> hasMore)
Sets Builder.hasMore to an arbitrary JSON value.
You should usually call Builder.hasMore with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final BalanceListPageResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BalanceListPageResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BalanceListPageResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BalanceListPageResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BalanceListPageResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BalanceListPageResponse build()
Returns an immutable instance of BalanceListPageResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.data() .hasMore()
-
-
-
-