Class BalanceListResponse
-
- All Implemented Interfaces:
public final class BalanceListResponseBalance of a Financial Account
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBalanceListResponse.BuilderA builder for BalanceListResponse.
public final classBalanceListResponse.TypeType of financial account.
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier for the financial account that holds this balance. final LongavailableAmount()Funds available for spend in the currency's smallest unit (e.g. final OffsetDateTimecreated()Date and time for when the balance was first created. final Stringcurrency()3-character alphabetic ISO 4217 code for the local currency of the balance. final StringlastTransactionEventToken()Globally unique identifier for the last financial transaction event that impacted this balance. final StringlastTransactionToken()Globally unique identifier for the last financial transaction that impacted this balance. final LongpendingAmount()Funds not available for spend due to card authorizations or pending ACH release. final LongtotalAmount()The sum of available and pending balance in the currency's smallest unit (e.g., cents for USD). final BalanceListResponse.Typetype()Type of financial account. final OffsetDateTimeupdated()Date and time for when the balance was last updated. final JsonField<String>_token()Globally unique identifier for the financial account that holds this balance. final JsonField<Long>_availableAmount()Funds available for spend in the currency's smallest unit (e.g. final JsonField<OffsetDateTime>_created()Date and time for when the balance was first created. final JsonField<String>_currency()3-character alphabetic ISO 4217 code for the local currency of the balance. final JsonField<String>_lastTransactionEventToken()Globally unique identifier for the last financial transaction event that impacted this balance. final JsonField<String>_lastTransactionToken()Globally unique identifier for the last financial transaction that impacted this balance. final JsonField<Long>_pendingAmount()Funds not available for spend due to card authorizations or pending ACH release. final JsonField<Long>_totalAmount()The sum of available and pending balance in the currency's smallest unit (e.g., cents for USD). final JsonField<BalanceListResponse.Type>_type()Type of financial account. final JsonField<OffsetDateTime>_updated()Date and time for when the balance was last updated. final Map<String, JsonValue>_additionalProperties()final BalanceListResponsevalidate()final BalanceListResponse.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BalanceListResponse.Builderbuilder()Returns a mutable builder for constructing an instance of BalanceListResponse. -
-
Method Detail
-
token
final String token()
Globally unique identifier for the financial account that holds this balance.
-
availableAmount
final Long availableAmount()
Funds available for spend in the currency's smallest unit (e.g., cents for USD)
-
created
final OffsetDateTime created()
Date and time for when the balance was first created.
-
currency
final String currency()
3-character alphabetic ISO 4217 code for the local currency of the balance.
-
lastTransactionEventToken
final String lastTransactionEventToken()
Globally unique identifier for the last financial transaction event that impacted this balance.
-
lastTransactionToken
final String lastTransactionToken()
Globally unique identifier for the last financial transaction that impacted this balance.
-
pendingAmount
final Long pendingAmount()
Funds not available for spend due to card authorizations or pending ACH release. Shown in the currency's smallest unit (e.g., cents for USD).
-
totalAmount
final Long totalAmount()
The sum of available and pending balance in the currency's smallest unit (e.g., cents for USD).
-
type
final BalanceListResponse.Type type()
Type of financial account.
-
updated
final OffsetDateTime updated()
Date and time for when the balance was last updated.
-
_token
final JsonField<String> _token()
Globally unique identifier for the financial account that holds this balance.
-
_availableAmount
final JsonField<Long> _availableAmount()
Funds available for spend in the currency's smallest unit (e.g., cents for USD)
-
_created
final JsonField<OffsetDateTime> _created()
Date and time for when the balance was first created.
-
_currency
final JsonField<String> _currency()
3-character alphabetic ISO 4217 code for the local currency of the balance.
-
_lastTransactionEventToken
final JsonField<String> _lastTransactionEventToken()
Globally unique identifier for the last financial transaction event that impacted this balance.
-
_lastTransactionToken
final JsonField<String> _lastTransactionToken()
Globally unique identifier for the last financial transaction that impacted this balance.
-
_pendingAmount
final JsonField<Long> _pendingAmount()
Funds not available for spend due to card authorizations or pending ACH release. Shown in the currency's smallest unit (e.g., cents for USD).
-
_totalAmount
final JsonField<Long> _totalAmount()
The sum of available and pending balance in the currency's smallest unit (e.g., cents for USD).
-
_type
final JsonField<BalanceListResponse.Type> _type()
Type of financial account.
-
_updated
final JsonField<OffsetDateTime> _updated()
Date and time for when the balance was last updated.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final BalanceListResponse validate()
-
toBuilder
final BalanceListResponse.Builder toBuilder()
-
builder
final static BalanceListResponse.Builder builder()
Returns a mutable builder for constructing an instance of BalanceListResponse.
The following fields are required:
.token() .availableAmount() .created() .currency() .lastTransactionEventToken() .lastTransactionToken() .pendingAmount() .totalAmount() .type() .updated()
-
-
-
-