Class BalanceListResponse.Builder
-
- All Implemented Interfaces:
public final class BalanceListResponse.BuilderA builder for BalanceListResponse.
-
-
Method Summary
Modifier and Type Method Description final BalanceListResponse.Buildertoken(String token)Globally unique identifier for the financial account that holds this balance. final BalanceListResponse.Buildertoken(JsonField<String> token)Sets Builder.token to an arbitrary JSON value. final BalanceListResponse.BuilderavailableAmount(Long availableAmount)Funds available for spend in the currency's smallest unit (e.g. final BalanceListResponse.BuilderavailableAmount(JsonField<Long> availableAmount)Sets Builder.availableAmount to an arbitrary JSON value. final BalanceListResponse.Buildercreated(OffsetDateTime created)Date and time for when the balance was first created. final BalanceListResponse.Buildercreated(JsonField<OffsetDateTime> created)Sets Builder.created to an arbitrary JSON value. final BalanceListResponse.Buildercurrency(String currency)3-character alphabetic ISO 4217 code for the local currency of the balance. final BalanceListResponse.Buildercurrency(JsonField<String> currency)Sets Builder.currency to an arbitrary JSON value. final BalanceListResponse.BuilderlastTransactionEventToken(String lastTransactionEventToken)Globally unique identifier for the last financial transaction event that impacted this balance. final BalanceListResponse.BuilderlastTransactionEventToken(JsonField<String> lastTransactionEventToken)Sets Builder.lastTransactionEventToken to an arbitrary JSON value. final BalanceListResponse.BuilderlastTransactionToken(String lastTransactionToken)Globally unique identifier for the last financial transaction that impacted this balance. final BalanceListResponse.BuilderlastTransactionToken(JsonField<String> lastTransactionToken)Sets Builder.lastTransactionToken to an arbitrary JSON value. final BalanceListResponse.BuilderpendingAmount(Long pendingAmount)Funds not available for spend due to card authorizations or pending ACH release. final BalanceListResponse.BuilderpendingAmount(JsonField<Long> pendingAmount)Sets Builder.pendingAmount to an arbitrary JSON value. final BalanceListResponse.BuildertotalAmount(Long totalAmount)The sum of available and pending balance in the currency's smallest unit (e.g., cents for USD). final BalanceListResponse.BuildertotalAmount(JsonField<Long> totalAmount)Sets Builder.totalAmount to an arbitrary JSON value. final BalanceListResponse.Buildertype(BalanceListResponse.Type type)Type of financial account. final BalanceListResponse.Buildertype(JsonField<BalanceListResponse.Type> type)Sets Builder.type to an arbitrary JSON value. final BalanceListResponse.Builderupdated(OffsetDateTime updated)Date and time for when the balance was last updated. final BalanceListResponse.Builderupdated(JsonField<OffsetDateTime> updated)Sets Builder.updated to an arbitrary JSON value. final BalanceListResponse.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final BalanceListResponse.BuilderputAdditionalProperty(String key, JsonValue value)final BalanceListResponse.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final BalanceListResponse.BuilderremoveAdditionalProperty(String key)final BalanceListResponse.BuilderremoveAllAdditionalProperties(Set<String> keys)final BalanceListResponsebuild()Returns an immutable instance of BalanceListResponse. -
-
Method Detail
-
token
final BalanceListResponse.Builder token(String token)
Globally unique identifier for the financial account that holds this balance.
-
token
final BalanceListResponse.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
availableAmount
final BalanceListResponse.Builder availableAmount(Long availableAmount)
Funds available for spend in the currency's smallest unit (e.g., cents for USD)
-
availableAmount
final BalanceListResponse.Builder availableAmount(JsonField<Long> availableAmount)
Sets Builder.availableAmount to an arbitrary JSON value.
You should usually call Builder.availableAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final BalanceListResponse.Builder created(OffsetDateTime created)
Date and time for when the balance was first created.
-
created
final BalanceListResponse.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final BalanceListResponse.Builder currency(String currency)
3-character alphabetic ISO 4217 code for the local currency of the balance.
-
currency
final BalanceListResponse.Builder currency(JsonField<String> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastTransactionEventToken
final BalanceListResponse.Builder lastTransactionEventToken(String lastTransactionEventToken)
Globally unique identifier for the last financial transaction event that impacted this balance.
-
lastTransactionEventToken
final BalanceListResponse.Builder lastTransactionEventToken(JsonField<String> lastTransactionEventToken)
Sets Builder.lastTransactionEventToken to an arbitrary JSON value.
You should usually call Builder.lastTransactionEventToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastTransactionToken
final BalanceListResponse.Builder lastTransactionToken(String lastTransactionToken)
Globally unique identifier for the last financial transaction that impacted this balance.
-
lastTransactionToken
final BalanceListResponse.Builder lastTransactionToken(JsonField<String> lastTransactionToken)
Sets Builder.lastTransactionToken to an arbitrary JSON value.
You should usually call Builder.lastTransactionToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pendingAmount
final BalanceListResponse.Builder pendingAmount(Long pendingAmount)
Funds not available for spend due to card authorizations or pending ACH release. Shown in the currency's smallest unit (e.g., cents for USD).
-
pendingAmount
final BalanceListResponse.Builder pendingAmount(JsonField<Long> pendingAmount)
Sets Builder.pendingAmount to an arbitrary JSON value.
You should usually call Builder.pendingAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalAmount
final BalanceListResponse.Builder totalAmount(Long totalAmount)
The sum of available and pending balance in the currency's smallest unit (e.g., cents for USD).
-
totalAmount
final BalanceListResponse.Builder totalAmount(JsonField<Long> totalAmount)
Sets Builder.totalAmount to an arbitrary JSON value.
You should usually call Builder.totalAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final BalanceListResponse.Builder type(BalanceListResponse.Type type)
Type of financial account.
-
type
final BalanceListResponse.Builder type(JsonField<BalanceListResponse.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updated
final BalanceListResponse.Builder updated(OffsetDateTime updated)
Date and time for when the balance was last updated.
-
updated
final BalanceListResponse.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final BalanceListResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BalanceListResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BalanceListResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BalanceListResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BalanceListResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BalanceListResponse build()
Returns an immutable instance of BalanceListResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .availableAmount() .created() .currency() .lastTransactionEventToken() .lastTransactionToken() .pendingAmount() .totalAmount() .type() .updated()
-
-
-
-