Class BookTransferCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class BookTransferCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
Modifier and Type Method Description final BookTransferCreateParams.Body.Builderamount(Long amount)Amount to be transferred in the currency’s smallest unit (e.g., cents for USD). final BookTransferCreateParams.Body.Builderamount(JsonField<Long> amount)Amount to be transferred in the currency’s smallest unit (e.g., cents for USD). final BookTransferCreateParams.Body.Buildercategory(BookTransferCreateParams.Category category)Category of the book transfer final BookTransferCreateParams.Body.Buildercategory(JsonField<BookTransferCreateParams.Category> category)Category of the book transfer final BookTransferCreateParams.Body.BuilderfromFinancialAccountToken(String fromFinancialAccountToken)Globally unique identifier for the financial account or card that will send the funds. final BookTransferCreateParams.Body.BuilderfromFinancialAccountToken(JsonField<String> fromFinancialAccountToken)Globally unique identifier for the financial account or card that will send the funds. final BookTransferCreateParams.Body.Buildersubtype(String subtype)The program specific subtype code for the specified category/type. final BookTransferCreateParams.Body.Buildersubtype(JsonField<String> subtype)The program specific subtype code for the specified category/type. final BookTransferCreateParams.Body.BuildertoFinancialAccountToken(String toFinancialAccountToken)Globally unique identifier for the financial account or card that will receive the funds. final BookTransferCreateParams.Body.BuildertoFinancialAccountToken(JsonField<String> toFinancialAccountToken)Globally unique identifier for the financial account or card that will receive the funds. final BookTransferCreateParams.Body.Buildertype(BookTransferCreateParams.Type type)Type of book_transfer final BookTransferCreateParams.Body.Buildertype(JsonField<BookTransferCreateParams.Type> type)Type of book_transfer final BookTransferCreateParams.Body.Buildertoken(String token)Customer-provided token that will serve as an idempotency token. final BookTransferCreateParams.Body.Buildertoken(JsonField<String> token)Customer-provided token that will serve as an idempotency token. final BookTransferCreateParams.Body.Buildermemo(String memo)Optional descriptor for the transfer. final BookTransferCreateParams.Body.Buildermemo(JsonField<String> memo)Optional descriptor for the transfer. final BookTransferCreateParams.Body.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final BookTransferCreateParams.Body.BuilderputAdditionalProperty(String key, JsonValue value)final BookTransferCreateParams.Body.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final BookTransferCreateParams.Body.BuilderremoveAdditionalProperty(String key)final BookTransferCreateParams.Body.BuilderremoveAllAdditionalProperties(Set<String> keys)final BookTransferCreateParams.Bodybuild()-
-
Method Detail
-
amount
final BookTransferCreateParams.Body.Builder amount(Long amount)
Amount to be transferred in the currency’s smallest unit (e.g., cents for USD). This should always be a positive value.
-
amount
final BookTransferCreateParams.Body.Builder amount(JsonField<Long> amount)
Amount to be transferred in the currency’s smallest unit (e.g., cents for USD). This should always be a positive value.
-
category
final BookTransferCreateParams.Body.Builder category(BookTransferCreateParams.Category category)
Category of the book transfer
-
category
final BookTransferCreateParams.Body.Builder category(JsonField<BookTransferCreateParams.Category> category)
Category of the book transfer
-
fromFinancialAccountToken
final BookTransferCreateParams.Body.Builder fromFinancialAccountToken(String fromFinancialAccountToken)
Globally unique identifier for the financial account or card that will send the funds. Accepted type dependent on the program's use case.
-
fromFinancialAccountToken
final BookTransferCreateParams.Body.Builder fromFinancialAccountToken(JsonField<String> fromFinancialAccountToken)
Globally unique identifier for the financial account or card that will send the funds. Accepted type dependent on the program's use case.
-
subtype
final BookTransferCreateParams.Body.Builder subtype(String subtype)
The program specific subtype code for the specified category/type.
-
subtype
final BookTransferCreateParams.Body.Builder subtype(JsonField<String> subtype)
The program specific subtype code for the specified category/type.
-
toFinancialAccountToken
final BookTransferCreateParams.Body.Builder toFinancialAccountToken(String toFinancialAccountToken)
Globally unique identifier for the financial account or card that will receive the funds. Accepted type dependent on the program's use case.
-
toFinancialAccountToken
final BookTransferCreateParams.Body.Builder toFinancialAccountToken(JsonField<String> toFinancialAccountToken)
Globally unique identifier for the financial account or card that will receive the funds. Accepted type dependent on the program's use case.
-
type
final BookTransferCreateParams.Body.Builder type(BookTransferCreateParams.Type type)
Type of book_transfer
-
type
final BookTransferCreateParams.Body.Builder type(JsonField<BookTransferCreateParams.Type> type)
Type of book_transfer
-
token
final BookTransferCreateParams.Body.Builder token(String token)
Customer-provided token that will serve as an idempotency token. This token will become the transaction token.
-
token
final BookTransferCreateParams.Body.Builder token(JsonField<String> token)
Customer-provided token that will serve as an idempotency token. This token will become the transaction token.
-
memo
final BookTransferCreateParams.Body.Builder memo(String memo)
Optional descriptor for the transfer.
-
memo
final BookTransferCreateParams.Body.Builder memo(JsonField<String> memo)
Optional descriptor for the transfer.
-
additionalProperties
final BookTransferCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BookTransferCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BookTransferCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BookTransferCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BookTransferCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BookTransferCreateParams.Body build()
-
-
-
-