Package com.lithic.api.models
Class BookTransferListPage
-
- All Implemented Interfaces:
public final class BookTransferListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookTransferListPage.BuilderA builder for BookTransferListPage.
public final classBookTransferListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<BookTransferResponse>data()Delegates to BookTransferListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to BookTransferListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<BookTransferListParams>getNextPageParams()final Optional<BookTransferListPage>getNextPage()final BookTransferListPage.AutoPagerautoPager()final BookTransferListParamsparams()The parameters that were used to request this page. final BookTransferListPageResponseresponse()The response that this page was parsed from. final BookTransferListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookTransferListPage.Builderbuilder()Returns a mutable builder for constructing an instance of BookTransferListPage. -
-
Method Detail
-
data
final List<BookTransferResponse> data()
Delegates to BookTransferListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to BookTransferListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<BookTransferListParams> getNextPageParams()
-
getNextPage
final Optional<BookTransferListPage> getNextPage()
-
autoPager
final BookTransferListPage.AutoPager autoPager()
-
params
final BookTransferListParams params()
The parameters that were used to request this page.
-
response
final BookTransferListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final BookTransferListPage.Builder toBuilder()
-
builder
final static BookTransferListPage.Builder builder()
Returns a mutable builder for constructing an instance of BookTransferListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-