Package com.lithic.api.models
Class BookTransferListPage.Builder
-
- All Implemented Interfaces:
public final class BookTransferListPage.BuilderA builder for BookTransferListPage.
-
-
Method Summary
Modifier and Type Method Description final BookTransferListPage.Builderservice(BookTransferService service)final BookTransferListPage.Builderparams(BookTransferListParams params)The parameters that were used to request this page. final BookTransferListPage.Builderresponse(BookTransferListPageResponse response)The response that this page was parsed from. final BookTransferListPagebuild()Returns an immutable instance of BookTransferListPage. -
-
Method Detail
-
service
final BookTransferListPage.Builder service(BookTransferService service)
-
params
final BookTransferListPage.Builder params(BookTransferListParams params)
The parameters that were used to request this page.
-
response
final BookTransferListPage.Builder response(BookTransferListPageResponse response)
The response that this page was parsed from.
-
build
final BookTransferListPage build()
Returns an immutable instance of BookTransferListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-