Package com.lithic.api.models
Class BookTransferListPageAsync
-
- All Implemented Interfaces:
public final class BookTransferListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookTransferListPageAsync.BuilderA builder for BookTransferListPageAsync.
public final classBookTransferListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<BookTransferResponse>data()Delegates to BookTransferListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to BookTransferListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<BookTransferListParams>getNextPageParams()final CompletableFuture<Optional<BookTransferListPageAsync>>getNextPage()final BookTransferListPageAsync.AutoPagerautoPager()final BookTransferListParamsparams()The parameters that were used to request this page. final BookTransferListPageResponseresponse()The response that this page was parsed from. final BookTransferListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookTransferListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of BookTransferListPageAsync. -
-
Method Detail
-
data
final List<BookTransferResponse> data()
Delegates to BookTransferListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to BookTransferListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<BookTransferListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<BookTransferListPageAsync>> getNextPage()
-
autoPager
final BookTransferListPageAsync.AutoPager autoPager()
-
params
final BookTransferListParams params()
The parameters that were used to request this page.
-
response
final BookTransferListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final BookTransferListPageAsync.Builder toBuilder()
-
builder
final static BookTransferListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of BookTransferListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-