Package com.lithic.api.models
Class BookTransferListPageAsync.Response
-
- All Implemented Interfaces:
public final class BookTransferListPageAsync.Response
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookTransferListPageAsync.Response.Builder
-
Constructor Summary
Constructors Constructor Description BookTransferListPageAsync.Response(JsonField<List<BookTransferResponse>> data, JsonField<Boolean> hasMore, Map<String, JsonValue> additionalProperties)
-
Method Summary
Modifier and Type Method Description final List<BookTransferResponse>data()final BooleanhasMore()final Optional<JsonField<List<BookTransferResponse>>>_data()final Optional<JsonField<Boolean>>_hasMore()final Map<String, JsonValue>_additionalProperties()final BookTransferListPageAsync.Responsevalidate()final BooleanisValid()final BookTransferListPageAsync.Response.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookTransferListPageAsync.Response.Builderbuilder()Returns a mutable builder for constructing an instance of BookTransferListPageAsync. -
-
Method Detail
-
data
final List<BookTransferResponse> data()
-
_data
final Optional<JsonField<List<BookTransferResponse>>> _data()
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final BookTransferListPageAsync.Response validate()
-
toBuilder
final BookTransferListPageAsync.Response.Builder toBuilder()
-
builder
final static BookTransferListPageAsync.Response.Builder builder()
Returns a mutable builder for constructing an instance of BookTransferListPageAsync.
-
-
-
-