Package com.lithic.api.models
Class BookTransferListPageResponse
-
- All Implemented Interfaces:
public final class BookTransferListPageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookTransferListPageResponse.BuilderA builder for BookTransferListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<BookTransferResponse>data()final BooleanhasMore()final JsonField<List<BookTransferResponse>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final BookTransferListPageResponse.BuildertoBuilder()final BookTransferListPageResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookTransferListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of BookTransferListPageResponse. -
-
Method Detail
-
data
final List<BookTransferResponse> data()
-
_data
final JsonField<List<BookTransferResponse>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BookTransferListPageResponse.Builder toBuilder()
-
validate
final BookTransferListPageResponse validate()
-
builder
final static BookTransferListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of BookTransferListPageResponse.
The following fields are required:
.data() .hasMore()
-
-
-
-