Package com.lithic.api.models
Class BookTransferListPageResponse.Builder
-
- All Implemented Interfaces:
public final class BookTransferListPageResponse.BuilderA builder for BookTransferListPageResponse.
-
-
Method Summary
-
-
Method Detail
-
data
final BookTransferListPageResponse.Builder data(List<BookTransferResponse> data)
-
data
final BookTransferListPageResponse.Builder data(JsonField<List<BookTransferResponse>> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed
List<BookTransferResponse>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addData
final BookTransferListPageResponse.Builder addData(BookTransferResponse data)
Adds a single BookTransferResponse to Builder.data.
-
hasMore
final BookTransferListPageResponse.Builder hasMore(Boolean hasMore)
-
hasMore
final BookTransferListPageResponse.Builder hasMore(JsonField<Boolean> hasMore)
Sets Builder.hasMore to an arbitrary JSON value.
You should usually call Builder.hasMore with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final BookTransferListPageResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BookTransferListPageResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BookTransferListPageResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BookTransferListPageResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BookTransferListPageResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BookTransferListPageResponse build()
Returns an immutable instance of BookTransferListPageResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.data() .hasMore()
-
-
-
-