Class BookTransferResponse.BookTransferEvent
-
- All Implemented Interfaces:
public final class BookTransferResponse.BookTransferEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookTransferResponse.BookTransferEvent.BuilderA builder for BookTransferEvent.
public final classBookTransferResponse.BookTransferEvent.DetailedResultpublic final classBookTransferResponse.BookTransferEvent.ResultAPPROVED financial events were successful while DECLINED financial events were declined by user, Lithic, or the network.
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier. final Longamount()Amount of the financial event that has been settled in the currency's smallest unit (e.g., cents). final OffsetDateTimecreated()Date and time when the financial event occurred. final List<BookTransferResponse.BookTransferEvent.DetailedResult>detailedResults()Detailed Results final Stringmemo()Memo for the transfer. final BookTransferResponse.BookTransferEvent.Resultresult()APPROVED financial events were successful while DECLINED financial events were declined by user, Lithic, or the network. final Stringsubtype()The program specific subtype code for the specified category/type. final Stringtype()Type of the book transfer final JsonField<String>_token()Globally unique identifier. final JsonField<Long>_amount()Amount of the financial event that has been settled in the currency's smallest unit (e.g., cents). final JsonField<OffsetDateTime>_created()Date and time when the financial event occurred. final JsonField<List<BookTransferResponse.BookTransferEvent.DetailedResult>>_detailedResults()Detailed Results final JsonField<String>_memo()Memo for the transfer. final JsonField<BookTransferResponse.BookTransferEvent.Result>_result()APPROVED financial events were successful while DECLINED financial events were declined by user, Lithic, or the network. final JsonField<String>_subtype()The program specific subtype code for the specified category/type. final JsonField<String>_type()Type of the book transfer final Map<String, JsonValue>_additionalProperties()final BookTransferResponse.BookTransferEventvalidate()final BookTransferResponse.BookTransferEvent.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookTransferResponse.BookTransferEvent.Builderbuilder()Returns a mutable builder for constructing an instance of BookTransferEvent. -
-
Method Detail
-
amount
final Long amount()
Amount of the financial event that has been settled in the currency's smallest unit (e.g., cents).
-
created
final OffsetDateTime created()
Date and time when the financial event occurred. UTC time zone.
-
detailedResults
final List<BookTransferResponse.BookTransferEvent.DetailedResult> detailedResults()
Detailed Results
-
result
final BookTransferResponse.BookTransferEvent.Result result()
APPROVED financial events were successful while DECLINED financial events were declined by user, Lithic, or the network.
-
_amount
final JsonField<Long> _amount()
Amount of the financial event that has been settled in the currency's smallest unit (e.g., cents).
-
_created
final JsonField<OffsetDateTime> _created()
Date and time when the financial event occurred. UTC time zone.
-
_detailedResults
final JsonField<List<BookTransferResponse.BookTransferEvent.DetailedResult>> _detailedResults()
Detailed Results
-
_result
final JsonField<BookTransferResponse.BookTransferEvent.Result> _result()
APPROVED financial events were successful while DECLINED financial events were declined by user, Lithic, or the network.
-
_subtype
final JsonField<String> _subtype()
The program specific subtype code for the specified category/type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final BookTransferResponse.BookTransferEvent validate()
-
toBuilder
final BookTransferResponse.BookTransferEvent.Builder toBuilder()
-
builder
final static BookTransferResponse.BookTransferEvent.Builder builder()
Returns a mutable builder for constructing an instance of BookTransferEvent.
The following fields are required:
.token() .amount() .created() .detailedResults() .memo() .result() .subtype() .type()
-
-
-
-