Class BookTransferResponse.Builder
-
- All Implemented Interfaces:
public final class BookTransferResponse.BuilderA builder for BookTransferResponse.
-
-
Method Summary
-
-
Method Detail
-
token
final BookTransferResponse.Builder token(String token)
Unique identifier for the transaction
-
token
final BookTransferResponse.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
category
final BookTransferResponse.Builder category(BookTransferResponse.BookTransferCategory category)
-
category
final BookTransferResponse.Builder category(JsonField<BookTransferResponse.BookTransferCategory> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed BookTransferCategory value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final BookTransferResponse.Builder created(OffsetDateTime created)
ISO 8601 timestamp of when the transaction was created
-
created
final BookTransferResponse.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final BookTransferResponse.Builder currency(String currency)
3-character alphabetic ISO 4217 code for the settling currency of the transaction
-
currency
final BookTransferResponse.Builder currency(JsonField<String> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
events
final BookTransferResponse.Builder events(List<BookTransferResponse.BookTransferEvent> events)
A list of all financial events that have modified this transfer
-
events
final BookTransferResponse.Builder events(JsonField<List<BookTransferResponse.BookTransferEvent>> events)
Sets Builder.events to an arbitrary JSON value.
You should usually call Builder.events with a well-typed
List<BookTransferEvent>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEvent
final BookTransferResponse.Builder addEvent(BookTransferResponse.BookTransferEvent event)
Adds a single BookTransferEvent to events.
-
family
final BookTransferResponse.Builder family(BookTransferResponse.Family family)
TRANSFER - Book Transfer Transaction
-
family
final BookTransferResponse.Builder family(JsonField<BookTransferResponse.Family> family)
Sets Builder.family to an arbitrary JSON value.
You should usually call Builder.family with a well-typed Family value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fromFinancialAccountToken
final BookTransferResponse.Builder fromFinancialAccountToken(String fromFinancialAccountToken)
Globally unique identifier for the financial account or card that will send the funds. Accepted type dependent on the program's use case
-
fromFinancialAccountToken
final BookTransferResponse.Builder fromFinancialAccountToken(JsonField<String> fromFinancialAccountToken)
Sets Builder.fromFinancialAccountToken to an arbitrary JSON value.
You should usually call Builder.fromFinancialAccountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pendingAmount
final BookTransferResponse.Builder pendingAmount(Long pendingAmount)
Pending amount of the transaction in the currency's smallest unit (e.g., cents), including any acquirer fees.
The value of this field will go to zero over time once the financial transaction is settled.
-
pendingAmount
final BookTransferResponse.Builder pendingAmount(JsonField<Long> pendingAmount)
Sets Builder.pendingAmount to an arbitrary JSON value.
You should usually call Builder.pendingAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
result
final BookTransferResponse.Builder result(BookTransferResponse.TransactionResult result)
-
result
final BookTransferResponse.Builder result(JsonField<BookTransferResponse.TransactionResult> result)
Sets Builder.result to an arbitrary JSON value.
You should usually call Builder.result with a well-typed TransactionResult value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
settledAmount
final BookTransferResponse.Builder settledAmount(Long settledAmount)
Amount of the transaction that has been settled in the currency's smallest unit (e.g., cents)
-
settledAmount
final BookTransferResponse.Builder settledAmount(JsonField<Long> settledAmount)
Sets Builder.settledAmount to an arbitrary JSON value.
You should usually call Builder.settledAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final BookTransferResponse.Builder status(BookTransferResponse.TransactionStatus status)
The status of the transaction
-
status
final BookTransferResponse.Builder status(JsonField<BookTransferResponse.TransactionStatus> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed TransactionStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
toFinancialAccountToken
final BookTransferResponse.Builder toFinancialAccountToken(String toFinancialAccountToken)
Globally unique identifier for the financial account or card that will receive the funds. Accepted type dependent on the program's use case
-
toFinancialAccountToken
final BookTransferResponse.Builder toFinancialAccountToken(JsonField<String> toFinancialAccountToken)
Sets Builder.toFinancialAccountToken to an arbitrary JSON value.
You should usually call Builder.toFinancialAccountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updated
final BookTransferResponse.Builder updated(OffsetDateTime updated)
ISO 8601 timestamp of when the transaction was last updated
-
updated
final BookTransferResponse.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
externalId
final BookTransferResponse.Builder externalId(String externalId)
External ID defined by the customer
-
externalId
final BookTransferResponse.Builder externalId(Optional<String> externalId)
Alias for calling Builder.externalId with
externalId.orElse(null).
-
externalId
final BookTransferResponse.Builder externalId(JsonField<String> externalId)
Sets Builder.externalId to an arbitrary JSON value.
You should usually call Builder.externalId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
externalResource
final BookTransferResponse.Builder externalResource(ExternalResource externalResource)
External resource associated with the management operation
-
externalResource
final BookTransferResponse.Builder externalResource(Optional<ExternalResource> externalResource)
Alias for calling Builder.externalResource with
externalResource.orElse(null).
-
externalResource
final BookTransferResponse.Builder externalResource(JsonField<ExternalResource> externalResource)
Sets Builder.externalResource to an arbitrary JSON value.
You should usually call Builder.externalResource with a well-typed ExternalResource value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionSeries
final BookTransferResponse.Builder transactionSeries(BookTransferResponse.TransactionSeries transactionSeries)
A series of transactions that are grouped together
-
transactionSeries
final BookTransferResponse.Builder transactionSeries(Optional<BookTransferResponse.TransactionSeries> transactionSeries)
Alias for calling Builder.transactionSeries with
transactionSeries.orElse(null).
-
transactionSeries
final BookTransferResponse.Builder transactionSeries(JsonField<BookTransferResponse.TransactionSeries> transactionSeries)
Sets Builder.transactionSeries to an arbitrary JSON value.
You should usually call Builder.transactionSeries with a well-typed TransactionSeries value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final BookTransferResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BookTransferResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BookTransferResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BookTransferResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BookTransferResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BookTransferResponse build()
Returns an immutable instance of BookTransferResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .category() .created() .currency() .events() .family() .fromFinancialAccountToken() .pendingAmount() .result() .settledAmount() .status() .toFinancialAccountToken() .updated()
-
-
-
-