Class Card

  • All Implemented Interfaces:

    
    public final class Card
    
                        
    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
      public final class Card.Builder

      A builder for Card.

      public final class Card.FundingAccount

      Deprecated: Funding account for the card.

      public final class Card.PinStatus

      Indicates if a card is blocked due a PIN status issue (e.g. excessive incorrect attempts).

      public final class Card.State

      Card state values:

      • CLOSED - Card will no longer approve authorizations. Closing a card cannot be undone.

      • OPEN - Card will approve authorizations (if they match card and account parameters).

      • PAUSED - Card will decline authorizations, but can be resumed at a later time.

      • PENDING_FULFILLMENT - The initial state for cards of type PHYSICAL. The card is provisioned pending manufacturing and fulfillment. Cards in this state can accept authorizations for e-commerce purchases, but not for "Card Present" purchases where the physical card itself is present.

      • PENDING_ACTIVATION - At regular intervals, cards of type PHYSICAL in state PENDING_FULFILLMENT are sent to the card production warehouse and updated to state PENDING_ACTIVATION . Similar to PENDING_FULFILLMENT, cards in this state can be used for e-commerce transactions or can be added to mobile wallets. API clients should update the card's state to OPEN only after the cardholder confirms receipt of the card.

      In sandbox, the same daily batch fulfillment occurs, but no cards are actually manufactured.

      public final class Card.Type

      Card types:

      • VIRTUAL - Card will authorize at any merchant and can be added to a digital wallet like Apple Pay or Google Pay (if the card program is digital wallet-enabled).

      • PHYSICAL - Manufactured and sent to the cardholder. We offer white label branding, credit, ATM, PIN debit, chip/EMV, NFC and magstripe functionality. Reach out at lithic.com/contact for more information.

      • SINGLE_USE - Card is closed upon first successful authorization.

      • MERCHANT_LOCKED - Deprecated Card is locked to the first merchant that successfully authorizes the card.

      • UNLOCKED - Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.

      • DIGITAL_WALLET - Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.

    • Field Summary

      Fields 
      Modifier and Type Field Description
    • Constructor Summary

      Constructors 
      Constructor Description
    • Enum Constant Summary

      Enum Constants 
      Enum Constant Description
    • Constructor Detail

    • Method Detail

      • token

         final String token()

        Globally unique identifier.

      • accountToken

         final String accountToken()

        Globally unique identifier for the account to which the card belongs.

      • cardProgramToken

         final String cardProgramToken()

        Globally unique identifier for the card program on which the card exists.

      • created

         final OffsetDateTime created()

        An RFC 3339 timestamp for when the card was created. UTC time zone.

      • lastFour

         final String lastFour()

        Last four digits of the card number.

      • pinStatus

         final Card.PinStatus pinStatus()

        Indicates if a card is blocked due a PIN status issue (e.g. excessive incorrect attempts).

      • spendLimit

         final Long spendLimit()

        Amount (in cents) to limit approved authorizations (e.g. 100000 would be a $1,000 limit). Transaction requests above the spend limit will be declined.

      • spendLimitDuration

         final SpendLimitDuration spendLimitDuration()

        Spend limit duration values:

        • ANNUALLY - Card will authorize transactions up to spend limit for the trailing year.

        • FOREVER - Card will authorize only up to spend limit for the entire lifetime of the card.

        • MONTHLY - Card will authorize transactions up to spend limit for the trailing month. To support recurring monthly payments, which can occur on different day every month, the time window we consider for monthly velocity starts 6 days after the current calendar date one month prior.

        • TRANSACTION - Card will authorize multiple transactions if each individual transaction is under the spend limit.

      • state

         final Card.State state()

        Card state values:

        • CLOSED - Card will no longer approve authorizations. Closing a card cannot be undone.

        • OPEN - Card will approve authorizations (if they match card and account parameters).

        • PAUSED - Card will decline authorizations, but can be resumed at a later time.

        • PENDING_FULFILLMENT - The initial state for cards of type PHYSICAL. The card is provisioned pending manufacturing and fulfillment. Cards in this state can accept authorizations for e-commerce purchases, but not for "Card Present" purchases where the physical card itself is present.

        • PENDING_ACTIVATION - At regular intervals, cards of type PHYSICAL in state PENDING_FULFILLMENT are sent to the card production warehouse and updated to state PENDING_ACTIVATION . Similar to PENDING_FULFILLMENT, cards in this state can be used for e-commerce transactions or can be added to mobile wallets. API clients should update the card's state to OPEN only after the cardholder confirms receipt of the card.

        In sandbox, the same daily batch fulfillment occurs, but no cards are actually manufactured.

      • type

         final Card.Type type()

        Card types:

        • VIRTUAL - Card will authorize at any merchant and can be added to a digital wallet like Apple Pay or Google Pay (if the card program is digital wallet-enabled).

        • PHYSICAL - Manufactured and sent to the cardholder. We offer white label branding, credit, ATM, PIN debit, chip/EMV, NFC and magstripe functionality. Reach out at lithic.com/contact for more information.

        • SINGLE_USE - Card is closed upon first successful authorization.

        • MERCHANT_LOCKED - Deprecated Card is locked to the first merchant that successfully authorizes the card.

        • UNLOCKED - Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.

        • DIGITAL_WALLET - Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.

      • authRuleTokens

        @Deprecated(message = "deprecated") final Optional<List<String>> authRuleTokens()

        List of identifiers for the Auth Rule(s) that are applied on the card. This field is deprecated and will no longer be populated in the Card object. The key will be removed from the schema in a future release. Use the /auth_rules endpoints to fetch Auth Rule information instead.

      • hostname

         final Optional<String> hostname()

        Hostname of card’s locked merchant (will be empty if not applicable).

      • pan

         final Optional<String> pan()

        Primary Account Number (PAN) (i.e. the card number). Customers must be PCI compliant to have PAN returned as a field in production. Please contact [email protected] for questions.

      • pendingCommands

         final Optional<List<String>> pendingCommands()

        Indicates if there are offline PIN changes pending card interaction with an offline PIN terminal. Possible commands are: CHANGE_PIN, UNBLOCK_PIN. Applicable only to cards issued in markets supporting offline PINs.

      • productId

         final Optional<String> productId()

        Only applicable to cards of type PHYSICAL. This must be configured with Lithic before use. Specifies the configuration (i.e., physical card art) that the card should be manufactured with.

      • replacementFor

         final Optional<String> replacementFor()

        If the card is a replacement for another card, the globally unique identifier for the card that was replaced.

      • _token

         final JsonField<String> _token()

        Returns the raw JSON value of token.

        Unlike token, this method doesn't throw if the JSON field has an unexpected type.

      • _type

         final JsonField<Card.Type> _type()

        Returns the raw JSON value of type.

        Unlike type, this method doesn't throw if the JSON field has an unexpected type.

      • _cvv

         final JsonField<String> _cvv()

        Returns the raw JSON value of cvv.

        Unlike cvv, this method doesn't throw if the JSON field has an unexpected type.

      • _memo

         final JsonField<String> _memo()

        Returns the raw JSON value of memo.

        Unlike memo, this method doesn't throw if the JSON field has an unexpected type.

      • _pan

         final JsonField<String> _pan()

        Returns the raw JSON value of pan.

        Unlike pan, this method doesn't throw if the JSON field has an unexpected type.

      • builder

         final static Card.Builder builder()

        Returns a mutable builder for constructing an instance of Card.

        The following fields are required:

        .token()
        .accountToken()
        .cardProgramToken()
        .created()
        .funding()
        .lastFour()
        .pinStatus()
        .spendLimit()
        .spendLimitDuration()
        .state()
        .type()