Class Card.Builder
-
- All Implemented Interfaces:
public final class Card.BuilderA builder for Card.
-
-
Method Summary
Modifier and Type Method Description final Card.Buildertoken(String token)Globally unique identifier. final Card.Buildertoken(JsonField<String> token)Sets Builder.token to an arbitrary JSON value. final Card.BuilderaccountToken(String accountToken)Globally unique identifier for the account to which the card belongs. final Card.BuilderaccountToken(JsonField<String> accountToken)Sets Builder.accountToken to an arbitrary JSON value. final Card.BuildercardProgramToken(String cardProgramToken)Globally unique identifier for the card program on which the card exists. final Card.BuildercardProgramToken(JsonField<String> cardProgramToken)Sets Builder.cardProgramToken to an arbitrary JSON value. final Card.Buildercreated(OffsetDateTime created)An RFC 3339 timestamp for when the card was created. final Card.Buildercreated(JsonField<OffsetDateTime> created)Sets Builder.created to an arbitrary JSON value. final Card.Builderfunding(NonPciCard.FundingAccount funding)Deprecated: Funding account for the card. final Card.Builderfunding(JsonField<NonPciCard.FundingAccount> funding)Sets Builder.funding to an arbitrary JSON value. final Card.BuilderlastFour(String lastFour)Last four digits of the card number. final Card.BuilderlastFour(JsonField<String> lastFour)Sets Builder.lastFour to an arbitrary JSON value. final Card.BuilderpinStatus(NonPciCard.PinStatus pinStatus)Indicates if a card is blocked due a PIN status issue (e.g. final Card.BuilderpinStatus(JsonField<NonPciCard.PinStatus> pinStatus)Sets Builder.pinStatus to an arbitrary JSON value. final Card.BuilderspendLimit(Long spendLimit)Amount (in cents) to limit approved authorizations (e.g. final Card.BuilderspendLimit(JsonField<Long> spendLimit)Sets Builder.spendLimit to an arbitrary JSON value. final Card.BuilderspendLimitDuration(NonPciCard.SpendLimitDuration spendLimitDuration)Spend limit duration final Card.BuilderspendLimitDuration(JsonField<NonPciCard.SpendLimitDuration> spendLimitDuration)Sets Builder.spendLimitDuration to an arbitrary JSON value. final Card.Builderstate(NonPciCard.State state)Card state values: _ CLOSED- Card will no longer approve authorizations.final Card.Builderstate(JsonField<NonPciCard.State> state)Sets Builder.state to an arbitrary JSON value. final Card.Buildertype(NonPciCard.Type type)Card types: _ VIRTUAL- Card will authorize at any merchant and can be added to a digital wallet like Apple Pay or Google Pay (if the card program is digital wallet-enabled).final Card.Buildertype(JsonField<NonPciCard.Type> type)Sets Builder.type to an arbitrary JSON value. final Card.BuilderauthRuleTokens(List<String> authRuleTokens)List of identifiers for the Auth Rule(s) that are applied on the card. final Card.BuilderauthRuleTokens(JsonField<List<String>> authRuleTokens)Sets Builder.authRuleTokens to an arbitrary JSON value. final Card.BuilderaddAuthRuleToken(String authRuleToken)Adds a single String to authRuleTokens. final Card.BuildercardholderCurrency(String cardholderCurrency)3-character alphabetic ISO 4217 code for the currency of the cardholder. final Card.BuildercardholderCurrency(JsonField<String> cardholderCurrency)Sets Builder.cardholderCurrency to an arbitrary JSON value. final Card.BuilderdigitalCardArtToken(String digitalCardArtToken)Specifies the digital card art to be displayed in the user's digital wallet after tokenization. final Card.BuilderdigitalCardArtToken(JsonField<String> digitalCardArtToken)Sets Builder.digitalCardArtToken to an arbitrary JSON value. final Card.BuilderexpMonth(String expMonth)Two digit (MM) expiry month. final Card.BuilderexpMonth(JsonField<String> expMonth)Sets Builder.expMonth to an arbitrary JSON value. final Card.BuilderexpYear(String expYear)Four digit (yyyy) expiry year. final Card.BuilderexpYear(JsonField<String> expYear)Sets Builder.expYear to an arbitrary JSON value. final Card.Builderhostname(String hostname)Hostname of card's locked merchant (will be empty if not applicable). final Card.Builderhostname(JsonField<String> hostname)Sets Builder.hostname to an arbitrary JSON value. final Card.Buildermemo(String memo)Friendly name to identify the card. final Card.Buildermemo(JsonField<String> memo)Sets Builder.memo to an arbitrary JSON value. final Card.BuilderpendingCommands(List<String> pendingCommands)Indicates if there are offline PIN changes pending card interaction with an offline PIN terminal. final Card.BuilderpendingCommands(JsonField<List<String>> pendingCommands)Sets Builder.pendingCommands to an arbitrary JSON value. final Card.BuilderaddPendingCommand(String pendingCommand)Adds a single String to pendingCommands. final Card.BuilderproductId(String productId)Only applicable to cards of type PHYSICAL.final Card.BuilderproductId(JsonField<String> productId)Sets Builder.productId to an arbitrary JSON value. final Card.BuilderreplacementFor(String replacementFor)If the card is a replacement for another card, the globally unique identifier for the card that was replaced. final Card.BuilderreplacementFor(Optional<String> replacementFor)Alias for calling Builder.replacementFor with replacementFor.orElse(null).final Card.BuilderreplacementFor(JsonField<String> replacementFor)Sets Builder.replacementFor to an arbitrary JSON value. final Card.Buildercvv(String cvv)Three digit cvv printed on the back of the card. final Card.Buildercvv(JsonField<String> cvv)Sets Builder.cvv to an arbitrary JSON value. final Card.Builderpan(String pan)Primary Account Number (PAN) (i.e. final Card.Builderpan(JsonField<String> pan)Sets Builder.pan to an arbitrary JSON value. final Card.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Card.BuilderputAdditionalProperty(String key, JsonValue value)final Card.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Card.BuilderremoveAdditionalProperty(String key)final Card.BuilderremoveAllAdditionalProperties(Set<String> keys)final Cardbuild()Returns an immutable instance of Card. -
-
Method Detail
-
token
final Card.Builder token(String token)
Globally unique identifier.
-
token
final Card.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountToken
final Card.Builder accountToken(String accountToken)
Globally unique identifier for the account to which the card belongs.
-
accountToken
final Card.Builder accountToken(JsonField<String> accountToken)
Sets Builder.accountToken to an arbitrary JSON value.
You should usually call Builder.accountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardProgramToken
final Card.Builder cardProgramToken(String cardProgramToken)
Globally unique identifier for the card program on which the card exists.
-
cardProgramToken
final Card.Builder cardProgramToken(JsonField<String> cardProgramToken)
Sets Builder.cardProgramToken to an arbitrary JSON value.
You should usually call Builder.cardProgramToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final Card.Builder created(OffsetDateTime created)
An RFC 3339 timestamp for when the card was created. UTC time zone.
-
created
final Card.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
funding
final Card.Builder funding(NonPciCard.FundingAccount funding)
Deprecated: Funding account for the card.
-
funding
final Card.Builder funding(JsonField<NonPciCard.FundingAccount> funding)
Sets Builder.funding to an arbitrary JSON value.
You should usually call Builder.funding with a well-typed NonPciCard.FundingAccount value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastFour
final Card.Builder lastFour(String lastFour)
Last four digits of the card number.
-
lastFour
final Card.Builder lastFour(JsonField<String> lastFour)
Sets Builder.lastFour to an arbitrary JSON value.
You should usually call Builder.lastFour with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pinStatus
final Card.Builder pinStatus(NonPciCard.PinStatus pinStatus)
Indicates if a card is blocked due a PIN status issue (e.g. excessive incorrect attempts).
-
pinStatus
final Card.Builder pinStatus(JsonField<NonPciCard.PinStatus> pinStatus)
Sets Builder.pinStatus to an arbitrary JSON value.
You should usually call Builder.pinStatus with a well-typed NonPciCard.PinStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
spendLimit
final Card.Builder spendLimit(Long spendLimit)
Amount (in cents) to limit approved authorizations (e.g. 100000 would be a $1,000 limit). Transaction requests above the spend limit will be declined.
-
spendLimit
final Card.Builder spendLimit(JsonField<Long> spendLimit)
Sets Builder.spendLimit to an arbitrary JSON value.
You should usually call Builder.spendLimit with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
spendLimitDuration
final Card.Builder spendLimitDuration(NonPciCard.SpendLimitDuration spendLimitDuration)
Spend limit duration
-
spendLimitDuration
final Card.Builder spendLimitDuration(JsonField<NonPciCard.SpendLimitDuration> spendLimitDuration)
Sets Builder.spendLimitDuration to an arbitrary JSON value.
You should usually call Builder.spendLimitDuration with a well-typed NonPciCard.SpendLimitDuration value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
state
final Card.Builder state(NonPciCard.State state)
Card state values: _
CLOSED- Card will no longer approve authorizations. Closing a card cannot be undone. _OPEN- Card will approve authorizations (if they match card and account parameters). _PAUSED- Card will decline authorizations, but can be resumed at a later time. _PENDING_FULFILLMENT- The initial state for cards of typePHYSICAL. The card is provisioned pending manufacturing and fulfillment. Cards in this state can accept authorizations for e-commerce purchases, but not for "Card Present" purchases where the physical card itself is present. \*PENDING_ACTIVATION- At regular intervals, cards of typePHYSICALin statePENDING_FULFILLMENTare sent to the card production warehouse and updated to statePENDING_ACTIVATION. Similar toPENDING_FULFILLMENT, cards in this state can be used for e-commerce transactions or can be added to mobile wallets. API clients should update the card's state toOPENonly after the cardholder confirms receipt of the card. In sandbox, the same daily batch fulfillment occurs, but no cards are actually manufactured.
-
state
final Card.Builder state(JsonField<NonPciCard.State> state)
Sets Builder.state to an arbitrary JSON value.
You should usually call Builder.state with a well-typed NonPciCard.State value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final Card.Builder type(NonPciCard.Type type)
Card types: _
VIRTUAL- Card will authorize at any merchant and can be added to a digital wallet like Apple Pay or Google Pay (if the card program is digital wallet-enabled). _PHYSICAL- Manufactured and sent to the cardholder. We offer white label branding, credit, ATM, PIN debit, chip/EMV, NFC and magstripe functionality. _SINGLE_USE- Card is closed upon first successful authorization. _MERCHANT_LOCKED- Deprecated Card is locked to the first merchant that successfully authorizes the card. _UNLOCKED- Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead. _DIGITAL_WALLET- Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.
-
type
final Card.Builder type(JsonField<NonPciCard.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed NonPciCard.Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
authRuleTokens
@Deprecated(message = "deprecated") final Card.Builder authRuleTokens(List<String> authRuleTokens)
List of identifiers for the Auth Rule(s) that are applied on the card. This field is deprecated and will no longer be populated in the
Cardobject. The key will be removed from the schema in a future release. Use the/auth_rulesendpoints to fetch Auth Rule information instead.
-
authRuleTokens
@Deprecated(message = "deprecated") final Card.Builder authRuleTokens(JsonField<List<String>> authRuleTokens)
Sets Builder.authRuleTokens to an arbitrary JSON value.
You should usually call Builder.authRuleTokens with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addAuthRuleToken
@Deprecated(message = "deprecated") final Card.Builder addAuthRuleToken(String authRuleToken)
Adds a single String to authRuleTokens.
-
cardholderCurrency
final Card.Builder cardholderCurrency(String cardholderCurrency)
3-character alphabetic ISO 4217 code for the currency of the cardholder.
-
cardholderCurrency
final Card.Builder cardholderCurrency(JsonField<String> cardholderCurrency)
Sets Builder.cardholderCurrency to an arbitrary JSON value.
You should usually call Builder.cardholderCurrency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
digitalCardArtToken
final Card.Builder digitalCardArtToken(String digitalCardArtToken)
Specifies the digital card art to be displayed in the user's digital wallet after tokenization. This artwork must be approved by Mastercard and configured by Lithic to use.
-
digitalCardArtToken
final Card.Builder digitalCardArtToken(JsonField<String> digitalCardArtToken)
Sets Builder.digitalCardArtToken to an arbitrary JSON value.
You should usually call Builder.digitalCardArtToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
expMonth
final Card.Builder expMonth(String expMonth)
Two digit (MM) expiry month.
-
expMonth
final Card.Builder expMonth(JsonField<String> expMonth)
Sets Builder.expMonth to an arbitrary JSON value.
You should usually call Builder.expMonth with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
expYear
final Card.Builder expYear(String expYear)
Four digit (yyyy) expiry year.
-
expYear
final Card.Builder expYear(JsonField<String> expYear)
Sets Builder.expYear to an arbitrary JSON value.
You should usually call Builder.expYear with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
hostname
final Card.Builder hostname(String hostname)
Hostname of card's locked merchant (will be empty if not applicable).
-
hostname
final Card.Builder hostname(JsonField<String> hostname)
Sets Builder.hostname to an arbitrary JSON value.
You should usually call Builder.hostname with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
memo
final Card.Builder memo(String memo)
Friendly name to identify the card.
-
memo
final Card.Builder memo(JsonField<String> memo)
Sets Builder.memo to an arbitrary JSON value.
You should usually call Builder.memo with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pendingCommands
final Card.Builder pendingCommands(List<String> pendingCommands)
Indicates if there are offline PIN changes pending card interaction with an offline PIN terminal. Possible commands are: CHANGE_PIN, UNBLOCK_PIN. Applicable only to cards issued in markets supporting offline PINs.
-
pendingCommands
final Card.Builder pendingCommands(JsonField<List<String>> pendingCommands)
Sets Builder.pendingCommands to an arbitrary JSON value.
You should usually call Builder.pendingCommands with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addPendingCommand
final Card.Builder addPendingCommand(String pendingCommand)
Adds a single String to pendingCommands.
-
productId
final Card.Builder productId(String productId)
Only applicable to cards of type
PHYSICAL. This must be configured with Lithic before use. Specifies the configuration (i.e., physical card art) that the card should be manufactured with.
-
productId
final Card.Builder productId(JsonField<String> productId)
Sets Builder.productId to an arbitrary JSON value.
You should usually call Builder.productId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
replacementFor
final Card.Builder replacementFor(String replacementFor)
If the card is a replacement for another card, the globally unique identifier for the card that was replaced.
-
replacementFor
final Card.Builder replacementFor(Optional<String> replacementFor)
Alias for calling Builder.replacementFor with
replacementFor.orElse(null).
-
replacementFor
final Card.Builder replacementFor(JsonField<String> replacementFor)
Sets Builder.replacementFor to an arbitrary JSON value.
You should usually call Builder.replacementFor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cvv
final Card.Builder cvv(String cvv)
Three digit cvv printed on the back of the card.
-
cvv
final Card.Builder cvv(JsonField<String> cvv)
Sets Builder.cvv to an arbitrary JSON value.
You should usually call Builder.cvv with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pan
final Card.Builder pan(String pan)
Primary Account Number (PAN) (i.e. the card number). Customers must be PCI compliant to have PAN returned as a field in production. Please contact [email protected] for questions.
-
pan
final Card.Builder pan(JsonField<String> pan)
Sets Builder.pan to an arbitrary JSON value.
You should usually call Builder.pan with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Card.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Card.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Card.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Card.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Card.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Card build()
Returns an immutable instance of Card.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .accountToken() .cardProgramToken() .created() .funding() .lastFour() .pinStatus() .spendLimit() .spendLimitDuration() .state() .type()
-
-
-
-