Package com.lithic.api.models
Class CardAggregateBalanceListPage
-
- All Implemented Interfaces:
public final class CardAggregateBalanceListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAggregateBalanceListPage.BuilderA builder for CardAggregateBalanceListPage.
public final classCardAggregateBalanceListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<AggregateBalanceListResponse>data()Delegates to CardAggregateBalanceListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to CardAggregateBalanceListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<CardAggregateBalanceListParams>getNextPageParams()final Optional<CardAggregateBalanceListPage>getNextPage()final CardAggregateBalanceListPage.AutoPagerautoPager()final CardAggregateBalanceListParamsparams()The parameters that were used to request this page. final CardAggregateBalanceListPageResponseresponse()The response that this page was parsed from. final CardAggregateBalanceListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardAggregateBalanceListPage.Builderbuilder()Returns a mutable builder for constructing an instance of CardAggregateBalanceListPage. -
-
Method Detail
-
data
final List<AggregateBalanceListResponse> data()
Delegates to CardAggregateBalanceListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to CardAggregateBalanceListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<CardAggregateBalanceListParams> getNextPageParams()
-
getNextPage
final Optional<CardAggregateBalanceListPage> getNextPage()
-
autoPager
final CardAggregateBalanceListPage.AutoPager autoPager()
-
params
final CardAggregateBalanceListParams params()
The parameters that were used to request this page.
-
response
final CardAggregateBalanceListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final CardAggregateBalanceListPage.Builder toBuilder()
-
builder
final static CardAggregateBalanceListPage.Builder builder()
Returns a mutable builder for constructing an instance of CardAggregateBalanceListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-