Package com.lithic.api.models
Class CardAggregateBalanceListPageAsync
-
- All Implemented Interfaces:
public final class CardAggregateBalanceListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAggregateBalanceListPageAsync.BuilderA builder for CardAggregateBalanceListPageAsync.
public final classCardAggregateBalanceListPageAsync.AutoPager
-
Method Summary
-
-
Method Detail
-
data
final List<AggregateBalanceListResponse> data()
Delegates to CardAggregateBalanceListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to CardAggregateBalanceListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<CardAggregateBalanceListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<CardAggregateBalanceListPageAsync>> getNextPage()
-
autoPager
final CardAggregateBalanceListPageAsync.AutoPager autoPager()
-
params
final CardAggregateBalanceListParams params()
The parameters that were used to request this page.
-
response
final CardAggregateBalanceListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final CardAggregateBalanceListPageAsync.Builder toBuilder()
-
builder
final static CardAggregateBalanceListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of CardAggregateBalanceListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-