Package com.lithic.api.models
Class CardAggregateBalanceListPageAsync.Builder
-
- All Implemented Interfaces:
public final class CardAggregateBalanceListPageAsync.BuilderA builder for CardAggregateBalanceListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final CardAggregateBalanceListPageAsync.Builderservice(AggregateBalanceServiceAsync service)final CardAggregateBalanceListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final CardAggregateBalanceListPageAsync.Builderparams(CardAggregateBalanceListParams params)The parameters that were used to request this page. final CardAggregateBalanceListPageAsync.Builderresponse(CardAggregateBalanceListPageResponse response)The response that this page was parsed from. final CardAggregateBalanceListPageAsyncbuild()Returns an immutable instance of CardAggregateBalanceListPageAsync. -
-
Method Detail
-
service
final CardAggregateBalanceListPageAsync.Builder service(AggregateBalanceServiceAsync service)
-
streamHandlerExecutor
final CardAggregateBalanceListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final CardAggregateBalanceListPageAsync.Builder params(CardAggregateBalanceListParams params)
The parameters that were used to request this page.
-
response
final CardAggregateBalanceListPageAsync.Builder response(CardAggregateBalanceListPageResponse response)
The response that this page was parsed from.
-
build
final CardAggregateBalanceListPageAsync build()
Returns an immutable instance of CardAggregateBalanceListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-