Package com.lithic.api.models
Class CardAggregateBalanceListPageAsync.Response
-
- All Implemented Interfaces:
public final class CardAggregateBalanceListPageAsync.Response
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAggregateBalanceListPageAsync.Response.Builder
-
Constructor Summary
Constructors Constructor Description CardAggregateBalanceListPageAsync.Response(JsonField<List<AggregateBalanceListResponse>> data, JsonField<Boolean> hasMore, Map<String, JsonValue> additionalProperties)
-
Method Summary
Modifier and Type Method Description final List<AggregateBalanceListResponse>data()final BooleanhasMore()final Optional<JsonField<List<AggregateBalanceListResponse>>>_data()final Optional<JsonField<Boolean>>_hasMore()final Map<String, JsonValue>_additionalProperties()final CardAggregateBalanceListPageAsync.Responsevalidate()final CardAggregateBalanceListPageAsync.Response.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardAggregateBalanceListPageAsync.Response.Builderbuilder()Returns a mutable builder for constructing an instance of CardAggregateBalanceListPageAsync. -
-
Method Detail
-
data
final List<AggregateBalanceListResponse> data()
-
_data
final Optional<JsonField<List<AggregateBalanceListResponse>>> _data()
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CardAggregateBalanceListPageAsync.Response validate()
-
toBuilder
final CardAggregateBalanceListPageAsync.Response.Builder toBuilder()
-
builder
final static CardAggregateBalanceListPageAsync.Response.Builder builder()
Returns a mutable builder for constructing an instance of CardAggregateBalanceListPageAsync.
-
-
-
-