Class CardAggregateBalanceListPageResponse.Builder
-
- All Implemented Interfaces:
public final class CardAggregateBalanceListPageResponse.BuilderA builder for CardAggregateBalanceListPageResponse.
-
-
Method Summary
-
-
Method Detail
-
data
final CardAggregateBalanceListPageResponse.Builder data(List<AggregateBalanceListResponse> data)
-
data
final CardAggregateBalanceListPageResponse.Builder data(JsonField<List<AggregateBalanceListResponse>> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed
List<AggregateBalanceListResponse>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addData
final CardAggregateBalanceListPageResponse.Builder addData(AggregateBalanceListResponse data)
Adds a single AggregateBalanceListResponse to Builder.data.
-
hasMore
final CardAggregateBalanceListPageResponse.Builder hasMore(Boolean hasMore)
More data exists.
-
hasMore
final CardAggregateBalanceListPageResponse.Builder hasMore(JsonField<Boolean> hasMore)
Sets Builder.hasMore to an arbitrary JSON value.
You should usually call Builder.hasMore with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardAggregateBalanceListPageResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardAggregateBalanceListPageResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardAggregateBalanceListPageResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardAggregateBalanceListPageResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardAggregateBalanceListPageResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardAggregateBalanceListPageResponse build()
Returns an immutable instance of CardAggregateBalanceListPageResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.data() .hasMore()
-
-
-
-