Package com.lithic.api.models
Class CardAuthorization.Amounts.Amount
-
- All Implemented Interfaces:
public final class CardAuthorization.Amounts.Amount
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorization.Amounts.Amount.BuilderA builder for Amount.
-
Method Summary
Modifier and Type Method Description final Longamount()Amount in the smallest unit of the applicable currency (e.g. final Stringcurrency()3-character alphabetic ISO 4217 currency final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_currency()Returns the raw JSON value of currency. final Map<String, JsonValue>_additionalProperties()final CardAuthorization.Amounts.Amount.BuildertoBuilder()final CardAuthorization.Amounts.Amountvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardAuthorization.Amounts.Amount.Builderbuilder()Returns a mutable builder for constructing an instance of Amount. -
-
Method Detail
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardAuthorization.Amounts.Amount.Builder toBuilder()
-
validate
final CardAuthorization.Amounts.Amount validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardAuthorization.Amounts.Amount.Builder builder()
Returns a mutable builder for constructing an instance of Amount.
The following fields are required:
.amount() .currency()
-
-
-
-