Class CardAuthorization.AsaRequestFleetInfo.FleetPromptCode

  • All Implemented Interfaces:
    com.lithic.api.core.Enum

    
    public final class CardAuthorization.AsaRequestFleetInfo.FleetPromptCode
     implements Enum
                        

    Code indicating what the driver was prompted to enter at time of purchase. This is configured at a program level and is a static configuration, and does not change on a request to request basis