Package com.lithic.api.models
Class CardAuthorization.NameValidation.NameValidationResult
-
- All Implemented Interfaces:
public final class CardAuthorization.NameValidation.NameValidationResultLithic's computed match result comparing the network-provided name to the name on file.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorization.NameValidation.NameValidationResult.BuilderA builder for NameValidationResult.
public final classCardAuthorization.NameValidation.NameValidationResult.FullNameOverall name match result.
-
Method Summary
Modifier and Type Method Description final CardAuthorization.NameValidation.NameValidationResult.FullNamefullName()Overall name match result. final JsonField<CardAuthorization.NameValidation.NameValidationResult.FullName>_fullName()Returns the raw JSON value of fullName. final Map<String, JsonValue>_additionalProperties()final CardAuthorization.NameValidation.NameValidationResult.BuildertoBuilder()final CardAuthorization.NameValidation.NameValidationResultvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardAuthorization.NameValidation.NameValidationResult.Builderbuilder()Returns a mutable builder for constructing an instance of NameValidationResult. -
-
Method Detail
-
fullName
final CardAuthorization.NameValidation.NameValidationResult.FullName fullName()
Overall name match result.
-
_fullName
final JsonField<CardAuthorization.NameValidation.NameValidationResult.FullName> _fullName()
Returns the raw JSON value of fullName.
Unlike fullName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardAuthorization.NameValidation.NameValidationResult.Builder toBuilder()
-
validate
final CardAuthorization.NameValidation.NameValidationResult validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardAuthorization.NameValidation.NameValidationResult.Builder builder()
Returns a mutable builder for constructing an instance of NameValidationResult.
The following fields are required:
.fullName()
-
-
-
-