Class CardAuthorizationApprovalRequestWebhookEvent.Amounts.Builder
-
- All Implemented Interfaces:
public final class CardAuthorizationApprovalRequestWebhookEvent.Amounts.BuilderA builder for Amounts.
-
-
Method Summary
-
-
Method Detail
-
cardholder
final CardAuthorizationApprovalRequestWebhookEvent.Amounts.Builder cardholder(CardAuthorizationApprovalRequestWebhookEvent.Amounts.ConvertedAmount cardholder)
-
cardholder
final CardAuthorizationApprovalRequestWebhookEvent.Amounts.Builder cardholder(JsonField<CardAuthorizationApprovalRequestWebhookEvent.Amounts.ConvertedAmount> cardholder)
Sets Builder.cardholder to an arbitrary JSON value.
You should usually call Builder.cardholder with a well-typed ConvertedAmount value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
hold
final CardAuthorizationApprovalRequestWebhookEvent.Amounts.Builder hold(CardAuthorizationApprovalRequestWebhookEvent.Amounts.Amount hold)
-
hold
final CardAuthorizationApprovalRequestWebhookEvent.Amounts.Builder hold(Optional<CardAuthorizationApprovalRequestWebhookEvent.Amounts.Amount> hold)
Alias for calling Builder.hold with
hold.orElse(null).
-
hold
final CardAuthorizationApprovalRequestWebhookEvent.Amounts.Builder hold(JsonField<CardAuthorizationApprovalRequestWebhookEvent.Amounts.Amount> hold)
Sets Builder.hold to an arbitrary JSON value.
You should usually call Builder.hold with a well-typed Amount value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchant
final CardAuthorizationApprovalRequestWebhookEvent.Amounts.Builder merchant(CardAuthorizationApprovalRequestWebhookEvent.Amounts.Amount merchant)
-
merchant
final CardAuthorizationApprovalRequestWebhookEvent.Amounts.Builder merchant(JsonField<CardAuthorizationApprovalRequestWebhookEvent.Amounts.Amount> merchant)
Sets Builder.merchant to an arbitrary JSON value.
You should usually call Builder.merchant with a well-typed Amount value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
settlement
final CardAuthorizationApprovalRequestWebhookEvent.Amounts.Builder settlement(CardAuthorizationApprovalRequestWebhookEvent.Amounts.Amount settlement)
-
settlement
final CardAuthorizationApprovalRequestWebhookEvent.Amounts.Builder settlement(Optional<CardAuthorizationApprovalRequestWebhookEvent.Amounts.Amount> settlement)
Alias for calling Builder.settlement with
settlement.orElse(null).
-
settlement
final CardAuthorizationApprovalRequestWebhookEvent.Amounts.Builder settlement(JsonField<CardAuthorizationApprovalRequestWebhookEvent.Amounts.Amount> settlement)
Sets Builder.settlement to an arbitrary JSON value.
You should usually call Builder.settlement with a well-typed Amount value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardAuthorizationApprovalRequestWebhookEvent.Amounts.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardAuthorizationApprovalRequestWebhookEvent.Amounts.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardAuthorizationApprovalRequestWebhookEvent.Amounts.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardAuthorizationApprovalRequestWebhookEvent.Amounts.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardAuthorizationApprovalRequestWebhookEvent.Amounts.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardAuthorizationApprovalRequestWebhookEvent.Amounts build()
Returns an immutable instance of Amounts.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.cardholder() .hold() .merchant() .settlement()
-
-
-
-