Class CardAuthorizationApprovalRequestWebhookEvent.AsaNetworkSpecificData

  • All Implemented Interfaces:

    
    public final class CardAuthorizationApprovalRequestWebhookEvent.AsaNetworkSpecificData
    
                        

    Contains raw data provided by the card network, including attributes that provide further context about the authorization. If populated by the network, data is organized by Lithic and passed through without further modification. Please consult the official network documentation for more details about these values and how to use them. This object is only available to certain programs- contact your Customer Success Manager to discuss enabling access.