Class CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard
-
- All Implemented Interfaces:
public final class CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCardCard object in ASA
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.BuilderA builder for AsaRequestCard.
public final classCardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.SpendLimitDurationNote that to support recurring monthly payments, which can occur on different day every month, the time window we consider for MONTHLY velocity starts 6 days after the current calendar date one month prior.
public final classCardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.Statepublic final classCardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.CardType
-
Method Summary
-
-
Method Detail
-
hostname
final Optional<String> hostname()
Hostname of card’s locked merchant (will be empty if not applicable)
-
memo
final Optional<String> memo()
Customizable name to identify the card. We recommend against using this field to store JSON data as it can cause unexpected behavior.
-
spendLimit
final Optional<Long> spendLimit()
Amount (in cents) to limit approved authorizations. Purchase requests above the spend limit will be declined (refunds and credits will be approved).
Note that while spend limits are enforced based on authorized and settled volume on a card, they are not recommended to be used for balance or reconciliation-level accuracy. Spend limits also cannot block force posted charges (i.e., when a merchant sends a clearing message without a prior authorization).
-
spendLimitDuration
final Optional<CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.SpendLimitDuration> spendLimitDuration()
Note that to support recurring monthly payments, which can occur on different day every month, the time window we consider for MONTHLY velocity starts 6 days after the current calendar date one month prior.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_hostname
final JsonField<String> _hostname()
Returns the raw JSON value of hostname.
Unlike hostname, this method doesn't throw if the JSON field has an unexpected type.
-
_lastFour
final JsonField<String> _lastFour()
Returns the raw JSON value of lastFour.
Unlike lastFour, this method doesn't throw if the JSON field has an unexpected type.
-
_memo
final JsonField<String> _memo()
Returns the raw JSON value of memo.
Unlike memo, this method doesn't throw if the JSON field has an unexpected type.
-
_spendLimit
final JsonField<Long> _spendLimit()
Returns the raw JSON value of spendLimit.
Unlike spendLimit, this method doesn't throw if the JSON field has an unexpected type.
-
_spendLimitDuration
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.SpendLimitDuration> _spendLimitDuration()
Returns the raw JSON value of spendLimitDuration.
Unlike spendLimitDuration, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.State> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.CardType> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.Builder toBuilder()
-
validate
final CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard validate()
-
builder
final static CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.Builder builder()
Returns a mutable builder for constructing an instance of AsaRequestCard.
-
-
-
-