Class CardAuthorizationApprovalRequestWebhookEvent.Avs.Builder
-
- All Implemented Interfaces:
public final class CardAuthorizationApprovalRequestWebhookEvent.Avs.BuilderA builder for Avs.
-
-
Method Summary
-
-
Method Detail
-
address
final CardAuthorizationApprovalRequestWebhookEvent.Avs.Builder address(String address)
Cardholder address
-
address
final CardAuthorizationApprovalRequestWebhookEvent.Avs.Builder address(JsonField<String> address)
Sets Builder.address to an arbitrary JSON value.
You should usually call Builder.address with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addressOnFileMatch
final CardAuthorizationApprovalRequestWebhookEvent.Avs.Builder addressOnFileMatch(CardAuthorizationApprovalRequestWebhookEvent.Avs.AddressMatchResult addressOnFileMatch)
Lithic's evaluation result comparing the transaction's address data with the cardholder KYC data if it exists. In the event Lithic does not have any Cardholder KYC data, or the transaction does not contain any address data, NOT_PRESENT will be returned
-
addressOnFileMatch
final CardAuthorizationApprovalRequestWebhookEvent.Avs.Builder addressOnFileMatch(JsonField<CardAuthorizationApprovalRequestWebhookEvent.Avs.AddressMatchResult> addressOnFileMatch)
Sets Builder.addressOnFileMatch to an arbitrary JSON value.
You should usually call Builder.addressOnFileMatch with a well-typed AddressMatchResult value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
zipcode
final CardAuthorizationApprovalRequestWebhookEvent.Avs.Builder zipcode(String zipcode)
Cardholder ZIP code
-
zipcode
final CardAuthorizationApprovalRequestWebhookEvent.Avs.Builder zipcode(JsonField<String> zipcode)
Sets Builder.zipcode to an arbitrary JSON value.
You should usually call Builder.zipcode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardAuthorizationApprovalRequestWebhookEvent.Avs.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardAuthorizationApprovalRequestWebhookEvent.Avs.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardAuthorizationApprovalRequestWebhookEvent.Avs.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardAuthorizationApprovalRequestWebhookEvent.Avs.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardAuthorizationApprovalRequestWebhookEvent.Avs.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardAuthorizationApprovalRequestWebhookEvent.Avs build()
Returns an immutable instance of Avs.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.address() .addressOnFileMatch() .zipcode()
-
-
-
-