Package com.lithic.api.models
Class CardAuthorizationApprovalRequestWebhookEvent.Pos
-
- All Implemented Interfaces:
public final class CardAuthorizationApprovalRequestWebhookEvent.Pos
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorizationApprovalRequestWebhookEvent.Pos.BuilderA builder for Pos.
public final classCardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryModePOS Entry Mode object in ASA
public final classCardAuthorizationApprovalRequestWebhookEvent.Pos.AsaPosTerminal
-
Method Summary
-
-
Method Detail
-
entryMode
final Optional<CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode> entryMode()
POS Entry Mode object in ASA
-
terminal
final Optional<CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaPosTerminal> terminal()
-
_entryMode
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode> _entryMode()
Returns the raw JSON value of entryMode.
Unlike entryMode, this method doesn't throw if the JSON field has an unexpected type.
-
_terminal
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaPosTerminal> _terminal()
Returns the raw JSON value of terminal.
Unlike terminal, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardAuthorizationApprovalRequestWebhookEvent.Pos.Builder toBuilder()
-
validate
final CardAuthorizationApprovalRequestWebhookEvent.Pos validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardAuthorizationApprovalRequestWebhookEvent.Pos.Builder builder()
Returns a mutable builder for constructing an instance of Pos.
-
-
-
-