Class CardAuthorizationChallengeResponseParams

  • All Implemented Interfaces:
    com.lithic.api.core.Params

    
    public final class CardAuthorizationChallengeResponseParams
     implements Params
                        

    Card program's response to Authorization Challenge. Programs that have Authorization Challenges configured as Out of Band receive a card_authorization.challenge webhook when an authorization attempt triggers a challenge. The card program should respond using this endpoint after the cardholder completes the challenge.