Package com.lithic.api.models
Class CardAuthorizationChallengeResponseParams.Body
-
- All Implemented Interfaces:
public final class CardAuthorizationChallengeResponseParams.BodyCard program's response to Authorization Challenge
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorizationChallengeResponseParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final CardAuthorizationChallengeResponseParams.Responseresponse()Whether the cardholder has approved or declined the issued challenge final JsonField<CardAuthorizationChallengeResponseParams.Response>_response()Returns the raw JSON value of response. final Map<String, JsonValue>_additionalProperties()final CardAuthorizationChallengeResponseParams.Body.BuildertoBuilder()final CardAuthorizationChallengeResponseParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardAuthorizationChallengeResponseParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
response
final CardAuthorizationChallengeResponseParams.Response response()
Whether the cardholder has approved or declined the issued challenge
-
_response
final JsonField<CardAuthorizationChallengeResponseParams.Response> _response()
Returns the raw JSON value of response.
Unlike response, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardAuthorizationChallengeResponseParams.Body.Builder toBuilder()
-
validate
final CardAuthorizationChallengeResponseParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardAuthorizationChallengeResponseParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.response()
-
-
-
-