Class CardAuthorizationChallengeResponseWebhookEvent
-
- All Implemented Interfaces:
public final class CardAuthorizationChallengeResponseWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorizationChallengeResponseWebhookEvent.BuilderA builder for CardAuthorizationChallengeResponseWebhookEvent.
public final classCardAuthorizationChallengeResponseWebhookEvent.ChallengeMethodThe method used to deliver the challenge to the cardholder
public final classCardAuthorizationChallengeResponseWebhookEvent.EventTypeEvent type
public final classCardAuthorizationChallengeResponseWebhookEvent.ResponseThe cardholder's response to the challenge
-
Method Summary
-
-
Method Detail
-
challengeMethod
final CardAuthorizationChallengeResponseWebhookEvent.ChallengeMethod challengeMethod()
The method used to deliver the challenge to the cardholder
-
completed
final Optional<OffsetDateTime> completed()
The timestamp of when the challenge was completed
-
created
final OffsetDateTime created()
The timestamp of when the challenge was created
-
eventToken
final String eventToken()
Globally unique identifier for the event
-
eventType
final CardAuthorizationChallengeResponseWebhookEvent.EventType eventType()
Event type
-
response
final CardAuthorizationChallengeResponseWebhookEvent.Response response()
The cardholder's response to the challenge
-
transactionToken
final Optional<String> transactionToken()
The token of the transaction associated with the authorization event being challenged
-
_cardToken
final JsonField<String> _cardToken()
Returns the raw JSON value of cardToken.
Unlike cardToken, this method doesn't throw if the JSON field has an unexpected type.
-
_challengeMethod
final JsonField<CardAuthorizationChallengeResponseWebhookEvent.ChallengeMethod> _challengeMethod()
Returns the raw JSON value of challengeMethod.
Unlike challengeMethod, this method doesn't throw if the JSON field has an unexpected type.
-
_completed
final JsonField<OffsetDateTime> _completed()
Returns the raw JSON value of completed.
Unlike completed, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_eventToken
final JsonField<String> _eventToken()
Returns the raw JSON value of eventToken.
Unlike eventToken, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<CardAuthorizationChallengeResponseWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_response
final JsonField<CardAuthorizationChallengeResponseWebhookEvent.Response> _response()
Returns the raw JSON value of response.
Unlike response, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionToken
final JsonField<String> _transactionToken()
Returns the raw JSON value of transactionToken.
Unlike transactionToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardAuthorizationChallengeResponseWebhookEvent.Builder toBuilder()
-
validate
final CardAuthorizationChallengeResponseWebhookEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardAuthorizationChallengeResponseWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of CardAuthorizationChallengeResponseWebhookEvent.
The following fields are required:
.cardToken() .challengeMethod() .completed() .created() .eventToken() .eventType() .response() .transactionToken()
-
-
-
-