Package com.lithic.api.models
Class CardBalanceListPage
-
- All Implemented Interfaces:
public final class CardBalanceListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardBalanceListPage.BuilderA builder for CardBalanceListPage.
public final classCardBalanceListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<BalanceListResponse>data()Delegates to CardBalanceListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to CardBalanceListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<CardBalanceListParams>getNextPageParams()final Optional<CardBalanceListPage>getNextPage()final CardBalanceListPage.AutoPagerautoPager()final CardBalanceListParamsparams()The parameters that were used to request this page. final CardBalanceListPageResponseresponse()The response that this page was parsed from. final CardBalanceListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardBalanceListPage.Builderbuilder()Returns a mutable builder for constructing an instance of CardBalanceListPage. -
-
Method Detail
-
data
final List<BalanceListResponse> data()
Delegates to CardBalanceListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to CardBalanceListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<CardBalanceListParams> getNextPageParams()
-
getNextPage
final Optional<CardBalanceListPage> getNextPage()
-
autoPager
final CardBalanceListPage.AutoPager autoPager()
-
params
final CardBalanceListParams params()
The parameters that were used to request this page.
-
response
final CardBalanceListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final CardBalanceListPage.Builder toBuilder()
-
builder
final static CardBalanceListPage.Builder builder()
Returns a mutable builder for constructing an instance of CardBalanceListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-