Package com.lithic.api.models
Class CardBalanceListPageAsync
-
- All Implemented Interfaces:
public final class CardBalanceListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardBalanceListPageAsync.BuilderA builder for CardBalanceListPageAsync.
public final classCardBalanceListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<BalanceListResponse>data()Delegates to CardBalanceListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to CardBalanceListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<CardBalanceListParams>getNextPageParams()final CompletableFuture<Optional<CardBalanceListPageAsync>>getNextPage()final CardBalanceListPageAsync.AutoPagerautoPager()final CardBalanceListParamsparams()The parameters that were used to request this page. final CardBalanceListPageResponseresponse()The response that this page was parsed from. final CardBalanceListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardBalanceListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of CardBalanceListPageAsync. -
-
Method Detail
-
data
final List<BalanceListResponse> data()
Delegates to CardBalanceListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to CardBalanceListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<CardBalanceListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<CardBalanceListPageAsync>> getNextPage()
-
autoPager
final CardBalanceListPageAsync.AutoPager autoPager()
-
params
final CardBalanceListParams params()
The parameters that were used to request this page.
-
response
final CardBalanceListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final CardBalanceListPageAsync.Builder toBuilder()
-
builder
final static CardBalanceListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of CardBalanceListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-