Package com.lithic.api.models
Class CardBalanceListPageAsync.Builder
-
- All Implemented Interfaces:
public final class CardBalanceListPageAsync.BuilderA builder for CardBalanceListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final CardBalanceListPageAsync.Builderservice(BalanceServiceAsync service)final CardBalanceListPageAsync.Builderparams(CardBalanceListParams params)The parameters that were used to request this page. final CardBalanceListPageAsync.Builderresponse(CardBalanceListPageResponse response)The response that this page was parsed from. final CardBalanceListPageAsyncbuild()Returns an immutable instance of CardBalanceListPageAsync. -
-
Method Detail
-
service
final CardBalanceListPageAsync.Builder service(BalanceServiceAsync service)
-
params
final CardBalanceListPageAsync.Builder params(CardBalanceListParams params)
The parameters that were used to request this page.
-
response
final CardBalanceListPageAsync.Builder response(CardBalanceListPageResponse response)
The response that this page was parsed from.
-
build
final CardBalanceListPageAsync build()
Returns an immutable instance of CardBalanceListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-