Package com.lithic.api.models
Class CardBalanceListPageAsync.Response
-
- All Implemented Interfaces:
public final class CardBalanceListPageAsync.Response
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardBalanceListPageAsync.Response.Builder
-
Constructor Summary
Constructors Constructor Description CardBalanceListPageAsync.Response(JsonField<List<BalanceListResponse>> data, JsonField<Boolean> hasMore, Map<String, JsonValue> additionalProperties)
-
Method Summary
Modifier and Type Method Description final List<BalanceListResponse>data()final BooleanhasMore()final Optional<JsonField<List<BalanceListResponse>>>_data()final Optional<JsonField<Boolean>>_hasMore()final Map<String, JsonValue>_additionalProperties()final CardBalanceListPageAsync.Responsevalidate()final BooleanisValid()final CardBalanceListPageAsync.Response.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardBalanceListPageAsync.Response.Builderbuilder()Returns a mutable builder for constructing an instance of CardBalanceListPageAsync. -
-
Method Detail
-
data
final List<BalanceListResponse> data()
-
_data
final Optional<JsonField<List<BalanceListResponse>>> _data()
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CardBalanceListPageAsync.Response validate()
-
toBuilder
final CardBalanceListPageAsync.Response.Builder toBuilder()
-
builder
final static CardBalanceListPageAsync.Response.Builder builder()
Returns a mutable builder for constructing an instance of CardBalanceListPageAsync.
-
-
-
-