Class CardBulkOrderListPage
-
- All Implemented Interfaces:
-
com.lithic.api.core.Page
public final class CardBulkOrderListPage implements Page<CardBulkOrder>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardBulkOrderListPage.BuilderA builder for CardBulkOrderListPage.
-
Method Summary
Modifier and Type Method Description final List<CardBulkOrder>data()Delegates to CardBulkOrderListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to CardBulkOrderListPageResponse, but gracefully handles missing data. List<CardBulkOrder>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final CardBulkOrderListParamsnextPageParams()CardBulkOrderListPagenextPage()Returns the page after this one by making another request. final AutoPager<CardBulkOrder>autoPager()final CardBulkOrderListParamsparams()The parameters that were used to request this page. final CardBulkOrderListPageResponseresponse()The response that this page was parsed from. final CardBulkOrderListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardBulkOrderListPage.Builderbuilder()Returns a mutable builder for constructing an instance of CardBulkOrderListPage. -
-
Method Detail
-
data
final List<CardBulkOrder> data()
Delegates to CardBulkOrderListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to CardBulkOrderListPageResponse, but gracefully handles missing data.
-
items
List<CardBulkOrder> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final CardBulkOrderListParams nextPageParams()
-
nextPage
CardBulkOrderListPage nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPager<CardBulkOrder> autoPager()
-
params
final CardBulkOrderListParams params()
The parameters that were used to request this page.
-
response
final CardBulkOrderListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final CardBulkOrderListPage.Builder toBuilder()
-
builder
final static CardBulkOrderListPage.Builder builder()
Returns a mutable builder for constructing an instance of CardBulkOrderListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-