Package com.lithic.api.models
Class CardFinancialTransactionListPage
-
- All Implemented Interfaces:
public final class CardFinancialTransactionListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardFinancialTransactionListPage.BuilderA builder for CardFinancialTransactionListPage.
public final classCardFinancialTransactionListPage.AutoPager
-
Method Summary
-
-
Method Detail
-
data
final List<FinancialTransaction> data()
Delegates to CardFinancialTransactionListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to CardFinancialTransactionListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<CardFinancialTransactionListParams> getNextPageParams()
-
getNextPage
final Optional<CardFinancialTransactionListPage> getNextPage()
-
autoPager
final CardFinancialTransactionListPage.AutoPager autoPager()
-
params
final CardFinancialTransactionListParams params()
The parameters that were used to request this page.
-
response
final CardFinancialTransactionListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final CardFinancialTransactionListPage.Builder toBuilder()
-
builder
final static CardFinancialTransactionListPage.Builder builder()
Returns a mutable builder for constructing an instance of CardFinancialTransactionListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-