Package com.lithic.api.models
Class CardFinancialTransactionListPageAsync
-
- All Implemented Interfaces:
public final class CardFinancialTransactionListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardFinancialTransactionListPageAsync.BuilderA builder for CardFinancialTransactionListPageAsync.
public final classCardFinancialTransactionListPageAsync.AutoPager
-
Method Summary
-
-
Method Detail
-
data
final List<FinancialTransaction> data()
Delegates to CardFinancialTransactionListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to CardFinancialTransactionListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<CardFinancialTransactionListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<CardFinancialTransactionListPageAsync>> getNextPage()
-
autoPager
final CardFinancialTransactionListPageAsync.AutoPager autoPager()
-
params
final CardFinancialTransactionListParams params()
The parameters that were used to request this page.
-
response
final CardFinancialTransactionListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final CardFinancialTransactionListPageAsync.Builder toBuilder()
-
builder
final static CardFinancialTransactionListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of CardFinancialTransactionListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-