Package com.lithic.api.models
Class CardListPage
-
- All Implemented Interfaces:
public final class CardListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardListPage.BuilderA builder for CardListPage.
public final classCardListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<NonPciCard>data()Delegates to CardListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to CardListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<CardListParams>getNextPageParams()final Optional<CardListPage>getNextPage()final CardListPage.AutoPagerautoPager()final CardListParamsparams()The parameters that were used to request this page. final CardListPageResponseresponse()The response that this page was parsed from. final CardListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardListPage.Builderbuilder()Returns a mutable builder for constructing an instance of CardListPage. -
-
Method Detail
-
data
final List<NonPciCard> data()
Delegates to CardListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to CardListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<CardListParams> getNextPageParams()
-
getNextPage
final Optional<CardListPage> getNextPage()
-
autoPager
final CardListPage.AutoPager autoPager()
-
params
final CardListParams params()
The parameters that were used to request this page.
-
response
final CardListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final CardListPage.Builder toBuilder()
-
builder
final static CardListPage.Builder builder()
Returns a mutable builder for constructing an instance of CardListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-