Package com.lithic.api.models
Class CardListPageAsync
-
- All Implemented Interfaces:
public final class CardListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardListPageAsync.BuilderA builder for CardListPageAsync.
public final classCardListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<NonPciCard>data()Delegates to CardListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to CardListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<CardListParams>getNextPageParams()final CompletableFuture<Optional<CardListPageAsync>>getNextPage()final CardListPageAsync.AutoPagerautoPager()final CardListParamsparams()The parameters that were used to request this page. final CardListPageResponseresponse()The response that this page was parsed from. final CardListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of CardListPageAsync. -
-
Method Detail
-
data
final List<NonPciCard> data()
Delegates to CardListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to CardListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<CardListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<CardListPageAsync>> getNextPage()
-
autoPager
final CardListPageAsync.AutoPager autoPager()
-
params
final CardListParams params()
The parameters that were used to request this page.
-
response
final CardListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final CardListPageAsync.Builder toBuilder()
-
builder
final static CardListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of CardListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-