Package com.lithic.api.models
Class CardListPageResponse
-
- All Implemented Interfaces:
public final class CardListPageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardListPageResponse.BuilderA builder for CardListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<NonPciCard>data()final BooleanhasMore()More data exists. final JsonField<List<NonPciCard>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final CardListPageResponse.BuildertoBuilder()final CardListPageResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of CardListPageResponse. -
-
Method Detail
-
data
final List<NonPciCard> data()
-
_data
final JsonField<List<NonPciCard>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardListPageResponse.Builder toBuilder()
-
validate
final CardListPageResponse validate()
-
builder
final static CardListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of CardListPageResponse.
The following fields are required:
.data() .hasMore()
-
-
-
-