Package com.lithic.api.models
Class CardProgramListPage
-
- All Implemented Interfaces:
public final class CardProgramListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardProgramListPage.BuilderA builder for CardProgramListPage.
public final classCardProgramListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<CardProgram>data()Delegates to CardProgramListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to CardProgramListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<CardProgramListParams>getNextPageParams()final Optional<CardProgramListPage>getNextPage()final CardProgramListPage.AutoPagerautoPager()final CardProgramListParamsparams()The parameters that were used to request this page. final CardProgramListPageResponseresponse()The response that this page was parsed from. final CardProgramListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardProgramListPage.Builderbuilder()Returns a mutable builder for constructing an instance of CardProgramListPage. -
-
Method Detail
-
data
final List<CardProgram> data()
Delegates to CardProgramListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to CardProgramListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<CardProgramListParams> getNextPageParams()
-
getNextPage
final Optional<CardProgramListPage> getNextPage()
-
autoPager
final CardProgramListPage.AutoPager autoPager()
-
params
final CardProgramListParams params()
The parameters that were used to request this page.
-
response
final CardProgramListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final CardProgramListPage.Builder toBuilder()
-
builder
final static CardProgramListPage.Builder builder()
Returns a mutable builder for constructing an instance of CardProgramListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-