Class CardProvisionParams.Body
-
- All Implemented Interfaces:
public final class CardProvisionParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardProvisionParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>certificate()Only applicable if digital_walletisAPPLE_PAY.final Optional<String>clientDeviceId()Only applicable if digital_walletisGOOGLE_PAYorSAMSUNG_PAYand the card is on the Visa network.final Optional<String>clientWalletAccountId()Only applicable if digital_walletisGOOGLE_PAYorSAMSUNG_PAYand the card is on the Visa network.final Optional<CardProvisionParams.DigitalWallet>digitalWallet()Name of digital wallet provider. final Optional<String>nonce()Only applicable if digital_walletisAPPLE_PAY.final Optional<String>nonceSignature()Only applicable if digital_walletisAPPLE_PAY.final JsonField<String>_certificate()Returns the raw JSON value of certificate. final JsonField<String>_clientDeviceId()Returns the raw JSON value of clientDeviceId. final JsonField<String>_clientWalletAccountId()Returns the raw JSON value of clientWalletAccountId. final JsonField<CardProvisionParams.DigitalWallet>_digitalWallet()Returns the raw JSON value of digitalWallet. final JsonField<String>_nonce()Returns the raw JSON value of nonce. final JsonField<String>_nonceSignature()Returns the raw JSON value of nonceSignature. final Map<String, JsonValue>_additionalProperties()final CardProvisionParams.Body.BuildertoBuilder()final CardProvisionParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardProvisionParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
certificate
final Optional<String> certificate()
Only applicable if
digital_walletisAPPLE_PAY. Omit to receive onlyactivationDatain the response. Apple's public leaf certificate. Base64 encoded in PEM format with headers(-----BEGIN CERTIFICATE-----)and trailers omitted. Provided by the device's wallet.
-
clientDeviceId
final Optional<String> clientDeviceId()
Only applicable if
digital_walletisGOOGLE_PAYorSAMSUNG_PAYand the card is on the Visa network. Stable device identification set by the wallet provider.
-
clientWalletAccountId
final Optional<String> clientWalletAccountId()
Only applicable if
digital_walletisGOOGLE_PAYorSAMSUNG_PAYand the card is on the Visa network. Consumer ID that identifies the wallet account holder entity.
-
digitalWallet
final Optional<CardProvisionParams.DigitalWallet> digitalWallet()
Name of digital wallet provider.
-
nonce
final Optional<String> nonce()
Only applicable if
digital_walletisAPPLE_PAY. Omit to receive onlyactivationDatain the response. Base64 cryptographic nonce provided by the device's wallet.
-
nonceSignature
final Optional<String> nonceSignature()
Only applicable if
digital_walletisAPPLE_PAY. Omit to receive onlyactivationDatain the response. Base64 cryptographic nonce provided by the device's wallet.
-
_certificate
final JsonField<String> _certificate()
Returns the raw JSON value of certificate.
Unlike certificate, this method doesn't throw if the JSON field has an unexpected type.
-
_clientDeviceId
final JsonField<String> _clientDeviceId()
Returns the raw JSON value of clientDeviceId.
Unlike clientDeviceId, this method doesn't throw if the JSON field has an unexpected type.
-
_clientWalletAccountId
final JsonField<String> _clientWalletAccountId()
Returns the raw JSON value of clientWalletAccountId.
Unlike clientWalletAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_digitalWallet
final JsonField<CardProvisionParams.DigitalWallet> _digitalWallet()
Returns the raw JSON value of digitalWallet.
Unlike digitalWallet, this method doesn't throw if the JSON field has an unexpected type.
-
_nonce
final JsonField<String> _nonce()
Returns the raw JSON value of nonce.
Unlike nonce, this method doesn't throw if the JSON field has an unexpected type.
-
_nonceSignature
final JsonField<String> _nonceSignature()
Returns the raw JSON value of nonceSignature.
Unlike nonceSignature, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardProvisionParams.Body.Builder toBuilder()
-
validate
final CardProvisionParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardProvisionParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-