Class CardProvisionParams.Body.Builder
-
- All Implemented Interfaces:
public final class CardProvisionParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
certificate
final CardProvisionParams.Body.Builder certificate(String certificate)
Only applicable if
digital_walletisAPPLE_PAY. Omit to receive onlyactivationDatain the response. Apple's public leaf certificate. Base64 encoded in PEM format with headers(-----BEGIN CERTIFICATE-----)and trailers omitted. Provided by the device's wallet.
-
certificate
final CardProvisionParams.Body.Builder certificate(JsonField<String> certificate)
Sets Builder.certificate to an arbitrary JSON value.
You should usually call Builder.certificate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
clientDeviceId
final CardProvisionParams.Body.Builder clientDeviceId(String clientDeviceId)
Only applicable if
digital_walletisGOOGLE_PAYorSAMSUNG_PAYand the card is on the Visa network. Stable device identification set by the wallet provider.
-
clientDeviceId
final CardProvisionParams.Body.Builder clientDeviceId(JsonField<String> clientDeviceId)
Sets Builder.clientDeviceId to an arbitrary JSON value.
You should usually call Builder.clientDeviceId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
clientWalletAccountId
final CardProvisionParams.Body.Builder clientWalletAccountId(String clientWalletAccountId)
Only applicable if
digital_walletisGOOGLE_PAYorSAMSUNG_PAYand the card is on the Visa network. Consumer ID that identifies the wallet account holder entity.
-
clientWalletAccountId
final CardProvisionParams.Body.Builder clientWalletAccountId(JsonField<String> clientWalletAccountId)
Sets Builder.clientWalletAccountId to an arbitrary JSON value.
You should usually call Builder.clientWalletAccountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
digitalWallet
final CardProvisionParams.Body.Builder digitalWallet(CardProvisionParams.DigitalWallet digitalWallet)
Name of digital wallet provider.
-
digitalWallet
final CardProvisionParams.Body.Builder digitalWallet(JsonField<CardProvisionParams.DigitalWallet> digitalWallet)
Sets Builder.digitalWallet to an arbitrary JSON value.
You should usually call Builder.digitalWallet with a well-typed DigitalWallet value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
nonce
final CardProvisionParams.Body.Builder nonce(String nonce)
Only applicable if
digital_walletisAPPLE_PAY. Omit to receive onlyactivationDatain the response. Base64 cryptographic nonce provided by the device's wallet.
-
nonce
final CardProvisionParams.Body.Builder nonce(JsonField<String> nonce)
Sets Builder.nonce to an arbitrary JSON value.
You should usually call Builder.nonce with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
nonceSignature
final CardProvisionParams.Body.Builder nonceSignature(String nonceSignature)
Only applicable if
digital_walletisAPPLE_PAY. Omit to receive onlyactivationDatain the response. Base64 cryptographic nonce provided by the device's wallet.
-
nonceSignature
final CardProvisionParams.Body.Builder nonceSignature(JsonField<String> nonceSignature)
Sets Builder.nonceSignature to an arbitrary JSON value.
You should usually call Builder.nonceSignature with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardProvisionParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardProvisionParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardProvisionParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardProvisionParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardProvisionParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardProvisionParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-