Package com.lithic.api.models
Class CardProvisionResponse
-
- All Implemented Interfaces:
public final class CardProvisionResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardProvisionResponse.BuilderA builder for CardProvisionResponse.
public final classCardProvisionResponse.ProvisioningPayloadBase64 encoded JSON payload representing a payment card that can be passed to a device's digital wallet. Applies to Google and Samsung Pay wallets.
-
Method Summary
Modifier and Type Method Description final Optional<CardProvisionResponse.ProvisioningPayload>provisioningPayload()Base64 encoded JSON payload representing a payment card that can be passed to a device's digital wallet. final JsonField<CardProvisionResponse.ProvisioningPayload>_provisioningPayload()Returns the raw JSON value of provisioningPayload. final Map<String, JsonValue>_additionalProperties()final CardProvisionResponse.BuildertoBuilder()final CardProvisionResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardProvisionResponse.Builderbuilder()Returns a mutable builder for constructing an instance of CardProvisionResponse. -
-
Method Detail
-
provisioningPayload
final Optional<CardProvisionResponse.ProvisioningPayload> provisioningPayload()
Base64 encoded JSON payload representing a payment card that can be passed to a device's digital wallet. Applies to Google and Samsung Pay wallets.
-
_provisioningPayload
final JsonField<CardProvisionResponse.ProvisioningPayload> _provisioningPayload()
Returns the raw JSON value of provisioningPayload.
Unlike provisioningPayload, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardProvisionResponse.Builder toBuilder()
-
validate
final CardProvisionResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardProvisionResponse.Builder builder()
Returns a mutable builder for constructing an instance of CardProvisionResponse.
-
-
-
-