Package com.lithic.api.models
Interface CardProvisionResponse.ProvisioningPayload.Visitor
-
- All Implemented Interfaces:
public interface CardProvisionResponse.ProvisioningPayload.Visitor<T extends Object>An interface that defines how to map each variant of ProvisioningPayload to a value of type T.
-
-
Method Summary
Modifier and Type Method Description abstract TvisitString(String string)Base64 encoded JSON payload representing a payment card that can be passed to a device's digital wallet. abstract TvisitProvisionResponse(ProvisionResponse provisionResponse)Object containing the fields required to add a card to Apple Pay. Tunknown(JsonValue json)Maps an unknown variant of ProvisioningPayload to a value of type T. -
-
Method Detail
-
visitString
abstract T visitString(String string)
Base64 encoded JSON payload representing a payment card that can be passed to a device's digital wallet. Applies to Google and Samsung Pay wallets.
-
visitProvisionResponse
abstract T visitProvisionResponse(ProvisionResponse provisionResponse)
Object containing the fields required to add a card to Apple Pay. Applies only to Apple Pay wallet.
-
unknown
T unknown(JsonValue json)
Maps an unknown variant of ProvisioningPayload to a value of type T.
An instance of ProvisioningPayload can contain an unknown variant if it was deserialized from data that doesn't match any known variant. For example, if the SDK is on an older version than the API, then the API may respond with new variants that the SDK is unaware of.
-
-
-
-