Class CardRenewParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class CardRenewParams implements Params
Applies to card types
PHYSICALandVIRTUAL. ForPHYSICAL, creates a new card with the same card token and PAN, but updated expiry and CVC2 code. The original card will keep working for card-present transactions until the new card is activated. For card-not-present transactions, the original card details (expiry, CVC2) will also keep working until the new card is activated. APHYSICALcard can be reissued or renewed a total of 8 times. ForVIRTUAL, the card will retain the same card token and PAN and receive an updated expiry and CVC2 code.product_id,shipping_method,shipping_address,carrierare only relevant for renewingPHYSICALcards.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardRenewParams.BuilderA builder for CardRenewParams.
public final classCardRenewParams.Bodypublic final classCardRenewParams.ShippingMethodShipping method for the card. Only applies to cards of type PHYSICAL. Use of options besides
STANDARDrequire additional permissions.STANDARD- USPS regular mail or similar international option, with no trackingSTANDARD_WITH_TRACKING- USPS regular mail or similar international option, with trackingPRIORITY- USPS Priority, 1-3 day shipping, with trackingEXPRESS- FedEx or UPS depending on card manufacturer, Express, 3-day shipping, with tracking2_DAY- FedEx or UPS depending on card manufacturer, 2-day shipping, with trackingEXPEDITED- FedEx or UPS depending on card manufacturer, Standard Overnight or similar international option, with tracking
-
Method Summary
Modifier and Type Method Description final Optional<String>cardToken()final ShippingAddressshippingAddress()The shipping address this card will be sent to. final Optional<Carrier>carrier()If omitted, the previous carrier will be used. final Optional<String>expMonth()Two digit (MM) expiry month. final Optional<String>expYear()Four digit (yyyy) expiry year. final Optional<String>productId()Specifies the configuration (e.g. final Optional<CardRenewParams.ShippingMethod>shippingMethod()Shipping method for the card. final JsonField<ShippingAddress>_shippingAddress()Returns the raw JSON value of shippingAddress. final JsonField<Carrier>_carrier()Returns the raw JSON value of carrier. final JsonField<String>_expMonth()Returns the raw JSON value of expMonth. final JsonField<String>_expYear()Returns the raw JSON value of expYear. final JsonField<String>_productId()Returns the raw JSON value of productId. final JsonField<CardRenewParams.ShippingMethod>_shippingMethod()Returns the raw JSON value of shippingMethod. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final CardRenewParams.BuildertoBuilder()final CardRenewParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardRenewParams.Builderbuilder()Returns a mutable builder for constructing an instance of CardRenewParams. -
-
Method Detail
-
shippingAddress
final ShippingAddress shippingAddress()
The shipping address this card will be sent to.
-
expMonth
final Optional<String> expMonth()
Two digit (MM) expiry month. If neither
exp_monthnorexp_yearis provided, an expiration date six years in the future will be generated.
-
expYear
final Optional<String> expYear()
Four digit (yyyy) expiry year. If neither
exp_monthnorexp_yearis provided, an expiration date six years in the future will be generated.
-
productId
final Optional<String> productId()
Specifies the configuration (e.g. physical card art) that the card should be manufactured with, and only applies to cards of type
PHYSICAL. This must be configured with Lithic before use.
-
shippingMethod
final Optional<CardRenewParams.ShippingMethod> shippingMethod()
Shipping method for the card. Only applies to cards of type PHYSICAL. Use of options besides
STANDARDrequire additional permissions.STANDARD- USPS regular mail or similar international option, with no trackingSTANDARD_WITH_TRACKING- USPS regular mail or similar international option, with trackingPRIORITY- USPS Priority, 1-3 day shipping, with trackingEXPRESS- FedEx or UPS depending on card manufacturer, Express, 3-day shipping, with tracking2_DAY- FedEx or UPS depending on card manufacturer, 2-day shipping, with trackingEXPEDITED- FedEx or UPS depending on card manufacturer, Standard Overnight or similar international option, with tracking
-
_shippingAddress
final JsonField<ShippingAddress> _shippingAddress()
Returns the raw JSON value of shippingAddress.
Unlike shippingAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_carrier
final JsonField<Carrier> _carrier()
Returns the raw JSON value of carrier.
Unlike carrier, this method doesn't throw if the JSON field has an unexpected type.
-
_expMonth
final JsonField<String> _expMonth()
Returns the raw JSON value of expMonth.
Unlike expMonth, this method doesn't throw if the JSON field has an unexpected type.
-
_expYear
final JsonField<String> _expYear()
Returns the raw JSON value of expYear.
Unlike expYear, this method doesn't throw if the JSON field has an unexpected type.
-
_productId
final JsonField<String> _productId()
Returns the raw JSON value of productId.
Unlike productId, this method doesn't throw if the JSON field has an unexpected type.
-
_shippingMethod
final JsonField<CardRenewParams.ShippingMethod> _shippingMethod()
Returns the raw JSON value of shippingMethod.
Unlike shippingMethod, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final CardRenewParams.Builder toBuilder()
-
_body
final CardRenewParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static CardRenewParams.Builder builder()
Returns a mutable builder for constructing an instance of CardRenewParams.
The following fields are required:
.shippingAddress()
-
-
-
-