Class CardSpendLimits.Builder
-
- All Implemented Interfaces:
public final class CardSpendLimits.BuilderA builder for CardSpendLimits.
-
-
Method Summary
-
-
Method Detail
-
availableSpendLimit
final CardSpendLimits.Builder availableSpendLimit(CardSpendLimits.AvailableSpendLimit availableSpendLimit)
-
availableSpendLimit
final CardSpendLimits.Builder availableSpendLimit(JsonField<CardSpendLimits.AvailableSpendLimit> availableSpendLimit)
Sets Builder.availableSpendLimit to an arbitrary JSON value.
You should usually call Builder.availableSpendLimit with a well-typed AvailableSpendLimit value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
spendLimit
final CardSpendLimits.Builder spendLimit(CardSpendLimits.SpendLimit spendLimit)
-
spendLimit
final CardSpendLimits.Builder spendLimit(JsonField<CardSpendLimits.SpendLimit> spendLimit)
Sets Builder.spendLimit to an arbitrary JSON value.
You should usually call Builder.spendLimit with a well-typed SpendLimit value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
spendVelocity
final CardSpendLimits.Builder spendVelocity(CardSpendLimits.SpendVelocity spendVelocity)
-
spendVelocity
final CardSpendLimits.Builder spendVelocity(JsonField<CardSpendLimits.SpendVelocity> spendVelocity)
Sets Builder.spendVelocity to an arbitrary JSON value.
You should usually call Builder.spendVelocity with a well-typed SpendVelocity value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardSpendLimits.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardSpendLimits.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardSpendLimits.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardSpendLimits.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardSpendLimits.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardSpendLimits build()
Returns an immutable instance of CardSpendLimits.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.availableSpendLimit()
-
-
-
-