Class CardTransactionUpdateAction.CreateCaseAction
-
- All Implemented Interfaces:
public final class CardTransactionUpdateAction.CreateCaseAction
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardTransactionUpdateAction.CreateCaseAction.BuilderA builder for CreateCaseAction.
public final classCardTransactionUpdateAction.CreateCaseAction.ScopeThe scope of the case to create
public final classCardTransactionUpdateAction.CreateCaseAction.TypeCreate a case for the transaction
-
Method Summary
-
-
Method Detail
-
queueToken
final String queueToken()
The token of the queue to create the case in
-
scope
final CardTransactionUpdateAction.CreateCaseAction.Scope scope()
The scope of the case to create
-
type
final CardTransactionUpdateAction.CreateCaseAction.Type type()
Create a case for the transaction
-
_queueToken
final JsonField<String> _queueToken()
Returns the raw JSON value of queueToken.
Unlike queueToken, this method doesn't throw if the JSON field has an unexpected type.
-
_scope
final JsonField<CardTransactionUpdateAction.CreateCaseAction.Scope> _scope()
Returns the raw JSON value of scope.
Unlike scope, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<CardTransactionUpdateAction.CreateCaseAction.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardTransactionUpdateAction.CreateCaseAction.Builder toBuilder()
-
validate
final CardTransactionUpdateAction.CreateCaseAction validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardTransactionUpdateAction.CreateCaseAction.Builder builder()
Returns a mutable builder for constructing an instance of CreateCaseAction.
The following fields are required:
.queueToken() .scope() .type()
-
-
-
-