Class CardTransactionUpdatedWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class CardTransactionUpdatedWebhookEvent.BuilderA builder for CardTransactionUpdatedWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
token
final CardTransactionUpdatedWebhookEvent.Builder token(String token)
Globally unique identifier.
-
token
final CardTransactionUpdatedWebhookEvent.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountToken
final CardTransactionUpdatedWebhookEvent.Builder accountToken(String accountToken)
The token for the account associated with this transaction.
-
accountToken
final CardTransactionUpdatedWebhookEvent.Builder accountToken(JsonField<String> accountToken)
Sets Builder.accountToken to an arbitrary JSON value.
You should usually call Builder.accountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
acquirerFee
final CardTransactionUpdatedWebhookEvent.Builder acquirerFee(Long acquirerFee)
Fee assessed by the merchant and paid for by the cardholder in the smallest unit of the currency. Will be zero if no fee is assessed. Rebates may be transmitted as a negative value to indicate credited fees.
-
acquirerFee
final CardTransactionUpdatedWebhookEvent.Builder acquirerFee(Long acquirerFee)
Alias for Builder.acquirerFee.
This unboxed primitive overload exists for backwards compatibility.
-
acquirerFee
final CardTransactionUpdatedWebhookEvent.Builder acquirerFee(Optional<Long> acquirerFee)
Alias for calling Builder.acquirerFee with
acquirerFee.orElse(null).
-
acquirerFee
final CardTransactionUpdatedWebhookEvent.Builder acquirerFee(JsonField<Long> acquirerFee)
Sets Builder.acquirerFee to an arbitrary JSON value.
You should usually call Builder.acquirerFee with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
acquirerReferenceNumber
@Deprecated(message = "deprecated") final CardTransactionUpdatedWebhookEvent.Builder acquirerReferenceNumber(String acquirerReferenceNumber)
Unique identifier assigned to a transaction by the acquirer that can be used in dispute and chargeback filing. This field has been deprecated in favor of the
acquirer_reference_numberthat resides in the event-levelnetwork_info.
-
acquirerReferenceNumber
@Deprecated(message = "deprecated") final CardTransactionUpdatedWebhookEvent.Builder acquirerReferenceNumber(Optional<String> acquirerReferenceNumber)
Alias for calling Builder.acquirerReferenceNumber with
acquirerReferenceNumber.orElse(null).
-
acquirerReferenceNumber
@Deprecated(message = "deprecated") final CardTransactionUpdatedWebhookEvent.Builder acquirerReferenceNumber(JsonField<String> acquirerReferenceNumber)
Sets Builder.acquirerReferenceNumber to an arbitrary JSON value.
You should usually call Builder.acquirerReferenceNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
@Deprecated(message = "deprecated") final CardTransactionUpdatedWebhookEvent.Builder amount(Long amount)
When the transaction is pending, this represents the authorization amount of the transaction in the anticipated settlement currency. Once the transaction has settled, this field represents the settled amount in the settlement currency.
-
amount
@Deprecated(message = "deprecated") final CardTransactionUpdatedWebhookEvent.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amounts
final CardTransactionUpdatedWebhookEvent.Builder amounts(Transaction.TransactionAmounts amounts)
-
amounts
final CardTransactionUpdatedWebhookEvent.Builder amounts(JsonField<Transaction.TransactionAmounts> amounts)
Sets Builder.amounts to an arbitrary JSON value.
You should usually call Builder.amounts with a well-typed Transaction.TransactionAmounts value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
authorizationAmount
@Deprecated(message = "deprecated") final CardTransactionUpdatedWebhookEvent.Builder authorizationAmount(Long authorizationAmount)
The authorization amount of the transaction in the anticipated settlement currency.
-
authorizationAmount
@Deprecated(message = "deprecated") final CardTransactionUpdatedWebhookEvent.Builder authorizationAmount(Long authorizationAmount)
Alias for Builder.authorizationAmount.
This unboxed primitive overload exists for backwards compatibility.
-
authorizationAmount
@Deprecated(message = "deprecated") final CardTransactionUpdatedWebhookEvent.Builder authorizationAmount(Optional<Long> authorizationAmount)
Alias for calling Builder.authorizationAmount with
authorizationAmount.orElse(null).
-
authorizationAmount
@Deprecated(message = "deprecated") final CardTransactionUpdatedWebhookEvent.Builder authorizationAmount(JsonField<Long> authorizationAmount)
Sets Builder.authorizationAmount to an arbitrary JSON value.
You should usually call Builder.authorizationAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
authorizationCode
final CardTransactionUpdatedWebhookEvent.Builder authorizationCode(String authorizationCode)
A fixed-width 6-digit numeric identifier that can be used to identify a transaction with networks.
-
authorizationCode
final CardTransactionUpdatedWebhookEvent.Builder authorizationCode(Optional<String> authorizationCode)
Alias for calling Builder.authorizationCode with
authorizationCode.orElse(null).
-
authorizationCode
final CardTransactionUpdatedWebhookEvent.Builder authorizationCode(JsonField<String> authorizationCode)
Sets Builder.authorizationCode to an arbitrary JSON value.
You should usually call Builder.authorizationCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
avs
final CardTransactionUpdatedWebhookEvent.Builder avs(Transaction.Avs avs)
-
avs
final CardTransactionUpdatedWebhookEvent.Builder avs(Optional<Transaction.Avs> avs)
Alias for calling Builder.avs with
avs.orElse(null).
-
avs
final CardTransactionUpdatedWebhookEvent.Builder avs(JsonField<Transaction.Avs> avs)
Sets Builder.avs to an arbitrary JSON value.
You should usually call Builder.avs with a well-typed Transaction.Avs value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardToken
final CardTransactionUpdatedWebhookEvent.Builder cardToken(String cardToken)
Token for the card used in this transaction.
-
cardToken
final CardTransactionUpdatedWebhookEvent.Builder cardToken(JsonField<String> cardToken)
Sets Builder.cardToken to an arbitrary JSON value.
You should usually call Builder.cardToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardholderAuthentication
final CardTransactionUpdatedWebhookEvent.Builder cardholderAuthentication(CardholderAuthentication cardholderAuthentication)
-
cardholderAuthentication
final CardTransactionUpdatedWebhookEvent.Builder cardholderAuthentication(Optional<CardholderAuthentication> cardholderAuthentication)
Alias for calling Builder.cardholderAuthentication with
cardholderAuthentication.orElse(null).
-
cardholderAuthentication
final CardTransactionUpdatedWebhookEvent.Builder cardholderAuthentication(JsonField<CardholderAuthentication> cardholderAuthentication)
Sets Builder.cardholderAuthentication to an arbitrary JSON value.
You should usually call Builder.cardholderAuthentication with a well-typed CardholderAuthentication value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final CardTransactionUpdatedWebhookEvent.Builder created(OffsetDateTime created)
Date and time when the transaction first occurred. UTC time zone.
-
created
final CardTransactionUpdatedWebhookEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
financialAccountToken
final CardTransactionUpdatedWebhookEvent.Builder financialAccountToken(String financialAccountToken)
-
financialAccountToken
final CardTransactionUpdatedWebhookEvent.Builder financialAccountToken(Optional<String> financialAccountToken)
Alias for calling Builder.financialAccountToken with
financialAccountToken.orElse(null).
-
financialAccountToken
final CardTransactionUpdatedWebhookEvent.Builder financialAccountToken(JsonField<String> financialAccountToken)
Sets Builder.financialAccountToken to an arbitrary JSON value.
You should usually call Builder.financialAccountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchant
final CardTransactionUpdatedWebhookEvent.Builder merchant(Transaction.TransactionMerchant merchant)
Merchant information including full location details.
-
merchant
final CardTransactionUpdatedWebhookEvent.Builder merchant(JsonField<Transaction.TransactionMerchant> merchant)
Sets Builder.merchant to an arbitrary JSON value.
You should usually call Builder.merchant with a well-typed Transaction.TransactionMerchant value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantAmount
@Deprecated(message = "deprecated") final CardTransactionUpdatedWebhookEvent.Builder merchantAmount(Long merchantAmount)
Analogous to the 'amount', but in the merchant currency.
-
merchantAmount
@Deprecated(message = "deprecated") final CardTransactionUpdatedWebhookEvent.Builder merchantAmount(Long merchantAmount)
Alias for Builder.merchantAmount.
This unboxed primitive overload exists for backwards compatibility.
-
merchantAmount
@Deprecated(message = "deprecated") final CardTransactionUpdatedWebhookEvent.Builder merchantAmount(Optional<Long> merchantAmount)
Alias for calling Builder.merchantAmount with
merchantAmount.orElse(null).
-
merchantAmount
@Deprecated(message = "deprecated") final CardTransactionUpdatedWebhookEvent.Builder merchantAmount(JsonField<Long> merchantAmount)
Sets Builder.merchantAmount to an arbitrary JSON value.
You should usually call Builder.merchantAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantAuthorizationAmount
@Deprecated(message = "deprecated") final CardTransactionUpdatedWebhookEvent.Builder merchantAuthorizationAmount(Long merchantAuthorizationAmount)
Analogous to the 'authorization_amount', but in the merchant currency.
-
merchantAuthorizationAmount
@Deprecated(message = "deprecated") final CardTransactionUpdatedWebhookEvent.Builder merchantAuthorizationAmount(Long merchantAuthorizationAmount)
Alias for Builder.merchantAuthorizationAmount.
This unboxed primitive overload exists for backwards compatibility.
-
merchantAuthorizationAmount
@Deprecated(message = "deprecated") final CardTransactionUpdatedWebhookEvent.Builder merchantAuthorizationAmount(Optional<Long> merchantAuthorizationAmount)
Alias for calling Builder.merchantAuthorizationAmount with
merchantAuthorizationAmount.orElse(null).
-
merchantAuthorizationAmount
@Deprecated(message = "deprecated") final CardTransactionUpdatedWebhookEvent.Builder merchantAuthorizationAmount(JsonField<Long> merchantAuthorizationAmount)
Sets Builder.merchantAuthorizationAmount to an arbitrary JSON value.
You should usually call Builder.merchantAuthorizationAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCurrency
@Deprecated(message = "deprecated") final CardTransactionUpdatedWebhookEvent.Builder merchantCurrency(String merchantCurrency)
3-character alphabetic ISO 4217 code for the local currency of the transaction.
-
merchantCurrency
@Deprecated(message = "deprecated") final CardTransactionUpdatedWebhookEvent.Builder merchantCurrency(JsonField<String> merchantCurrency)
Sets Builder.merchantCurrency to an arbitrary JSON value.
You should usually call Builder.merchantCurrency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
network
final CardTransactionUpdatedWebhookEvent.Builder network(Transaction.Network network)
Card network of the authorization. Value is
UNKNOWNwhen Lithic cannot determine the network code from the upstream provider.
-
network
final CardTransactionUpdatedWebhookEvent.Builder network(Optional<Transaction.Network> network)
Alias for calling Builder.network with
network.orElse(null).
-
network
final CardTransactionUpdatedWebhookEvent.Builder network(JsonField<Transaction.Network> network)
Sets Builder.network to an arbitrary JSON value.
You should usually call Builder.network with a well-typed Transaction.Network value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
networkRiskScore
final CardTransactionUpdatedWebhookEvent.Builder networkRiskScore(Long networkRiskScore)
Network-provided score assessing risk level associated with a given authorization. Scores are on a range of 0-999, with 0 representing the lowest risk and 999 representing the highest risk. For Visa transactions, where the raw score has a range of 0-99, Lithic will normalize the score by multiplying the raw score by 10x.
-
networkRiskScore
final CardTransactionUpdatedWebhookEvent.Builder networkRiskScore(Long networkRiskScore)
Alias for Builder.networkRiskScore.
This unboxed primitive overload exists for backwards compatibility.
-
networkRiskScore
final CardTransactionUpdatedWebhookEvent.Builder networkRiskScore(Optional<Long> networkRiskScore)
Alias for calling Builder.networkRiskScore with
networkRiskScore.orElse(null).
-
networkRiskScore
final CardTransactionUpdatedWebhookEvent.Builder networkRiskScore(JsonField<Long> networkRiskScore)
Sets Builder.networkRiskScore to an arbitrary JSON value.
You should usually call Builder.networkRiskScore with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pos
final CardTransactionUpdatedWebhookEvent.Builder pos(Transaction.Pos pos)
-
pos
final CardTransactionUpdatedWebhookEvent.Builder pos(JsonField<Transaction.Pos> pos)
Sets Builder.pos to an arbitrary JSON value.
You should usually call Builder.pos with a well-typed Transaction.Pos value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
result
final CardTransactionUpdatedWebhookEvent.Builder result(Transaction.DeclineResult result)
-
result
final CardTransactionUpdatedWebhookEvent.Builder result(JsonField<Transaction.DeclineResult> result)
Sets Builder.result to an arbitrary JSON value.
You should usually call Builder.result with a well-typed Transaction.DeclineResult value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
serviceLocation
final CardTransactionUpdatedWebhookEvent.Builder serviceLocation(Transaction.ServiceLocation serviceLocation)
Where the cardholder received the service, when different from the card acceptor location. This is populated from network data elements such as Mastercard DE-122 SE1 SF9-14 and Visa F34 DS02.
-
serviceLocation
final CardTransactionUpdatedWebhookEvent.Builder serviceLocation(Optional<Transaction.ServiceLocation> serviceLocation)
Alias for calling Builder.serviceLocation with
serviceLocation.orElse(null).
-
serviceLocation
final CardTransactionUpdatedWebhookEvent.Builder serviceLocation(JsonField<Transaction.ServiceLocation> serviceLocation)
Sets Builder.serviceLocation to an arbitrary JSON value.
You should usually call Builder.serviceLocation with a well-typed Transaction.ServiceLocation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
settledAmount
@Deprecated(message = "deprecated") final CardTransactionUpdatedWebhookEvent.Builder settledAmount(Long settledAmount)
The settled amount of the transaction in the settlement currency.
-
settledAmount
@Deprecated(message = "deprecated") final CardTransactionUpdatedWebhookEvent.Builder settledAmount(JsonField<Long> settledAmount)
Sets Builder.settledAmount to an arbitrary JSON value.
You should usually call Builder.settledAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final CardTransactionUpdatedWebhookEvent.Builder status(Transaction.Status status)
Status of the transaction.
-
status
final CardTransactionUpdatedWebhookEvent.Builder status(JsonField<Transaction.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Transaction.Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tags
final CardTransactionUpdatedWebhookEvent.Builder tags(Transaction.Tags tags)
Key-value pairs for tagging resources. Tags allow you to associate arbitrary metadata with a resource for your own purposes.
-
tags
final CardTransactionUpdatedWebhookEvent.Builder tags(JsonField<Transaction.Tags> tags)
Sets Builder.tags to an arbitrary JSON value.
You should usually call Builder.tags with a well-typed Transaction.Tags value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tokenInfo
final CardTransactionUpdatedWebhookEvent.Builder tokenInfo(TokenInfo tokenInfo)
-
tokenInfo
final CardTransactionUpdatedWebhookEvent.Builder tokenInfo(Optional<TokenInfo> tokenInfo)
Alias for calling Builder.tokenInfo with
tokenInfo.orElse(null).
-
tokenInfo
final CardTransactionUpdatedWebhookEvent.Builder tokenInfo(JsonField<TokenInfo> tokenInfo)
Sets Builder.tokenInfo to an arbitrary JSON value.
You should usually call Builder.tokenInfo with a well-typed TokenInfo value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updated
final CardTransactionUpdatedWebhookEvent.Builder updated(OffsetDateTime updated)
Date and time when the transaction last updated. UTC time zone.
-
updated
final CardTransactionUpdatedWebhookEvent.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
events
final CardTransactionUpdatedWebhookEvent.Builder events(List<Transaction.TransactionEvent> events)
-
events
final CardTransactionUpdatedWebhookEvent.Builder events(JsonField<List<Transaction.TransactionEvent>> events)
Sets Builder.events to an arbitrary JSON value.
You should usually call Builder.events with a well-typed
List<Transaction.TransactionEvent>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEvent
final CardTransactionUpdatedWebhookEvent.Builder addEvent(Transaction.TransactionEvent event)
Adds a single Transaction.TransactionEvent to events.
-
eventType
final CardTransactionUpdatedWebhookEvent.Builder eventType(CardTransactionUpdatedWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final CardTransactionUpdatedWebhookEvent.Builder eventType(JsonField<CardTransactionUpdatedWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardTransactionUpdatedWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardTransactionUpdatedWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardTransactionUpdatedWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardTransactionUpdatedWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardTransactionUpdatedWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardTransactionUpdatedWebhookEvent build()
Returns an immutable instance of CardTransactionUpdatedWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .accountToken() .acquirerFee() .acquirerReferenceNumber() .amount() .amounts() .authorizationAmount() .authorizationCode() .avs() .cardToken() .cardholderAuthentication() .created() .financialAccountToken() .merchant() .merchantAmount() .merchantAuthorizationAmount() .merchantCurrency() .network() .networkRiskScore() .pos() .result() .serviceLocation() .settledAmount() .status() .tags() .tokenInfo() .updated() .eventType()
-
-
-
-