Class CardWebProvisionResponse.GoogleWebPushProvisioningResponse.Builder
-
- All Implemented Interfaces:
public final class CardWebProvisionResponse.GoogleWebPushProvisioningResponse.BuilderA builder for GoogleWebPushProvisioningResponse.
-
-
Method Summary
-
-
Method Detail
-
googleOpc
final CardWebProvisionResponse.GoogleWebPushProvisioningResponse.Builder googleOpc(String googleOpc)
A base64 encoded and encrypted payload representing card data for the Google Pay UWPP FPAN flow.
-
googleOpc
final CardWebProvisionResponse.GoogleWebPushProvisioningResponse.Builder googleOpc(JsonField<String> googleOpc)
Sets Builder.googleOpc to an arbitrary JSON value.
You should usually call Builder.googleOpc with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tspOpc
final CardWebProvisionResponse.GoogleWebPushProvisioningResponse.Builder tspOpc(String tspOpc)
A base64 encoded and encrypted payload representing card data for the Google Pay UWPP tokenization flow.
-
tspOpc
final CardWebProvisionResponse.GoogleWebPushProvisioningResponse.Builder tspOpc(JsonField<String> tspOpc)
Sets Builder.tspOpc to an arbitrary JSON value.
You should usually call Builder.tspOpc with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardWebProvisionResponse.GoogleWebPushProvisioningResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardWebProvisionResponse.GoogleWebPushProvisioningResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardWebProvisionResponse.GoogleWebPushProvisioningResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardWebProvisionResponse.GoogleWebPushProvisioningResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardWebProvisionResponse.GoogleWebPushProvisioningResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardWebProvisionResponse.GoogleWebPushProvisioningResponse build()
Returns an immutable instance of GoogleWebPushProvisioningResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-