Class CardholderAuthentication
-
- All Implemented Interfaces:
public final class CardholderAuthentication
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardholderAuthentication.BuilderA builder for CardholderAuthentication.
public final classCardholderAuthentication.AuthenticationMethodIndicates the method used to authenticate the cardholder.
public final classCardholderAuthentication.AuthenticationResultIndicates the outcome of the 3DS authentication process.
public final classCardholderAuthentication.DecisionMadeByIndicates which party made the 3DS authentication decision.
public final classCardholderAuthentication.LiabilityShiftIndicates whether chargeback liability shift applies to the transaction. Possible enum values:
3DS_AUTHENTICATED: The transaction was fully authenticated through a 3-D Secure flow, chargeback liability shift applies.NONE: Chargeback liability shift has not shifted to the issuer, i.e. the merchant is liable.TOKEN_AUTHENTICATED: The transaction was a tokenized payment with validated cryptography, possibly recurring. Chargeback liability shift to the issuer applies.
-
Method Summary
Modifier and Type Method Description final CardholderAuthentication.AuthenticationMethodauthenticationMethod()Indicates the method used to authenticate the cardholder. final CardholderAuthentication.AuthenticationResultauthenticationResult()Indicates the outcome of the 3DS authentication process. final CardholderAuthentication.DecisionMadeBydecisionMadeBy()Indicates which party made the 3DS authentication decision. final CardholderAuthentication.LiabilityShiftliabilityShift()Indicates whether chargeback liability shift applies to the transaction. final Optional<String>threeDSAuthenticationToken()Unique identifier you can use to match a given 3DS authentication (available via the three_ds_authentication.created event webhook) and the transaction. final JsonField<CardholderAuthentication.AuthenticationMethod>_authenticationMethod()Returns the raw JSON value of authenticationMethod. final JsonField<CardholderAuthentication.AuthenticationResult>_authenticationResult()Returns the raw JSON value of authenticationResult. final JsonField<CardholderAuthentication.DecisionMadeBy>_decisionMadeBy()Returns the raw JSON value of decisionMadeBy. final JsonField<CardholderAuthentication.LiabilityShift>_liabilityShift()Returns the raw JSON value of liabilityShift. final JsonField<String>_threeDSAuthenticationToken()Returns the raw JSON value of threeDSAuthenticationToken. final Map<String, JsonValue>_additionalProperties()final CardholderAuthentication.BuildertoBuilder()final CardholderAuthenticationvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardholderAuthentication.Builderbuilder()Returns a mutable builder for constructing an instance of CardholderAuthentication. -
-
Method Detail
-
authenticationMethod
final CardholderAuthentication.AuthenticationMethod authenticationMethod()
Indicates the method used to authenticate the cardholder.
-
authenticationResult
final CardholderAuthentication.AuthenticationResult authenticationResult()
Indicates the outcome of the 3DS authentication process.
-
decisionMadeBy
final CardholderAuthentication.DecisionMadeBy decisionMadeBy()
Indicates which party made the 3DS authentication decision.
-
liabilityShift
final CardholderAuthentication.LiabilityShift liabilityShift()
Indicates whether chargeback liability shift applies to the transaction. Possible enum values:
3DS_AUTHENTICATED: The transaction was fully authenticated through a 3-D Secure flow, chargeback liability shift applies.NONE: Chargeback liability shift has not shifted to the issuer, i.e. the merchant is liable.TOKEN_AUTHENTICATED: The transaction was a tokenized payment with validated cryptography, possibly recurring. Chargeback liability shift to the issuer applies.
-
threeDSAuthenticationToken
final Optional<String> threeDSAuthenticationToken()
Unique identifier you can use to match a given 3DS authentication (available via the three_ds_authentication.created event webhook) and the transaction. Note that in cases where liability shift does not occur, this token is matched to the transaction on a best-effort basis.
-
_authenticationMethod
final JsonField<CardholderAuthentication.AuthenticationMethod> _authenticationMethod()
Returns the raw JSON value of authenticationMethod.
Unlike authenticationMethod, this method doesn't throw if the JSON field has an unexpected type.
-
_authenticationResult
final JsonField<CardholderAuthentication.AuthenticationResult> _authenticationResult()
Returns the raw JSON value of authenticationResult.
Unlike authenticationResult, this method doesn't throw if the JSON field has an unexpected type.
-
_decisionMadeBy
final JsonField<CardholderAuthentication.DecisionMadeBy> _decisionMadeBy()
Returns the raw JSON value of decisionMadeBy.
Unlike decisionMadeBy, this method doesn't throw if the JSON field has an unexpected type.
-
_liabilityShift
final JsonField<CardholderAuthentication.LiabilityShift> _liabilityShift()
Returns the raw JSON value of liabilityShift.
Unlike liabilityShift, this method doesn't throw if the JSON field has an unexpected type.
-
_threeDSAuthenticationToken
final JsonField<String> _threeDSAuthenticationToken()
Returns the raw JSON value of threeDSAuthenticationToken.
Unlike threeDSAuthenticationToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardholderAuthentication.Builder toBuilder()
-
validate
final CardholderAuthentication validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardholderAuthentication.Builder builder()
Returns a mutable builder for constructing an instance of CardholderAuthentication.
The following fields are required:
.authenticationMethod() .authenticationResult() .decisionMadeBy() .liabilityShift() .threeDSAuthenticationToken()
-
-
-
-