Package com.lithic.api.models
Class ChallengeResponse
-
- All Implemented Interfaces:
public final class ChallengeResponseResponse from Card Program to a 3DS Authentication challenge
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChallengeResponse.BuilderA builder for ChallengeResponse.
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier for 3DS Authentication that resulted in PENDING_CHALLENGE authentication result. final ChallengeResultchallengeResponse()Whether the Cardholder has approved or declined the issued Challenge final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<ChallengeResult>_challengeResponse()Returns the raw JSON value of challengeResponse. final Map<String, JsonValue>_additionalProperties()final ChallengeResponse.BuildertoBuilder()final ChallengeResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChallengeResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ChallengeResponse. -
-
Method Detail
-
token
final String token()
Globally unique identifier for 3DS Authentication that resulted in PENDING_CHALLENGE authentication result.
-
challengeResponse
final ChallengeResult challengeResponse()
Whether the Cardholder has approved or declined the issued Challenge
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_challengeResponse
final JsonField<ChallengeResult> _challengeResponse()
Returns the raw JSON value of challengeResponse.
Unlike challengeResponse, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChallengeResponse.Builder toBuilder()
-
validate
final ChallengeResponse validate()
-
builder
final static ChallengeResponse.Builder builder()
Returns a mutable builder for constructing an instance of ChallengeResponse.
The following fields are required:
.token() .challengeResponse()
-
-
-
-