Class Conditional3dsActionParameters.Condition
-
- All Implemented Interfaces:
public final class Conditional3dsActionParameters.Condition
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classConditional3dsActionParameters.Condition.BuilderA builder for Condition.
public final classConditional3dsActionParameters.Condition.AttributeThe attribute to target.
The following attributes may be targeted:
MCC: A four-digit number listed in ISO 18245. An MCC is used to classify a business by the types of goods or services it provides.COUNTRY: Country of entity of card acceptor. Possible values are: (1) all ISO 3166-1 alpha-3 country codes, (2) QZZ for Kosovo, and (3) ANT for Netherlands Antilles.CURRENCY: 3-character alphabetic ISO 4217 code for the merchant currency of the transaction.MERCHANT_ID: Unique alphanumeric identifier for the payment card acceptor (merchant).DESCRIPTOR: Short description of card acceptor.TRANSACTION_AMOUNT: The base transaction amount (in cents) plus the acquirer fee field in the settlement/cardholder billing currency. This is the amount the issuer should authorize against unless the issuer is paying the acquirer fee on behalf of the cardholder.RISK_SCORE: Mastercard only: Assessment by the network of the authentication risk level, with a higher value indicating a higher amount of risk.MESSAGE_CATEGORY: The category of the authentication being processed.ADDRESS_MATCH: Lithic's evaluation result comparing transaction's address data with the cardholder KYC data if it exists. Valid values areMATCH,MATCH_ADDRESS_ONLY,MATCH_ZIP_ONLY,MISMATCH,NOT_PRESENT.
-
Method Summary
Modifier and Type Method Description final Conditional3dsActionParameters.Condition.Attributeattribute()The attribute to target. final ConditionalOperationoperation()The operation to apply to the attribute final ConditionalValuevalue()A regex string, to be used with MATCHESorDOES_NOT_MATCHfinal JsonField<Conditional3dsActionParameters.Condition.Attribute>_attribute()Returns the raw JSON value of attribute. final JsonField<ConditionalOperation>_operation()Returns the raw JSON value of operation. final JsonField<ConditionalValue>_value()Returns the raw JSON value of value. final Map<String, JsonValue>_additionalProperties()final Conditional3dsActionParameters.Condition.BuildertoBuilder()final Conditional3dsActionParameters.Conditionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Conditional3dsActionParameters.Condition.Builderbuilder()Returns a mutable builder for constructing an instance of Condition. -
-
Method Detail
-
attribute
final Conditional3dsActionParameters.Condition.Attribute attribute()
The attribute to target.
The following attributes may be targeted:
MCC: A four-digit number listed in ISO 18245. An MCC is used to classify a business by the types of goods or services it provides.COUNTRY: Country of entity of card acceptor. Possible values are: (1) all ISO 3166-1 alpha-3 country codes, (2) QZZ for Kosovo, and (3) ANT for Netherlands Antilles.CURRENCY: 3-character alphabetic ISO 4217 code for the merchant currency of the transaction.MERCHANT_ID: Unique alphanumeric identifier for the payment card acceptor (merchant).DESCRIPTOR: Short description of card acceptor.TRANSACTION_AMOUNT: The base transaction amount (in cents) plus the acquirer fee field in the settlement/cardholder billing currency. This is the amount the issuer should authorize against unless the issuer is paying the acquirer fee on behalf of the cardholder.RISK_SCORE: Mastercard only: Assessment by the network of the authentication risk level, with a higher value indicating a higher amount of risk.MESSAGE_CATEGORY: The category of the authentication being processed.ADDRESS_MATCH: Lithic's evaluation result comparing transaction's address data with the cardholder KYC data if it exists. Valid values areMATCH,MATCH_ADDRESS_ONLY,MATCH_ZIP_ONLY,MISMATCH,NOT_PRESENT.
-
operation
final ConditionalOperation operation()
The operation to apply to the attribute
-
value
final ConditionalValue value()
A regex string, to be used with
MATCHESorDOES_NOT_MATCH
-
_attribute
final JsonField<Conditional3dsActionParameters.Condition.Attribute> _attribute()
Returns the raw JSON value of attribute.
Unlike attribute, this method doesn't throw if the JSON field has an unexpected type.
-
_operation
final JsonField<ConditionalOperation> _operation()
Returns the raw JSON value of operation.
Unlike operation, this method doesn't throw if the JSON field has an unexpected type.
-
_value
final JsonField<ConditionalValue> _value()
Returns the raw JSON value of value.
Unlike value, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Conditional3dsActionParameters.Condition.Builder toBuilder()
-
validate
final Conditional3dsActionParameters.Condition validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Conditional3dsActionParameters.Condition.Builder builder()
Returns a mutable builder for constructing an instance of Condition.
The following fields are required:
.attribute() .operation() .value()
-
-
-
-