Class Conditional3dsActionParameters.Condition.Builder
-
- All Implemented Interfaces:
public final class Conditional3dsActionParameters.Condition.BuilderA builder for Condition.
-
-
Method Summary
-
-
Method Detail
-
attribute
final Conditional3dsActionParameters.Condition.Builder attribute(Conditional3dsActionParameters.Condition.Attribute attribute)
The attribute to target.
The following attributes may be targeted:
MCC: A four-digit number listed in ISO 18245. An MCC is used to classify a business by the types of goods or services it provides.COUNTRY: Country of entity of card acceptor. Possible values are: (1) all ISO 3166-1 alpha-3 country codes, (2) QZZ for Kosovo, and (3) ANT for Netherlands Antilles.CURRENCY: 3-character alphabetic ISO 4217 code for the merchant currency of the transaction.MERCHANT_ID: Unique alphanumeric identifier for the payment card acceptor (merchant).DESCRIPTOR: Short description of card acceptor.TRANSACTION_AMOUNT: The base transaction amount (in cents) plus the acquirer fee field in the settlement/cardholder billing currency. This is the amount the issuer should authorize against unless the issuer is paying the acquirer fee on behalf of the cardholder.RISK_SCORE: Mastercard only: Assessment by the network of the authentication risk level, with a higher value indicating a higher amount of risk.MESSAGE_CATEGORY: The category of the authentication being processed.ADDRESS_MATCH: Lithic's evaluation result comparing transaction's address data with the cardholder KYC data if it exists. Valid values areMATCH,MATCH_ADDRESS_ONLY,MATCH_ZIP_ONLY,MISMATCH,NOT_PRESENT.
-
attribute
final Conditional3dsActionParameters.Condition.Builder attribute(JsonField<Conditional3dsActionParameters.Condition.Attribute> attribute)
Sets Builder.attribute to an arbitrary JSON value.
You should usually call Builder.attribute with a well-typed Attribute value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
operation
final Conditional3dsActionParameters.Condition.Builder operation(ConditionalOperation operation)
The operation to apply to the attribute
-
operation
final Conditional3dsActionParameters.Condition.Builder operation(JsonField<ConditionalOperation> operation)
Sets Builder.operation to an arbitrary JSON value.
You should usually call Builder.operation with a well-typed ConditionalOperation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
value
final Conditional3dsActionParameters.Condition.Builder value(ConditionalValue value)
A regex string, to be used with
MATCHESorDOES_NOT_MATCH
-
value
final Conditional3dsActionParameters.Condition.Builder value(JsonField<ConditionalValue> value)
Sets Builder.value to an arbitrary JSON value.
You should usually call Builder.value with a well-typed ConditionalValue value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
value
final Conditional3dsActionParameters.Condition.Builder value(String regex)
Alias for calling value with
ConditionalValue.ofRegex(regex).
-
value
final Conditional3dsActionParameters.Condition.Builder value(Long number)
Alias for calling value with
ConditionalValue.ofNumber(number).
-
valueOfListOfStrings
final Conditional3dsActionParameters.Condition.Builder valueOfListOfStrings(List<String> listOfStrings)
Alias for calling value with
ConditionalValue.ofListOfStrings(listOfStrings).
-
additionalProperties
final Conditional3dsActionParameters.Condition.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Conditional3dsActionParameters.Condition.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Conditional3dsActionParameters.Condition.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Conditional3dsActionParameters.Condition.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Conditional3dsActionParameters.Condition.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Conditional3dsActionParameters.Condition build()
Returns an immutable instance of Condition.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.attribute() .operation() .value()
-
-
-
-