Package com.lithic.api.models
Class ConditionalAchActionParameters
-
- All Implemented Interfaces:
public final class ConditionalAchActionParameters
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classConditionalAchActionParameters.BuilderA builder for ConditionalAchActionParameters.
public final classConditionalAchActionParameters.ActionThe action to take if the conditions are met.
public final classConditionalAchActionParameters.Condition
-
Method Summary
Modifier and Type Method Description final ConditionalAchActionParameters.Actionaction()The action to take if the conditions are met. final List<ConditionalAchActionParameters.Condition>conditions()final JsonField<ConditionalAchActionParameters.Action>_action()Returns the raw JSON value of action. final JsonField<List<ConditionalAchActionParameters.Condition>>_conditions()Returns the raw JSON value of conditions. final Map<String, JsonValue>_additionalProperties()final ConditionalAchActionParameters.BuildertoBuilder()final ConditionalAchActionParametersvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ConditionalAchActionParameters.Builderbuilder()Returns a mutable builder for constructing an instance of ConditionalAchActionParameters. -
-
Method Detail
-
action
final ConditionalAchActionParameters.Action action()
The action to take if the conditions are met.
-
conditions
final List<ConditionalAchActionParameters.Condition> conditions()
-
_action
final JsonField<ConditionalAchActionParameters.Action> _action()
Returns the raw JSON value of action.
Unlike action, this method doesn't throw if the JSON field has an unexpected type.
-
_conditions
final JsonField<List<ConditionalAchActionParameters.Condition>> _conditions()
Returns the raw JSON value of conditions.
Unlike conditions, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ConditionalAchActionParameters.Builder toBuilder()
-
validate
final ConditionalAchActionParameters validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ConditionalAchActionParameters.Builder builder()
Returns a mutable builder for constructing an instance of ConditionalAchActionParameters.
The following fields are required:
.action() .conditions()
-
-
-
-