Class ConditionalAuthorizationAdjustmentParameters.Adjustment
-
- All Implemented Interfaces:
public final class ConditionalAuthorizationAdjustmentParameters.AdjustmentThe hold adjustment to apply if the conditions are met
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classConditionalAuthorizationAdjustmentParameters.Adjustment.BuilderA builder for Adjustment.
public final classConditionalAuthorizationAdjustmentParameters.Adjustment.ModeThe mode of the hold adjustment, determining how the value is interpreted:
REPLACE_WITH_AMOUNT: The value is the approved hold amount in cents.ADD_PERCENTAGE: The value adjusts the hold amount by a percentage. 1000 represents a 10% increase, 0 represents no change.ADD_AMOUNT: The value is added to the hold amount in cents.
public final classConditionalAuthorizationAdjustmentParameters.Adjustment.TypeThe type of adjustment to apply
-
Method Summary
Modifier and Type Method Description final ConditionalAuthorizationAdjustmentParameters.Adjustment.Modemode()The mode of the hold adjustment, determining how the value is interpreted: REPLACE_WITH_AMOUNT: The value is the approved hold amount in cents.ADD_PERCENTAGE: The value adjusts the hold amount by a percentage. 1000 represents a 10% increase, 0 represents no change.ADD_AMOUNT: The value is added to the hold amount in cents.
final ConditionalAuthorizationAdjustmentParameters.Adjustment.Typetype()The type of adjustment to apply final Longvalue()The value used for the hold adjustment, interpreted based on the mode final JsonField<ConditionalAuthorizationAdjustmentParameters.Adjustment.Mode>_mode()Returns the raw JSON value of mode. final JsonField<ConditionalAuthorizationAdjustmentParameters.Adjustment.Type>_type()Returns the raw JSON value of type. final JsonField<Long>_value()Returns the raw JSON value of value. final Map<String, JsonValue>_additionalProperties()final ConditionalAuthorizationAdjustmentParameters.Adjustment.BuildertoBuilder()final ConditionalAuthorizationAdjustmentParameters.Adjustmentvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ConditionalAuthorizationAdjustmentParameters.Adjustment.Builderbuilder()Returns a mutable builder for constructing an instance of Adjustment. -
-
Method Detail
-
mode
final ConditionalAuthorizationAdjustmentParameters.Adjustment.Mode mode()
The mode of the hold adjustment, determining how the value is interpreted:
REPLACE_WITH_AMOUNT: The value is the approved hold amount in cents.ADD_PERCENTAGE: The value adjusts the hold amount by a percentage. 1000 represents a 10% increase, 0 represents no change.ADD_AMOUNT: The value is added to the hold amount in cents.
-
type
final ConditionalAuthorizationAdjustmentParameters.Adjustment.Type type()
The type of adjustment to apply
-
_mode
final JsonField<ConditionalAuthorizationAdjustmentParameters.Adjustment.Mode> _mode()
Returns the raw JSON value of mode.
Unlike mode, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<ConditionalAuthorizationAdjustmentParameters.Adjustment.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_value
final JsonField<Long> _value()
Returns the raw JSON value of value.
Unlike value, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ConditionalAuthorizationAdjustmentParameters.Adjustment.Builder toBuilder()
-
validate
final ConditionalAuthorizationAdjustmentParameters.Adjustment validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ConditionalAuthorizationAdjustmentParameters.Adjustment.Builder builder()
Returns a mutable builder for constructing an instance of Adjustment.
The following fields are required:
.mode() .type() .value()
-
-
-