Class ConditionalCardTransactionUpdateActionParameters.Condition.Parameters
-
- All Implemented Interfaces:
public final class ConditionalCardTransactionUpdateActionParameters.Condition.ParametersAdditional parameters for spend velocity attributes. Required when
attributeisSPEND_VELOCITY_COUNTorSPEND_VELOCITY_AMOUNT. Not used for other attributes.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classConditionalCardTransactionUpdateActionParameters.Condition.Parameters.BuilderA builder for Parameters.
public final classConditionalCardTransactionUpdateActionParameters.Condition.Parameters.ScopeThe entity scope to evaluate the attribute against.
-
Method Summary
-
-
Method Detail
-
filters
final Optional<SpendVelocityFilters> filters()
-
period
final Optional<VelocityLimitPeriod> period()
The time period over which to calculate the spend velocity.
-
scope
final Optional<ConditionalCardTransactionUpdateActionParameters.Condition.Parameters.Scope> scope()
The entity scope to evaluate the attribute against.
-
_filters
final JsonField<SpendVelocityFilters> _filters()
Returns the raw JSON value of filters.
Unlike filters, this method doesn't throw if the JSON field has an unexpected type.
-
_period
final JsonField<VelocityLimitPeriod> _period()
Returns the raw JSON value of period.
Unlike period, this method doesn't throw if the JSON field has an unexpected type.
-
_scope
final JsonField<ConditionalCardTransactionUpdateActionParameters.Condition.Parameters.Scope> _scope()
Returns the raw JSON value of scope.
Unlike scope, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ConditionalCardTransactionUpdateActionParameters.Condition.Parameters.Builder toBuilder()
-
validate
final ConditionalCardTransactionUpdateActionParameters.Condition.Parameters validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ConditionalCardTransactionUpdateActionParameters.Condition.Parameters.Builder builder()
Returns a mutable builder for constructing an instance of Parameters.
-
-
-
-