Class ConditionalTokenizationActionParameters.Condition.Attribute

  • All Implemented Interfaces:
    com.lithic.api.core.Enum

    
    public final class ConditionalTokenizationActionParameters.Condition.Attribute
     implements Enum
                        

    The attribute to target.

    The following attributes may be targeted:

    • TIMESTAMP: The timestamp of the tokenization request in ISO 8601 format.

    • TOKENIZATION_CHANNEL: The channel through which the tokenization request was initiated (e.g., DIGITAL_WALLET, ECOMMERCE).

    • TOKENIZATION_SOURCE: The source of the tokenization request.

    • TOKEN_REQUESTOR_NAME: The name of the entity requesting the token. Valid values are ALT_ID, AMAZON_ONE, AMERICAN_EXPRESS_TOKEN_SERVICE, ANDROID_PAY, APPLE_PAY, FACEBOOK, FITBIT_PAY, GARMIN_PAY, GOOGLE_PAY, GOOGLE_VCN, ISSUER_HCE, MICROSOFT_PAY, NETFLIX, SAMSUNG_PAY, UNKNOWN, VISA_CHECKOUT.

    • WALLET_ACCOUNT_SCORE: Risk score for the account in the digital wallet. Numeric value where lower numbers indicate higher risk (e.g., 1 = high risk, 2 = medium risk).

    • WALLET_DEVICE_SCORE: Risk score for the device in the digital wallet. Numeric value where lower numbers indicate higher risk (e.g., 1 = high risk, 2 = medium risk).

    • WALLET_RECOMMENDED_DECISION: The decision recommended by the digital wallet provider. Valid values include APPROVE, DECLINE, REQUIRE_ADDITIONAL_AUTHENTICATION.

    • WALLET_RECOMMENDATION_REASONS: List of reasons provided by the digital wallet provider for the recommended decision. Valid values are ACCOUNT_CARD_TOO_NEW, ACCOUNT_RECENTLY_CHANGED, ACCOUNT_TOO_NEW, ACCOUNT_TOO_NEW_SINCE_LAUNCH, DEVICE_RECENTLY_LOST, HAS_SUSPENDED_TOKENS, HIGH_RISK, INACTIVE_ACCOUNT, LOW_ACCOUNT_SCORE, LOW_DEVICE_SCORE, OUTSIDE_HOME_TERRITORY, SUSPICIOUS_ACTIVITY, TOO_MANY_DIFFERENT_CARDHOLDERS, TOO_MANY_RECENT_ATTEMPTS, TOO_MANY_RECENT_TOKENS, UNABLE_TO_ASSESS.

    • TOKEN_REQUESTOR_ID: Unique identifier for the entity requesting the token.

    • WALLET_TOKEN_STATUS: The current status of the wallet token.