Class DigitalCardArt
-
- All Implemented Interfaces:
public final class DigitalCardArt
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalCardArt.BuilderA builder for DigitalCardArt.
public final classDigitalCardArt.NetworkCard network.
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier for the card art. final StringcardProgramToken()Globally unique identifier for the card program. final OffsetDateTimecreated()Timestamp of when card art was created. final Stringdescription()Description of the card art. final BooleanisEnabled()Whether the card art is enabled. final DigitalCardArt.Networknetwork()Card network. final Optional<Boolean>isCardProgramDefault()Whether the card art is the default card art to be added upon tokenization. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<String>_cardProgramToken()Returns the raw JSON value of cardProgramToken. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<Boolean>_isEnabled()Returns the raw JSON value of isEnabled. final JsonField<DigitalCardArt.Network>_network()Returns the raw JSON value of network. final JsonField<Boolean>_isCardProgramDefault()Returns the raw JSON value of isCardProgramDefault. final Map<String, JsonValue>_additionalProperties()final DigitalCardArt.BuildertoBuilder()final DigitalCardArtvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DigitalCardArt.Builderbuilder()Returns a mutable builder for constructing an instance of DigitalCardArt. -
-
Method Detail
-
cardProgramToken
final String cardProgramToken()
Globally unique identifier for the card program.
-
created
final OffsetDateTime created()
Timestamp of when card art was created.
-
description
final String description()
Description of the card art.
-
network
final DigitalCardArt.Network network()
Card network.
-
isCardProgramDefault
final Optional<Boolean> isCardProgramDefault()
Whether the card art is the default card art to be added upon tokenization.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_cardProgramToken
final JsonField<String> _cardProgramToken()
Returns the raw JSON value of cardProgramToken.
Unlike cardProgramToken, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_isEnabled
final JsonField<Boolean> _isEnabled()
Returns the raw JSON value of isEnabled.
Unlike isEnabled, this method doesn't throw if the JSON field has an unexpected type.
-
_network
final JsonField<DigitalCardArt.Network> _network()
Returns the raw JSON value of network.
Unlike network, this method doesn't throw if the JSON field has an unexpected type.
-
_isCardProgramDefault
final JsonField<Boolean> _isCardProgramDefault()
Returns the raw JSON value of isCardProgramDefault.
Unlike isCardProgramDefault, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DigitalCardArt.Builder toBuilder()
-
validate
final DigitalCardArt validate()
-
builder
final static DigitalCardArt.Builder builder()
Returns a mutable builder for constructing an instance of DigitalCardArt.
The following fields are required:
.token() .cardProgramToken() .created() .description() .isEnabled() .network()
-
-
-
-