Class DigitalWalletTokenMetadata.TokenRequestorName
-
- All Implemented Interfaces:
-
com.lithic.api.core.Enum
public final class DigitalWalletTokenMetadata.TokenRequestorName implements EnumHuman-readable name of the wallet that the token_requestor_id maps to.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumDigitalWalletTokenMetadata.TokenRequestorName.KnownAn enum containing TokenRequestorName's known values.
public enumDigitalWalletTokenMetadata.TokenRequestorName.ValueAn enum containing TokenRequestorName's known values, as well as an _UNKNOWN member.
An instance of TokenRequestorName can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static DigitalWalletTokenMetadata.TokenRequestorNameAMAZON_ONEpublic final static DigitalWalletTokenMetadata.TokenRequestorNameANDROID_PAYpublic final static DigitalWalletTokenMetadata.TokenRequestorNameAPPLE_PAYpublic final static DigitalWalletTokenMetadata.TokenRequestorNameFACEBOOKpublic final static DigitalWalletTokenMetadata.TokenRequestorNameFITBIT_PAYpublic final static DigitalWalletTokenMetadata.TokenRequestorNameGARMIN_PAYpublic final static DigitalWalletTokenMetadata.TokenRequestorNameMICROSOFT_PAYpublic final static DigitalWalletTokenMetadata.TokenRequestorNameNETFLIXpublic final static DigitalWalletTokenMetadata.TokenRequestorNameSAMSUNG_PAYpublic final static DigitalWalletTokenMetadata.TokenRequestorNameUNKNOWNpublic final static DigitalWalletTokenMetadata.TokenRequestorNameVISA_CHECKOUT
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final DigitalWalletTokenMetadata.TokenRequestorName.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final DigitalWalletTokenMetadata.TokenRequestorName.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. final DigitalWalletTokenMetadata.TokenRequestorNamevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DigitalWalletTokenMetadata.TokenRequestorNameof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final DigitalWalletTokenMetadata.TokenRequestorName.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final DigitalWalletTokenMetadata.TokenRequestorName.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
validate
final DigitalWalletTokenMetadata.TokenRequestorName validate()
-
of
final static DigitalWalletTokenMetadata.TokenRequestorName of(String value)
-
-
-
-