Class DigitalWalletTokenizationApprovalRequestWebhookEvent
-
- All Implemented Interfaces:
public final class DigitalWalletTokenizationApprovalRequestWebhookEventPayload for digital wallet tokenization approval requests. Used for both the decisioning responder request (sent to the customer's endpoint for a real-time decision) and the subsequent webhook event (sent after the decision is made). Fields like customer_tokenization_decision, tokenization_decline_reasons, tokenization_tfa_reasons, and rule_results are only populated in the webhook event, not in the initial decisioning request.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalWalletTokenizationApprovalRequestWebhookEvent.BuilderA builder for DigitalWalletTokenizationApprovalRequestWebhookEvent.
public final classDigitalWalletTokenizationApprovalRequestWebhookEvent.EventTypeThe name of this event
public final classDigitalWalletTokenizationApprovalRequestWebhookEvent.IssuerDecisionWhether Lithic decisioned on the token, and if so, what the decision was. APPROVED/VERIFICATION_REQUIRED/DENIED.
public final classDigitalWalletTokenizationApprovalRequestWebhookEvent.TokenizationChannelThe channel through which the tokenization was made.
public final classDigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecisionContains the metadata for the customer tokenization decision.
public final classDigitalWalletTokenizationApprovalRequestWebhookEvent.TokenizationSourceThe source of the tokenization.
-
Method Summary
-
-
Method Detail
-
accountToken
final String accountToken()
Unique identifier for the user tokenizing a card
-
created
final OffsetDateTime created()
Indicate when the request was received from Mastercard or Visa
-
digitalWalletTokenMetadata
final TokenMetadata digitalWalletTokenMetadata()
Contains the metadata for the digital wallet being tokenized.
-
eventType
final DigitalWalletTokenizationApprovalRequestWebhookEvent.EventType eventType()
The name of this event
-
issuerDecision
final DigitalWalletTokenizationApprovalRequestWebhookEvent.IssuerDecision issuerDecision()
Whether Lithic decisioned on the token, and if so, what the decision was. APPROVED/VERIFICATION_REQUIRED/DENIED.
-
tokenizationChannel
final DigitalWalletTokenizationApprovalRequestWebhookEvent.TokenizationChannel tokenizationChannel()
The channel through which the tokenization was made.
-
tokenizationToken
final String tokenizationToken()
Unique identifier for the digital wallet token attempt
-
walletDecisioningInfo
final WalletDecisioningInfo walletDecisioningInfo()
-
customerTokenizationDecision
final Optional<DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision> customerTokenizationDecision()
Contains the metadata for the customer tokenization decision.
-
ruleResults
final Optional<List<TokenizationRuleResult>> ruleResults()
Results from rules that were evaluated for this tokenization. Only populated in webhook events, not in the initial decisioning request
-
tokenizationDeclineReasons
final Optional<List<TokenizationDeclineReason>> tokenizationDeclineReasons()
List of reasons why the tokenization was declined. Only populated in webhook events, not in the initial decisioning request
-
tokenizationSource
final Optional<DigitalWalletTokenizationApprovalRequestWebhookEvent.TokenizationSource> tokenizationSource()
The source of the tokenization.
-
tokenizationTfaReasons
final Optional<List<TokenizationTfaReason>> tokenizationTfaReasons()
List of reasons why two-factor authentication was required. Only populated in webhook events, not in the initial decisioning request
-
_accountToken
final JsonField<String> _accountToken()
Returns the raw JSON value of accountToken.
Unlike accountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_cardToken
final JsonField<String> _cardToken()
Returns the raw JSON value of cardToken.
Unlike cardToken, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_digitalWalletTokenMetadata
final JsonField<TokenMetadata> _digitalWalletTokenMetadata()
Returns the raw JSON value of digitalWalletTokenMetadata.
Unlike digitalWalletTokenMetadata, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<DigitalWalletTokenizationApprovalRequestWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_issuerDecision
final JsonField<DigitalWalletTokenizationApprovalRequestWebhookEvent.IssuerDecision> _issuerDecision()
Returns the raw JSON value of issuerDecision.
Unlike issuerDecision, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenizationChannel
final JsonField<DigitalWalletTokenizationApprovalRequestWebhookEvent.TokenizationChannel> _tokenizationChannel()
Returns the raw JSON value of tokenizationChannel.
Unlike tokenizationChannel, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenizationToken
final JsonField<String> _tokenizationToken()
Returns the raw JSON value of tokenizationToken.
Unlike tokenizationToken, this method doesn't throw if the JSON field has an unexpected type.
-
_walletDecisioningInfo
final JsonField<WalletDecisioningInfo> _walletDecisioningInfo()
Returns the raw JSON value of walletDecisioningInfo.
Unlike walletDecisioningInfo, this method doesn't throw if the JSON field has an unexpected type.
-
_customerTokenizationDecision
final JsonField<DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision> _customerTokenizationDecision()
Returns the raw JSON value of customerTokenizationDecision.
Unlike customerTokenizationDecision, this method doesn't throw if the JSON field has an unexpected type.
-
_device
final JsonField<Device> _device()
Returns the raw JSON value of device.
Unlike device, this method doesn't throw if the JSON field has an unexpected type.
-
_ruleResults
final JsonField<List<TokenizationRuleResult>> _ruleResults()
Returns the raw JSON value of ruleResults.
Unlike ruleResults, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenizationDeclineReasons
final JsonField<List<TokenizationDeclineReason>> _tokenizationDeclineReasons()
Returns the raw JSON value of tokenizationDeclineReasons.
Unlike tokenizationDeclineReasons, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenizationSource
final JsonField<DigitalWalletTokenizationApprovalRequestWebhookEvent.TokenizationSource> _tokenizationSource()
Returns the raw JSON value of tokenizationSource.
Unlike tokenizationSource, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenizationTfaReasons
final JsonField<List<TokenizationTfaReason>> _tokenizationTfaReasons()
Returns the raw JSON value of tokenizationTfaReasons.
Unlike tokenizationTfaReasons, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder toBuilder()
-
validate
final DigitalWalletTokenizationApprovalRequestWebhookEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of DigitalWalletTokenizationApprovalRequestWebhookEvent.
The following fields are required:
.accountToken() .cardToken() .created() .digitalWalletTokenMetadata() .eventType() .issuerDecision() .tokenizationChannel() .tokenizationToken() .walletDecisioningInfo()
-
-
-
-