Class DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision
-
- All Implemented Interfaces:
public final class DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecisionContains the metadata for the customer tokenization decision.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision.BuilderA builder for CustomerTokenizationDecision.
public final classDigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision.OutcomeThe outcome of the customer's decision
-
Method Summary
-
-
Method Detail
-
outcome
final DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision.Outcome outcome()
The outcome of the customer's decision
-
responderUrl
final String responderUrl()
The customer's subscribed URL
-
responseCode
final Optional<String> responseCode()
The response code that the customer provided
-
_outcome
final JsonField<DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision.Outcome> _outcome()
Returns the raw JSON value of outcome.
Unlike outcome, this method doesn't throw if the JSON field has an unexpected type.
-
_responderUrl
final JsonField<String> _responderUrl()
Returns the raw JSON value of responderUrl.
Unlike responderUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_latency
final JsonField<String> _latency()
Returns the raw JSON value of latency.
Unlike latency, this method doesn't throw if the JSON field has an unexpected type.
-
_responseCode
final JsonField<String> _responseCode()
Returns the raw JSON value of responseCode.
Unlike responseCode, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision.Builder toBuilder()
-
validate
final DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision.Builder builder()
Returns a mutable builder for constructing an instance of CustomerTokenizationDecision.
The following fields are required:
.outcome() .responderUrl()
-
-
-
-