Class DigitalWalletTokenizationUpdatedWebhookEvent
-
- All Implemented Interfaces:
public final class DigitalWalletTokenizationUpdatedWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalWalletTokenizationUpdatedWebhookEvent.BuilderA builder for DigitalWalletTokenizationUpdatedWebhookEvent.
public final classDigitalWalletTokenizationUpdatedWebhookEvent.EventTypeThe type of event that occurred.
-
Method Summary
-
-
Method Detail
-
accountToken
final String accountToken()
Account token
-
created
final OffsetDateTime created()
Created date
-
eventType
final DigitalWalletTokenizationUpdatedWebhookEvent.EventType eventType()
The type of event that occurred.
-
tokenization
final Tokenization tokenization()
-
_accountToken
final JsonField<String> _accountToken()
Returns the raw JSON value of accountToken.
Unlike accountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_cardToken
final JsonField<String> _cardToken()
Returns the raw JSON value of cardToken.
Unlike cardToken, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<DigitalWalletTokenizationUpdatedWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenization
final JsonField<Tokenization> _tokenization()
Returns the raw JSON value of tokenization.
Unlike tokenization, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DigitalWalletTokenizationUpdatedWebhookEvent.Builder toBuilder()
-
validate
final DigitalWalletTokenizationUpdatedWebhookEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DigitalWalletTokenizationUpdatedWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of DigitalWalletTokenizationUpdatedWebhookEvent.
The following fields are required:
.accountToken() .cardToken() .created() .eventType() .tokenization()
-
-
-
-