Package com.lithic.api.models
Class Dispute.Event
-
- All Implemented Interfaces:
public final class Dispute.EventEvent that occurred in the dispute lifecycle
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDispute.Event.BuilderA builder for Event.
public final classDispute.Event.DataDetails specific to the event type
public final classDispute.Event.TypeType of event
-
Method Summary
Modifier and Type Method Description final Stringtoken()Unique identifier for the event, in UUID format final OffsetDateTimecreated()When the event occurred final Dispute.Event.Datadata()Details specific to the event type final Dispute.Event.Typetype()Type of event final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<Dispute.Event.Data>_data()Returns the raw JSON value of data. final JsonField<Dispute.Event.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final Dispute.Event.BuildertoBuilder()final Dispute.Eventvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Dispute.Event.Builderbuilder()Returns a mutable builder for constructing an instance of Event. -
-
Method Detail
-
created
final OffsetDateTime created()
When the event occurred
-
data
final Dispute.Event.Data data()
Details specific to the event type
-
type
final Dispute.Event.Type type()
Type of event
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_data
final JsonField<Dispute.Event.Data> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<Dispute.Event.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Dispute.Event.Builder toBuilder()
-
validate
final Dispute.Event validate()
-
builder
final static Dispute.Event.Builder builder()
Returns a mutable builder for constructing an instance of Event.
The following fields are required:
.token() .created() .data() .type()
-
-
-
-