Package com.lithic.api.models
Class Dispute.Event.Data.FinancialEventData
-
- All Implemented Interfaces:
public final class Dispute.Event.Data.FinancialEventDataDetails specific to financial events
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDispute.Event.Data.FinancialEventData.BuilderA builder for FinancialEventData.
public final classDispute.Event.Data.FinancialEventData.PolarityDirection of funds flow
public final classDispute.Event.Data.FinancialEventData.StageStage at which the financial event occurred
-
Method Summary
Modifier and Type Method Description final Longamount()Amount in minor units final Dispute.Event.Data.FinancialEventData.Polaritypolarity()Direction of funds flow final Dispute.Event.Data.FinancialEventData.Stagestage()Stage at which the financial event occurred final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<Dispute.Event.Data.FinancialEventData.Polarity>_polarity()Returns the raw JSON value of polarity. final JsonField<Dispute.Event.Data.FinancialEventData.Stage>_stage()Returns the raw JSON value of stage. final Map<String, JsonValue>_additionalProperties()final Dispute.Event.Data.FinancialEventData.BuildertoBuilder()final Dispute.Event.Data.FinancialEventDatavalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Dispute.Event.Data.FinancialEventData.Builderbuilder()Returns a mutable builder for constructing an instance of FinancialEventData. -
-
Method Detail
-
polarity
final Dispute.Event.Data.FinancialEventData.Polarity polarity()
Direction of funds flow
-
stage
final Dispute.Event.Data.FinancialEventData.Stage stage()
Stage at which the financial event occurred
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_polarity
final JsonField<Dispute.Event.Data.FinancialEventData.Polarity> _polarity()
Returns the raw JSON value of polarity.
Unlike polarity, this method doesn't throw if the JSON field has an unexpected type.
-
_stage
final JsonField<Dispute.Event.Data.FinancialEventData.Stage> _stage()
Returns the raw JSON value of stage.
Unlike stage, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Dispute.Event.Data.FinancialEventData.Builder toBuilder()
-
validate
final Dispute.Event.Data.FinancialEventData validate()
-
builder
final static Dispute.Event.Data.FinancialEventData.Builder builder()
Returns a mutable builder for constructing an instance of FinancialEventData.
The following fields are required:
.amount() .polarity() .stage()
-
-
-
-