Class Dispute.Event.Data.FinancialEventData.Builder
-
- All Implemented Interfaces:
public final class Dispute.Event.Data.FinancialEventData.BuilderA builder for FinancialEventData.
-
-
Method Summary
-
-
Method Detail
-
amount
final Dispute.Event.Data.FinancialEventData.Builder amount(Long amount)
Amount in minor units
-
amount
final Dispute.Event.Data.FinancialEventData.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
polarity
final Dispute.Event.Data.FinancialEventData.Builder polarity(Dispute.Event.Data.FinancialEventData.Polarity polarity)
Direction of funds flow
-
polarity
final Dispute.Event.Data.FinancialEventData.Builder polarity(JsonField<Dispute.Event.Data.FinancialEventData.Polarity> polarity)
Sets Builder.polarity to an arbitrary JSON value.
You should usually call Builder.polarity with a well-typed Polarity value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
stage
final Dispute.Event.Data.FinancialEventData.Builder stage(Dispute.Event.Data.FinancialEventData.Stage stage)
Stage at which the financial event occurred
-
stage
final Dispute.Event.Data.FinancialEventData.Builder stage(JsonField<Dispute.Event.Data.FinancialEventData.Stage> stage)
Sets Builder.stage to an arbitrary JSON value.
You should usually call Builder.stage with a well-typed Stage value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Dispute.Event.Data.FinancialEventData.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Dispute.Event.Data.FinancialEventData.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Dispute.Event.Data.FinancialEventData.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Dispute.Event.Data.FinancialEventData.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Dispute.Event.Data.FinancialEventData.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Dispute.Event.Data.FinancialEventData build()
Returns an immutable instance of FinancialEventData.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.amount() .polarity() .stage()
-
-
-
-