Class Dispute.Event.Data.WorkflowEventData
-
- All Implemented Interfaces:
public final class Dispute.Event.Data.WorkflowEventDataDetails specific to workflow events
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDispute.Event.Data.WorkflowEventData.BuilderA builder for WorkflowEventData.
public final classDispute.Event.Data.WorkflowEventData.ActionAction taken in this stage
public final classDispute.Event.Data.WorkflowEventData.DispositionDispute resolution outcome
public final classDispute.Event.Data.WorkflowEventData.StageCurrent stage of the dispute workflow
-
Method Summary
-
-
Method Detail
-
action
final Dispute.Event.Data.WorkflowEventData.Action action()
Action taken in this stage
-
disposition
final Optional<Dispute.Event.Data.WorkflowEventData.Disposition> disposition()
Dispute resolution outcome
-
stage
final Dispute.Event.Data.WorkflowEventData.Stage stage()
Current stage of the dispute workflow
-
_action
final JsonField<Dispute.Event.Data.WorkflowEventData.Action> _action()
Returns the raw JSON value of action.
Unlike action, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_disposition
final JsonField<Dispute.Event.Data.WorkflowEventData.Disposition> _disposition()
Returns the raw JSON value of disposition.
Unlike disposition, this method doesn't throw if the JSON field has an unexpected type.
-
_reason
final JsonField<String> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_stage
final JsonField<Dispute.Event.Data.WorkflowEventData.Stage> _stage()
Returns the raw JSON value of stage.
Unlike stage, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Dispute.Event.Data.WorkflowEventData.Builder toBuilder()
-
validate
final Dispute.Event.Data.WorkflowEventData validate()
-
builder
final static Dispute.Event.Data.WorkflowEventData.Builder builder()
Returns a mutable builder for constructing an instance of WorkflowEventData.
The following fields are required:
.action() .amount() .disposition() .reason() .stage()
-
-
-
-