Class Dispute.LiabilityAllocation
-
- All Implemented Interfaces:
public final class Dispute.LiabilityAllocationCurrent breakdown of how liability is allocated for the disputed amount
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDispute.LiabilityAllocation.BuilderA builder for LiabilityAllocation.
-
Method Summary
Modifier and Type Method Description final LongdeniedAmount()The amount that has been denied to the cardholder final LongoriginalAmount()The initial amount disputed final LongrecoveredAmount()The amount that has been recovered from the merchant through the dispute process final LongremainingAmount()Any disputed amount that is still outstanding, i.e. final LongwrittenOffAmount()The amount the issuer has chosen to write off final JsonField<Long>_deniedAmount()Returns the raw JSON value of deniedAmount. final JsonField<Long>_originalAmount()Returns the raw JSON value of originalAmount. final JsonField<Long>_recoveredAmount()Returns the raw JSON value of recoveredAmount. final JsonField<Long>_remainingAmount()Returns the raw JSON value of remainingAmount. final JsonField<Long>_writtenOffAmount()Returns the raw JSON value of writtenOffAmount. final Map<String, JsonValue>_additionalProperties()final Dispute.LiabilityAllocation.BuildertoBuilder()final Dispute.LiabilityAllocationvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Dispute.LiabilityAllocation.Builderbuilder()Returns a mutable builder for constructing an instance of LiabilityAllocation. -
-
Method Detail
-
deniedAmount
final Long deniedAmount()
The amount that has been denied to the cardholder
-
originalAmount
final Long originalAmount()
The initial amount disputed
-
recoveredAmount
final Long recoveredAmount()
The amount that has been recovered from the merchant through the dispute process
-
remainingAmount
final Long remainingAmount()
Any disputed amount that is still outstanding, i.e. has not been recovered, written off, or denied
-
writtenOffAmount
final Long writtenOffAmount()
The amount the issuer has chosen to write off
-
_deniedAmount
final JsonField<Long> _deniedAmount()
Returns the raw JSON value of deniedAmount.
Unlike deniedAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_originalAmount
final JsonField<Long> _originalAmount()
Returns the raw JSON value of originalAmount.
Unlike originalAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_recoveredAmount
final JsonField<Long> _recoveredAmount()
Returns the raw JSON value of recoveredAmount.
Unlike recoveredAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_remainingAmount
final JsonField<Long> _remainingAmount()
Returns the raw JSON value of remainingAmount.
Unlike remainingAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_writtenOffAmount
final JsonField<Long> _writtenOffAmount()
Returns the raw JSON value of writtenOffAmount.
Unlike writtenOffAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Dispute.LiabilityAllocation.Builder toBuilder()
-
validate
final Dispute.LiabilityAllocation validate()
-
builder
final static Dispute.LiabilityAllocation.Builder builder()
Returns a mutable builder for constructing an instance of LiabilityAllocation.
The following fields are required:
.deniedAmount() .originalAmount() .recoveredAmount() .remainingAmount() .writtenOffAmount()
-
-
-
-