Class DisputeRetrieveResponse.Status
-
- All Implemented Interfaces:
-
com.lithic.api.core.Enum
public final class DisputeRetrieveResponse.Status implements EnumStatus types:
NEW- New dispute case is opened.PENDING_CUSTOMER- Lithic is waiting for customer to provide more information.SUBMITTED- Dispute is submitted to the card network.REPRESENTMENT- Case has entered second presentment.PREARBITRATION- Case has entered prearbitration.ARBITRATION- Case has entered arbitration.CASE_WON- Case was won and credit will be issued.CASE_CLOSED- Case was lost or withdrawn.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumDisputeRetrieveResponse.Status.KnownAn enum containing Status's known values.
public enumDisputeRetrieveResponse.Status.ValueAn enum containing Status's known values, as well as an _UNKNOWN member.
An instance of Status can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static DisputeRetrieveResponse.StatusARBITRATIONpublic final static DisputeRetrieveResponse.StatusCASE_CLOSEDpublic final static DisputeRetrieveResponse.StatusCASE_WONpublic final static DisputeRetrieveResponse.StatusNEWpublic final static DisputeRetrieveResponse.StatusPENDING_CUSTOMERpublic final static DisputeRetrieveResponse.StatusPREARBITRATIONpublic final static DisputeRetrieveResponse.StatusREPRESENTMENTpublic final static DisputeRetrieveResponse.StatusSUBMITTED
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final DisputeRetrieveResponse.Status.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final DisputeRetrieveResponse.Status.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. final DisputeRetrieveResponse.Statusvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DisputeRetrieveResponse.Statusof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final DisputeRetrieveResponse.Status.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final DisputeRetrieveResponse.Status.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
validate
final DisputeRetrieveResponse.Status validate()
-
of
final static DisputeRetrieveResponse.Status of(String value)
-
-
-
-