Class DisputeUpdateParams.Body
-
- All Implemented Interfaces:
public final class DisputeUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDisputeUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<Long>amount()Amount for chargeback final Optional<OffsetDateTime>customerFiledDate()Date the customer filed the chargeback request final Optional<String>customerNote()Customer description final Optional<DisputeUpdateParams.Reason>reason()Reason for chargeback final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<OffsetDateTime>_customerFiledDate()Returns the raw JSON value of customerFiledDate. final JsonField<String>_customerNote()Returns the raw JSON value of customerNote. final JsonField<DisputeUpdateParams.Reason>_reason()Returns the raw JSON value of reason. final Map<String, JsonValue>_additionalProperties()final DisputeUpdateParams.Body.BuildertoBuilder()final DisputeUpdateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DisputeUpdateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
customerFiledDate
final Optional<OffsetDateTime> customerFiledDate()
Date the customer filed the chargeback request
-
customerNote
final Optional<String> customerNote()
Customer description
-
reason
final Optional<DisputeUpdateParams.Reason> reason()
Reason for chargeback
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_customerFiledDate
final JsonField<OffsetDateTime> _customerFiledDate()
Returns the raw JSON value of customerFiledDate.
Unlike customerFiledDate, this method doesn't throw if the JSON field has an unexpected type.
-
_customerNote
final JsonField<String> _customerNote()
Returns the raw JSON value of customerNote.
Unlike customerNote, this method doesn't throw if the JSON field has an unexpected type.
-
_reason
final JsonField<DisputeUpdateParams.Reason> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DisputeUpdateParams.Body.Builder toBuilder()
-
validate
final DisputeUpdateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DisputeUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-