Class DisputeUpdateResponse.Reason
-
- All Implemented Interfaces:
-
com.lithic.api.core.Enum
public final class DisputeUpdateResponse.Reason implements EnumDispute reason:
ATM_CASH_MISDISPENSE: ATM cash misdispense.CANCELLED: Transaction was cancelled by the customer.DUPLICATED: The transaction was a duplicate.FRAUD_CARD_NOT_PRESENT: Fraudulent transaction, card not present.FRAUD_CARD_PRESENT: Fraudulent transaction, card present.FRAUD_OTHER: Fraudulent transaction, other types such as questionable merchant activity.GOODS_SERVICES_NOT_AS_DESCRIBED: The goods or services were not as described.GOODS_SERVICES_NOT_RECEIVED: The goods or services were not received.INCORRECT_AMOUNT: The transaction amount was incorrect.MISSING_AUTH: The transaction was missing authorization.OTHER: Other reason.PROCESSING_ERROR: Processing error.REFUND_NOT_PROCESSED: The refund was not processed.RECURRING_TRANSACTION_NOT_CANCELLED: The recurring transaction was not cancelled.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumDisputeUpdateResponse.Reason.KnownAn enum containing Reason's known values.
public enumDisputeUpdateResponse.Reason.ValueAn enum containing Reason's known values, as well as an _UNKNOWN member.
An instance of Reason can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static DisputeUpdateResponse.ReasonATM_CASH_MISDISPENSEpublic final static DisputeUpdateResponse.ReasonCANCELLEDpublic final static DisputeUpdateResponse.ReasonDUPLICATEDpublic final static DisputeUpdateResponse.ReasonFRAUD_CARD_NOT_PRESENTpublic final static DisputeUpdateResponse.ReasonFRAUD_CARD_PRESENTpublic final static DisputeUpdateResponse.ReasonFRAUD_OTHERpublic final static DisputeUpdateResponse.ReasonGOODS_SERVICES_NOT_AS_DESCRIBEDpublic final static DisputeUpdateResponse.ReasonGOODS_SERVICES_NOT_RECEIVEDpublic final static DisputeUpdateResponse.ReasonINCORRECT_AMOUNTpublic final static DisputeUpdateResponse.ReasonMISSING_AUTHpublic final static DisputeUpdateResponse.ReasonOTHERpublic final static DisputeUpdateResponse.ReasonPROCESSING_ERRORpublic final static DisputeUpdateResponse.ReasonRECURRING_TRANSACTION_NOT_CANCELLEDpublic final static DisputeUpdateResponse.ReasonREFUND_NOT_PROCESSED
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final DisputeUpdateResponse.Reason.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final DisputeUpdateResponse.Reason.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. final DisputeUpdateResponse.Reasonvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DisputeUpdateResponse.Reasonof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final DisputeUpdateResponse.Reason.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final DisputeUpdateResponse.Reason.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
validate
final DisputeUpdateResponse.Reason validate()
-
of
final static DisputeUpdateResponse.Reason of(String value)
-
-
-
-