Package com.lithic.api.models
Enum DisputeUpdateResponse.ResolutionReason.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum DisputeUpdateResponse.ResolutionReason.Known extends Enum<DisputeUpdateResponse.ResolutionReason.Known>
An enum containing ResolutionReason's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<DisputeUpdateResponse.ResolutionReason.Known>entries
-
Enum Constant Summary
-
Method Summary
Modifier and Type Method Description final DisputeUpdateResponse.ResolutionReason.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<DisputeUpdateResponse.ResolutionReason.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<DisputeUpdateResponse.ResolutionReason.Known>getEntries()An enum containing ResolutionReason's known values. -
-
Method Detail
-
valueOf
final DisputeUpdateResponse.ResolutionReason.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<DisputeUpdateResponse.ResolutionReason.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<DisputeUpdateResponse.ResolutionReason.Known> getEntries()
An enum containing ResolutionReason's known values.
-
-
-
-