Package com.lithic.api.models
Class DisputeV2.Event
-
- All Implemented Interfaces:
public final class DisputeV2.EventEvent that occurred in the dispute lifecycle
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDisputeV2.Event.BuilderA builder for Event.
public final classDisputeV2.Event.DataDetails specific to the event type
public final classDisputeV2.Event.TypeType of event
-
Method Summary
Modifier and Type Method Description final Stringtoken()Unique identifier for the event, in UUID format final OffsetDateTimecreated()When the event occurred final DisputeV2.Event.Datadata()Details specific to the event type final DisputeV2.Event.Typetype()Type of event final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<DisputeV2.Event.Data>_data()Returns the raw JSON value of data. final JsonField<DisputeV2.Event.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final DisputeV2.Event.BuildertoBuilder()final DisputeV2.Eventvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DisputeV2.Event.Builderbuilder()Returns a mutable builder for constructing an instance of Event. -
-
Method Detail
-
created
final OffsetDateTime created()
When the event occurred
-
data
final DisputeV2.Event.Data data()
Details specific to the event type
-
type
final DisputeV2.Event.Type type()
Type of event
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_data
final JsonField<DisputeV2.Event.Data> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<DisputeV2.Event.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DisputeV2.Event.Builder toBuilder()
-
validate
final DisputeV2.Event validate()
-
builder
final static DisputeV2.Event.Builder builder()
Returns a mutable builder for constructing an instance of Event.
The following fields are required:
.token() .created() .data() .type()
-
-
-
-