Class DisputeV2.Event.Data.CardholderLiabilityEventData
-
- All Implemented Interfaces:
public final class DisputeV2.Event.Data.CardholderLiabilityEventDataDetails specific to cardholder liability events
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDisputeV2.Event.Data.CardholderLiabilityEventData.BuilderA builder for CardholderLiabilityEventData.
public final classDisputeV2.Event.Data.CardholderLiabilityEventData.ActionAction taken regarding cardholder liability
public final classDisputeV2.Event.Data.CardholderLiabilityEventData.TypeEvent type discriminator
-
Method Summary
-
-
Method Detail
-
action
final DisputeV2.Event.Data.CardholderLiabilityEventData.Action action()
Action taken regarding cardholder liability
-
type
final DisputeV2.Event.Data.CardholderLiabilityEventData.Type type()
Event type discriminator
-
_action
final JsonField<DisputeV2.Event.Data.CardholderLiabilityEventData.Action> _action()
Returns the raw JSON value of action.
Unlike action, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_reason
final JsonField<String> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<DisputeV2.Event.Data.CardholderLiabilityEventData.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DisputeV2.Event.Data.CardholderLiabilityEventData.Builder toBuilder()
-
validate
final DisputeV2.Event.Data.CardholderLiabilityEventData validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DisputeV2.Event.Data.CardholderLiabilityEventData.Builder builder()
Returns a mutable builder for constructing an instance of CardholderLiabilityEventData.
The following fields are required:
.action() .amount() .reason() .type()
-
-
-
-