Class Document
-
- All Implemented Interfaces:
public final class DocumentDescribes the document and the required document image uploads required to re-run KYC
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDocument.BuilderA builder for Document.
public final classDocument.DocumentTypeType of documentation to be submitted for verification of an account holder
public final classDocument.RequiredDocumentUploadRepresents a single image of the document to upload.
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier for the document. final StringaccountHolderToken()Globally unique identifier for the account holder. final Document.DocumentTypedocumentType()Type of documentation to be submitted for verification of an account holder final StringentityToken()Globally unique identifier for an entity. final List<Document.RequiredDocumentUpload>requiredDocumentUploads()Represents a single image of the document to upload. final JsonField<String>_token()Globally unique identifier for the document. final JsonField<String>_accountHolderToken()Globally unique identifier for the account holder. final JsonField<Document.DocumentType>_documentType()Type of documentation to be submitted for verification of an account holder final JsonField<String>_entityToken()Globally unique identifier for an entity. final JsonField<List<Document.RequiredDocumentUpload>>_requiredDocumentUploads()Represents a single image of the document to upload. final Map<String, JsonValue>_additionalProperties()final Documentvalidate()final Document.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Document.Builderbuilder()Returns a mutable builder for constructing an instance of Document. -
-
Method Detail
-
accountHolderToken
final String accountHolderToken()
Globally unique identifier for the account holder.
-
documentType
final Document.DocumentType documentType()
Type of documentation to be submitted for verification of an account holder
-
entityToken
final String entityToken()
Globally unique identifier for an entity.
-
requiredDocumentUploads
final List<Document.RequiredDocumentUpload> requiredDocumentUploads()
Represents a single image of the document to upload.
-
_accountHolderToken
final JsonField<String> _accountHolderToken()
Globally unique identifier for the account holder.
-
_documentType
final JsonField<Document.DocumentType> _documentType()
Type of documentation to be submitted for verification of an account holder
-
_entityToken
final JsonField<String> _entityToken()
Globally unique identifier for an entity.
-
_requiredDocumentUploads
final JsonField<List<Document.RequiredDocumentUpload>> _requiredDocumentUploads()
Represents a single image of the document to upload.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Document.Builder toBuilder()
-
builder
final static Document.Builder builder()
Returns a mutable builder for constructing an instance of Document.
The following fields are required:
.token() .accountHolderToken() .documentType() .entityToken() .requiredDocumentUploads()
-
-
-
-