Class Document.RequiredDocumentUpload
-
- All Implemented Interfaces:
public final class Document.RequiredDocumentUploadRepresents a single image of the document to upload.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDocument.RequiredDocumentUpload.BuilderA builder for RequiredDocumentUpload.
public final classDocument.RequiredDocumentUpload.ImageTypeType of image to upload.
public final classDocument.RequiredDocumentUpload.DocumentUploadStatusStatus of an account holder's document upload.
public final classDocument.RequiredDocumentUpload.DocumentUploadStatusReasonsThe status reasons for an account holder document upload that is not ACCEPTED
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier for the document upload. final List<String>acceptedEntityStatusReasons()A list of status reasons associated with a KYB account holder that have been satisfied by the document upload final OffsetDateTimecreated()When the document upload was created final Document.RequiredDocumentUpload.ImageTypeimageType()Type of image to upload. final List<String>rejectedEntityStatusReasons()A list of status reasons associated with a KYB account holder that have not been satisfied by the document upload final Document.RequiredDocumentUpload.DocumentUploadStatusstatus()Status of an account holder's document upload. final List<Document.RequiredDocumentUpload.DocumentUploadStatusReasons>statusReasons()Reasons for document image upload status. final OffsetDateTimeupdated()When the document upload was last updated final StringuploadUrl()URL to upload document image to. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<List<String>>_acceptedEntityStatusReasons()Returns the raw JSON value of acceptedEntityStatusReasons. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<Document.RequiredDocumentUpload.ImageType>_imageType()Returns the raw JSON value of imageType. final JsonField<List<String>>_rejectedEntityStatusReasons()Returns the raw JSON value of rejectedEntityStatusReasons. final JsonField<Document.RequiredDocumentUpload.DocumentUploadStatus>_status()Returns the raw JSON value of status. final JsonField<List<Document.RequiredDocumentUpload.DocumentUploadStatusReasons>>_statusReasons()Returns the raw JSON value of statusReasons. final JsonField<OffsetDateTime>_updated()Returns the raw JSON value of updated. final JsonField<String>_uploadUrl()Returns the raw JSON value of uploadUrl. final Map<String, JsonValue>_additionalProperties()final Document.RequiredDocumentUpload.BuildertoBuilder()final Document.RequiredDocumentUploadvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Document.RequiredDocumentUpload.Builderbuilder()Returns a mutable builder for constructing an instance of RequiredDocumentUpload. -
-
Method Detail
-
acceptedEntityStatusReasons
final List<String> acceptedEntityStatusReasons()
A list of status reasons associated with a KYB account holder that have been satisfied by the document upload
-
created
final OffsetDateTime created()
When the document upload was created
-
imageType
final Document.RequiredDocumentUpload.ImageType imageType()
Type of image to upload.
-
rejectedEntityStatusReasons
final List<String> rejectedEntityStatusReasons()
A list of status reasons associated with a KYB account holder that have not been satisfied by the document upload
-
status
final Document.RequiredDocumentUpload.DocumentUploadStatus status()
Status of an account holder's document upload.
-
statusReasons
final List<Document.RequiredDocumentUpload.DocumentUploadStatusReasons> statusReasons()
Reasons for document image upload status.
-
updated
final OffsetDateTime updated()
When the document upload was last updated
-
uploadUrl
final String uploadUrl()
URL to upload document image to.
Note that the upload URLs expire after 7 days. If an upload URL expires, you can refresh the URLs by retrieving the document upload from
GET /account_holders/{account_holder_token}/documents.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_acceptedEntityStatusReasons
final JsonField<List<String>> _acceptedEntityStatusReasons()
Returns the raw JSON value of acceptedEntityStatusReasons.
Unlike acceptedEntityStatusReasons, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_imageType
final JsonField<Document.RequiredDocumentUpload.ImageType> _imageType()
Returns the raw JSON value of imageType.
Unlike imageType, this method doesn't throw if the JSON field has an unexpected type.
-
_rejectedEntityStatusReasons
final JsonField<List<String>> _rejectedEntityStatusReasons()
Returns the raw JSON value of rejectedEntityStatusReasons.
Unlike rejectedEntityStatusReasons, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<Document.RequiredDocumentUpload.DocumentUploadStatus> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_statusReasons
final JsonField<List<Document.RequiredDocumentUpload.DocumentUploadStatusReasons>> _statusReasons()
Returns the raw JSON value of statusReasons.
Unlike statusReasons, this method doesn't throw if the JSON field has an unexpected type.
-
_updated
final JsonField<OffsetDateTime> _updated()
Returns the raw JSON value of updated.
Unlike updated, this method doesn't throw if the JSON field has an unexpected type.
-
_uploadUrl
final JsonField<String> _uploadUrl()
Returns the raw JSON value of uploadUrl.
Unlike uploadUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Document.RequiredDocumentUpload.Builder toBuilder()
-
validate
final Document.RequiredDocumentUpload validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Document.RequiredDocumentUpload.Builder builder()
Returns a mutable builder for constructing an instance of RequiredDocumentUpload.
The following fields are required:
.token() .acceptedEntityStatusReasons() .created() .imageType() .rejectedEntityStatusReasons() .status() .statusReasons() .updated() .uploadUrl()
-
-
-
-