Enum Document.RequiredDocumentUpload.DocumentUploadStatusReasons.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum Document.RequiredDocumentUpload.DocumentUploadStatusReasons.Value extends Enum<Document.RequiredDocumentUpload.DocumentUploadStatusReasons.Value>
An enum containing DocumentUploadStatusReasons's known values, as well as an _UNKNOWN member.
An instance of DocumentUploadStatusReasons can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<Document.RequiredDocumentUpload.DocumentUploadStatusReasons.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description DOCUMENT_MISSING_REQUIRED_DATADOCUMENT_UPLOAD_TOO_BLURRYFILE_SIZE_TOO_LARGEINVALID_DOCUMENT_TYPEINVALID_DOCUMENT_UPLOADINVALID_ENTITYDOCUMENT_EXPIREDDOCUMENT_ISSUED_GREATER_THAN_30_DAYSDOCUMENT_TYPE_NOT_SUPPORTEDUNKNOWN_FAILURE_REASONUNKNOWN_ERROR_UNKNOWNAn enum member indicating that DocumentUploadStatusReasons was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final Document.RequiredDocumentUpload.DocumentUploadStatusReasons.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<Document.RequiredDocumentUpload.DocumentUploadStatusReasons.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<Document.RequiredDocumentUpload.DocumentUploadStatusReasons.Value>getEntries()An enum containing DocumentUploadStatusReasons's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final Document.RequiredDocumentUpload.DocumentUploadStatusReasons.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<Document.RequiredDocumentUpload.DocumentUploadStatusReasons.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<Document.RequiredDocumentUpload.DocumentUploadStatusReasons.Value> getEntries()
An enum containing DocumentUploadStatusReasons's known values, as well as an _UNKNOWN member.
An instance of DocumentUploadStatusReasons can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-