Package com.lithic.api.models
Class EnhancedCommercialDataRetrieveResponse
-
- All Implemented Interfaces:
public final class EnhancedCommercialDataRetrieveResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEnhancedCommercialDataRetrieveResponse.BuilderA builder for EnhancedCommercialDataRetrieveResponse.
-
Method Summary
Modifier and Type Method Description final List<EnhancedData>data()final JsonField<List<EnhancedData>>_data()Returns the raw JSON value of data. final Map<String, JsonValue>_additionalProperties()final EnhancedCommercialDataRetrieveResponse.BuildertoBuilder()final EnhancedCommercialDataRetrieveResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EnhancedCommercialDataRetrieveResponse.Builderbuilder()Returns a mutable builder for constructing an instance of EnhancedCommercialDataRetrieveResponse. -
-
Method Detail
-
data
final List<EnhancedData> data()
-
_data
final JsonField<List<EnhancedData>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EnhancedCommercialDataRetrieveResponse.Builder toBuilder()
-
validate
final EnhancedCommercialDataRetrieveResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EnhancedCommercialDataRetrieveResponse.Builder builder()
Returns a mutable builder for constructing an instance of EnhancedCommercialDataRetrieveResponse.
The following fields are required:
.data()
-
-
-
-