Package com.lithic.api.models
Class EnhancedData
-
- All Implemented Interfaces:
public final class EnhancedData
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEnhancedData.BuilderA builder for EnhancedData.
public final classEnhancedData.CommonDatapublic final classEnhancedData.Fleet
-
Method Summary
Modifier and Type Method Description final Stringtoken()A unique identifier for the enhanced commercial data. final EnhancedData.CommonDatacommon()final StringeventToken()The token of the event that the enhanced data is associated with. final List<EnhancedData.Fleet>fleet()final StringtransactionToken()The token of the transaction that the enhanced data is associated with. final JsonField<String>_token()A unique identifier for the enhanced commercial data. final JsonField<EnhancedData.CommonData>_common()final JsonField<String>_eventToken()The token of the event that the enhanced data is associated with. final JsonField<List<EnhancedData.Fleet>>_fleet()final JsonField<String>_transactionToken()The token of the transaction that the enhanced data is associated with. final Map<String, JsonValue>_additionalProperties()final EnhancedDatavalidate()final EnhancedData.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EnhancedData.Builderbuilder()Returns a mutable builder for constructing an instance of EnhancedData. -
-
Method Detail
-
common
final EnhancedData.CommonData common()
-
eventToken
final String eventToken()
The token of the event that the enhanced data is associated with.
-
fleet
final List<EnhancedData.Fleet> fleet()
-
transactionToken
final String transactionToken()
The token of the transaction that the enhanced data is associated with.
-
_common
final JsonField<EnhancedData.CommonData> _common()
-
_eventToken
final JsonField<String> _eventToken()
The token of the event that the enhanced data is associated with.
-
_fleet
final JsonField<List<EnhancedData.Fleet>> _fleet()
-
_transactionToken
final JsonField<String> _transactionToken()
The token of the transaction that the enhanced data is associated with.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final EnhancedData validate()
-
toBuilder
final EnhancedData.Builder toBuilder()
-
builder
final static EnhancedData.Builder builder()
Returns a mutable builder for constructing an instance of EnhancedData.
The following fields are required:
.token() .common() .eventToken() .fleet() .transactionToken()
-
-
-
-