Package com.lithic.api.models
Class EnhancedData.Builder
-
- All Implemented Interfaces:
public final class EnhancedData.BuilderA builder for EnhancedData.
-
-
Method Summary
-
-
Method Detail
-
token
final EnhancedData.Builder token(String token)
A unique identifier for the enhanced commercial data.
-
token
final EnhancedData.Builder token(JsonField<String> token)
A unique identifier for the enhanced commercial data.
-
common
final EnhancedData.Builder common(EnhancedData.CommonData common)
-
common
final EnhancedData.Builder common(JsonField<EnhancedData.CommonData> common)
-
eventToken
final EnhancedData.Builder eventToken(String eventToken)
The token of the event that the enhanced data is associated with.
-
eventToken
final EnhancedData.Builder eventToken(JsonField<String> eventToken)
The token of the event that the enhanced data is associated with.
-
fleet
final EnhancedData.Builder fleet(List<EnhancedData.Fleet> fleet)
-
fleet
final EnhancedData.Builder fleet(JsonField<List<EnhancedData.Fleet>> fleet)
-
addFleet
final EnhancedData.Builder addFleet(EnhancedData.Fleet fleet)
-
transactionToken
final EnhancedData.Builder transactionToken(String transactionToken)
The token of the transaction that the enhanced data is associated with.
-
transactionToken
final EnhancedData.Builder transactionToken(JsonField<String> transactionToken)
The token of the transaction that the enhanced data is associated with.
-
additionalProperties
final EnhancedData.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EnhancedData.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EnhancedData.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EnhancedData.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EnhancedData.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EnhancedData build()
-
-
-
-