Class EnhancedData.Fleet.FuelData.Builder
-
- All Implemented Interfaces:
public final class EnhancedData.Fleet.FuelData.BuilderA builder for FuelData.
-
-
Method Summary
-
-
Method Detail
-
quantity
final EnhancedData.Fleet.FuelData.Builder quantity(String quantity)
The quantity of fuel purchased.
-
quantity
final EnhancedData.Fleet.FuelData.Builder quantity(Optional<String> quantity)
Alias for calling Builder.quantity with
quantity.orElse(null).
-
quantity
final EnhancedData.Fleet.FuelData.Builder quantity(JsonField<String> quantity)
Sets Builder.quantity to an arbitrary JSON value.
You should usually call Builder.quantity with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final EnhancedData.Fleet.FuelData.Builder type(EnhancedData.Fleet.FuelData.FuelType type)
The type of fuel purchased.
-
type
final EnhancedData.Fleet.FuelData.Builder type(Optional<EnhancedData.Fleet.FuelData.FuelType> type)
Alias for calling Builder.type with
type.orElse(null).
-
type
final EnhancedData.Fleet.FuelData.Builder type(JsonField<EnhancedData.Fleet.FuelData.FuelType> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed FuelType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
unitOfMeasure
final EnhancedData.Fleet.FuelData.Builder unitOfMeasure(EnhancedData.Fleet.FuelData.FuelUnitOfMeasure unitOfMeasure)
Unit of measure for fuel disbursement.
-
unitOfMeasure
final EnhancedData.Fleet.FuelData.Builder unitOfMeasure(Optional<EnhancedData.Fleet.FuelData.FuelUnitOfMeasure> unitOfMeasure)
Alias for calling Builder.unitOfMeasure with
unitOfMeasure.orElse(null).
-
unitOfMeasure
final EnhancedData.Fleet.FuelData.Builder unitOfMeasure(JsonField<EnhancedData.Fleet.FuelData.FuelUnitOfMeasure> unitOfMeasure)
Sets Builder.unitOfMeasure to an arbitrary JSON value.
You should usually call Builder.unitOfMeasure with a well-typed FuelUnitOfMeasure value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
unitPrice
final EnhancedData.Fleet.FuelData.Builder unitPrice(Long unitPrice)
The price per unit of fuel.
-
unitPrice
final EnhancedData.Fleet.FuelData.Builder unitPrice(Long unitPrice)
Alias for Builder.unitPrice.
This unboxed primitive overload exists for backwards compatibility.
-
unitPrice
final EnhancedData.Fleet.FuelData.Builder unitPrice(Optional<Long> unitPrice)
Alias for calling Builder.unitPrice with
unitPrice.orElse(null).
-
unitPrice
final EnhancedData.Fleet.FuelData.Builder unitPrice(JsonField<Long> unitPrice)
Sets Builder.unitPrice to an arbitrary JSON value.
You should usually call Builder.unitPrice with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EnhancedData.Fleet.FuelData.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EnhancedData.Fleet.FuelData.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EnhancedData.Fleet.FuelData.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EnhancedData.Fleet.FuelData.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EnhancedData.Fleet.FuelData.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EnhancedData.Fleet.FuelData build()
Returns an immutable instance of FuelData.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-