Package com.lithic.api.models
Class EventListPage
-
- All Implemented Interfaces:
public final class EventListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventListPage.BuilderA builder for EventListPage.
public final classEventListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<Event>data()Delegates to EventListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to EventListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<EventListParams>getNextPageParams()final Optional<EventListPage>getNextPage()final EventListPage.AutoPagerautoPager()final EventListParamsparams()The parameters that were used to request this page. final EventListPageResponseresponse()The response that this page was parsed from. final EventListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EventListPage.Builderbuilder()Returns a mutable builder for constructing an instance of EventListPage. -
-
Method Detail
-
data
final List<Event> data()
Delegates to EventListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to EventListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<EventListParams> getNextPageParams()
-
getNextPage
final Optional<EventListPage> getNextPage()
-
autoPager
final EventListPage.AutoPager autoPager()
-
params
final EventListParams params()
The parameters that were used to request this page.
-
response
final EventListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final EventListPage.Builder toBuilder()
-
builder
final static EventListPage.Builder builder()
Returns a mutable builder for constructing an instance of EventListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-