Package com.lithic.api.models
Class EventListPageAsync
-
- All Implemented Interfaces:
public final class EventListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventListPageAsync.BuilderA builder for EventListPageAsync.
public final classEventListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<Event>data()Delegates to EventListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to EventListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<EventListParams>getNextPageParams()final CompletableFuture<Optional<EventListPageAsync>>getNextPage()final EventListPageAsync.AutoPagerautoPager()final EventListParamsparams()The parameters that were used to request this page. final EventListPageResponseresponse()The response that this page was parsed from. final EventListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EventListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of EventListPageAsync. -
-
Method Detail
-
data
final List<Event> data()
Delegates to EventListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to EventListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<EventListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<EventListPageAsync>> getNextPage()
-
autoPager
final EventListPageAsync.AutoPager autoPager()
-
params
final EventListParams params()
The parameters that were used to request this page.
-
response
final EventListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final EventListPageAsync.Builder toBuilder()
-
builder
final static EventListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of EventListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-