Package com.lithic.api.models
Class EventListPageResponse
-
- All Implemented Interfaces:
public final class EventListPageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventListPageResponse.BuilderA builder for EventListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<Event>data()final BooleanhasMore()final JsonField<List<Event>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final EventListPageResponse.BuildertoBuilder()final EventListPageResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EventListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of EventListPageResponse. -
-
Method Detail
-
_data
final JsonField<List<Event>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EventListPageResponse.Builder toBuilder()
-
validate
final EventListPageResponse validate()
-
builder
final static EventListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of EventListPageResponse.
The following fields are required:
.data() .hasMore()
-
-
-
-