Package com.lithic.api.models
Class EventSubscriptionListPage
-
- All Implemented Interfaces:
public final class EventSubscriptionListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventSubscriptionListPage.BuilderA builder for EventSubscriptionListPage.
public final classEventSubscriptionListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<EventSubscription>data()Delegates to EventSubscriptionListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to EventSubscriptionListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<EventSubscriptionListParams>getNextPageParams()final Optional<EventSubscriptionListPage>getNextPage()final EventSubscriptionListPage.AutoPagerautoPager()final EventSubscriptionListParamsparams()The parameters that were used to request this page. final EventSubscriptionListPageResponseresponse()The response that this page was parsed from. final EventSubscriptionListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EventSubscriptionListPage.Builderbuilder()Returns a mutable builder for constructing an instance of EventSubscriptionListPage. -
-
Method Detail
-
data
final List<EventSubscription> data()
Delegates to EventSubscriptionListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to EventSubscriptionListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<EventSubscriptionListParams> getNextPageParams()
-
getNextPage
final Optional<EventSubscriptionListPage> getNextPage()
-
autoPager
final EventSubscriptionListPage.AutoPager autoPager()
-
params
final EventSubscriptionListParams params()
The parameters that were used to request this page.
-
response
final EventSubscriptionListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final EventSubscriptionListPage.Builder toBuilder()
-
builder
final static EventSubscriptionListPage.Builder builder()
Returns a mutable builder for constructing an instance of EventSubscriptionListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-