Package com.lithic.api.models
Class EventSubscriptionListPageAsync
-
- All Implemented Interfaces:
public final class EventSubscriptionListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventSubscriptionListPageAsync.BuilderA builder for EventSubscriptionListPageAsync.
public final classEventSubscriptionListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<EventSubscription>data()Delegates to EventSubscriptionListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to EventSubscriptionListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<EventSubscriptionListParams>getNextPageParams()final CompletableFuture<Optional<EventSubscriptionListPageAsync>>getNextPage()final EventSubscriptionListPageAsync.AutoPagerautoPager()final EventSubscriptionListParamsparams()The parameters that were used to request this page. final EventSubscriptionListPageResponseresponse()The response that this page was parsed from. final EventSubscriptionListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EventSubscriptionListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of EventSubscriptionListPageAsync. -
-
Method Detail
-
data
final List<EventSubscription> data()
Delegates to EventSubscriptionListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to EventSubscriptionListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<EventSubscriptionListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<EventSubscriptionListPageAsync>> getNextPage()
-
autoPager
final EventSubscriptionListPageAsync.AutoPager autoPager()
-
params
final EventSubscriptionListParams params()
The parameters that were used to request this page.
-
response
final EventSubscriptionListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final EventSubscriptionListPageAsync.Builder toBuilder()
-
builder
final static EventSubscriptionListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of EventSubscriptionListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-