Package com.lithic.api.models
Class EventSubscriptionListPageAsync.Builder
-
- All Implemented Interfaces:
public final class EventSubscriptionListPageAsync.BuilderA builder for EventSubscriptionListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final EventSubscriptionListPageAsync.Builderservice(SubscriptionServiceAsync service)final EventSubscriptionListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final EventSubscriptionListPageAsync.Builderparams(EventSubscriptionListParams params)The parameters that were used to request this page. final EventSubscriptionListPageAsync.Builderresponse(EventSubscriptionListPageResponse response)The response that this page was parsed from. final EventSubscriptionListPageAsyncbuild()Returns an immutable instance of EventSubscriptionListPageAsync. -
-
Method Detail
-
service
final EventSubscriptionListPageAsync.Builder service(SubscriptionServiceAsync service)
-
streamHandlerExecutor
final EventSubscriptionListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final EventSubscriptionListPageAsync.Builder params(EventSubscriptionListParams params)
The parameters that were used to request this page.
-
response
final EventSubscriptionListPageAsync.Builder response(EventSubscriptionListPageResponse response)
The response that this page was parsed from.
-
build
final EventSubscriptionListPageAsync build()
Returns an immutable instance of EventSubscriptionListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-