Package com.lithic.api.models
Class EventSubscriptionSendSimulatedExampleParams.Body
-
- All Implemented Interfaces:
public final class EventSubscriptionSendSimulatedExampleParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventSubscriptionSendSimulatedExampleParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<EventSubscriptionSendSimulatedExampleParams.EventType>eventType()Event type to send example message for. final JsonField<EventSubscriptionSendSimulatedExampleParams.EventType>_eventType()Returns the raw JSON value of eventType. final Map<String, JsonValue>_additionalProperties()final EventSubscriptionSendSimulatedExampleParams.Body.BuildertoBuilder()final EventSubscriptionSendSimulatedExampleParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EventSubscriptionSendSimulatedExampleParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
eventType
final Optional<EventSubscriptionSendSimulatedExampleParams.EventType> eventType()
Event type to send example message for.
-
_eventType
final JsonField<EventSubscriptionSendSimulatedExampleParams.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EventSubscriptionSendSimulatedExampleParams.Body.Builder toBuilder()
-
validate
final EventSubscriptionSendSimulatedExampleParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EventSubscriptionSendSimulatedExampleParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-