Class ExternalBankAccountAddress.Builder
-
- All Implemented Interfaces:
public final class ExternalBankAccountAddress.BuilderA builder for ExternalBankAccountAddress.
-
-
Method Summary
-
-
Method Detail
-
address1
final ExternalBankAccountAddress.Builder address1(String address1)
-
address1
final ExternalBankAccountAddress.Builder address1(JsonField<String> address1)
Sets Builder.address1 to an arbitrary JSON value.
You should usually call Builder.address1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
city
final ExternalBankAccountAddress.Builder city(String city)
-
city
final ExternalBankAccountAddress.Builder city(JsonField<String> city)
Sets Builder.city to an arbitrary JSON value.
You should usually call Builder.city with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
country
final ExternalBankAccountAddress.Builder country(String country)
-
country
final ExternalBankAccountAddress.Builder country(JsonField<String> country)
Sets Builder.country to an arbitrary JSON value.
You should usually call Builder.country with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
postalCode
final ExternalBankAccountAddress.Builder postalCode(String postalCode)
-
postalCode
final ExternalBankAccountAddress.Builder postalCode(JsonField<String> postalCode)
Sets Builder.postalCode to an arbitrary JSON value.
You should usually call Builder.postalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
state
final ExternalBankAccountAddress.Builder state(String state)
-
state
final ExternalBankAccountAddress.Builder state(JsonField<String> state)
Sets Builder.state to an arbitrary JSON value.
You should usually call Builder.state with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
address2
final ExternalBankAccountAddress.Builder address2(String address2)
-
address2
final ExternalBankAccountAddress.Builder address2(JsonField<String> address2)
Sets Builder.address2 to an arbitrary JSON value.
You should usually call Builder.address2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ExternalBankAccountAddress.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ExternalBankAccountAddress.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ExternalBankAccountAddress.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ExternalBankAccountAddress.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ExternalBankAccountAddress.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ExternalBankAccountAddress build()
Returns an immutable instance of ExternalBankAccountAddress.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.address1() .city() .country() .postalCode() .state()
-
-
-
-