Class ExternalBankAccountListPageAsync
-
- All Implemented Interfaces:
-
com.lithic.api.core.PageAsync
public final class ExternalBankAccountListPageAsync implements PageAsync<ExternalBankAccountListResponse>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalBankAccountListPageAsync.BuilderA builder for ExternalBankAccountListPageAsync.
-
Method Summary
-
-
Method Detail
-
data
final List<ExternalBankAccountListResponse> data()
Delegates to ExternalBankAccountListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to ExternalBankAccountListPageResponse, but gracefully handles missing data.
-
items
List<ExternalBankAccountListResponse> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final ExternalBankAccountListParams nextPageParams()
-
nextPage
CompletableFuture<ExternalBankAccountListPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<ExternalBankAccountListResponse> autoPager()
-
params
final ExternalBankAccountListParams params()
The parameters that were used to request this page.
-
response
final ExternalBankAccountListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final ExternalBankAccountListPageAsync.Builder toBuilder()
-
builder
final static ExternalBankAccountListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of ExternalBankAccountListPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-