Package com.lithic.api.models
Class ExternalBankAccountListPageAsync.Response
-
- All Implemented Interfaces:
public final class ExternalBankAccountListPageAsync.Response
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalBankAccountListPageAsync.Response.Builder
-
Constructor Summary
Constructors Constructor Description ExternalBankAccountListPageAsync.Response(JsonField<List<ExternalBankAccountListResponse>> data, JsonField<Boolean> hasMore, Map<String, JsonValue> additionalProperties)
-
Method Summary
Modifier and Type Method Description final List<ExternalBankAccountListResponse>data()final BooleanhasMore()final Optional<JsonField<List<ExternalBankAccountListResponse>>>_data()final Optional<JsonField<Boolean>>_hasMore()final Map<String, JsonValue>_additionalProperties()final ExternalBankAccountListPageAsync.Responsevalidate()final ExternalBankAccountListPageAsync.Response.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExternalBankAccountListPageAsync.Response.Builderbuilder()Returns a mutable builder for constructing an instance of ExternalBankAccountListPageAsync. -
-
Method Detail
-
data
final List<ExternalBankAccountListResponse> data()
-
_data
final Optional<JsonField<List<ExternalBankAccountListResponse>>> _data()
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final ExternalBankAccountListPageAsync.Response validate()
-
toBuilder
final ExternalBankAccountListPageAsync.Response.Builder toBuilder()
-
builder
final static ExternalBankAccountListPageAsync.Response.Builder builder()
Returns a mutable builder for constructing an instance of ExternalBankAccountListPageAsync.
-
-
-
-