Package com.lithic.api.models
Class ExternalBankAccountListPageResponse
-
- All Implemented Interfaces:
public final class ExternalBankAccountListPageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalBankAccountListPageResponse.BuilderA builder for ExternalBankAccountListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<ExternalBankAccountListResponse>data()final BooleanhasMore()final JsonField<List<ExternalBankAccountListResponse>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final ExternalBankAccountListPageResponse.BuildertoBuilder()final ExternalBankAccountListPageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExternalBankAccountListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ExternalBankAccountListPageResponse. -
-
Method Detail
-
data
final List<ExternalBankAccountListResponse> data()
-
_data
final JsonField<List<ExternalBankAccountListResponse>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExternalBankAccountListPageResponse.Builder toBuilder()
-
validate
final ExternalBankAccountListPageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ExternalBankAccountListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of ExternalBankAccountListPageResponse.
The following fields are required:
.data() .hasMore()
-
-
-
-