Class ExternalBankAccountListParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class ExternalBankAccountListParams implements Params
List all the external bank accounts for the provided search criteria.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalBankAccountListParams.BuilderA builder for ExternalBankAccountListParams.
public final classExternalBankAccountListParams.AccountTypepublic final classExternalBankAccountListParams.AccountStatepublic final classExternalBankAccountListParams.VerificationState
-
Method Summary
Modifier and Type Method Description final Optional<String>accountToken()final Optional<List<ExternalBankAccountListParams.AccountType>>accountTypes()final Optional<List<String>>countries()final Optional<String>endingBefore()A cursor representing an item's token before which a page of results should end. final Optional<List<OwnerType>>ownerTypes()final Optional<Long>pageSize()Page size (for pagination). final Optional<String>startingAfter()A cursor representing an item's token after which a page of results should begin. final Optional<List<ExternalBankAccountListParams.AccountState>>states()final Optional<List<ExternalBankAccountListParams.VerificationState>>verificationStates()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ExternalBankAccountListParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExternalBankAccountListParamsnone()final static ExternalBankAccountListParams.Builderbuilder()Returns a mutable builder for constructing an instance of ExternalBankAccountListParams. -
-
Method Detail
-
accountToken
final Optional<String> accountToken()
-
accountTypes
final Optional<List<ExternalBankAccountListParams.AccountType>> accountTypes()
-
endingBefore
final Optional<String> endingBefore()
A cursor representing an item's token before which a page of results should end. Used to retrieve the previous page of results before this item.
-
ownerTypes
final Optional<List<OwnerType>> ownerTypes()
-
startingAfter
final Optional<String> startingAfter()
A cursor representing an item's token after which a page of results should begin. Used to retrieve the next page of results after this item.
-
states
final Optional<List<ExternalBankAccountListParams.AccountState>> states()
-
verificationStates
final Optional<List<ExternalBankAccountListParams.VerificationState>> verificationStates()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ExternalBankAccountListParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static ExternalBankAccountListParams none()
-
builder
final static ExternalBankAccountListParams.Builder builder()
Returns a mutable builder for constructing an instance of ExternalBankAccountListParams.
-
-
-
-