Package com.lithic.api.models
Class ExternalBankAccountMicroDepositCreateParams.MicroDepositVerificationRequest
-
- All Implemented Interfaces:
public final class ExternalBankAccountMicroDepositCreateParams.MicroDepositVerificationRequest
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalBankAccountMicroDepositCreateParams.MicroDepositVerificationRequest.BuilderA builder for MicroDepositVerificationRequest.
-
Method Summary
Modifier and Type Method Description final List<Long>microDeposits()final JsonField<List<Long>>_microDeposits()Returns the raw JSON value of microDeposits. final Map<String, JsonValue>_additionalProperties()final ExternalBankAccountMicroDepositCreateParams.MicroDepositVerificationRequest.BuildertoBuilder()final ExternalBankAccountMicroDepositCreateParams.MicroDepositVerificationRequestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExternalBankAccountMicroDepositCreateParams.MicroDepositVerificationRequest.Builderbuilder()Returns a mutable builder for constructing an instance of MicroDepositVerificationRequest. -
-
Method Detail
-
microDeposits
final List<Long> microDeposits()
-
_microDeposits
final JsonField<List<Long>> _microDeposits()
Returns the raw JSON value of microDeposits.
Unlike microDeposits, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExternalBankAccountMicroDepositCreateParams.MicroDepositVerificationRequest.Builder toBuilder()
-
validate
final ExternalBankAccountMicroDepositCreateParams.MicroDepositVerificationRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ExternalBankAccountMicroDepositCreateParams.MicroDepositVerificationRequest.Builder builder()
Returns a mutable builder for constructing an instance of MicroDepositVerificationRequest.
The following fields are required:
.microDeposits()
-
-
-
-