Package com.lithic.api.models
Class ExternalBankAccountRetrieveParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class ExternalBankAccountRetrieveParams implements Params
Get the external bank account by token.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalBankAccountRetrieveParams.BuilderA builder for ExternalBankAccountRetrieveParams.
-
Method Summary
Modifier and Type Method Description final StringexternalBankAccountToken()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()final ExternalBankAccountRetrieveParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExternalBankAccountRetrieveParams.Builderbuilder()Returns a mutable builder for constructing an instance of ExternalBankAccountRetrieveParams. -
-
Method Detail
-
externalBankAccountToken
final String externalBankAccountToken()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
toBuilder
final ExternalBankAccountRetrieveParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static ExternalBankAccountRetrieveParams.Builder builder()
Returns a mutable builder for constructing an instance of ExternalBankAccountRetrieveParams.
The following fields are required:
.externalBankAccountToken()
-
-
-
-