Class ExternalBankAccountSetVerificationMethodParams

  • All Implemented Interfaces:
    com.lithic.api.core.Params

    
    public final class ExternalBankAccountSetVerificationMethodParams
     implements Params
                        

    Update the verification method for an external bank account. Verification method can only be updated if the verification_state is PENDING.