Class ExternalPayment
-
- All Implemented Interfaces:
public final class ExternalPayment
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalPayment.BuilderA builder for ExternalPayment.
public final classExternalPayment.TransactionFamilyTypespublic final classExternalPayment.TransactionStatusThe status of the transaction
public final classExternalPayment.ExternalPaymentCategorypublic final classExternalPayment.ExternalPaymentEventpublic final classExternalPayment.ExternalPaymentDirectionpublic final classExternalPayment.TransactionResult
-
Method Summary
-
-
Method Detail
-
created
final OffsetDateTime created()
ISO 8601 timestamp of when the transaction was created
-
family
final ExternalPayment.TransactionFamilyTypes family()
-
status
final ExternalPayment.TransactionStatus status()
The status of the transaction
-
updated
final OffsetDateTime updated()
ISO 8601 timestamp of when the transaction was last updated
-
category
final Optional<ExternalPayment.ExternalPaymentCategory> category()
-
events
final Optional<List<ExternalPayment.ExternalPaymentEvent>> events()
-
financialAccountToken
final Optional<String> financialAccountToken()
-
paymentType
final Optional<ExternalPayment.ExternalPaymentDirection> paymentType()
-
pendingAmount
final Optional<Long> pendingAmount()
-
result
final Optional<ExternalPayment.TransactionResult> result()
-
settledAmount
final Optional<Long> settledAmount()
-
userDefinedId
final Optional<String> userDefinedId()
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_family
final JsonField<ExternalPayment.TransactionFamilyTypes> _family()
Returns the raw JSON value of family.
Unlike family, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<ExternalPayment.TransactionStatus> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_updated
final JsonField<OffsetDateTime> _updated()
Returns the raw JSON value of updated.
Unlike updated, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<ExternalPayment.ExternalPaymentCategory> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_events
final JsonField<List<ExternalPayment.ExternalPaymentEvent>> _events()
Returns the raw JSON value of events.
Unlike events, this method doesn't throw if the JSON field has an unexpected type.
-
_financialAccountToken
final JsonField<String> _financialAccountToken()
Returns the raw JSON value of financialAccountToken.
Unlike financialAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_paymentType
final JsonField<ExternalPayment.ExternalPaymentDirection> _paymentType()
Returns the raw JSON value of paymentType.
Unlike paymentType, this method doesn't throw if the JSON field has an unexpected type.
-
_pendingAmount
final JsonField<Long> _pendingAmount()
Returns the raw JSON value of pendingAmount.
Unlike pendingAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_result
final JsonField<ExternalPayment.TransactionResult> _result()
Returns the raw JSON value of result.
Unlike result, this method doesn't throw if the JSON field has an unexpected type.
-
_settledAmount
final JsonField<Long> _settledAmount()
Returns the raw JSON value of settledAmount.
Unlike settledAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_userDefinedId
final JsonField<String> _userDefinedId()
Returns the raw JSON value of userDefinedId.
Unlike userDefinedId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExternalPayment.Builder toBuilder()
-
validate
final ExternalPayment validate()
-
builder
final static ExternalPayment.Builder builder()
Returns a mutable builder for constructing an instance of ExternalPayment.
The following fields are required:
.token() .created() .family() .status() .updated()
-
-
-
-