Package com.lithic.api.models
Class ExternalPaymentCreateParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class ExternalPaymentCreateParams implements Params
Create external payment
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalPaymentCreateParams.CreateExternalPaymentRequestpublic final classExternalPaymentCreateParams.BuilderA builder for ExternalPaymentCreateParams.
public final classExternalPaymentCreateParams.ExternalPaymentCategorypublic final classExternalPaymentCreateParams.ExternalPaymentDirectionpublic final classExternalPaymentCreateParams.ExternalPaymentProgressTo
-
Method Summary
-
-
Method Detail
-
category
final ExternalPaymentCreateParams.ExternalPaymentCategory category()
-
effectiveDate
final LocalDate effectiveDate()
-
financialAccountToken
final String financialAccountToken()
-
paymentType
final ExternalPaymentCreateParams.ExternalPaymentDirection paymentType()
-
progressTo
final Optional<ExternalPaymentCreateParams.ExternalPaymentProgressTo> progressTo()
-
userDefinedId
final Optional<String> userDefinedId()
-
_category
final JsonField<ExternalPaymentCreateParams.ExternalPaymentCategory> _category()
-
_effectiveDate
final JsonField<LocalDate> _effectiveDate()
-
_financialAccountToken
final JsonField<String> _financialAccountToken()
-
_paymentType
final JsonField<ExternalPaymentCreateParams.ExternalPaymentDirection> _paymentType()
-
_progressTo
final JsonField<ExternalPaymentCreateParams.ExternalPaymentProgressTo> _progressTo()
-
_userDefinedId
final JsonField<String> _userDefinedId()
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final ExternalPaymentCreateParams.Builder toBuilder()
-
builder
final static ExternalPaymentCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of ExternalPaymentCreateParams.
The following fields are required:
.amount() .category() .effectiveDate() .financialAccountToken() .paymentType()
-
-
-
-