Class ExternalResource
-
- All Implemented Interfaces:
public final class ExternalResourceExternal resource associated with the management operation
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalResource.BuilderA builder for ExternalResource.
-
Method Summary
Modifier and Type Method Description final StringexternalResourceToken()Token identifying the external resource final ExternalResourceTypeexternalResourceType()Type of external resource associated with the management operation final Optional<String>externalResourceSubToken()Token identifying the external resource sub-resource final JsonField<String>_externalResourceToken()Returns the raw JSON value of externalResourceToken. final JsonField<ExternalResourceType>_externalResourceType()Returns the raw JSON value of externalResourceType. final JsonField<String>_externalResourceSubToken()Returns the raw JSON value of externalResourceSubToken. final Map<String, JsonValue>_additionalProperties()final ExternalResource.BuildertoBuilder()final ExternalResourcevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExternalResource.Builderbuilder()Returns a mutable builder for constructing an instance of ExternalResource. -
-
Method Detail
-
externalResourceToken
final String externalResourceToken()
Token identifying the external resource
-
externalResourceType
final ExternalResourceType externalResourceType()
Type of external resource associated with the management operation
-
externalResourceSubToken
final Optional<String> externalResourceSubToken()
Token identifying the external resource sub-resource
-
_externalResourceToken
final JsonField<String> _externalResourceToken()
Returns the raw JSON value of externalResourceToken.
Unlike externalResourceToken, this method doesn't throw if the JSON field has an unexpected type.
-
_externalResourceType
final JsonField<ExternalResourceType> _externalResourceType()
Returns the raw JSON value of externalResourceType.
Unlike externalResourceType, this method doesn't throw if the JSON field has an unexpected type.
-
_externalResourceSubToken
final JsonField<String> _externalResourceSubToken()
Returns the raw JSON value of externalResourceSubToken.
Unlike externalResourceSubToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExternalResource.Builder toBuilder()
-
validate
final ExternalResource validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ExternalResource.Builder builder()
Returns a mutable builder for constructing an instance of ExternalResource.
The following fields are required:
.externalResourceToken() .externalResourceType()
-
-
-
-