Class FinancialAccount
-
- All Implemented Interfaces:
public final class FinancialAccount
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinancialAccount.BuilderA builder for FinancialAccount.
public final classFinancialAccount.FinancialAccountCreditConfigpublic final classFinancialAccount.FinancialAccountStatusStatus of the financial account
public final classFinancialAccount.FinancialAccountSubstatusSubstatus for the financial account
public final classFinancialAccount.Type
-
Method Summary
-
-
Method Detail
-
accountToken
final Optional<String> accountToken()
-
created
final OffsetDateTime created()
-
creditConfiguration
final Optional<FinancialAccount.FinancialAccountCreditConfig> creditConfiguration()
-
isForBenefitOf
final Boolean isForBenefitOf()
Whether financial account is for the benefit of another entity
-
status
final FinancialAccount.FinancialAccountStatus status()
Status of the financial account
-
substatus
final Optional<FinancialAccount.FinancialAccountSubstatus> substatus()
Substatus for the financial account
-
type
final FinancialAccount.Type type()
-
updated
final OffsetDateTime updated()
-
userDefinedStatus
final Optional<String> userDefinedStatus()
User-defined status for the financial account
-
accountNumber
final Optional<String> accountNumber()
-
routingNumber
final Optional<String> routingNumber()
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_accountToken
final JsonField<String> _accountToken()
Returns the raw JSON value of accountToken.
Unlike accountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_creditConfiguration
final JsonField<FinancialAccount.FinancialAccountCreditConfig> _creditConfiguration()
Returns the raw JSON value of creditConfiguration.
Unlike creditConfiguration, this method doesn't throw if the JSON field has an unexpected type.
-
_isForBenefitOf
final JsonField<Boolean> _isForBenefitOf()
Returns the raw JSON value of isForBenefitOf.
Unlike isForBenefitOf, this method doesn't throw if the JSON field has an unexpected type.
-
_nickname
final JsonField<String> _nickname()
Returns the raw JSON value of nickname.
Unlike nickname, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<FinancialAccount.FinancialAccountStatus> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_substatus
final JsonField<FinancialAccount.FinancialAccountSubstatus> _substatus()
Returns the raw JSON value of substatus.
Unlike substatus, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<FinancialAccount.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_updated
final JsonField<OffsetDateTime> _updated()
Returns the raw JSON value of updated.
Unlike updated, this method doesn't throw if the JSON field has an unexpected type.
-
_userDefinedStatus
final JsonField<String> _userDefinedStatus()
Returns the raw JSON value of userDefinedStatus.
Unlike userDefinedStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_accountNumber
final JsonField<String> _accountNumber()
Returns the raw JSON value of accountNumber.
Unlike accountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_routingNumber
final JsonField<String> _routingNumber()
Returns the raw JSON value of routingNumber.
Unlike routingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FinancialAccount.Builder toBuilder()
-
validate
final FinancialAccount validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FinancialAccount.Builder builder()
Returns a mutable builder for constructing an instance of FinancialAccount.
The following fields are required:
.token() .accountToken() .created() .creditConfiguration() .isForBenefitOf() .nickname() .status() .substatus() .type() .updated() .userDefinedStatus()
-
-
-
-