Class FinancialAccount.FinancialAccountCreditConfig
-
- All Implemented Interfaces:
public final class FinancialAccount.FinancialAccountCreditConfig
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinancialAccount.FinancialAccountCreditConfig.BuilderA builder for FinancialAccountCreditConfig.
public final classFinancialAccount.FinancialAccountCreditConfig.AutoCollectionConfigurationResponse
-
Method Summary
-
-
Method Detail
-
autoCollectionConfiguration
final Optional<FinancialAccount.FinancialAccountCreditConfig.AutoCollectionConfigurationResponse> autoCollectionConfiguration()
-
creditLimit
final Optional<Long> creditLimit()
-
creditProductToken
final Optional<String> creditProductToken()
Globally unique identifier for the credit product
-
externalBankAccountToken
final Optional<String> externalBankAccountToken()
-
_autoCollectionConfiguration
final JsonField<FinancialAccount.FinancialAccountCreditConfig.AutoCollectionConfigurationResponse> _autoCollectionConfiguration()
Returns the raw JSON value of autoCollectionConfiguration.
Unlike autoCollectionConfiguration, this method doesn't throw if the JSON field has an unexpected type.
-
_creditLimit
final JsonField<Long> _creditLimit()
Returns the raw JSON value of creditLimit.
Unlike creditLimit, this method doesn't throw if the JSON field has an unexpected type.
-
_creditProductToken
final JsonField<String> _creditProductToken()
Returns the raw JSON value of creditProductToken.
Unlike creditProductToken, this method doesn't throw if the JSON field has an unexpected type.
-
_externalBankAccountToken
final JsonField<String> _externalBankAccountToken()
Returns the raw JSON value of externalBankAccountToken.
Unlike externalBankAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_tier
final JsonField<String> _tier()
Returns the raw JSON value of tier.
Unlike tier, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FinancialAccount.FinancialAccountCreditConfig.Builder toBuilder()
-
validate
final FinancialAccount.FinancialAccountCreditConfig validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FinancialAccount.FinancialAccountCreditConfig.Builder builder()
Returns a mutable builder for constructing an instance of FinancialAccountCreditConfig.
The following fields are required:
.autoCollectionConfiguration() .creditLimit() .creditProductToken() .externalBankAccountToken() .tier()
-
-
-
-