Package com.lithic.api.models
Class FinancialAccountBalanceListPageAsync.Builder
-
- All Implemented Interfaces:
public final class FinancialAccountBalanceListPageAsync.BuilderA builder for FinancialAccountBalanceListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final FinancialAccountBalanceListPageAsync.Builderservice(BalanceServiceAsync service)final FinancialAccountBalanceListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final FinancialAccountBalanceListPageAsync.Builderparams(FinancialAccountBalanceListParams params)The parameters that were used to request this page. final FinancialAccountBalanceListPageAsync.Builderresponse(FinancialAccountBalanceListPageResponse response)The response that this page was parsed from. final FinancialAccountBalanceListPageAsyncbuild()Returns an immutable instance of FinancialAccountBalanceListPageAsync. -
-
Method Detail
-
service
final FinancialAccountBalanceListPageAsync.Builder service(BalanceServiceAsync service)
-
streamHandlerExecutor
final FinancialAccountBalanceListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final FinancialAccountBalanceListPageAsync.Builder params(FinancialAccountBalanceListParams params)
The parameters that were used to request this page.
-
response
final FinancialAccountBalanceListPageAsync.Builder response(FinancialAccountBalanceListPageResponse response)
The response that this page was parsed from.
-
build
final FinancialAccountBalanceListPageAsync build()
Returns an immutable instance of FinancialAccountBalanceListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-