Class FinancialAccountCreditConfig.Builder
-
- All Implemented Interfaces:
public final class FinancialAccountCreditConfig.BuilderA builder for FinancialAccountCreditConfig.
-
-
Method Summary
-
-
Method Detail
-
accountToken
final FinancialAccountCreditConfig.Builder accountToken(String accountToken)
Globally unique identifier for the account
-
accountToken
final FinancialAccountCreditConfig.Builder accountToken(JsonField<String> accountToken)
Sets Builder.accountToken to an arbitrary JSON value.
You should usually call Builder.accountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
chargedOffReason
final FinancialAccountCreditConfig.Builder chargedOffReason(FinancialAccountCreditConfig.ChargedOffReason chargedOffReason)
Reason for the financial account being marked as Charged Off
-
chargedOffReason
final FinancialAccountCreditConfig.Builder chargedOffReason(Optional<FinancialAccountCreditConfig.ChargedOffReason> chargedOffReason)
Alias for calling Builder.chargedOffReason with
chargedOffReason.orElse(null).
-
chargedOffReason
final FinancialAccountCreditConfig.Builder chargedOffReason(JsonField<FinancialAccountCreditConfig.ChargedOffReason> chargedOffReason)
Sets Builder.chargedOffReason to an arbitrary JSON value.
You should usually call Builder.chargedOffReason with a well-typed ChargedOffReason value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditLimit
final FinancialAccountCreditConfig.Builder creditLimit(Long creditLimit)
-
creditLimit
final FinancialAccountCreditConfig.Builder creditLimit(Long creditLimit)
Alias for Builder.creditLimit.
This unboxed primitive overload exists for backwards compatibility.
-
creditLimit
final FinancialAccountCreditConfig.Builder creditLimit(Optional<Long> creditLimit)
Alias for calling Builder.creditLimit with
creditLimit.orElse(null).
-
creditLimit
final FinancialAccountCreditConfig.Builder creditLimit(JsonField<Long> creditLimit)
Sets Builder.creditLimit to an arbitrary JSON value.
You should usually call Builder.creditLimit with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditProductToken
final FinancialAccountCreditConfig.Builder creditProductToken(String creditProductToken)
Globally unique identifier for the credit product
-
creditProductToken
final FinancialAccountCreditConfig.Builder creditProductToken(Optional<String> creditProductToken)
Alias for calling Builder.creditProductToken with
creditProductToken.orElse(null).
-
creditProductToken
final FinancialAccountCreditConfig.Builder creditProductToken(JsonField<String> creditProductToken)
Sets Builder.creditProductToken to an arbitrary JSON value.
You should usually call Builder.creditProductToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
externalBankAccountToken
final FinancialAccountCreditConfig.Builder externalBankAccountToken(String externalBankAccountToken)
-
externalBankAccountToken
final FinancialAccountCreditConfig.Builder externalBankAccountToken(Optional<String> externalBankAccountToken)
Alias for calling Builder.externalBankAccountToken with
externalBankAccountToken.orElse(null).
-
externalBankAccountToken
final FinancialAccountCreditConfig.Builder externalBankAccountToken(JsonField<String> externalBankAccountToken)
Sets Builder.externalBankAccountToken to an arbitrary JSON value.
You should usually call Builder.externalBankAccountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
financialAccountState
final FinancialAccountCreditConfig.Builder financialAccountState(FinancialAccountCreditConfig.FinancialAccountState financialAccountState)
State of the financial account
-
financialAccountState
final FinancialAccountCreditConfig.Builder financialAccountState(JsonField<FinancialAccountCreditConfig.FinancialAccountState> financialAccountState)
Sets Builder.financialAccountState to an arbitrary JSON value.
You should usually call Builder.financialAccountState with a well-typed FinancialAccountState value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
isSpendBlocked
final FinancialAccountCreditConfig.Builder isSpendBlocked(Boolean isSpendBlocked)
-
isSpendBlocked
final FinancialAccountCreditConfig.Builder isSpendBlocked(JsonField<Boolean> isSpendBlocked)
Sets Builder.isSpendBlocked to an arbitrary JSON value.
You should usually call Builder.isSpendBlocked with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tier
final FinancialAccountCreditConfig.Builder tier(String tier)
Tier assigned to the financial account
-
tier
final FinancialAccountCreditConfig.Builder tier(Optional<String> tier)
Alias for calling Builder.tier with
tier.orElse(null).
-
tier
final FinancialAccountCreditConfig.Builder tier(JsonField<String> tier)
Sets Builder.tier to an arbitrary JSON value.
You should usually call Builder.tier with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final FinancialAccountCreditConfig.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final FinancialAccountCreditConfig.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final FinancialAccountCreditConfig.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final FinancialAccountCreditConfig.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final FinancialAccountCreditConfig.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final FinancialAccountCreditConfig build()
Returns an immutable instance of FinancialAccountCreditConfig.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountToken() .chargedOffReason() .creditLimit() .creditProductToken() .externalBankAccountToken() .financialAccountState() .isSpendBlocked() .tier()
-
-
-
-