Package com.lithic.api.models
Class FinancialAccountListPage
-
- All Implemented Interfaces:
public final class FinancialAccountListPageRetrieve information on your financial accounts including routing and account number.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinancialAccountListPage.Responsepublic final classFinancialAccountListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final FinancialAccountListPage.Responseresponse()final List<FinancialAccount>data()final BooleanhasMore()Booleanequals(Object other)IntegerhashCode()StringtoString()final BooleanhasNextPage()final Optional<FinancialAccountListParams>getNextPageParams()final Optional<FinancialAccountListPage>getNextPage()final FinancialAccountListPage.AutoPagerautoPager()final static FinancialAccountListPageof(FinancialAccountService financialAccountsService, FinancialAccountListParams params, FinancialAccountListPage.Response response)-
-
Method Detail
-
response
final FinancialAccountListPage.Response response()
-
data
final List<FinancialAccount> data()
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<FinancialAccountListParams> getNextPageParams()
-
getNextPage
final Optional<FinancialAccountListPage> getNextPage()
-
autoPager
final FinancialAccountListPage.AutoPager autoPager()
-
of
final static FinancialAccountListPage of(FinancialAccountService financialAccountsService, FinancialAccountListParams params, FinancialAccountListPage.Response response)
-
-
-
-