Package com.lithic.api.models
Class FinancialAccountListPageAsync
-
- All Implemented Interfaces:
public final class FinancialAccountListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinancialAccountListPageAsync.BuilderA builder for FinancialAccountListPageAsync.
public final classFinancialAccountListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<FinancialAccount>data()Delegates to FinancialAccountListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to FinancialAccountListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<FinancialAccountListParams>getNextPageParams()final CompletableFuture<Optional<FinancialAccountListPageAsync>>getNextPage()final FinancialAccountListPageAsync.AutoPagerautoPager()final FinancialAccountListParamsparams()The parameters that were used to request this page. final FinancialAccountListPageResponseresponse()The response that this page was parsed from. final FinancialAccountListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FinancialAccountListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of FinancialAccountListPageAsync. -
-
Method Detail
-
data
final List<FinancialAccount> data()
Delegates to FinancialAccountListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to FinancialAccountListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<FinancialAccountListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<FinancialAccountListPageAsync>> getNextPage()
-
autoPager
final FinancialAccountListPageAsync.AutoPager autoPager()
-
params
final FinancialAccountListParams params()
The parameters that were used to request this page.
-
response
final FinancialAccountListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final FinancialAccountListPageAsync.Builder toBuilder()
-
builder
final static FinancialAccountListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of FinancialAccountListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-