Package com.lithic.api.models
Class FinancialAccountListPageAsync.Builder
-
- All Implemented Interfaces:
public final class FinancialAccountListPageAsync.BuilderA builder for FinancialAccountListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final FinancialAccountListPageAsync.Builderservice(FinancialAccountServiceAsync service)final FinancialAccountListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final FinancialAccountListPageAsync.Builderparams(FinancialAccountListParams params)The parameters that were used to request this page. final FinancialAccountListPageAsync.Builderresponse(FinancialAccountListPageResponse response)The response that this page was parsed from. final FinancialAccountListPageAsyncbuild()Returns an immutable instance of FinancialAccountListPageAsync. -
-
Method Detail
-
service
final FinancialAccountListPageAsync.Builder service(FinancialAccountServiceAsync service)
-
streamHandlerExecutor
final FinancialAccountListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final FinancialAccountListPageAsync.Builder params(FinancialAccountListParams params)
The parameters that were used to request this page.
-
response
final FinancialAccountListPageAsync.Builder response(FinancialAccountListPageResponse response)
The response that this page was parsed from.
-
build
final FinancialAccountListPageAsync build()
Returns an immutable instance of FinancialAccountListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-