Package com.lithic.api.models
Class FinancialAccountListPageResponse
-
- All Implemented Interfaces:
public final class FinancialAccountListPageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinancialAccountListPageResponse.BuilderA builder for FinancialAccountListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<FinancialAccount>data()final BooleanhasMore()final JsonField<List<FinancialAccount>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final FinancialAccountListPageResponse.BuildertoBuilder()final FinancialAccountListPageResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FinancialAccountListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of FinancialAccountListPageResponse. -
-
Method Detail
-
data
final List<FinancialAccount> data()
-
_data
final JsonField<List<FinancialAccount>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FinancialAccountListPageResponse.Builder toBuilder()
-
validate
final FinancialAccountListPageResponse validate()
-
builder
final static FinancialAccountListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of FinancialAccountListPageResponse.
The following fields are required:
.data() .hasMore()
-
-
-
-