Package com.lithic.api.models
Class FinancialAccountStatementLineItemListPage.Builder
-
- All Implemented Interfaces:
public final class FinancialAccountStatementLineItemListPage.BuilderA builder for FinancialAccountStatementLineItemListPage.
-
-
Method Summary
Modifier and Type Method Description final FinancialAccountStatementLineItemListPage.Builderservice(LineItemService service)final FinancialAccountStatementLineItemListPage.Builderparams(FinancialAccountStatementLineItemListParams params)The parameters that were used to request this page. final FinancialAccountStatementLineItemListPage.Builderresponse(StatementLineItems response)The response that this page was parsed from. final FinancialAccountStatementLineItemListPagebuild()Returns an immutable instance of FinancialAccountStatementLineItemListPage. -
-
Method Detail
-
service
final FinancialAccountStatementLineItemListPage.Builder service(LineItemService service)
-
params
final FinancialAccountStatementLineItemListPage.Builder params(FinancialAccountStatementLineItemListParams params)
The parameters that were used to request this page.
-
response
final FinancialAccountStatementLineItemListPage.Builder response(StatementLineItems response)
The response that this page was parsed from.
-
build
final FinancialAccountStatementLineItemListPage build()
Returns an immutable instance of FinancialAccountStatementLineItemListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-