Package com.lithic.api.models
Class FinancialAccountStatementLineItemListPageAsync
-
- All Implemented Interfaces:
public final class FinancialAccountStatementLineItemListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinancialAccountStatementLineItemListPageAsync.BuilderA builder for FinancialAccountStatementLineItemListPageAsync.
public final classFinancialAccountStatementLineItemListPageAsync.AutoPager
-
Method Summary
-
-
Method Detail
-
data
final List<StatementLineItems.StatementLineItemResponse> data()
Delegates to StatementLineItems, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to StatementLineItems, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<FinancialAccountStatementLineItemListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<FinancialAccountStatementLineItemListPageAsync>> getNextPage()
-
autoPager
final FinancialAccountStatementLineItemListPageAsync.AutoPager autoPager()
-
params
final FinancialAccountStatementLineItemListParams params()
The parameters that were used to request this page.
-
response
final StatementLineItems response()
The response that this page was parsed from.
-
toBuilder
final FinancialAccountStatementLineItemListPageAsync.Builder toBuilder()
-
builder
final static FinancialAccountStatementLineItemListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of FinancialAccountStatementLineItemListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-