Package com.lithic.api.models
Class FinancialAccountStatementListPage.Builder
-
- All Implemented Interfaces:
public final class FinancialAccountStatementListPage.BuilderA builder for FinancialAccountStatementListPage.
-
-
Method Summary
Modifier and Type Method Description final FinancialAccountStatementListPage.Builderservice(StatementService service)final FinancialAccountStatementListPage.Builderparams(FinancialAccountStatementListParams params)The parameters that were used to request this page. final FinancialAccountStatementListPage.Builderresponse(Statements response)The response that this page was parsed from. final FinancialAccountStatementListPagebuild()Returns an immutable instance of FinancialAccountStatementListPage. -
-
Method Detail
-
service
final FinancialAccountStatementListPage.Builder service(StatementService service)
-
params
final FinancialAccountStatementListPage.Builder params(FinancialAccountStatementListParams params)
The parameters that were used to request this page.
-
response
final FinancialAccountStatementListPage.Builder response(Statements response)
The response that this page was parsed from.
-
build
final FinancialAccountStatementListPage build()
Returns an immutable instance of FinancialAccountStatementListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-