Package com.lithic.api.models
Class FinancialAccountStatementListPageAsync
-
- All Implemented Interfaces:
public final class FinancialAccountStatementListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinancialAccountStatementListPageAsync.BuilderA builder for FinancialAccountStatementListPageAsync.
public final classFinancialAccountStatementListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<Statement>data()Delegates to Statements, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to Statements, but gracefully handles missing data. final BooleanhasNextPage()final Optional<FinancialAccountStatementListParams>getNextPageParams()final CompletableFuture<Optional<FinancialAccountStatementListPageAsync>>getNextPage()final FinancialAccountStatementListPageAsync.AutoPagerautoPager()final FinancialAccountStatementListParamsparams()The parameters that were used to request this page. final Statementsresponse()The response that this page was parsed from. final FinancialAccountStatementListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FinancialAccountStatementListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of FinancialAccountStatementListPageAsync. -
-
Method Detail
-
data
final List<Statement> data()
Delegates to Statements, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to Statements, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<FinancialAccountStatementListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<FinancialAccountStatementListPageAsync>> getNextPage()
-
autoPager
final FinancialAccountStatementListPageAsync.AutoPager autoPager()
-
params
final FinancialAccountStatementListParams params()
The parameters that were used to request this page.
-
response
final Statements response()
The response that this page was parsed from.
-
toBuilder
final FinancialAccountStatementListPageAsync.Builder toBuilder()
-
builder
final static FinancialAccountStatementListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of FinancialAccountStatementListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-