Class FinancialTransaction.Builder
-
- All Implemented Interfaces:
public final class FinancialTransaction.BuilderA builder for FinancialTransaction.
-
-
Method Summary
Modifier and Type Method Description final FinancialTransaction.Buildertoken(String token)Globally unique identifier. final FinancialTransaction.Buildertoken(JsonField<String> token)Globally unique identifier. final FinancialTransaction.Buildercategory(FinancialTransaction.Category category)Status types: CARD- Issuing card transaction.ACH- Transaction over ACH.INTERNAL- Transaction for internal adjustment.TRANSFER- Internal transfer of funds between financial accounts in your program.
final FinancialTransaction.Buildercategory(JsonField<FinancialTransaction.Category> category)Status types: CARD- Issuing card transaction.ACH- Transaction over ACH.INTERNAL- Transaction for internal adjustment.TRANSFER- Internal transfer of funds between financial accounts in your program.
final FinancialTransaction.Buildercreated(OffsetDateTime created)Date and time when the financial transaction first occurred. final FinancialTransaction.Buildercreated(JsonField<OffsetDateTime> created)Date and time when the financial transaction first occurred. final FinancialTransaction.Buildercurrency(String currency)3-character alphabetic ISO 4217 code for the settling currency of the transaction. final FinancialTransaction.Buildercurrency(JsonField<String> currency)3-character alphabetic ISO 4217 code for the settling currency of the transaction. final FinancialTransaction.Builderdescriptor(String descriptor)A string that provides a description of the financial transaction; may be useful to display to users. final FinancialTransaction.Builderdescriptor(JsonField<String> descriptor)A string that provides a description of the financial transaction; may be useful to display to users. final FinancialTransaction.Builderevents(List<FinancialTransaction.FinancialEvent> events)A list of all financial events that have modified this financial transaction. final FinancialTransaction.Builderevents(JsonField<List<FinancialTransaction.FinancialEvent>> events)A list of all financial events that have modified this financial transaction. final FinancialTransaction.BuilderaddEvent(FinancialTransaction.FinancialEvent event)A list of all financial events that have modified this financial transaction. final FinancialTransaction.BuilderpendingAmount(Long pendingAmount)Pending amount of the transaction in the currency's smallest unit (e.g., cents), including any acquirer fees. final FinancialTransaction.BuilderpendingAmount(JsonField<Long> pendingAmount)Pending amount of the transaction in the currency's smallest unit (e.g., cents), including any acquirer fees. final FinancialTransaction.Builderresult(FinancialTransaction.Result result)APPROVED transactions were successful while DECLINED transactions were declined by user, Lithic, or the network. final FinancialTransaction.Builderresult(JsonField<FinancialTransaction.Result> result)APPROVED transactions were successful while DECLINED transactions were declined by user, Lithic, or the network. final FinancialTransaction.BuildersettledAmount(Long settledAmount)Amount of the transaction that has been settled in the currency's smallest unit (e.g., cents), including any acquirer fees. final FinancialTransaction.BuildersettledAmount(JsonField<Long> settledAmount)Amount of the transaction that has been settled in the currency's smallest unit (e.g., cents), including any acquirer fees. final FinancialTransaction.Builderstatus(FinancialTransaction.Status status)Status types: DECLINED- The transaction was declined.EXPIRED- The authorization as it has passed its expiration time. Card transaction only.PENDING- The transaction is expected to settle.RETURNED- The transaction has been returned.SETTLED- The transaction is completed.VOIDED- The transaction was voided. Card transaction only.
final FinancialTransaction.Builderstatus(JsonField<FinancialTransaction.Status> status)Status types: DECLINED- The transaction was declined.EXPIRED- The authorization as it has passed its expiration time. Card transaction only.PENDING- The transaction is expected to settle.RETURNED- The transaction has been returned.SETTLED- The transaction is completed.VOIDED- The transaction was voided. Card transaction only.
final FinancialTransaction.Builderupdated(OffsetDateTime updated)Date and time when the financial transaction was last updated. final FinancialTransaction.Builderupdated(JsonField<OffsetDateTime> updated)Date and time when the financial transaction was last updated. final FinancialTransaction.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final FinancialTransaction.BuilderputAdditionalProperty(String key, JsonValue value)final FinancialTransaction.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final FinancialTransaction.BuilderremoveAdditionalProperty(String key)final FinancialTransaction.BuilderremoveAllAdditionalProperties(Set<String> keys)final FinancialTransactionbuild()-
-
Method Detail
-
token
final FinancialTransaction.Builder token(String token)
Globally unique identifier.
-
token
final FinancialTransaction.Builder token(JsonField<String> token)
Globally unique identifier.
-
category
final FinancialTransaction.Builder category(FinancialTransaction.Category category)
Status types:
CARD- Issuing card transaction.ACH- Transaction over ACH.INTERNAL- Transaction for internal adjustment.TRANSFER- Internal transfer of funds between financial accounts in your program.
-
category
final FinancialTransaction.Builder category(JsonField<FinancialTransaction.Category> category)
Status types:
CARD- Issuing card transaction.ACH- Transaction over ACH.INTERNAL- Transaction for internal adjustment.TRANSFER- Internal transfer of funds between financial accounts in your program.
-
created
final FinancialTransaction.Builder created(OffsetDateTime created)
Date and time when the financial transaction first occurred. UTC time zone.
-
created
final FinancialTransaction.Builder created(JsonField<OffsetDateTime> created)
Date and time when the financial transaction first occurred. UTC time zone.
-
currency
final FinancialTransaction.Builder currency(String currency)
3-character alphabetic ISO 4217 code for the settling currency of the transaction.
-
currency
final FinancialTransaction.Builder currency(JsonField<String> currency)
3-character alphabetic ISO 4217 code for the settling currency of the transaction.
-
descriptor
final FinancialTransaction.Builder descriptor(String descriptor)
A string that provides a description of the financial transaction; may be useful to display to users.
-
descriptor
final FinancialTransaction.Builder descriptor(JsonField<String> descriptor)
A string that provides a description of the financial transaction; may be useful to display to users.
-
events
final FinancialTransaction.Builder events(List<FinancialTransaction.FinancialEvent> events)
A list of all financial events that have modified this financial transaction.
-
events
final FinancialTransaction.Builder events(JsonField<List<FinancialTransaction.FinancialEvent>> events)
A list of all financial events that have modified this financial transaction.
-
addEvent
final FinancialTransaction.Builder addEvent(FinancialTransaction.FinancialEvent event)
A list of all financial events that have modified this financial transaction.
-
pendingAmount
final FinancialTransaction.Builder pendingAmount(Long pendingAmount)
Pending amount of the transaction in the currency's smallest unit (e.g., cents), including any acquirer fees. The value of this field will go to zero over time once the financial transaction is settled.
-
pendingAmount
final FinancialTransaction.Builder pendingAmount(JsonField<Long> pendingAmount)
Pending amount of the transaction in the currency's smallest unit (e.g., cents), including any acquirer fees. The value of this field will go to zero over time once the financial transaction is settled.
-
result
final FinancialTransaction.Builder result(FinancialTransaction.Result result)
APPROVED transactions were successful while DECLINED transactions were declined by user, Lithic, or the network.
-
result
final FinancialTransaction.Builder result(JsonField<FinancialTransaction.Result> result)
APPROVED transactions were successful while DECLINED transactions were declined by user, Lithic, or the network.
-
settledAmount
final FinancialTransaction.Builder settledAmount(Long settledAmount)
Amount of the transaction that has been settled in the currency's smallest unit (e.g., cents), including any acquirer fees. This may change over time.
-
settledAmount
final FinancialTransaction.Builder settledAmount(JsonField<Long> settledAmount)
Amount of the transaction that has been settled in the currency's smallest unit (e.g., cents), including any acquirer fees. This may change over time.
-
status
final FinancialTransaction.Builder status(FinancialTransaction.Status status)
Status types:
DECLINED- The transaction was declined.EXPIRED- The authorization as it has passed its expiration time. Card transaction only.PENDING- The transaction is expected to settle.RETURNED- The transaction has been returned.SETTLED- The transaction is completed.VOIDED- The transaction was voided. Card transaction only.
-
status
final FinancialTransaction.Builder status(JsonField<FinancialTransaction.Status> status)
Status types:
DECLINED- The transaction was declined.EXPIRED- The authorization as it has passed its expiration time. Card transaction only.PENDING- The transaction is expected to settle.RETURNED- The transaction has been returned.SETTLED- The transaction is completed.VOIDED- The transaction was voided. Card transaction only.
-
updated
final FinancialTransaction.Builder updated(OffsetDateTime updated)
Date and time when the financial transaction was last updated. UTC time zone.
-
updated
final FinancialTransaction.Builder updated(JsonField<OffsetDateTime> updated)
Date and time when the financial transaction was last updated. UTC time zone.
-
additionalProperties
final FinancialTransaction.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final FinancialTransaction.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final FinancialTransaction.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final FinancialTransaction.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final FinancialTransaction.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final FinancialTransaction build()
-
-
-