Package com.lithic.api.models
Class FinancialTransaction.FinancialEvent.Builder
-
- All Implemented Interfaces:
public final class FinancialTransaction.FinancialEvent.BuilderA builder for FinancialEvent.
-
-
Method Summary
-
-
Method Detail
-
token
final FinancialTransaction.FinancialEvent.Builder token(String token)
Globally unique identifier.
-
token
final FinancialTransaction.FinancialEvent.Builder token(JsonField<String> token)
Globally unique identifier.
-
amount
final FinancialTransaction.FinancialEvent.Builder amount(Long amount)
Amount of the financial event that has been settled in the currency's smallest unit (e.g., cents).
-
amount
final FinancialTransaction.FinancialEvent.Builder amount(JsonField<Long> amount)
Amount of the financial event that has been settled in the currency's smallest unit (e.g., cents).
-
created
final FinancialTransaction.FinancialEvent.Builder created(OffsetDateTime created)
Date and time when the financial event occurred. UTC time zone.
-
created
final FinancialTransaction.FinancialEvent.Builder created(JsonField<OffsetDateTime> created)
Date and time when the financial event occurred. UTC time zone.
-
result
final FinancialTransaction.FinancialEvent.Builder result(FinancialTransaction.FinancialEvent.Result result)
APPROVED financial events were successful while DECLINED financial events were declined by user, Lithic, or the network.
-
result
final FinancialTransaction.FinancialEvent.Builder result(JsonField<FinancialTransaction.FinancialEvent.Result> result)
APPROVED financial events were successful while DECLINED financial events were declined by user, Lithic, or the network.
-
type
final FinancialTransaction.FinancialEvent.Builder type(FinancialTransaction.FinancialEvent.FinancialEventType type)
-
type
final FinancialTransaction.FinancialEvent.Builder type(JsonField<FinancialTransaction.FinancialEvent.FinancialEventType> type)
-
additionalProperties
final FinancialTransaction.FinancialEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final FinancialTransaction.FinancialEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final FinancialTransaction.FinancialEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final FinancialTransaction.FinancialEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final FinancialTransaction.FinancialEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final FinancialTransaction.FinancialEvent build()
-
-
-
-