Package com.lithic.api.models
Class FinancialTransactionListPage
-
- All Implemented Interfaces:
public final class FinancialTransactionListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinancialTransactionListPage.BuilderA builder for FinancialTransactionListPage.
public final classFinancialTransactionListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<FinancialTransaction>data()Delegates to FinancialTransactionListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to FinancialTransactionListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<FinancialTransactionListParams>getNextPageParams()final Optional<FinancialTransactionListPage>getNextPage()final FinancialTransactionListPage.AutoPagerautoPager()final FinancialTransactionListParamsparams()The parameters that were used to request this page. final FinancialTransactionListPageResponseresponse()The response that this page was parsed from. final FinancialTransactionListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FinancialTransactionListPage.Builderbuilder()Returns a mutable builder for constructing an instance of FinancialTransactionListPage. -
-
Method Detail
-
data
final List<FinancialTransaction> data()
Delegates to FinancialTransactionListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to FinancialTransactionListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<FinancialTransactionListParams> getNextPageParams()
-
getNextPage
final Optional<FinancialTransactionListPage> getNextPage()
-
autoPager
final FinancialTransactionListPage.AutoPager autoPager()
-
params
final FinancialTransactionListParams params()
The parameters that were used to request this page.
-
response
final FinancialTransactionListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final FinancialTransactionListPage.Builder toBuilder()
-
builder
final static FinancialTransactionListPage.Builder builder()
Returns a mutable builder for constructing an instance of FinancialTransactionListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-