Package com.lithic.api.models
Class FinancialTransactionListPageAsync
-
- All Implemented Interfaces:
public final class FinancialTransactionListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinancialTransactionListPageAsync.BuilderA builder for FinancialTransactionListPageAsync.
public final classFinancialTransactionListPageAsync.AutoPager
-
Method Summary
-
-
Method Detail
-
data
final List<FinancialTransaction> data()
Delegates to FinancialTransactionListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to FinancialTransactionListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<FinancialTransactionListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<FinancialTransactionListPageAsync>> getNextPage()
-
autoPager
final FinancialTransactionListPageAsync.AutoPager autoPager()
-
params
final FinancialTransactionListParams params()
The parameters that were used to request this page.
-
response
final FinancialTransactionListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final FinancialTransactionListPageAsync.Builder toBuilder()
-
builder
final static FinancialTransactionListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of FinancialTransactionListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-