Package com.lithic.api.models
Class FinancialTransactionListPageAsync.Builder
-
- All Implemented Interfaces:
public final class FinancialTransactionListPageAsync.BuilderA builder for FinancialTransactionListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final FinancialTransactionListPageAsync.Builderservice(FinancialTransactionServiceAsync service)final FinancialTransactionListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final FinancialTransactionListPageAsync.Builderparams(FinancialTransactionListParams params)The parameters that were used to request this page. final FinancialTransactionListPageAsync.Builderresponse(FinancialTransactionListPageResponse response)The response that this page was parsed from. final FinancialTransactionListPageAsyncbuild()Returns an immutable instance of FinancialTransactionListPageAsync. -
-
Method Detail
-
service
final FinancialTransactionListPageAsync.Builder service(FinancialTransactionServiceAsync service)
-
streamHandlerExecutor
final FinancialTransactionListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final FinancialTransactionListPageAsync.Builder params(FinancialTransactionListParams params)
The parameters that were used to request this page.
-
response
final FinancialTransactionListPageAsync.Builder response(FinancialTransactionListPageResponse response)
The response that this page was parsed from.
-
build
final FinancialTransactionListPageAsync build()
Returns an immutable instance of FinancialTransactionListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-