Package com.lithic.api.models
Class FundingEventListPageAsync.Builder
-
- All Implemented Interfaces:
public final class FundingEventListPageAsync.BuilderA builder for FundingEventListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final FundingEventListPageAsync.Builderservice(FundingEventServiceAsync service)final FundingEventListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final FundingEventListPageAsync.Builderparams(FundingEventListParams params)The parameters that were used to request this page. final FundingEventListPageAsync.Builderresponse(FundingEventListPageResponse response)The response that this page was parsed from. final FundingEventListPageAsyncbuild()Returns an immutable instance of FundingEventListPageAsync. -
-
Method Detail
-
service
final FundingEventListPageAsync.Builder service(FundingEventServiceAsync service)
-
streamHandlerExecutor
final FundingEventListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final FundingEventListPageAsync.Builder params(FundingEventListParams params)
The parameters that were used to request this page.
-
response
final FundingEventListPageAsync.Builder response(FundingEventListPageResponse response)
The response that this page was parsed from.
-
build
final FundingEventListPageAsync build()
Returns an immutable instance of FundingEventListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-