Package com.lithic.api.models
Class FundingEventListPageResponse
-
- All Implemented Interfaces:
public final class FundingEventListPageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFundingEventListPageResponse.BuilderA builder for FundingEventListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<FundingEvent>data()Funding Event Response final BooleanhasMore()final JsonField<List<FundingEvent>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final FundingEventListPageResponse.BuildertoBuilder()final FundingEventListPageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FundingEventListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of FundingEventListPageResponse. -
-
Method Detail
-
data
final List<FundingEvent> data()
Funding Event Response
-
_data
final JsonField<List<FundingEvent>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FundingEventListPageResponse.Builder toBuilder()
-
validate
final FundingEventListPageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FundingEventListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of FundingEventListPageResponse.
The following fields are required:
.data() .hasMore()
-
-
-
-