Class FundingEventListResponse
-
- All Implemented Interfaces:
public final class FundingEventListResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFundingEventListResponse.BuilderA builder for FundingEventListResponse.
public final classFundingEventListResponse.CollectionResourceTypeCollection resource type
public final classFundingEventListResponse.FundingEventSettlement
-
Method Summary
-
-
Method Detail
-
collectionResourceType
final FundingEventListResponse.CollectionResourceType collectionResourceType()
Collection resource type
-
collectionTokens
final List<String> collectionTokens()
IDs of collections, further information can be gathered from the appropriate collection API based on collection_resource_type
-
created
final OffsetDateTime created()
Time of the creation
-
highWatermark
final OffsetDateTime highWatermark()
Time of the high watermark
-
networkSettlementSummary
final List<FundingEventListResponse.FundingEventSettlement> networkSettlementSummary()
Network settlement summary breakdown by network settlement date
-
previousHighWatermark
final OffsetDateTime previousHighWatermark()
Time of the previous high watermark
-
updated
final OffsetDateTime updated()
Time of the update
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_collectionResourceType
final JsonField<FundingEventListResponse.CollectionResourceType> _collectionResourceType()
Returns the raw JSON value of collectionResourceType.
Unlike collectionResourceType, this method doesn't throw if the JSON field has an unexpected type.
-
_collectionTokens
final JsonField<List<String>> _collectionTokens()
Returns the raw JSON value of collectionTokens.
Unlike collectionTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_highWatermark
final JsonField<OffsetDateTime> _highWatermark()
Returns the raw JSON value of highWatermark.
Unlike highWatermark, this method doesn't throw if the JSON field has an unexpected type.
-
_networkSettlementSummary
final JsonField<List<FundingEventListResponse.FundingEventSettlement>> _networkSettlementSummary()
Returns the raw JSON value of networkSettlementSummary.
Unlike networkSettlementSummary, this method doesn't throw if the JSON field has an unexpected type.
-
_previousHighWatermark
final JsonField<OffsetDateTime> _previousHighWatermark()
Returns the raw JSON value of previousHighWatermark.
Unlike previousHighWatermark, this method doesn't throw if the JSON field has an unexpected type.
-
_updated
final JsonField<OffsetDateTime> _updated()
Returns the raw JSON value of updated.
Unlike updated, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FundingEventListResponse.Builder toBuilder()
-
validate
final FundingEventListResponse validate()
-
builder
final static FundingEventListResponse.Builder builder()
Returns a mutable builder for constructing an instance of FundingEventListResponse.
The following fields are required:
.token() .collectionResourceType() .collectionTokens() .created() .highWatermark() .networkSettlementSummary() .previousHighWatermark() .updated()
-
-
-
-