Class FundingEventRetrieveDetailsResponse
-
- All Implemented Interfaces:
public final class FundingEventRetrieveDetailsResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFundingEventRetrieveDetailsResponse.BuilderA builder for FundingEventRetrieveDetailsResponse.
-
Method Summary
Modifier and Type Method Description final Stringtoken()Unique token ID final StringsettlementDetailsUrl()URL of the settlement details final StringsettlementSummaryUrl()URL of the settlement summary final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<String>_settlementDetailsUrl()Returns the raw JSON value of settlementDetailsUrl. final JsonField<String>_settlementSummaryUrl()Returns the raw JSON value of settlementSummaryUrl. final Map<String, JsonValue>_additionalProperties()final FundingEventRetrieveDetailsResponse.BuildertoBuilder()final FundingEventRetrieveDetailsResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FundingEventRetrieveDetailsResponse.Builderbuilder()Returns a mutable builder for constructing an instance of FundingEventRetrieveDetailsResponse. -
-
Method Detail
-
settlementDetailsUrl
final String settlementDetailsUrl()
URL of the settlement details
-
settlementSummaryUrl
final String settlementSummaryUrl()
URL of the settlement summary
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_settlementDetailsUrl
final JsonField<String> _settlementDetailsUrl()
Returns the raw JSON value of settlementDetailsUrl.
Unlike settlementDetailsUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_settlementSummaryUrl
final JsonField<String> _settlementSummaryUrl()
Returns the raw JSON value of settlementSummaryUrl.
Unlike settlementSummaryUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FundingEventRetrieveDetailsResponse.Builder toBuilder()
-
validate
final FundingEventRetrieveDetailsResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FundingEventRetrieveDetailsResponse.Builder builder()
Returns a mutable builder for constructing an instance of FundingEventRetrieveDetailsResponse.
The following fields are required:
.token() .settlementDetailsUrl() .settlementSummaryUrl()
-
-
-
-