Class FundingEventRetrieveResponse.Builder
-
- All Implemented Interfaces:
public final class FundingEventRetrieveResponse.BuilderA builder for FundingEventRetrieveResponse.
-
-
Method Summary
-
-
Method Detail
-
token
final FundingEventRetrieveResponse.Builder token(String token)
Unique token ID
-
token
final FundingEventRetrieveResponse.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
collectionResourceType
final FundingEventRetrieveResponse.Builder collectionResourceType(FundingEventRetrieveResponse.CollectionResourceType collectionResourceType)
Collection resource type
-
collectionResourceType
final FundingEventRetrieveResponse.Builder collectionResourceType(JsonField<FundingEventRetrieveResponse.CollectionResourceType> collectionResourceType)
Sets Builder.collectionResourceType to an arbitrary JSON value.
You should usually call Builder.collectionResourceType with a well-typed CollectionResourceType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
collectionTokens
final FundingEventRetrieveResponse.Builder collectionTokens(List<String> collectionTokens)
IDs of collections
-
collectionTokens
final FundingEventRetrieveResponse.Builder collectionTokens(JsonField<List<String>> collectionTokens)
Sets Builder.collectionTokens to an arbitrary JSON value.
You should usually call Builder.collectionTokens with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addCollectionToken
final FundingEventRetrieveResponse.Builder addCollectionToken(String collectionToken)
Adds a single String to collectionTokens.
-
created
final FundingEventRetrieveResponse.Builder created(OffsetDateTime created)
Time of the creation
-
created
final FundingEventRetrieveResponse.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
highWatermark
final FundingEventRetrieveResponse.Builder highWatermark(OffsetDateTime highWatermark)
Time of the high watermark
-
highWatermark
final FundingEventRetrieveResponse.Builder highWatermark(JsonField<OffsetDateTime> highWatermark)
Sets Builder.highWatermark to an arbitrary JSON value.
You should usually call Builder.highWatermark with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
previousHighWatermark
final FundingEventRetrieveResponse.Builder previousHighWatermark(OffsetDateTime previousHighWatermark)
Time of the previous high watermark
-
previousHighWatermark
final FundingEventRetrieveResponse.Builder previousHighWatermark(JsonField<OffsetDateTime> previousHighWatermark)
Sets Builder.previousHighWatermark to an arbitrary JSON value.
You should usually call Builder.previousHighWatermark with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
settlementBreakdowns
final FundingEventRetrieveResponse.Builder settlementBreakdowns(List<FundingEventRetrieveResponse.FundingEventSettlement> settlementBreakdowns)
List of settlements
-
settlementBreakdowns
final FundingEventRetrieveResponse.Builder settlementBreakdowns(JsonField<List<FundingEventRetrieveResponse.FundingEventSettlement>> settlementBreakdowns)
Sets Builder.settlementBreakdowns to an arbitrary JSON value.
You should usually call Builder.settlementBreakdowns with a well-typed
List<FundingEventSettlement>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addSettlementBreakdown
final FundingEventRetrieveResponse.Builder addSettlementBreakdown(FundingEventRetrieveResponse.FundingEventSettlement settlementBreakdown)
Adds a single FundingEventSettlement to settlementBreakdowns.
-
updated
final FundingEventRetrieveResponse.Builder updated(OffsetDateTime updated)
Time of the update
-
updated
final FundingEventRetrieveResponse.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final FundingEventRetrieveResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final FundingEventRetrieveResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final FundingEventRetrieveResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final FundingEventRetrieveResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final FundingEventRetrieveResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final FundingEventRetrieveResponse build()
Returns an immutable instance of FundingEventRetrieveResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .collectionResourceType() .collectionTokens() .created() .highWatermark() .previousHighWatermark() .settlementBreakdowns() .updated()
-
-
-
-