Class HoldEvent.Builder
-
- All Implemented Interfaces:
public final class HoldEvent.BuilderA builder for HoldEvent.
-
-
Method Summary
-
-
Method Detail
-
token
final HoldEvent.Builder token(String token)
-
token
final HoldEvent.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final HoldEvent.Builder amount(Long amount)
Amount in cents
-
amount
final HoldEvent.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final HoldEvent.Builder created(OffsetDateTime created)
-
created
final HoldEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
detailedResults
final HoldEvent.Builder detailedResults(List<HoldEvent.DetailedResults> detailedResults)
-
detailedResults
final HoldEvent.Builder detailedResults(JsonField<List<HoldEvent.DetailedResults>> detailedResults)
Sets Builder.detailedResults to an arbitrary JSON value.
You should usually call Builder.detailedResults with a well-typed
List<DetailedResults>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addDetailedResult
final HoldEvent.Builder addDetailedResult(HoldEvent.DetailedResults detailedResult)
Adds a single DetailedResults to detailedResults.
-
memo
final HoldEvent.Builder memo(String memo)
-
memo
final HoldEvent.Builder memo(Optional<String> memo)
Alias for calling Builder.memo with
memo.orElse(null).
-
memo
final HoldEvent.Builder memo(JsonField<String> memo)
Sets Builder.memo to an arbitrary JSON value.
You should usually call Builder.memo with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
result
final HoldEvent.Builder result(HoldEvent.TransactionResult result)
-
result
final HoldEvent.Builder result(JsonField<HoldEvent.TransactionResult> result)
Sets Builder.result to an arbitrary JSON value.
You should usually call Builder.result with a well-typed TransactionResult value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
settlingTransactionToken
final HoldEvent.Builder settlingTransactionToken(String settlingTransactionToken)
Transaction token of the payment that settled this hold (only populated for HOLD_SETTLED events)
-
settlingTransactionToken
final HoldEvent.Builder settlingTransactionToken(Optional<String> settlingTransactionToken)
Alias for calling Builder.settlingTransactionToken with
settlingTransactionToken.orElse(null).
-
settlingTransactionToken
final HoldEvent.Builder settlingTransactionToken(JsonField<String> settlingTransactionToken)
Sets Builder.settlingTransactionToken to an arbitrary JSON value.
You should usually call Builder.settlingTransactionToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final HoldEvent.Builder type(HoldEvent.HoldEventType type)
Type of hold lifecycle event
-
type
final HoldEvent.Builder type(JsonField<HoldEvent.HoldEventType> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed HoldEventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final HoldEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final HoldEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final HoldEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final HoldEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final HoldEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-