Class InterestTierSchedule.Builder
-
- All Implemented Interfaces:
public final class InterestTierSchedule.BuilderA builder for InterestTierSchedule.
-
-
Method Summary
-
-
Method Detail
-
creditProductToken
final InterestTierSchedule.Builder creditProductToken(String creditProductToken)
Globally unique identifier for a credit product
-
creditProductToken
final InterestTierSchedule.Builder creditProductToken(JsonField<String> creditProductToken)
Sets Builder.creditProductToken to an arbitrary JSON value.
You should usually call Builder.creditProductToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
effectiveDate
final InterestTierSchedule.Builder effectiveDate(LocalDate effectiveDate)
Date the tier should be effective in YYYY-MM-DD format
-
effectiveDate
final InterestTierSchedule.Builder effectiveDate(JsonField<LocalDate> effectiveDate)
Sets Builder.effectiveDate to an arbitrary JSON value.
You should usually call Builder.effectiveDate with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
penaltyRates
final InterestTierSchedule.Builder penaltyRates(JsonValue penaltyRates)
Custom rates per category for penalties
-
tierName
final InterestTierSchedule.Builder tierName(String tierName)
Name of a tier contained in the credit product. Mutually exclusive with tier_rates
-
tierName
final InterestTierSchedule.Builder tierName(JsonField<String> tierName)
Sets Builder.tierName to an arbitrary JSON value.
You should usually call Builder.tierName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tierRates
final InterestTierSchedule.Builder tierRates(JsonValue tierRates)
Custom rates per category. Mutually exclusive with tier_name
-
additionalProperties
final InterestTierSchedule.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InterestTierSchedule.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InterestTierSchedule.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InterestTierSchedule.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InterestTierSchedule.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InterestTierSchedule build()
Returns an immutable instance of InterestTierSchedule.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.creditProductToken() .effectiveDate()
-
-
-
-