Class Kyb
-
- All Implemented Interfaces:
public final class Kyb
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classKyb.BuilderA builder for Kyb.
public final classKyb.KybIndividualIndividuals associated with a KYB application. Phone number is optional.
public final classKyb.BusinessEntityInformation for business for which the account is being opened and KYB is being run.
public final classKyb.WorkflowSpecifies the type of KYB workflow to run.
-
Method Summary
Modifier and Type Method Description final List<Kyb.KybIndividual>beneficialOwnerIndividuals()You must submit a list of all direct and indirect individuals with 25% or more ownership in the company. final Kyb.BusinessEntitybusinessEntity()Information for business for which the account is being opened and KYB is being run. final Kyb.KybIndividualcontrolPerson()An individual with significant responsibility for managing the legal entity (e.g., a Chief Executive Officer, Chief Financial Officer, Chief Operating Officer, Managing Member, General Partner, President, Vice President, or Treasurer). final StringnatureOfBusiness()Short description of the company's line of business (i.e., what does the company do?). final StringtosTimestamp()An RFC 3339 timestamp indicating when the account holder accepted the applicable legal agreements (e.g., cardholder terms) as agreed upon during API customer's implementation with Lithic. final Kyb.Workflowworkflow()Specifies the type of KYB workflow to run. final Optional<List<Kyb.BusinessEntity>>beneficialOwnerEntities()Deprecated. final Optional<String>externalId()A user provided id that can be used to link an account holder with an external system final Optional<String>kybPassedTimestamp()An RFC 3339 timestamp indicating when precomputed KYC was completed on the business with a pass result. final Optional<String>websiteUrl()Company website URL. final JsonField<List<Kyb.KybIndividual>>_beneficialOwnerIndividuals()Returns the raw JSON value of beneficialOwnerIndividuals. final JsonField<Kyb.BusinessEntity>_businessEntity()Returns the raw JSON value of businessEntity. final JsonField<Kyb.KybIndividual>_controlPerson()Returns the raw JSON value of controlPerson. final JsonField<String>_natureOfBusiness()Returns the raw JSON value of natureOfBusiness. final JsonField<String>_tosTimestamp()Returns the raw JSON value of tosTimestamp. final JsonField<Kyb.Workflow>_workflow()Returns the raw JSON value of workflow. final JsonField<List<Kyb.BusinessEntity>>_beneficialOwnerEntities()Returns the raw JSON value of beneficialOwnerEntities. final JsonField<String>_externalId()Returns the raw JSON value of externalId. final JsonField<String>_kybPassedTimestamp()Returns the raw JSON value of kybPassedTimestamp. final JsonField<String>_websiteUrl()Returns the raw JSON value of websiteUrl. final Map<String, JsonValue>_additionalProperties()final Kyb.BuildertoBuilder()final Kybvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Kyb.Builderbuilder()Returns a mutable builder for constructing an instance of Kyb. -
-
Method Detail
-
beneficialOwnerIndividuals
final List<Kyb.KybIndividual> beneficialOwnerIndividuals()
You must submit a list of all direct and indirect individuals with 25% or more ownership in the company. A maximum of 4 beneficial owners can be submitted. If no individual owns 25% of the company you do not need to send beneficial owner information. See FinCEN requirements (Section I) for more background on individuals that should be included.
-
businessEntity
final Kyb.BusinessEntity businessEntity()
Information for business for which the account is being opened and KYB is being run.
-
controlPerson
final Kyb.KybIndividual controlPerson()
An individual with significant responsibility for managing the legal entity (e.g., a Chief Executive Officer, Chief Financial Officer, Chief Operating Officer, Managing Member, General Partner, President, Vice President, or Treasurer). This can be an executive, or someone who will have program-wide access to the cards that Lithic will provide. In some cases, this individual could also be a beneficial owner listed above. See FinCEN requirements (Section II) for more background.
-
natureOfBusiness
final String natureOfBusiness()
Short description of the company's line of business (i.e., what does the company do?).
-
tosTimestamp
final String tosTimestamp()
An RFC 3339 timestamp indicating when the account holder accepted the applicable legal agreements (e.g., cardholder terms) as agreed upon during API customer's implementation with Lithic.
-
workflow
final Kyb.Workflow workflow()
Specifies the type of KYB workflow to run.
-
beneficialOwnerEntities
@Deprecated(message = "deprecated") final Optional<List<Kyb.BusinessEntity>> beneficialOwnerEntities()
Deprecated.
-
externalId
final Optional<String> externalId()
A user provided id that can be used to link an account holder with an external system
-
kybPassedTimestamp
final Optional<String> kybPassedTimestamp()
An RFC 3339 timestamp indicating when precomputed KYC was completed on the business with a pass result.
This field is required only if workflow type is
KYB_BYO.
-
websiteUrl
final Optional<String> websiteUrl()
Company website URL.
-
_beneficialOwnerIndividuals
final JsonField<List<Kyb.KybIndividual>> _beneficialOwnerIndividuals()
Returns the raw JSON value of beneficialOwnerIndividuals.
Unlike beneficialOwnerIndividuals, this method doesn't throw if the JSON field has an unexpected type.
-
_businessEntity
final JsonField<Kyb.BusinessEntity> _businessEntity()
Returns the raw JSON value of businessEntity.
Unlike businessEntity, this method doesn't throw if the JSON field has an unexpected type.
-
_controlPerson
final JsonField<Kyb.KybIndividual> _controlPerson()
Returns the raw JSON value of controlPerson.
Unlike controlPerson, this method doesn't throw if the JSON field has an unexpected type.
-
_natureOfBusiness
final JsonField<String> _natureOfBusiness()
Returns the raw JSON value of natureOfBusiness.
Unlike natureOfBusiness, this method doesn't throw if the JSON field has an unexpected type.
-
_tosTimestamp
final JsonField<String> _tosTimestamp()
Returns the raw JSON value of tosTimestamp.
Unlike tosTimestamp, this method doesn't throw if the JSON field has an unexpected type.
-
_workflow
final JsonField<Kyb.Workflow> _workflow()
Returns the raw JSON value of workflow.
Unlike workflow, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficialOwnerEntities
@Deprecated(message = "deprecated") final JsonField<List<Kyb.BusinessEntity>> _beneficialOwnerEntities()
Returns the raw JSON value of beneficialOwnerEntities.
Unlike beneficialOwnerEntities, this method doesn't throw if the JSON field has an unexpected type.
-
_externalId
final JsonField<String> _externalId()
Returns the raw JSON value of externalId.
Unlike externalId, this method doesn't throw if the JSON field has an unexpected type.
-
_kybPassedTimestamp
final JsonField<String> _kybPassedTimestamp()
Returns the raw JSON value of kybPassedTimestamp.
Unlike kybPassedTimestamp, this method doesn't throw if the JSON field has an unexpected type.
-
_websiteUrl
final JsonField<String> _websiteUrl()
Returns the raw JSON value of websiteUrl.
Unlike websiteUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Kyb.Builder toBuilder()
-
builder
final static Kyb.Builder builder()
Returns a mutable builder for constructing an instance of Kyb.
The following fields are required:
.beneficialOwnerIndividuals() .businessEntity() .controlPerson() .natureOfBusiness() .tosTimestamp() .workflow()
-
-
-
-