Class Kyb.Builder
-
- All Implemented Interfaces:
public final class Kyb.BuilderA builder for Kyb.
-
-
Method Summary
Modifier and Type Method Description final Kyb.BuilderbeneficialOwnerIndividuals(List<Kyb.KybIndividual> beneficialOwnerIndividuals)You must submit a list of all direct and indirect individuals with 25% or more ownership in the company. final Kyb.BuilderbeneficialOwnerIndividuals(JsonField<List<Kyb.KybIndividual>> beneficialOwnerIndividuals)Sets Builder.beneficialOwnerIndividuals to an arbitrary JSON value. final Kyb.BuilderaddBeneficialOwnerIndividual(Kyb.KybIndividual beneficialOwnerIndividual)Adds a single KybIndividual to beneficialOwnerIndividuals. final Kyb.BuilderbusinessEntity(Kyb.BusinessEntity businessEntity)Information for business for which the account is being opened and KYB is being run. final Kyb.BuilderbusinessEntity(JsonField<Kyb.BusinessEntity> businessEntity)Sets Builder.businessEntity to an arbitrary JSON value. final Kyb.BuildercontrolPerson(Kyb.KybIndividual controlPerson)An individual with significant responsibility for managing the legal entity (e.g., a Chief Executive Officer, Chief Financial Officer, Chief Operating Officer, Managing Member, General Partner, President, Vice President, or Treasurer). final Kyb.BuildercontrolPerson(JsonField<Kyb.KybIndividual> controlPerson)Sets Builder.controlPerson to an arbitrary JSON value. final Kyb.BuildernatureOfBusiness(String natureOfBusiness)Short description of the company's line of business (i.e., what does the company do?). final Kyb.BuildernatureOfBusiness(JsonField<String> natureOfBusiness)Sets Builder.natureOfBusiness to an arbitrary JSON value. final Kyb.BuildertosTimestamp(String tosTimestamp)An RFC 3339 timestamp indicating when the account holder accepted the applicable legal agreements (e.g., cardholder terms) as agreed upon during API customer's implementation with Lithic. final Kyb.BuildertosTimestamp(JsonField<String> tosTimestamp)Sets Builder.tosTimestamp to an arbitrary JSON value. final Kyb.Builderworkflow(Kyb.Workflow workflow)Specifies the type of KYB workflow to run. final Kyb.Builderworkflow(JsonField<Kyb.Workflow> workflow)Sets Builder.workflow to an arbitrary JSON value. final Kyb.BuilderbeneficialOwnerEntities(List<Kyb.BusinessEntity> beneficialOwnerEntities)Deprecated. final Kyb.BuilderbeneficialOwnerEntities(JsonField<List<Kyb.BusinessEntity>> beneficialOwnerEntities)Sets Builder.beneficialOwnerEntities to an arbitrary JSON value. final Kyb.BuilderaddBeneficialOwnerEntity(Kyb.BusinessEntity beneficialOwnerEntity)Adds a single BusinessEntity to beneficialOwnerEntities. final Kyb.BuilderexternalId(String externalId)A user provided id that can be used to link an account holder with an external system final Kyb.BuilderexternalId(JsonField<String> externalId)Sets Builder.externalId to an arbitrary JSON value. final Kyb.BuilderkybPassedTimestamp(String kybPassedTimestamp)An RFC 3339 timestamp indicating when precomputed KYC was completed on the business with a pass result. final Kyb.BuilderkybPassedTimestamp(JsonField<String> kybPassedTimestamp)Sets Builder.kybPassedTimestamp to an arbitrary JSON value. final Kyb.BuilderwebsiteUrl(String websiteUrl)Company website URL. final Kyb.BuilderwebsiteUrl(JsonField<String> websiteUrl)Sets Builder.websiteUrl to an arbitrary JSON value. final Kyb.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Kyb.BuilderputAdditionalProperty(String key, JsonValue value)final Kyb.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Kyb.BuilderremoveAdditionalProperty(String key)final Kyb.BuilderremoveAllAdditionalProperties(Set<String> keys)final Kybbuild()Returns an immutable instance of Kyb. -
-
Method Detail
-
beneficialOwnerIndividuals
final Kyb.Builder beneficialOwnerIndividuals(List<Kyb.KybIndividual> beneficialOwnerIndividuals)
You must submit a list of all direct and indirect individuals with 25% or more ownership in the company. A maximum of 4 beneficial owners can be submitted. If no individual owns 25% of the company you do not need to send beneficial owner information. See FinCEN requirements (Section I) for more background on individuals that should be included.
-
beneficialOwnerIndividuals
final Kyb.Builder beneficialOwnerIndividuals(JsonField<List<Kyb.KybIndividual>> beneficialOwnerIndividuals)
Sets Builder.beneficialOwnerIndividuals to an arbitrary JSON value.
You should usually call Builder.beneficialOwnerIndividuals with a well-typed
List<KybIndividual>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addBeneficialOwnerIndividual
final Kyb.Builder addBeneficialOwnerIndividual(Kyb.KybIndividual beneficialOwnerIndividual)
Adds a single KybIndividual to beneficialOwnerIndividuals.
-
businessEntity
final Kyb.Builder businessEntity(Kyb.BusinessEntity businessEntity)
Information for business for which the account is being opened and KYB is being run.
-
businessEntity
final Kyb.Builder businessEntity(JsonField<Kyb.BusinessEntity> businessEntity)
Sets Builder.businessEntity to an arbitrary JSON value.
You should usually call Builder.businessEntity with a well-typed BusinessEntity value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
controlPerson
final Kyb.Builder controlPerson(Kyb.KybIndividual controlPerson)
An individual with significant responsibility for managing the legal entity (e.g., a Chief Executive Officer, Chief Financial Officer, Chief Operating Officer, Managing Member, General Partner, President, Vice President, or Treasurer). This can be an executive, or someone who will have program-wide access to the cards that Lithic will provide. In some cases, this individual could also be a beneficial owner listed above. See FinCEN requirements (Section II) for more background.
-
controlPerson
final Kyb.Builder controlPerson(JsonField<Kyb.KybIndividual> controlPerson)
Sets Builder.controlPerson to an arbitrary JSON value.
You should usually call Builder.controlPerson with a well-typed KybIndividual value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
natureOfBusiness
final Kyb.Builder natureOfBusiness(String natureOfBusiness)
Short description of the company's line of business (i.e., what does the company do?).
-
natureOfBusiness
final Kyb.Builder natureOfBusiness(JsonField<String> natureOfBusiness)
Sets Builder.natureOfBusiness to an arbitrary JSON value.
You should usually call Builder.natureOfBusiness with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tosTimestamp
final Kyb.Builder tosTimestamp(String tosTimestamp)
An RFC 3339 timestamp indicating when the account holder accepted the applicable legal agreements (e.g., cardholder terms) as agreed upon during API customer's implementation with Lithic.
-
tosTimestamp
final Kyb.Builder tosTimestamp(JsonField<String> tosTimestamp)
Sets Builder.tosTimestamp to an arbitrary JSON value.
You should usually call Builder.tosTimestamp with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
workflow
final Kyb.Builder workflow(Kyb.Workflow workflow)
Specifies the type of KYB workflow to run.
-
workflow
final Kyb.Builder workflow(JsonField<Kyb.Workflow> workflow)
Sets Builder.workflow to an arbitrary JSON value.
You should usually call Builder.workflow with a well-typed Workflow value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficialOwnerEntities
@Deprecated(message = "deprecated") final Kyb.Builder beneficialOwnerEntities(List<Kyb.BusinessEntity> beneficialOwnerEntities)
Deprecated.
-
beneficialOwnerEntities
@Deprecated(message = "deprecated") final Kyb.Builder beneficialOwnerEntities(JsonField<List<Kyb.BusinessEntity>> beneficialOwnerEntities)
Sets Builder.beneficialOwnerEntities to an arbitrary JSON value.
You should usually call Builder.beneficialOwnerEntities with a well-typed
List<BusinessEntity>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addBeneficialOwnerEntity
@Deprecated(message = "deprecated") final Kyb.Builder addBeneficialOwnerEntity(Kyb.BusinessEntity beneficialOwnerEntity)
Adds a single BusinessEntity to beneficialOwnerEntities.
-
externalId
final Kyb.Builder externalId(String externalId)
A user provided id that can be used to link an account holder with an external system
-
externalId
final Kyb.Builder externalId(JsonField<String> externalId)
Sets Builder.externalId to an arbitrary JSON value.
You should usually call Builder.externalId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
kybPassedTimestamp
final Kyb.Builder kybPassedTimestamp(String kybPassedTimestamp)
An RFC 3339 timestamp indicating when precomputed KYC was completed on the business with a pass result.
This field is required only if workflow type is
KYB_BYO.
-
kybPassedTimestamp
final Kyb.Builder kybPassedTimestamp(JsonField<String> kybPassedTimestamp)
Sets Builder.kybPassedTimestamp to an arbitrary JSON value.
You should usually call Builder.kybPassedTimestamp with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
websiteUrl
final Kyb.Builder websiteUrl(String websiteUrl)
Company website URL.
-
websiteUrl
final Kyb.Builder websiteUrl(JsonField<String> websiteUrl)
Sets Builder.websiteUrl to an arbitrary JSON value.
You should usually call Builder.websiteUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Kyb.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Kyb.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Kyb.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Kyb.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Kyb.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-