Class KybBusinessEntity
-
- All Implemented Interfaces:
public final class KybBusinessEntity
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classKybBusinessEntity.BuilderA builder for KybBusinessEntity.
public final classKybBusinessEntity.AddressBusiness''s physical address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable.
-
Method Summary
Modifier and Type Method Description final KybBusinessEntity.Addressaddress()Business''s physical address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable. final StringgovernmentId()Government-issued identification number. final StringlegalBusinessName()Legal (formal) business name. final List<String>phoneNumbers()One or more of the business's phone number(s), entered as a list in E.164 format. final Optional<String>dbaBusinessName()Any name that the business operates under that is not its legal business name (if applicable). final Optional<String>parentCompany()Parent company name (if applicable). final JsonField<KybBusinessEntity.Address>_address()Returns the raw JSON value of address. final JsonField<String>_governmentId()Returns the raw JSON value of governmentId. final JsonField<String>_legalBusinessName()Returns the raw JSON value of legalBusinessName. final JsonField<List<String>>_phoneNumbers()Returns the raw JSON value of phoneNumbers. final JsonField<String>_dbaBusinessName()Returns the raw JSON value of dbaBusinessName. final JsonField<String>_parentCompany()Returns the raw JSON value of parentCompany. final Map<String, JsonValue>_additionalProperties()final KybBusinessEntity.BuildertoBuilder()final KybBusinessEntityvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static KybBusinessEntity.Builderbuilder()Returns a mutable builder for constructing an instance of KybBusinessEntity. -
-
Method Detail
-
address
final KybBusinessEntity.Address address()
Business''s physical address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable.
-
governmentId
final String governmentId()
Government-issued identification number. US Federal Employer Identification Numbers (EIN) are currently supported, entered as full nine-digits, with or without hyphens.
-
legalBusinessName
final String legalBusinessName()
Legal (formal) business name.
-
phoneNumbers
final List<String> phoneNumbers()
One or more of the business's phone number(s), entered as a list in E.164 format.
-
dbaBusinessName
final Optional<String> dbaBusinessName()
Any name that the business operates under that is not its legal business name (if applicable).
-
parentCompany
final Optional<String> parentCompany()
Parent company name (if applicable).
-
_address
final JsonField<KybBusinessEntity.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_governmentId
final JsonField<String> _governmentId()
Returns the raw JSON value of governmentId.
Unlike governmentId, this method doesn't throw if the JSON field has an unexpected type.
-
_legalBusinessName
final JsonField<String> _legalBusinessName()
Returns the raw JSON value of legalBusinessName.
Unlike legalBusinessName, this method doesn't throw if the JSON field has an unexpected type.
-
_phoneNumbers
final JsonField<List<String>> _phoneNumbers()
Returns the raw JSON value of phoneNumbers.
Unlike phoneNumbers, this method doesn't throw if the JSON field has an unexpected type.
-
_dbaBusinessName
final JsonField<String> _dbaBusinessName()
Returns the raw JSON value of dbaBusinessName.
Unlike dbaBusinessName, this method doesn't throw if the JSON field has an unexpected type.
-
_parentCompany
final JsonField<String> _parentCompany()
Returns the raw JSON value of parentCompany.
Unlike parentCompany, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final KybBusinessEntity.Builder toBuilder()
-
validate
final KybBusinessEntity validate()
-
builder
final static KybBusinessEntity.Builder builder()
Returns a mutable builder for constructing an instance of KybBusinessEntity.
The following fields are required:
.address() .governmentId() .legalBusinessName() .phoneNumbers()
-
-
-
-