Class KybBusinessEntity.Address
-
- All Implemented Interfaces:
public final class KybBusinessEntity.AddressBusiness''s physical address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classKybBusinessEntity.Address.BuilderA builder for Address.
-
Method Summary
Modifier and Type Method Description final Stringaddress1()Valid deliverable address (no PO boxes). final Stringcity()Name of city. final Stringcountry()Valid country code. final StringpostalCode()Valid postal code. final Stringstate()Valid state code. final Optional<String>address2()Unit or apartment number (if applicable). final JsonField<String>_address1()Returns the raw JSON value of address1. final JsonField<String>_city()Returns the raw JSON value of city. final JsonField<String>_country()Returns the raw JSON value of country. final JsonField<String>_postalCode()Returns the raw JSON value of postalCode. final JsonField<String>_state()Returns the raw JSON value of state. final JsonField<String>_address2()Returns the raw JSON value of address2. final Map<String, JsonValue>_additionalProperties()final KybBusinessEntity.Address.BuildertoBuilder()final KybBusinessEntity.Addressvalidate()Booleanequals(Object other)IntegerhashCode()StringtoString()final static KybBusinessEntity.Address.Builderbuilder()Returns a mutable builder for constructing an instance of Address. -
-
Method Detail
-
country
final String country()
Valid country code. Only USA is currently supported, entered in uppercase ISO 3166-1 alpha-3 three-character format.
-
postalCode
final String postalCode()
Valid postal code. Only USA ZIP codes are currently supported, entered as a five-digit ZIP or nine-digit ZIP+4.
-
state
final String state()
Valid state code. Only USA state codes are currently supported, entered in uppercase ISO 3166-2 two-character format.
-
_address1
final JsonField<String> _address1()
Returns the raw JSON value of address1.
Unlike address1, this method doesn't throw if the JSON field has an unexpected type.
-
_city
final JsonField<String> _city()
Returns the raw JSON value of city.
Unlike city, this method doesn't throw if the JSON field has an unexpected type.
-
_country
final JsonField<String> _country()
Returns the raw JSON value of country.
Unlike country, this method doesn't throw if the JSON field has an unexpected type.
-
_postalCode
final JsonField<String> _postalCode()
Returns the raw JSON value of postalCode.
Unlike postalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<String> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_address2
final JsonField<String> _address2()
Returns the raw JSON value of address2.
Unlike address2, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final KybBusinessEntity.Address.Builder toBuilder()
-
validate
final KybBusinessEntity.Address validate()
-
builder
final static KybBusinessEntity.Address.Builder builder()
Returns a mutable builder for constructing an instance of Address.
The following fields are required:
.address1() .city() .country() .postalCode() .state()
-
-
-
-