Class KybBusinessEntity.Address.Builder
-
- All Implemented Interfaces:
public final class KybBusinessEntity.Address.BuilderA builder for Address.
-
-
Method Summary
-
-
Method Detail
-
address1
final KybBusinessEntity.Address.Builder address1(String address1)
Valid deliverable address (no PO boxes).
-
address1
final KybBusinessEntity.Address.Builder address1(JsonField<String> address1)
Sets Builder.address1 to an arbitrary JSON value.
You should usually call Builder.address1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
city
final KybBusinessEntity.Address.Builder city(String city)
Name of city.
-
city
final KybBusinessEntity.Address.Builder city(JsonField<String> city)
Sets Builder.city to an arbitrary JSON value.
You should usually call Builder.city with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
country
final KybBusinessEntity.Address.Builder country(String country)
Valid country code. Only USA is currently supported, entered in uppercase ISO 3166-1 alpha-3 three-character format.
-
country
final KybBusinessEntity.Address.Builder country(JsonField<String> country)
Sets Builder.country to an arbitrary JSON value.
You should usually call Builder.country with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
postalCode
final KybBusinessEntity.Address.Builder postalCode(String postalCode)
Valid postal code. Only USA ZIP codes are currently supported, entered as a five-digit ZIP or nine-digit ZIP+4.
-
postalCode
final KybBusinessEntity.Address.Builder postalCode(JsonField<String> postalCode)
Sets Builder.postalCode to an arbitrary JSON value.
You should usually call Builder.postalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
state
final KybBusinessEntity.Address.Builder state(String state)
Valid state code. Only USA state codes are currently supported, entered in uppercase ISO 3166-2 two-character format.
-
state
final KybBusinessEntity.Address.Builder state(JsonField<String> state)
Sets Builder.state to an arbitrary JSON value.
You should usually call Builder.state with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
address2
final KybBusinessEntity.Address.Builder address2(String address2)
Unit or apartment number (if applicable).
-
address2
final KybBusinessEntity.Address.Builder address2(JsonField<String> address2)
Sets Builder.address2 to an arbitrary JSON value.
You should usually call Builder.address2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final KybBusinessEntity.Address.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final KybBusinessEntity.Address.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final KybBusinessEntity.Address.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final KybBusinessEntity.Address.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final KybBusinessEntity.Address.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final KybBusinessEntity.Address build()
Returns an immutable instance of Address.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.address1() .city() .country() .postalCode() .state()
-
-
-
-