Class Kyc.Builder
-
- All Implemented Interfaces:
public final class Kyc.BuilderA builder for Kyc.
-
-
Method Summary
Modifier and Type Method Description final Kyc.Builderindividual(Kyc.Individual individual)Information on individual for whom the account is being opened and KYC is being run. final Kyc.Builderindividual(JsonField<Kyc.Individual> individual)Sets Builder.individual to an arbitrary JSON value. final Kyc.BuildertosTimestamp(String tosTimestamp)An RFC 3339 timestamp indicating when the account holder accepted the applicable legal agreements (e.g., cardholder terms) as agreed upon during API customer's implementation with Lithic. final Kyc.BuildertosTimestamp(JsonField<String> tosTimestamp)Sets Builder.tosTimestamp to an arbitrary JSON value. final Kyc.Builderworkflow(Kyc.Workflow workflow)Specifies the type of KYC workflow to run. final Kyc.Builderworkflow(JsonField<Kyc.Workflow> workflow)Sets Builder.workflow to an arbitrary JSON value. final Kyc.BuilderexternalId(String externalId)A user provided id that can be used to link an account holder with an external system final Kyc.BuilderexternalId(JsonField<String> externalId)Sets Builder.externalId to an arbitrary JSON value. final Kyc.BuilderkycPassedTimestamp(String kycPassedTimestamp)An RFC 3339 timestamp indicating when precomputed KYC was completed on the individual with a pass result. final Kyc.BuilderkycPassedTimestamp(JsonField<String> kycPassedTimestamp)Sets Builder.kycPassedTimestamp to an arbitrary JSON value. final Kyc.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Kyc.BuilderputAdditionalProperty(String key, JsonValue value)final Kyc.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Kyc.BuilderremoveAdditionalProperty(String key)final Kyc.BuilderremoveAllAdditionalProperties(Set<String> keys)final Kycbuild()Returns an immutable instance of Kyc. -
-
Method Detail
-
individual
final Kyc.Builder individual(Kyc.Individual individual)
Information on individual for whom the account is being opened and KYC is being run.
-
individual
final Kyc.Builder individual(JsonField<Kyc.Individual> individual)
Sets Builder.individual to an arbitrary JSON value.
You should usually call Builder.individual with a well-typed Individual value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tosTimestamp
final Kyc.Builder tosTimestamp(String tosTimestamp)
An RFC 3339 timestamp indicating when the account holder accepted the applicable legal agreements (e.g., cardholder terms) as agreed upon during API customer's implementation with Lithic.
-
tosTimestamp
final Kyc.Builder tosTimestamp(JsonField<String> tosTimestamp)
Sets Builder.tosTimestamp to an arbitrary JSON value.
You should usually call Builder.tosTimestamp with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
workflow
final Kyc.Builder workflow(Kyc.Workflow workflow)
Specifies the type of KYC workflow to run.
-
workflow
final Kyc.Builder workflow(JsonField<Kyc.Workflow> workflow)
Sets Builder.workflow to an arbitrary JSON value.
You should usually call Builder.workflow with a well-typed Workflow value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
externalId
final Kyc.Builder externalId(String externalId)
A user provided id that can be used to link an account holder with an external system
-
externalId
final Kyc.Builder externalId(JsonField<String> externalId)
Sets Builder.externalId to an arbitrary JSON value.
You should usually call Builder.externalId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
kycPassedTimestamp
final Kyc.Builder kycPassedTimestamp(String kycPassedTimestamp)
An RFC 3339 timestamp indicating when precomputed KYC was completed on the individual with a pass result.
This field is required only if workflow type is
KYC_BYO.
-
kycPassedTimestamp
final Kyc.Builder kycPassedTimestamp(JsonField<String> kycPassedTimestamp)
Sets Builder.kycPassedTimestamp to an arbitrary JSON value.
You should usually call Builder.kycPassedTimestamp with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Kyc.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Kyc.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Kyc.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Kyc.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Kyc.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-