Class KycExempt
-
- All Implemented Interfaces:
public final class KycExempt
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classKycExempt.BuilderA builder for KycExempt.
public final classKycExempt.KycExemptionTypeSpecifies the type of KYC Exempt user
public final classKycExempt.WorkflowSpecifies the workflow type. This must be 'KYC_EXEMPT'
-
Method Summary
Modifier and Type Method Description final Addressaddress()KYC Exempt user's current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable. final Stringemail()The KYC Exempt user's email final StringfirstName()The KYC Exempt user's first name final KycExempt.KycExemptionTypekycExemptionType()Specifies the type of KYC Exempt user final StringlastName()The KYC Exempt user's last name final StringphoneNumber()The KYC Exempt user's phone number, entered in E.164 format. final KycExempt.Workflowworkflow()Specifies the workflow type. final Optional<String>businessAccountToken()Only applicable for customers using the KYC-Exempt workflow to enroll authorized users of businesses. final Optional<String>externalId()A user provided id that can be used to link an account holder with an external system final JsonField<Address>_address()Returns the raw JSON value of address. final JsonField<String>_email()Returns the raw JSON value of email. final JsonField<String>_firstName()Returns the raw JSON value of firstName. final JsonField<KycExempt.KycExemptionType>_kycExemptionType()Returns the raw JSON value of kycExemptionType. final JsonField<String>_lastName()Returns the raw JSON value of lastName. final JsonField<String>_phoneNumber()Returns the raw JSON value of phoneNumber. final JsonField<KycExempt.Workflow>_workflow()Returns the raw JSON value of workflow. final JsonField<String>_businessAccountToken()Returns the raw JSON value of businessAccountToken. final JsonField<String>_externalId()Returns the raw JSON value of externalId. final Map<String, JsonValue>_additionalProperties()final KycExempt.BuildertoBuilder()final KycExemptvalidate()Booleanequals(Object other)IntegerhashCode()StringtoString()final static KycExempt.Builderbuilder()Returns a mutable builder for constructing an instance of KycExempt. -
-
Method Detail
-
address
final Address address()
KYC Exempt user's current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable.
-
kycExemptionType
final KycExempt.KycExemptionType kycExemptionType()
Specifies the type of KYC Exempt user
-
phoneNumber
final String phoneNumber()
The KYC Exempt user's phone number, entered in E.164 format.
-
workflow
final KycExempt.Workflow workflow()
Specifies the workflow type. This must be 'KYC_EXEMPT'
-
businessAccountToken
final Optional<String> businessAccountToken()
Only applicable for customers using the KYC-Exempt workflow to enroll authorized users of businesses. Pass the account_token of the enrolled business associated with the AUTHORIZED_USER in this field.
-
externalId
final Optional<String> externalId()
A user provided id that can be used to link an account holder with an external system
-
_address
final JsonField<Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_email
final JsonField<String> _email()
Returns the raw JSON value of email.
Unlike email, this method doesn't throw if the JSON field has an unexpected type.
-
_firstName
final JsonField<String> _firstName()
Returns the raw JSON value of firstName.
Unlike firstName, this method doesn't throw if the JSON field has an unexpected type.
-
_kycExemptionType
final JsonField<KycExempt.KycExemptionType> _kycExemptionType()
Returns the raw JSON value of kycExemptionType.
Unlike kycExemptionType, this method doesn't throw if the JSON field has an unexpected type.
-
_lastName
final JsonField<String> _lastName()
Returns the raw JSON value of lastName.
Unlike lastName, this method doesn't throw if the JSON field has an unexpected type.
-
_phoneNumber
final JsonField<String> _phoneNumber()
Returns the raw JSON value of phoneNumber.
Unlike phoneNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_workflow
final JsonField<KycExempt.Workflow> _workflow()
Returns the raw JSON value of workflow.
Unlike workflow, this method doesn't throw if the JSON field has an unexpected type.
-
_businessAccountToken
final JsonField<String> _businessAccountToken()
Returns the raw JSON value of businessAccountToken.
Unlike businessAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_externalId
final JsonField<String> _externalId()
Returns the raw JSON value of externalId.
Unlike externalId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final KycExempt.Builder toBuilder()
-
builder
final static KycExempt.Builder builder()
Returns a mutable builder for constructing an instance of KycExempt.
The following fields are required:
.address() .email() .firstName() .kycExemptionType() .lastName() .phoneNumber() .workflow()
-
-
-
-