Class KycExempt.Builder
-
- All Implemented Interfaces:
public final class KycExempt.BuilderA builder for KycExempt.
-
-
Method Summary
Modifier and Type Method Description final KycExempt.Builderaddress(Address address)KYC Exempt user's current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable. final KycExempt.Builderaddress(JsonField<Address> address)Sets Builder.address to an arbitrary JSON value. final KycExempt.Builderemail(String email)The KYC Exempt user's email final KycExempt.Builderemail(JsonField<String> email)Sets Builder.email to an arbitrary JSON value. final KycExempt.BuilderfirstName(String firstName)The KYC Exempt user's first name final KycExempt.BuilderfirstName(JsonField<String> firstName)Sets Builder.firstName to an arbitrary JSON value. final KycExempt.BuilderkycExemptionType(KycExempt.KycExemptionType kycExemptionType)Specifies the type of KYC Exempt user final KycExempt.BuilderkycExemptionType(JsonField<KycExempt.KycExemptionType> kycExemptionType)Sets Builder.kycExemptionType to an arbitrary JSON value. final KycExempt.BuilderlastName(String lastName)The KYC Exempt user's last name final KycExempt.BuilderlastName(JsonField<String> lastName)Sets Builder.lastName to an arbitrary JSON value. final KycExempt.BuilderphoneNumber(String phoneNumber)The KYC Exempt user's phone number, entered in E.164 format. final KycExempt.BuilderphoneNumber(JsonField<String> phoneNumber)Sets Builder.phoneNumber to an arbitrary JSON value. final KycExempt.Builderworkflow(KycExempt.Workflow workflow)Specifies the workflow type. final KycExempt.Builderworkflow(JsonField<KycExempt.Workflow> workflow)Sets Builder.workflow to an arbitrary JSON value. final KycExempt.BuilderbusinessAccountToken(String businessAccountToken)Only applicable for customers using the KYC-Exempt workflow to enroll authorized users of businesses. final KycExempt.BuilderbusinessAccountToken(JsonField<String> businessAccountToken)Sets Builder.businessAccountToken to an arbitrary JSON value. final KycExempt.BuilderexternalId(String externalId)A user provided id that can be used to link an account holder with an external system final KycExempt.BuilderexternalId(JsonField<String> externalId)Sets Builder.externalId to an arbitrary JSON value. final KycExempt.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final KycExempt.BuilderputAdditionalProperty(String key, JsonValue value)final KycExempt.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final KycExempt.BuilderremoveAdditionalProperty(String key)final KycExempt.BuilderremoveAllAdditionalProperties(Set<String> keys)final KycExemptbuild()Returns an immutable instance of KycExempt. -
-
Method Detail
-
address
final KycExempt.Builder address(Address address)
KYC Exempt user's current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable.
-
address
final KycExempt.Builder address(JsonField<Address> address)
Sets Builder.address to an arbitrary JSON value.
You should usually call Builder.address with a well-typed Address value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
email
final KycExempt.Builder email(String email)
The KYC Exempt user's email
-
email
final KycExempt.Builder email(JsonField<String> email)
Sets Builder.email to an arbitrary JSON value.
You should usually call Builder.email with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
firstName
final KycExempt.Builder firstName(String firstName)
The KYC Exempt user's first name
-
firstName
final KycExempt.Builder firstName(JsonField<String> firstName)
Sets Builder.firstName to an arbitrary JSON value.
You should usually call Builder.firstName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
kycExemptionType
final KycExempt.Builder kycExemptionType(KycExempt.KycExemptionType kycExemptionType)
Specifies the type of KYC Exempt user
-
kycExemptionType
final KycExempt.Builder kycExemptionType(JsonField<KycExempt.KycExemptionType> kycExemptionType)
Sets Builder.kycExemptionType to an arbitrary JSON value.
You should usually call Builder.kycExemptionType with a well-typed KycExemptionType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastName
final KycExempt.Builder lastName(String lastName)
The KYC Exempt user's last name
-
lastName
final KycExempt.Builder lastName(JsonField<String> lastName)
Sets Builder.lastName to an arbitrary JSON value.
You should usually call Builder.lastName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
phoneNumber
final KycExempt.Builder phoneNumber(String phoneNumber)
The KYC Exempt user's phone number, entered in E.164 format.
-
phoneNumber
final KycExempt.Builder phoneNumber(JsonField<String> phoneNumber)
Sets Builder.phoneNumber to an arbitrary JSON value.
You should usually call Builder.phoneNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
workflow
final KycExempt.Builder workflow(KycExempt.Workflow workflow)
Specifies the workflow type. This must be 'KYC_EXEMPT'
-
workflow
final KycExempt.Builder workflow(JsonField<KycExempt.Workflow> workflow)
Sets Builder.workflow to an arbitrary JSON value.
You should usually call Builder.workflow with a well-typed Workflow value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
businessAccountToken
final KycExempt.Builder businessAccountToken(String businessAccountToken)
Only applicable for customers using the KYC-Exempt workflow to enroll authorized users of businesses. Pass the account_token of the enrolled business associated with the AUTHORIZED_USER in this field.
-
businessAccountToken
final KycExempt.Builder businessAccountToken(JsonField<String> businessAccountToken)
Sets Builder.businessAccountToken to an arbitrary JSON value.
You should usually call Builder.businessAccountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
externalId
final KycExempt.Builder externalId(String externalId)
A user provided id that can be used to link an account holder with an external system
-
externalId
final KycExempt.Builder externalId(JsonField<String> externalId)
Sets Builder.externalId to an arbitrary JSON value.
You should usually call Builder.externalId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final KycExempt.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final KycExempt.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final KycExempt.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final KycExempt.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final KycExempt.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-