Class ManagementOperationCreatedWebhookEvent
-
- All Implemented Interfaces:
public final class ManagementOperationCreatedWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classManagementOperationCreatedWebhookEvent.BuilderA builder for ManagementOperationCreatedWebhookEvent.
public final classManagementOperationCreatedWebhookEvent.EventTypeThe type of event that occurred.
-
Method Summary
-
-
Method Detail
-
toManagementOperationTransaction
final ManagementOperationTransaction toManagementOperationTransaction()
-
created
final OffsetDateTime created()
ISO 8601 timestamp of when the transaction was created
-
status
final ManagementOperationTransaction.TransactionStatus status()
The status of the transaction
-
updated
final OffsetDateTime updated()
ISO 8601 timestamp of when the transaction was last updated
-
category
final Optional<ManagementOperationTransaction.ManagementOperationCategory> category()
-
direction
final Optional<ManagementOperationTransaction.ManagementOperationDirection> direction()
-
events
final Optional<List<ManagementOperationTransaction.ManagementOperationEvent>> events()
-
externalResource
final Optional<ExternalResource> externalResource()
External resource associated with the management operation
-
family
final Optional<ManagementOperationTransaction.Family> family()
MANAGEMENT_OPERATION - Management Operation Transaction
-
financialAccountToken
final Optional<String> financialAccountToken()
-
pendingAmount
final Optional<Long> pendingAmount()
-
result
final Optional<ManagementOperationTransaction.TransactionResult> result()
-
settledAmount
final Optional<Long> settledAmount()
-
transactionSeries
final Optional<ManagementOperationTransaction.TransactionSeries> transactionSeries()
-
userDefinedId
final Optional<String> userDefinedId()
-
eventType
final ManagementOperationCreatedWebhookEvent.EventType eventType()
The type of event that occurred.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<ManagementOperationTransaction.TransactionStatus> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_updated
final JsonField<OffsetDateTime> _updated()
Returns the raw JSON value of updated.
Unlike updated, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<ManagementOperationTransaction.ManagementOperationCategory> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_direction
final JsonField<ManagementOperationTransaction.ManagementOperationDirection> _direction()
Returns the raw JSON value of direction.
Unlike direction, this method doesn't throw if the JSON field has an unexpected type.
-
_events
final JsonField<List<ManagementOperationTransaction.ManagementOperationEvent>> _events()
Returns the raw JSON value of events.
Unlike events, this method doesn't throw if the JSON field has an unexpected type.
-
_externalResource
final JsonField<ExternalResource> _externalResource()
Returns the raw JSON value of externalResource.
Unlike externalResource, this method doesn't throw if the JSON field has an unexpected type.
-
_family
final JsonField<ManagementOperationTransaction.Family> _family()
Returns the raw JSON value of family.
Unlike family, this method doesn't throw if the JSON field has an unexpected type.
-
_financialAccountToken
final JsonField<String> _financialAccountToken()
Returns the raw JSON value of financialAccountToken.
Unlike financialAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_pendingAmount
final JsonField<Long> _pendingAmount()
Returns the raw JSON value of pendingAmount.
Unlike pendingAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_result
final JsonField<ManagementOperationTransaction.TransactionResult> _result()
Returns the raw JSON value of result.
Unlike result, this method doesn't throw if the JSON field has an unexpected type.
-
_settledAmount
final JsonField<Long> _settledAmount()
Returns the raw JSON value of settledAmount.
Unlike settledAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionSeries
final JsonField<ManagementOperationTransaction.TransactionSeries> _transactionSeries()
Returns the raw JSON value of transactionSeries.
Unlike transactionSeries, this method doesn't throw if the JSON field has an unexpected type.
-
_userDefinedId
final JsonField<String> _userDefinedId()
Returns the raw JSON value of userDefinedId.
Unlike userDefinedId, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<ManagementOperationCreatedWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ManagementOperationCreatedWebhookEvent.Builder toBuilder()
-
validate
final ManagementOperationCreatedWebhookEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ManagementOperationCreatedWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of ManagementOperationCreatedWebhookEvent.
The following fields are required:
.token() .created() .status() .updated() .eventType()
-
-
-
-