Package com.lithic.api.models
Class ManagementOperationListPage.Builder
-
- All Implemented Interfaces:
public final class ManagementOperationListPage.BuilderA builder for ManagementOperationListPage.
-
-
Method Summary
Modifier and Type Method Description final ManagementOperationListPage.Builderservice(ManagementOperationService service)final ManagementOperationListPage.Builderparams(ManagementOperationListParams params)The parameters that were used to request this page. final ManagementOperationListPage.Builderresponse(ManagementOperationListPageResponse response)The response that this page was parsed from. final ManagementOperationListPagebuild()Returns an immutable instance of ManagementOperationListPage. -
-
Method Detail
-
service
final ManagementOperationListPage.Builder service(ManagementOperationService service)
-
params
final ManagementOperationListPage.Builder params(ManagementOperationListParams params)
The parameters that were used to request this page.
-
response
final ManagementOperationListPage.Builder response(ManagementOperationListPageResponse response)
The response that this page was parsed from.
-
build
final ManagementOperationListPage build()
Returns an immutable instance of ManagementOperationListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-