Class ManagementOperationListPageAsync
-
- All Implemented Interfaces:
-
com.lithic.api.core.PageAsync
public final class ManagementOperationListPageAsync implements PageAsync<ManagementOperationTransaction>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classManagementOperationListPageAsync.BuilderA builder for ManagementOperationListPageAsync.
-
Method Summary
-
-
Method Detail
-
data
final List<ManagementOperationTransaction> data()
Delegates to ManagementOperationListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to ManagementOperationListPageResponse, but gracefully handles missing data.
-
items
List<ManagementOperationTransaction> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final ManagementOperationListParams nextPageParams()
-
nextPage
CompletableFuture<ManagementOperationListPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<ManagementOperationTransaction> autoPager()
-
params
final ManagementOperationListParams params()
The parameters that were used to request this page.
-
response
final ManagementOperationListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final ManagementOperationListPageAsync.Builder toBuilder()
-
builder
final static ManagementOperationListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of ManagementOperationListPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-