Class ManagementOperationListPageResponse.Builder
-
- All Implemented Interfaces:
public final class ManagementOperationListPageResponse.BuilderA builder for ManagementOperationListPageResponse.
-
-
Method Summary
-
-
Method Detail
-
data
final ManagementOperationListPageResponse.Builder data(List<ManagementOperationTransaction> data)
-
data
final ManagementOperationListPageResponse.Builder data(JsonField<List<ManagementOperationTransaction>> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed
List<ManagementOperationTransaction>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addData
final ManagementOperationListPageResponse.Builder addData(ManagementOperationTransaction data)
Adds a single ManagementOperationTransaction to Builder.data.
-
hasMore
final ManagementOperationListPageResponse.Builder hasMore(Boolean hasMore)
-
hasMore
final ManagementOperationListPageResponse.Builder hasMore(JsonField<Boolean> hasMore)
Sets Builder.hasMore to an arbitrary JSON value.
You should usually call Builder.hasMore with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ManagementOperationListPageResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ManagementOperationListPageResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ManagementOperationListPageResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ManagementOperationListPageResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ManagementOperationListPageResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ManagementOperationListPageResponse build()
Returns an immutable instance of ManagementOperationListPageResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.data() .hasMore()
-
-
-
-