Class ManagementOperationListParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class ManagementOperationListParams implements Params
List management operations
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classManagementOperationListParams.BuilderA builder for ManagementOperationListParams.
public final classManagementOperationListParams.ManagementOperationCategoryManagement operation category to be returned.
public final classManagementOperationListParams.TransactionStatusManagement operation status to be returned.
-
Method Summary
Modifier and Type Method Description final Optional<OffsetDateTime>begin()Date string in RFC 3339 format. final Optional<String>businessAccountToken()final Optional<ManagementOperationListParams.ManagementOperationCategory>category()Management operation category to be returned. final Optional<OffsetDateTime>end()Date string in RFC 3339 format. final Optional<String>endingBefore()A cursor representing an item's token before which a page of results should end. final Optional<String>financialAccountToken()Globally unique identifier for the financial account. final Optional<Long>pageSize()Page size (for pagination). final Optional<String>startingAfter()A cursor representing an item's token after which a page of results should begin. final Optional<ManagementOperationListParams.TransactionStatus>status()Management operation status to be returned. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ManagementOperationListParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ManagementOperationListParamsnone()final static ManagementOperationListParams.Builderbuilder()Returns a mutable builder for constructing an instance of ManagementOperationListParams. -
-
Method Detail
-
begin
final Optional<OffsetDateTime> begin()
Date string in RFC 3339 format. Only entries created after the specified time will be included. UTC time zone.
-
businessAccountToken
final Optional<String> businessAccountToken()
-
category
final Optional<ManagementOperationListParams.ManagementOperationCategory> category()
Management operation category to be returned.
-
end
final Optional<OffsetDateTime> end()
Date string in RFC 3339 format. Only entries created before the specified time will be included. UTC time zone.
-
endingBefore
final Optional<String> endingBefore()
A cursor representing an item's token before which a page of results should end. Used to retrieve the previous page of results before this item.
-
financialAccountToken
final Optional<String> financialAccountToken()
Globally unique identifier for the financial account. Accepted type dependent on the program's use case.
-
startingAfter
final Optional<String> startingAfter()
A cursor representing an item's token after which a page of results should begin. Used to retrieve the next page of results after this item.
-
status
final Optional<ManagementOperationListParams.TransactionStatus> status()
Management operation status to be returned.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ManagementOperationListParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static ManagementOperationListParams none()
-
builder
final static ManagementOperationListParams.Builder builder()
Returns a mutable builder for constructing an instance of ManagementOperationListParams.
-
-
-
-