Class ManagementOperationTransaction.Builder
-
- All Implemented Interfaces:
public final class ManagementOperationTransaction.BuilderA builder for ManagementOperationTransaction.
-
-
Method Summary
-
-
Method Detail
-
token
final ManagementOperationTransaction.Builder token(String token)
Unique identifier for the transaction
-
token
final ManagementOperationTransaction.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final ManagementOperationTransaction.Builder created(OffsetDateTime created)
ISO 8601 timestamp of when the transaction was created
-
created
final ManagementOperationTransaction.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
family
final ManagementOperationTransaction.Builder family(ManagementOperationTransaction.TransactionFamilyTypes family)
-
family
final ManagementOperationTransaction.Builder family(JsonField<ManagementOperationTransaction.TransactionFamilyTypes> family)
Sets Builder.family to an arbitrary JSON value.
You should usually call Builder.family with a well-typed TransactionFamilyTypes value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final ManagementOperationTransaction.Builder status(ManagementOperationTransaction.TransactionStatus status)
The status of the transaction
-
status
final ManagementOperationTransaction.Builder status(JsonField<ManagementOperationTransaction.TransactionStatus> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed TransactionStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updated
final ManagementOperationTransaction.Builder updated(OffsetDateTime updated)
ISO 8601 timestamp of when the transaction was last updated
-
updated
final ManagementOperationTransaction.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
category
final ManagementOperationTransaction.Builder category(ManagementOperationTransaction.ManagementOperationCategory category)
-
category
final ManagementOperationTransaction.Builder category(JsonField<ManagementOperationTransaction.ManagementOperationCategory> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed ManagementOperationCategory value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final ManagementOperationTransaction.Builder currency(String currency)
-
currency
final ManagementOperationTransaction.Builder currency(JsonField<String> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
direction
final ManagementOperationTransaction.Builder direction(ManagementOperationTransaction.ManagementOperationDirection direction)
-
direction
final ManagementOperationTransaction.Builder direction(JsonField<ManagementOperationTransaction.ManagementOperationDirection> direction)
Sets Builder.direction to an arbitrary JSON value.
You should usually call Builder.direction with a well-typed ManagementOperationDirection value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
events
final ManagementOperationTransaction.Builder events(List<ManagementOperationTransaction.ManagementOperationEvent> events)
-
events
final ManagementOperationTransaction.Builder events(JsonField<List<ManagementOperationTransaction.ManagementOperationEvent>> events)
Sets Builder.events to an arbitrary JSON value.
You should usually call Builder.events with a well-typed
List<ManagementOperationEvent>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEvent
final ManagementOperationTransaction.Builder addEvent(ManagementOperationTransaction.ManagementOperationEvent event)
Adds a single ManagementOperationEvent to events.
-
externalResource
final ManagementOperationTransaction.Builder externalResource(ExternalResource externalResource)
External resource associated with the management operation
-
externalResource
final ManagementOperationTransaction.Builder externalResource(Optional<ExternalResource> externalResource)
Alias for calling Builder.externalResource with
externalResource.orElse(null).
-
externalResource
final ManagementOperationTransaction.Builder externalResource(JsonField<ExternalResource> externalResource)
Sets Builder.externalResource to an arbitrary JSON value.
You should usually call Builder.externalResource with a well-typed ExternalResource value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
financialAccountToken
final ManagementOperationTransaction.Builder financialAccountToken(String financialAccountToken)
-
financialAccountToken
final ManagementOperationTransaction.Builder financialAccountToken(JsonField<String> financialAccountToken)
Sets Builder.financialAccountToken to an arbitrary JSON value.
You should usually call Builder.financialAccountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pendingAmount
final ManagementOperationTransaction.Builder pendingAmount(Long pendingAmount)
-
pendingAmount
final ManagementOperationTransaction.Builder pendingAmount(JsonField<Long> pendingAmount)
Sets Builder.pendingAmount to an arbitrary JSON value.
You should usually call Builder.pendingAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
result
final ManagementOperationTransaction.Builder result(ManagementOperationTransaction.TransactionResult result)
-
result
final ManagementOperationTransaction.Builder result(JsonField<ManagementOperationTransaction.TransactionResult> result)
Sets Builder.result to an arbitrary JSON value.
You should usually call Builder.result with a well-typed TransactionResult value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
settledAmount
final ManagementOperationTransaction.Builder settledAmount(Long settledAmount)
-
settledAmount
final ManagementOperationTransaction.Builder settledAmount(JsonField<Long> settledAmount)
Sets Builder.settledAmount to an arbitrary JSON value.
You should usually call Builder.settledAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionSeries
final ManagementOperationTransaction.Builder transactionSeries(ManagementOperationTransaction.TransactionSeries transactionSeries)
-
transactionSeries
final ManagementOperationTransaction.Builder transactionSeries(Optional<ManagementOperationTransaction.TransactionSeries> transactionSeries)
Alias for calling Builder.transactionSeries with
transactionSeries.orElse(null).
-
transactionSeries
final ManagementOperationTransaction.Builder transactionSeries(JsonField<ManagementOperationTransaction.TransactionSeries> transactionSeries)
Sets Builder.transactionSeries to an arbitrary JSON value.
You should usually call Builder.transactionSeries with a well-typed TransactionSeries value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
userDefinedId
final ManagementOperationTransaction.Builder userDefinedId(String userDefinedId)
-
userDefinedId
final ManagementOperationTransaction.Builder userDefinedId(JsonField<String> userDefinedId)
Sets Builder.userDefinedId to an arbitrary JSON value.
You should usually call Builder.userDefinedId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ManagementOperationTransaction.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ManagementOperationTransaction.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ManagementOperationTransaction.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ManagementOperationTransaction.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ManagementOperationTransaction.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ManagementOperationTransaction build()
Returns an immutable instance of ManagementOperationTransaction.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .created() .family() .status() .updated()
-
-
-
-