Class MerchantLockParameters
-
- All Implemented Interfaces:
public final class MerchantLockParameters
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMerchantLockParameters.BuilderA builder for MerchantLockParameters.
public final classMerchantLockParameters.MerchantRepresents a specific merchant lock based on their ID or descriptor. Each merchant object allows transaction rules to work at a granular level and requires at least one of merchant_id or descriptor.
-
Method Summary
Modifier and Type Method Description final List<MerchantLockParameters.Merchant>merchants()A list of merchant locks defining specific merchants or groups of merchants (based on descriptors or IDs) that the lock applies to. final JsonField<List<MerchantLockParameters.Merchant>>_merchants()Returns the raw JSON value of merchants. final Map<String, JsonValue>_additionalProperties()final MerchantLockParameters.BuildertoBuilder()final MerchantLockParametersvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static MerchantLockParameters.Builderbuilder()Returns a mutable builder for constructing an instance of MerchantLockParameters. -
-
Method Detail
-
merchants
final List<MerchantLockParameters.Merchant> merchants()
A list of merchant locks defining specific merchants or groups of merchants (based on descriptors or IDs) that the lock applies to.
-
_merchants
final JsonField<List<MerchantLockParameters.Merchant>> _merchants()
Returns the raw JSON value of merchants.
Unlike merchants, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final MerchantLockParameters.Builder toBuilder()
-
validate
final MerchantLockParameters validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static MerchantLockParameters.Builder builder()
Returns a mutable builder for constructing an instance of MerchantLockParameters.
The following fields are required:
.merchants()
-
-
-
-