Class NonPciCard.Builder
-
- All Implemented Interfaces:
public final class NonPciCard.BuilderA builder for NonPciCard.
-
-
Method Summary
Modifier and Type Method Description final NonPciCard.Buildertoken(String token)Globally unique identifier. final NonPciCard.Buildertoken(JsonField<String> token)Sets Builder.token to an arbitrary JSON value. final NonPciCard.BuilderaccountToken(String accountToken)Globally unique identifier for the account to which the card belongs. final NonPciCard.BuilderaccountToken(JsonField<String> accountToken)Sets Builder.accountToken to an arbitrary JSON value. final NonPciCard.BuildercardProgramToken(String cardProgramToken)Globally unique identifier for the card program on which the card exists. final NonPciCard.BuildercardProgramToken(JsonField<String> cardProgramToken)Sets Builder.cardProgramToken to an arbitrary JSON value. final NonPciCard.Buildercreated(OffsetDateTime created)An RFC 3339 timestamp for when the card was created. final NonPciCard.Buildercreated(JsonField<OffsetDateTime> created)Sets Builder.created to an arbitrary JSON value. final NonPciCard.Builderfunding(NonPciCard.FundingAccount funding)Deprecated: Funding account for the card. final NonPciCard.Builderfunding(JsonField<NonPciCard.FundingAccount> funding)Sets Builder.funding to an arbitrary JSON value. final NonPciCard.BuilderlastFour(String lastFour)Last four digits of the card number. final NonPciCard.BuilderlastFour(JsonField<String> lastFour)Sets Builder.lastFour to an arbitrary JSON value. final NonPciCard.BuilderpinStatus(NonPciCard.PinStatus pinStatus)Indicates if a card is blocked due a PIN status issue (e.g. final NonPciCard.BuilderpinStatus(JsonField<NonPciCard.PinStatus> pinStatus)Sets Builder.pinStatus to an arbitrary JSON value. final NonPciCard.BuilderspendLimit(Long spendLimit)Amount (in cents) to limit approved authorizations (e.g. final NonPciCard.BuilderspendLimit(JsonField<Long> spendLimit)Sets Builder.spendLimit to an arbitrary JSON value. final NonPciCard.BuilderspendLimitDuration(SpendLimitDuration spendLimitDuration)Spend limit duration values: ANNUALLY- Card will authorize transactions up to spend limit for the trailing year.FOREVER- Card will authorize only up to spend limit for the entire lifetime of the card.MONTHLY- Card will authorize transactions up to spend limit for the trailing month. To support recurring monthly payments, which can occur on different day every month, the time window we consider for monthly velocity starts 6 days after the current calendar date one month prior.TRANSACTION- Card will authorize multiple transactions if each individual transaction is under the spend limit.
final NonPciCard.BuilderspendLimitDuration(JsonField<SpendLimitDuration> spendLimitDuration)Sets Builder.spendLimitDuration to an arbitrary JSON value. final NonPciCard.Builderstate(NonPciCard.State state)Card state values: _ CLOSED- Card will no longer approve authorizations.final NonPciCard.Builderstate(JsonField<NonPciCard.State> state)Sets Builder.state to an arbitrary JSON value. final NonPciCard.Buildertype(NonPciCard.Type type)Card types: _ VIRTUAL- Card will authorize at any merchant and can be added to a digital wallet like Apple Pay or Google Pay (if the card program is digital wallet-enabled).final NonPciCard.Buildertype(JsonField<NonPciCard.Type> type)Sets Builder.type to an arbitrary JSON value. final NonPciCard.BuilderauthRuleTokens(List<String> authRuleTokens)List of identifiers for the Auth Rule(s) that are applied on the card. final NonPciCard.BuilderauthRuleTokens(JsonField<List<String>> authRuleTokens)Sets Builder.authRuleTokens to an arbitrary JSON value. final NonPciCard.BuilderaddAuthRuleToken(String authRuleToken)Adds a single String to authRuleTokens. final NonPciCard.BuildercardholderCurrency(String cardholderCurrency)3-character alphabetic ISO 4217 code for the currency of the cardholder. final NonPciCard.BuildercardholderCurrency(JsonField<String> cardholderCurrency)Sets Builder.cardholderCurrency to an arbitrary JSON value. final NonPciCard.Buildercomment(String comment)Additional context or information related to the card. final NonPciCard.Buildercomment(JsonField<String> comment)Sets Builder.comment to an arbitrary JSON value. final NonPciCard.BuilderdigitalCardArtToken(String digitalCardArtToken)Specifies the digital card art to be displayed in the user's digital wallet after tokenization. final NonPciCard.BuilderdigitalCardArtToken(JsonField<String> digitalCardArtToken)Sets Builder.digitalCardArtToken to an arbitrary JSON value. final NonPciCard.BuilderexpMonth(String expMonth)Two digit (MM) expiry month. final NonPciCard.BuilderexpMonth(JsonField<String> expMonth)Sets Builder.expMonth to an arbitrary JSON value. final NonPciCard.BuilderexpYear(String expYear)Four digit (yyyy) expiry year. final NonPciCard.BuilderexpYear(JsonField<String> expYear)Sets Builder.expYear to an arbitrary JSON value. final NonPciCard.Builderhostname(String hostname)Hostname of card's locked merchant (will be empty if not applicable). final NonPciCard.Builderhostname(JsonField<String> hostname)Sets Builder.hostname to an arbitrary JSON value. final NonPciCard.Buildermemo(String memo)Friendly name to identify the card. final NonPciCard.Buildermemo(JsonField<String> memo)Sets Builder.memo to an arbitrary JSON value. final NonPciCard.BuildernetworkProgramToken(String networkProgramToken)Globally unique identifier for the card's network program. final NonPciCard.BuildernetworkProgramToken(Optional<String> networkProgramToken)Alias for calling Builder.networkProgramToken with networkProgramToken.orElse(null).final NonPciCard.BuildernetworkProgramToken(JsonField<String> networkProgramToken)Sets Builder.networkProgramToken to an arbitrary JSON value. final NonPciCard.BuilderpendingCommands(List<String> pendingCommands)Indicates if there are offline PIN changes pending card interaction with an offline PIN terminal. final NonPciCard.BuilderpendingCommands(JsonField<List<String>> pendingCommands)Sets Builder.pendingCommands to an arbitrary JSON value. final NonPciCard.BuilderaddPendingCommand(String pendingCommand)Adds a single String to pendingCommands. final NonPciCard.BuilderproductId(String productId)Only applicable to cards of type PHYSICAL.final NonPciCard.BuilderproductId(JsonField<String> productId)Sets Builder.productId to an arbitrary JSON value. final NonPciCard.BuilderreplacementFor(String replacementFor)If the card is a replacement for another card, the globally unique identifier for the card that was replaced. final NonPciCard.BuilderreplacementFor(Optional<String> replacementFor)Alias for calling Builder.replacementFor with replacementFor.orElse(null).final NonPciCard.BuilderreplacementFor(JsonField<String> replacementFor)Sets Builder.replacementFor to an arbitrary JSON value. final NonPciCard.Buildersubstatus(NonPciCard.Substatus substatus)Card state substatus values: _ LOST- The physical card is no longer in the cardholder's possession due to being lost or never received by the cardholder.final NonPciCard.Buildersubstatus(JsonField<NonPciCard.Substatus> substatus)Sets Builder.substatus to an arbitrary JSON value. final NonPciCard.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final NonPciCard.BuilderputAdditionalProperty(String key, JsonValue value)final NonPciCard.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final NonPciCard.BuilderremoveAdditionalProperty(String key)final NonPciCard.BuilderremoveAllAdditionalProperties(Set<String> keys)final NonPciCardbuild()Returns an immutable instance of NonPciCard. -
-
Method Detail
-
token
final NonPciCard.Builder token(String token)
Globally unique identifier.
-
token
final NonPciCard.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountToken
final NonPciCard.Builder accountToken(String accountToken)
Globally unique identifier for the account to which the card belongs.
-
accountToken
final NonPciCard.Builder accountToken(JsonField<String> accountToken)
Sets Builder.accountToken to an arbitrary JSON value.
You should usually call Builder.accountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardProgramToken
final NonPciCard.Builder cardProgramToken(String cardProgramToken)
Globally unique identifier for the card program on which the card exists.
-
cardProgramToken
final NonPciCard.Builder cardProgramToken(JsonField<String> cardProgramToken)
Sets Builder.cardProgramToken to an arbitrary JSON value.
You should usually call Builder.cardProgramToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final NonPciCard.Builder created(OffsetDateTime created)
An RFC 3339 timestamp for when the card was created. UTC time zone.
-
created
final NonPciCard.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
funding
final NonPciCard.Builder funding(NonPciCard.FundingAccount funding)
Deprecated: Funding account for the card.
-
funding
final NonPciCard.Builder funding(JsonField<NonPciCard.FundingAccount> funding)
Sets Builder.funding to an arbitrary JSON value.
You should usually call Builder.funding with a well-typed FundingAccount value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastFour
final NonPciCard.Builder lastFour(String lastFour)
Last four digits of the card number.
-
lastFour
final NonPciCard.Builder lastFour(JsonField<String> lastFour)
Sets Builder.lastFour to an arbitrary JSON value.
You should usually call Builder.lastFour with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pinStatus
final NonPciCard.Builder pinStatus(NonPciCard.PinStatus pinStatus)
Indicates if a card is blocked due a PIN status issue (e.g. excessive incorrect attempts).
-
pinStatus
final NonPciCard.Builder pinStatus(JsonField<NonPciCard.PinStatus> pinStatus)
Sets Builder.pinStatus to an arbitrary JSON value.
You should usually call Builder.pinStatus with a well-typed PinStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
spendLimit
final NonPciCard.Builder spendLimit(Long spendLimit)
Amount (in cents) to limit approved authorizations (e.g. 100000 would be a $1,000 limit). Transaction requests above the spend limit will be declined.
-
spendLimit
final NonPciCard.Builder spendLimit(JsonField<Long> spendLimit)
Sets Builder.spendLimit to an arbitrary JSON value.
You should usually call Builder.spendLimit with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
spendLimitDuration
final NonPciCard.Builder spendLimitDuration(SpendLimitDuration spendLimitDuration)
Spend limit duration values:
ANNUALLY- Card will authorize transactions up to spend limit for the trailing year.FOREVER- Card will authorize only up to spend limit for the entire lifetime of the card.MONTHLY- Card will authorize transactions up to spend limit for the trailing month. To support recurring monthly payments, which can occur on different day every month, the time window we consider for monthly velocity starts 6 days after the current calendar date one month prior.TRANSACTION- Card will authorize multiple transactions if each individual transaction is under the spend limit.
-
spendLimitDuration
final NonPciCard.Builder spendLimitDuration(JsonField<SpendLimitDuration> spendLimitDuration)
Sets Builder.spendLimitDuration to an arbitrary JSON value.
You should usually call Builder.spendLimitDuration with a well-typed SpendLimitDuration value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
state
final NonPciCard.Builder state(NonPciCard.State state)
Card state values: _
CLOSED- Card will no longer approve authorizations. Closing a card cannot be undone. _OPEN- Card will approve authorizations (if they match card and account parameters). _PAUSED- Card will decline authorizations, but can be resumed at a later time. _PENDING_FULFILLMENT- The initial state for cards of typePHYSICAL. The card is provisioned pending manufacturing and fulfillment. Cards in this state can accept authorizations for e-commerce purchases, but not for "Card Present" purchases where the physical card itself is present. \*PENDING_ACTIVATION- At regular intervals, cards of typePHYSICALin statePENDING_FULFILLMENTare sent to the card production warehouse and updated to statePENDING_ACTIVATION. Similar toPENDING_FULFILLMENT, cards in this state can be used for e-commerce transactions or can be added to mobile wallets. API clients should update the card's state toOPENonly after the cardholder confirms receipt of the card. In sandbox, the same daily batch fulfillment occurs, but no cards are actually manufactured.
-
state
final NonPciCard.Builder state(JsonField<NonPciCard.State> state)
Sets Builder.state to an arbitrary JSON value.
You should usually call Builder.state with a well-typed State value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final NonPciCard.Builder type(NonPciCard.Type type)
Card types: _
VIRTUAL- Card will authorize at any merchant and can be added to a digital wallet like Apple Pay or Google Pay (if the card program is digital wallet-enabled). _PHYSICAL- Manufactured and sent to the cardholder. We offer white label branding, credit, ATM, PIN debit, chip/EMV, NFC and magstripe functionality. _SINGLE_USE- Card is closed upon first successful authorization. _MERCHANT_LOCKED- Deprecated Card is locked to the first merchant that successfully authorizes the card. _UNLOCKED- Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead. _DIGITAL_WALLET- Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.
-
type
final NonPciCard.Builder type(JsonField<NonPciCard.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
authRuleTokens
@Deprecated(message = "deprecated") final NonPciCard.Builder authRuleTokens(List<String> authRuleTokens)
List of identifiers for the Auth Rule(s) that are applied on the card. This field is deprecated and will no longer be populated in the
Cardobject. The key will be removed from the schema in a future release. Use the/auth_rulesendpoints to fetch Auth Rule information instead.
-
authRuleTokens
@Deprecated(message = "deprecated") final NonPciCard.Builder authRuleTokens(JsonField<List<String>> authRuleTokens)
Sets Builder.authRuleTokens to an arbitrary JSON value.
You should usually call Builder.authRuleTokens with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addAuthRuleToken
@Deprecated(message = "deprecated") final NonPciCard.Builder addAuthRuleToken(String authRuleToken)
Adds a single String to authRuleTokens.
-
cardholderCurrency
final NonPciCard.Builder cardholderCurrency(String cardholderCurrency)
3-character alphabetic ISO 4217 code for the currency of the cardholder.
-
cardholderCurrency
final NonPciCard.Builder cardholderCurrency(JsonField<String> cardholderCurrency)
Sets Builder.cardholderCurrency to an arbitrary JSON value.
You should usually call Builder.cardholderCurrency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
comment
final NonPciCard.Builder comment(String comment)
Additional context or information related to the card.
-
comment
final NonPciCard.Builder comment(JsonField<String> comment)
Sets Builder.comment to an arbitrary JSON value.
You should usually call Builder.comment with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
digitalCardArtToken
final NonPciCard.Builder digitalCardArtToken(String digitalCardArtToken)
Specifies the digital card art to be displayed in the user's digital wallet after tokenization. This artwork must be approved by Mastercard and configured by Lithic to use.
-
digitalCardArtToken
final NonPciCard.Builder digitalCardArtToken(JsonField<String> digitalCardArtToken)
Sets Builder.digitalCardArtToken to an arbitrary JSON value.
You should usually call Builder.digitalCardArtToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
expMonth
final NonPciCard.Builder expMonth(String expMonth)
Two digit (MM) expiry month.
-
expMonth
final NonPciCard.Builder expMonth(JsonField<String> expMonth)
Sets Builder.expMonth to an arbitrary JSON value.
You should usually call Builder.expMonth with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
expYear
final NonPciCard.Builder expYear(String expYear)
Four digit (yyyy) expiry year.
-
expYear
final NonPciCard.Builder expYear(JsonField<String> expYear)
Sets Builder.expYear to an arbitrary JSON value.
You should usually call Builder.expYear with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
hostname
final NonPciCard.Builder hostname(String hostname)
Hostname of card's locked merchant (will be empty if not applicable).
-
hostname
final NonPciCard.Builder hostname(JsonField<String> hostname)
Sets Builder.hostname to an arbitrary JSON value.
You should usually call Builder.hostname with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
memo
final NonPciCard.Builder memo(String memo)
Friendly name to identify the card.
-
memo
final NonPciCard.Builder memo(JsonField<String> memo)
Sets Builder.memo to an arbitrary JSON value.
You should usually call Builder.memo with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
networkProgramToken
final NonPciCard.Builder networkProgramToken(String networkProgramToken)
Globally unique identifier for the card's network program. Null if the card is not associated with a network program. Currently applicable to Visa cards participating in Account Level Management only
-
networkProgramToken
final NonPciCard.Builder networkProgramToken(Optional<String> networkProgramToken)
Alias for calling Builder.networkProgramToken with
networkProgramToken.orElse(null).
-
networkProgramToken
final NonPciCard.Builder networkProgramToken(JsonField<String> networkProgramToken)
Sets Builder.networkProgramToken to an arbitrary JSON value.
You should usually call Builder.networkProgramToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pendingCommands
final NonPciCard.Builder pendingCommands(List<String> pendingCommands)
Indicates if there are offline PIN changes pending card interaction with an offline PIN terminal. Possible commands are: CHANGE_PIN, UNBLOCK_PIN. Applicable only to cards issued in markets supporting offline PINs.
-
pendingCommands
final NonPciCard.Builder pendingCommands(JsonField<List<String>> pendingCommands)
Sets Builder.pendingCommands to an arbitrary JSON value.
You should usually call Builder.pendingCommands with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addPendingCommand
final NonPciCard.Builder addPendingCommand(String pendingCommand)
Adds a single String to pendingCommands.
-
productId
final NonPciCard.Builder productId(String productId)
Only applicable to cards of type
PHYSICAL. This must be configured with Lithic before use. Specifies the configuration (i.e., physical card art) that the card should be manufactured with.
-
productId
final NonPciCard.Builder productId(JsonField<String> productId)
Sets Builder.productId to an arbitrary JSON value.
You should usually call Builder.productId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
replacementFor
final NonPciCard.Builder replacementFor(String replacementFor)
If the card is a replacement for another card, the globally unique identifier for the card that was replaced.
-
replacementFor
final NonPciCard.Builder replacementFor(Optional<String> replacementFor)
Alias for calling Builder.replacementFor with
replacementFor.orElse(null).
-
replacementFor
final NonPciCard.Builder replacementFor(JsonField<String> replacementFor)
Sets Builder.replacementFor to an arbitrary JSON value.
You should usually call Builder.replacementFor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
substatus
final NonPciCard.Builder substatus(NonPciCard.Substatus substatus)
Card state substatus values: _
LOST- The physical card is no longer in the cardholder's possession due to being lost or never received by the cardholder. _COMPROMISED- Card information has been exposed, potentially leading to unauthorized access. This may involve physical card theft, cloning, or online data breaches. _DAMAGED- The physical card is not functioning properly, such as having chip failures or a demagnetized magnetic stripe. _END_USER_REQUEST- The cardholder requested the closure of the card for reasons unrelated to fraud or damage, such as switching to a different product or closing the account. _ISSUER_REQUEST- The issuer closed the card for reasons unrelated to fraud or damage, such as account inactivity, product or policy changes, or technology upgrades. _NOT_ACTIVE- The card hasn’t had any transaction activity for a specified period, applicable to statuses likePAUSEDorCLOSED. _SUSPICIOUS_ACTIVITY- The card has one or more suspicious transactions or activities that require review. This can involve prompting the cardholder to confirm legitimate use or report confirmed fraud. _INTERNAL_REVIEW- The card is temporarily paused pending further internal review. _EXPIRED- The card has expired and has been closed without being reissued. _UNDELIVERABLE- The card cannot be delivered to the cardholder and has been returned. \*OTHER- The reason for the status does not fall into any of the above categories. A comment can be provided to specify the reason.
-
substatus
final NonPciCard.Builder substatus(JsonField<NonPciCard.Substatus> substatus)
Sets Builder.substatus to an arbitrary JSON value.
You should usually call Builder.substatus with a well-typed Substatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final NonPciCard.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final NonPciCard.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final NonPciCard.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final NonPciCard.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final NonPciCard.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final NonPciCard build()
Returns an immutable instance of NonPciCard.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .accountToken() .cardProgramToken() .created() .funding() .lastFour() .pinStatus() .spendLimit() .spendLimitDuration() .state() .type()
-
-
-