Class Payment
-
- All Implemented Interfaces:
public final class Payment
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayment.BuilderA builder for Payment.
public final classPayment.CategoryPayment category
public final classPayment.Directionpublic final classPayment.PaymentEventpublic final classPayment.Methodpublic final classPayment.PaymentMethodAttributespublic final classPayment.ResultAPPROVED payments were successful while DECLINED payments were declined by Lithic or returned.
public final classPayment.Sourcepublic final classPayment.StatusStatus types:
DECLINED- The payment was declined.PENDING- The payment is being processed and has yet to settle or release (origination debit).RETURNED- The payment has been returned.SETTLED- The payment is completed.
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier. final Payment.Categorycategory()Payment category final OffsetDateTimecreated()Date and time when the payment first occurred. final Stringcurrency()3-character alphabetic ISO 4217 code for the settling currency of the payment. final Stringdescriptor()A string that provides a description of the payment; may be useful to display to users. final Payment.Directiondirection()final List<Payment.PaymentEvent>events()A list of all payment events that have modified this payment. final Optional<String>externalBankAccountToken()final StringfinancialAccountToken()final Payment.Methodmethod()final Payment.PaymentMethodAttributesmethodAttributes()final LongpendingAmount()Pending amount of the payment in the currency's smallest unit (e.g., cents). final Payment.Resultresult()APPROVED payments were successful while DECLINED payments were declined by Lithic or returned. final LongsettledAmount()Amount of the payment that has been settled in the currency's smallest unit (e.g., cents). final Payment.Sourcesource()final Payment.Statusstatus()Status types: DECLINED- The payment was declined.PENDING- The payment is being processed and has yet to settle or release (origination debit).RETURNED- The payment has been returned.SETTLED- The payment is completed.
final OffsetDateTimeupdated()Date and time when the financial transaction was last updated. final Optional<String>userDefinedId()final JsonField<String>_token()Globally unique identifier. final JsonField<Payment.Category>_category()Payment category final JsonField<OffsetDateTime>_created()Date and time when the payment first occurred. final JsonField<String>_currency()3-character alphabetic ISO 4217 code for the settling currency of the payment. final JsonField<String>_descriptor()A string that provides a description of the payment; may be useful to display to users. final JsonField<Payment.Direction>_direction()final JsonField<List<Payment.PaymentEvent>>_events()A list of all payment events that have modified this payment. final JsonField<String>_externalBankAccountToken()final JsonField<String>_financialAccountToken()final JsonField<Payment.Method>_method()final JsonField<Payment.PaymentMethodAttributes>_methodAttributes()final JsonField<Long>_pendingAmount()Pending amount of the payment in the currency's smallest unit (e.g., cents). final JsonField<Payment.Result>_result()APPROVED payments were successful while DECLINED payments were declined by Lithic or returned. final JsonField<Long>_settledAmount()Amount of the payment that has been settled in the currency's smallest unit (e.g., cents). final JsonField<Payment.Source>_source()final JsonField<Payment.Status>_status()Status types: DECLINED- The payment was declined.PENDING- The payment is being processed and has yet to settle or release (origination debit).RETURNED- The payment has been returned.SETTLED- The payment is completed.
final JsonField<OffsetDateTime>_updated()Date and time when the financial transaction was last updated. final JsonField<String>_userDefinedId()final Map<String, JsonValue>_additionalProperties()final Paymentvalidate()final Payment.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Payment.Builderbuilder()Returns a mutable builder for constructing an instance of Payment. -
-
Method Detail
-
category
final Payment.Category category()
Payment category
-
created
final OffsetDateTime created()
Date and time when the payment first occurred. UTC time zone.
-
currency
final String currency()
3-character alphabetic ISO 4217 code for the settling currency of the payment.
-
descriptor
final String descriptor()
A string that provides a description of the payment; may be useful to display to users.
-
direction
final Payment.Direction direction()
-
events
final List<Payment.PaymentEvent> events()
A list of all payment events that have modified this payment.
-
externalBankAccountToken
final Optional<String> externalBankAccountToken()
-
financialAccountToken
final String financialAccountToken()
-
method
final Payment.Method method()
-
methodAttributes
final Payment.PaymentMethodAttributes methodAttributes()
-
pendingAmount
final Long pendingAmount()
Pending amount of the payment in the currency's smallest unit (e.g., cents). The value of this field will go to zero over time once the payment is settled.
-
result
final Payment.Result result()
APPROVED payments were successful while DECLINED payments were declined by Lithic or returned.
-
settledAmount
final Long settledAmount()
Amount of the payment that has been settled in the currency's smallest unit (e.g., cents).
-
source
final Payment.Source source()
-
status
final Payment.Status status()
Status types:
DECLINED- The payment was declined.PENDING- The payment is being processed and has yet to settle or release (origination debit).RETURNED- The payment has been returned.SETTLED- The payment is completed.
-
updated
final OffsetDateTime updated()
Date and time when the financial transaction was last updated. UTC time zone.
-
userDefinedId
final Optional<String> userDefinedId()
-
_category
final JsonField<Payment.Category> _category()
Payment category
-
_created
final JsonField<OffsetDateTime> _created()
Date and time when the payment first occurred. UTC time zone.
-
_currency
final JsonField<String> _currency()
3-character alphabetic ISO 4217 code for the settling currency of the payment.
-
_descriptor
final JsonField<String> _descriptor()
A string that provides a description of the payment; may be useful to display to users.
-
_direction
final JsonField<Payment.Direction> _direction()
-
_events
final JsonField<List<Payment.PaymentEvent>> _events()
A list of all payment events that have modified this payment.
-
_externalBankAccountToken
final JsonField<String> _externalBankAccountToken()
-
_financialAccountToken
final JsonField<String> _financialAccountToken()
-
_method
final JsonField<Payment.Method> _method()
-
_methodAttributes
final JsonField<Payment.PaymentMethodAttributes> _methodAttributes()
-
_pendingAmount
final JsonField<Long> _pendingAmount()
Pending amount of the payment in the currency's smallest unit (e.g., cents). The value of this field will go to zero over time once the payment is settled.
-
_result
final JsonField<Payment.Result> _result()
APPROVED payments were successful while DECLINED payments were declined by Lithic or returned.
-
_settledAmount
final JsonField<Long> _settledAmount()
Amount of the payment that has been settled in the currency's smallest unit (e.g., cents).
-
_source
final JsonField<Payment.Source> _source()
-
_status
final JsonField<Payment.Status> _status()
Status types:
DECLINED- The payment was declined.PENDING- The payment is being processed and has yet to settle or release (origination debit).RETURNED- The payment has been returned.SETTLED- The payment is completed.
-
_updated
final JsonField<OffsetDateTime> _updated()
Date and time when the financial transaction was last updated. UTC time zone.
-
_userDefinedId
final JsonField<String> _userDefinedId()
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Payment.Builder toBuilder()
-
builder
final static Payment.Builder builder()
Returns a mutable builder for constructing an instance of Payment.
The following fields are required:
.token() .category() .created() .currency() .descriptor() .direction() .events() .externalBankAccountToken() .financialAccountToken() .method() .methodAttributes() .pendingAmount() .result() .settledAmount() .source() .status() .updated() .userDefinedId()
-
-
-