Class Payment.PaymentMethodAttributes.Builder
-
- All Implemented Interfaces:
public final class Payment.PaymentMethodAttributes.BuilderA builder for PaymentMethodAttributes.
-
-
Method Summary
-
-
Method Detail
-
companyId
final Payment.PaymentMethodAttributes.Builder companyId(String companyId)
-
companyId
final Payment.PaymentMethodAttributes.Builder companyId(Optional<String> companyId)
Alias for calling Builder.companyId with
companyId.orElse(null).
-
companyId
final Payment.PaymentMethodAttributes.Builder companyId(JsonField<String> companyId)
Sets Builder.companyId to an arbitrary JSON value.
You should usually call Builder.companyId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
receiptRoutingNumber
final Payment.PaymentMethodAttributes.Builder receiptRoutingNumber(String receiptRoutingNumber)
-
receiptRoutingNumber
final Payment.PaymentMethodAttributes.Builder receiptRoutingNumber(Optional<String> receiptRoutingNumber)
Alias for calling Builder.receiptRoutingNumber with
receiptRoutingNumber.orElse(null).
-
receiptRoutingNumber
final Payment.PaymentMethodAttributes.Builder receiptRoutingNumber(JsonField<String> receiptRoutingNumber)
Sets Builder.receiptRoutingNumber to an arbitrary JSON value.
You should usually call Builder.receiptRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
retries
final Payment.PaymentMethodAttributes.Builder retries(Long retries)
-
retries
final Payment.PaymentMethodAttributes.Builder retries(Long retries)
Alias for Builder.retries.
This unboxed primitive overload exists for backwards compatibility.
-
retries
final Payment.PaymentMethodAttributes.Builder retries(Optional<Long> retries)
Alias for calling Builder.retries with
retries.orElse(null).
-
retries
final Payment.PaymentMethodAttributes.Builder retries(JsonField<Long> retries)
Sets Builder.retries to an arbitrary JSON value.
You should usually call Builder.retries with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
returnReasonCode
final Payment.PaymentMethodAttributes.Builder returnReasonCode(String returnReasonCode)
-
returnReasonCode
final Payment.PaymentMethodAttributes.Builder returnReasonCode(Optional<String> returnReasonCode)
Alias for calling Builder.returnReasonCode with
returnReasonCode.orElse(null).
-
returnReasonCode
final Payment.PaymentMethodAttributes.Builder returnReasonCode(JsonField<String> returnReasonCode)
Sets Builder.returnReasonCode to an arbitrary JSON value.
You should usually call Builder.returnReasonCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
secCode
final Payment.PaymentMethodAttributes.Builder secCode(Payment.PaymentMethodAttributes.SecCode secCode)
-
secCode
final Payment.PaymentMethodAttributes.Builder secCode(JsonField<Payment.PaymentMethodAttributes.SecCode> secCode)
Sets Builder.secCode to an arbitrary JSON value.
You should usually call Builder.secCode with a well-typed SecCode value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
traceNumbers
final Payment.PaymentMethodAttributes.Builder traceNumbers(List<String> traceNumbers)
-
traceNumbers
final Payment.PaymentMethodAttributes.Builder traceNumbers(JsonField<List<String>> traceNumbers)
Sets Builder.traceNumbers to an arbitrary JSON value.
You should usually call Builder.traceNumbers with a well-typed
List<String?>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTraceNumber
final Payment.PaymentMethodAttributes.Builder addTraceNumber(String traceNumber)
Adds a single String to traceNumbers.
-
addenda
final Payment.PaymentMethodAttributes.Builder addenda(String addenda)
-
addenda
final Payment.PaymentMethodAttributes.Builder addenda(Optional<String> addenda)
Alias for calling Builder.addenda with
addenda.orElse(null).
-
addenda
final Payment.PaymentMethodAttributes.Builder addenda(JsonField<String> addenda)
Sets Builder.addenda to an arbitrary JSON value.
You should usually call Builder.addenda with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Payment.PaymentMethodAttributes.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Payment.PaymentMethodAttributes.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Payment.PaymentMethodAttributes.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Payment.PaymentMethodAttributes.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Payment.PaymentMethodAttributes.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Payment.PaymentMethodAttributes build()
Returns an immutable instance of PaymentMethodAttributes.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.companyId() .receiptRoutingNumber() .retries() .returnReasonCode() .secCode() .traceNumbers()
-
-
-
-