Class PaymentCreateResponse.Builder
-
- All Implemented Interfaces:
public final class PaymentCreateResponse.BuilderA builder for PaymentCreateResponse.
-
-
Method Summary
Modifier and Type Method Description final PaymentCreateResponse.Buildertoken(String token)Globally unique identifier. final PaymentCreateResponse.Buildertoken(JsonField<String> token)Globally unique identifier. final PaymentCreateResponse.Buildercategory(Payment.Category category)Payment category final PaymentCreateResponse.Buildercategory(JsonField<Payment.Category> category)Payment category final PaymentCreateResponse.Buildercreated(OffsetDateTime created)Date and time when the payment first occurred. final PaymentCreateResponse.Buildercreated(JsonField<OffsetDateTime> created)Date and time when the payment first occurred. final PaymentCreateResponse.Buildercurrency(String currency)3-character alphabetic ISO 4217 code for the settling currency of the payment. final PaymentCreateResponse.Buildercurrency(JsonField<String> currency)3-character alphabetic ISO 4217 code for the settling currency of the payment. final PaymentCreateResponse.Builderdescriptor(String descriptor)A string that provides a description of the payment; may be useful to display to users. final PaymentCreateResponse.Builderdescriptor(JsonField<String> descriptor)A string that provides a description of the payment; may be useful to display to users. final PaymentCreateResponse.Builderdirection(Payment.Direction direction)final PaymentCreateResponse.Builderdirection(JsonField<Payment.Direction> direction)final PaymentCreateResponse.Builderevents(List<Payment.PaymentEvent> events)A list of all payment events that have modified this payment. final PaymentCreateResponse.Builderevents(JsonField<List<Payment.PaymentEvent>> events)A list of all payment events that have modified this payment. final PaymentCreateResponse.BuilderaddEvent(Payment.PaymentEvent event)A list of all payment events that have modified this payment. final PaymentCreateResponse.BuilderexternalBankAccountToken(String externalBankAccountToken)final PaymentCreateResponse.BuilderexternalBankAccountToken(Optional<String> externalBankAccountToken)final PaymentCreateResponse.BuilderexternalBankAccountToken(JsonField<String> externalBankAccountToken)final PaymentCreateResponse.BuilderfinancialAccountToken(String financialAccountToken)final PaymentCreateResponse.BuilderfinancialAccountToken(JsonField<String> financialAccountToken)final PaymentCreateResponse.Buildermethod(Payment.Method method)final PaymentCreateResponse.Buildermethod(JsonField<Payment.Method> method)final PaymentCreateResponse.BuildermethodAttributes(Payment.PaymentMethodAttributes methodAttributes)final PaymentCreateResponse.BuildermethodAttributes(JsonField<Payment.PaymentMethodAttributes> methodAttributes)final PaymentCreateResponse.BuilderpendingAmount(Long pendingAmount)Pending amount of the payment in the currency's smallest unit (e.g., cents). final PaymentCreateResponse.BuilderpendingAmount(JsonField<Long> pendingAmount)Pending amount of the payment in the currency's smallest unit (e.g., cents). final PaymentCreateResponse.Builderresult(Payment.Result result)APPROVED payments were successful while DECLINED payments were declined by Lithic or returned. final PaymentCreateResponse.Builderresult(JsonField<Payment.Result> result)APPROVED payments were successful while DECLINED payments were declined by Lithic or returned. final PaymentCreateResponse.BuildersettledAmount(Long settledAmount)Amount of the payment that has been settled in the currency's smallest unit (e.g., cents). final PaymentCreateResponse.BuildersettledAmount(JsonField<Long> settledAmount)Amount of the payment that has been settled in the currency's smallest unit (e.g., cents). final PaymentCreateResponse.Buildersource(Payment.Source source)final PaymentCreateResponse.Buildersource(JsonField<Payment.Source> source)final PaymentCreateResponse.Builderstatus(Payment.Status status)Status types: DECLINED- The payment was declined.PENDING- The payment is being processed and has yet to settle or release (origination debit).RETURNED- The payment has been returned.SETTLED- The payment is completed.
final PaymentCreateResponse.Builderstatus(JsonField<Payment.Status> status)Status types: DECLINED- The payment was declined.PENDING- The payment is being processed and has yet to settle or release (origination debit).RETURNED- The payment has been returned.SETTLED- The payment is completed.
final PaymentCreateResponse.Builderupdated(OffsetDateTime updated)Date and time when the financial transaction was last updated. final PaymentCreateResponse.Builderupdated(JsonField<OffsetDateTime> updated)Date and time when the financial transaction was last updated. final PaymentCreateResponse.BuilderuserDefinedId(String userDefinedId)final PaymentCreateResponse.BuilderuserDefinedId(Optional<String> userDefinedId)final PaymentCreateResponse.BuilderuserDefinedId(JsonField<String> userDefinedId)final PaymentCreateResponse.Builderbalance(Balance balance)Balance final PaymentCreateResponse.Builderbalance(JsonField<Balance> balance)Balance final PaymentCreateResponse.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final PaymentCreateResponse.BuilderputAdditionalProperty(String key, JsonValue value)final PaymentCreateResponse.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final PaymentCreateResponse.BuilderremoveAdditionalProperty(String key)final PaymentCreateResponse.BuilderremoveAllAdditionalProperties(Set<String> keys)final PaymentCreateResponsebuild()-
-
Method Detail
-
token
final PaymentCreateResponse.Builder token(String token)
Globally unique identifier.
-
token
final PaymentCreateResponse.Builder token(JsonField<String> token)
Globally unique identifier.
-
category
final PaymentCreateResponse.Builder category(Payment.Category category)
Payment category
-
category
final PaymentCreateResponse.Builder category(JsonField<Payment.Category> category)
Payment category
-
created
final PaymentCreateResponse.Builder created(OffsetDateTime created)
Date and time when the payment first occurred. UTC time zone.
-
created
final PaymentCreateResponse.Builder created(JsonField<OffsetDateTime> created)
Date and time when the payment first occurred. UTC time zone.
-
currency
final PaymentCreateResponse.Builder currency(String currency)
3-character alphabetic ISO 4217 code for the settling currency of the payment.
-
currency
final PaymentCreateResponse.Builder currency(JsonField<String> currency)
3-character alphabetic ISO 4217 code for the settling currency of the payment.
-
descriptor
final PaymentCreateResponse.Builder descriptor(String descriptor)
A string that provides a description of the payment; may be useful to display to users.
-
descriptor
final PaymentCreateResponse.Builder descriptor(JsonField<String> descriptor)
A string that provides a description of the payment; may be useful to display to users.
-
direction
final PaymentCreateResponse.Builder direction(Payment.Direction direction)
-
direction
final PaymentCreateResponse.Builder direction(JsonField<Payment.Direction> direction)
-
events
final PaymentCreateResponse.Builder events(List<Payment.PaymentEvent> events)
A list of all payment events that have modified this payment.
-
events
final PaymentCreateResponse.Builder events(JsonField<List<Payment.PaymentEvent>> events)
A list of all payment events that have modified this payment.
-
addEvent
final PaymentCreateResponse.Builder addEvent(Payment.PaymentEvent event)
A list of all payment events that have modified this payment.
-
externalBankAccountToken
final PaymentCreateResponse.Builder externalBankAccountToken(String externalBankAccountToken)
-
externalBankAccountToken
final PaymentCreateResponse.Builder externalBankAccountToken(Optional<String> externalBankAccountToken)
-
externalBankAccountToken
final PaymentCreateResponse.Builder externalBankAccountToken(JsonField<String> externalBankAccountToken)
-
financialAccountToken
final PaymentCreateResponse.Builder financialAccountToken(String financialAccountToken)
-
financialAccountToken
final PaymentCreateResponse.Builder financialAccountToken(JsonField<String> financialAccountToken)
-
method
final PaymentCreateResponse.Builder method(Payment.Method method)
-
method
final PaymentCreateResponse.Builder method(JsonField<Payment.Method> method)
-
methodAttributes
final PaymentCreateResponse.Builder methodAttributes(Payment.PaymentMethodAttributes methodAttributes)
-
methodAttributes
final PaymentCreateResponse.Builder methodAttributes(JsonField<Payment.PaymentMethodAttributes> methodAttributes)
-
pendingAmount
final PaymentCreateResponse.Builder pendingAmount(Long pendingAmount)
Pending amount of the payment in the currency's smallest unit (e.g., cents). The value of this field will go to zero over time once the payment is settled.
-
pendingAmount
final PaymentCreateResponse.Builder pendingAmount(JsonField<Long> pendingAmount)
Pending amount of the payment in the currency's smallest unit (e.g., cents). The value of this field will go to zero over time once the payment is settled.
-
result
final PaymentCreateResponse.Builder result(Payment.Result result)
APPROVED payments were successful while DECLINED payments were declined by Lithic or returned.
-
result
final PaymentCreateResponse.Builder result(JsonField<Payment.Result> result)
APPROVED payments were successful while DECLINED payments were declined by Lithic or returned.
-
settledAmount
final PaymentCreateResponse.Builder settledAmount(Long settledAmount)
Amount of the payment that has been settled in the currency's smallest unit (e.g., cents).
-
settledAmount
final PaymentCreateResponse.Builder settledAmount(JsonField<Long> settledAmount)
Amount of the payment that has been settled in the currency's smallest unit (e.g., cents).
-
source
final PaymentCreateResponse.Builder source(Payment.Source source)
-
source
final PaymentCreateResponse.Builder source(JsonField<Payment.Source> source)
-
status
final PaymentCreateResponse.Builder status(Payment.Status status)
Status types:
DECLINED- The payment was declined.PENDING- The payment is being processed and has yet to settle or release (origination debit).RETURNED- The payment has been returned.SETTLED- The payment is completed.
-
status
final PaymentCreateResponse.Builder status(JsonField<Payment.Status> status)
Status types:
DECLINED- The payment was declined.PENDING- The payment is being processed and has yet to settle or release (origination debit).RETURNED- The payment has been returned.SETTLED- The payment is completed.
-
updated
final PaymentCreateResponse.Builder updated(OffsetDateTime updated)
Date and time when the financial transaction was last updated. UTC time zone.
-
updated
final PaymentCreateResponse.Builder updated(JsonField<OffsetDateTime> updated)
Date and time when the financial transaction was last updated. UTC time zone.
-
userDefinedId
final PaymentCreateResponse.Builder userDefinedId(String userDefinedId)
-
userDefinedId
final PaymentCreateResponse.Builder userDefinedId(Optional<String> userDefinedId)
-
userDefinedId
final PaymentCreateResponse.Builder userDefinedId(JsonField<String> userDefinedId)
-
balance
final PaymentCreateResponse.Builder balance(Balance balance)
Balance
-
balance
final PaymentCreateResponse.Builder balance(JsonField<Balance> balance)
Balance
-
additionalProperties
final PaymentCreateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PaymentCreateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PaymentCreateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PaymentCreateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PaymentCreateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PaymentCreateResponse build()
-
-
-