Class PaymentTransactionUpdatedWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class PaymentTransactionUpdatedWebhookEvent.BuilderA builder for PaymentTransactionUpdatedWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
token
final PaymentTransactionUpdatedWebhookEvent.Builder token(String token)
Unique identifier for the transaction
-
token
final PaymentTransactionUpdatedWebhookEvent.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
category
final PaymentTransactionUpdatedWebhookEvent.Builder category(Payment.TransactionCategory category)
Transaction category
-
category
final PaymentTransactionUpdatedWebhookEvent.Builder category(JsonField<Payment.TransactionCategory> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Payment.TransactionCategory value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final PaymentTransactionUpdatedWebhookEvent.Builder created(OffsetDateTime created)
ISO 8601 timestamp of when the transaction was created
-
created
final PaymentTransactionUpdatedWebhookEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
descriptor
final PaymentTransactionUpdatedWebhookEvent.Builder descriptor(String descriptor)
Transaction descriptor
-
descriptor
final PaymentTransactionUpdatedWebhookEvent.Builder descriptor(JsonField<String> descriptor)
Sets Builder.descriptor to an arbitrary JSON value.
You should usually call Builder.descriptor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
direction
final PaymentTransactionUpdatedWebhookEvent.Builder direction(Payment.Direction direction)
Transfer direction
-
direction
final PaymentTransactionUpdatedWebhookEvent.Builder direction(JsonField<Payment.Direction> direction)
Sets Builder.direction to an arbitrary JSON value.
You should usually call Builder.direction with a well-typed Payment.Direction value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
events
final PaymentTransactionUpdatedWebhookEvent.Builder events(List<Payment.PaymentEvent> events)
List of transaction events
-
events
final PaymentTransactionUpdatedWebhookEvent.Builder events(JsonField<List<Payment.PaymentEvent>> events)
Sets Builder.events to an arbitrary JSON value.
You should usually call Builder.events with a well-typed
List<Payment.PaymentEvent>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEvent
final PaymentTransactionUpdatedWebhookEvent.Builder addEvent(Payment.PaymentEvent event)
Adds a single Payment.PaymentEvent to events.
-
family
final PaymentTransactionUpdatedWebhookEvent.Builder family(Payment.Family family)
PAYMENT - Payment Transaction
-
family
final PaymentTransactionUpdatedWebhookEvent.Builder family(JsonField<Payment.Family> family)
Sets Builder.family to an arbitrary JSON value.
You should usually call Builder.family with a well-typed Payment.Family value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
financialAccountToken
final PaymentTransactionUpdatedWebhookEvent.Builder financialAccountToken(String financialAccountToken)
Financial account token
-
financialAccountToken
final PaymentTransactionUpdatedWebhookEvent.Builder financialAccountToken(JsonField<String> financialAccountToken)
Sets Builder.financialAccountToken to an arbitrary JSON value.
You should usually call Builder.financialAccountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
method
final PaymentTransactionUpdatedWebhookEvent.Builder method(Payment.Method method)
Transfer method
-
method
final PaymentTransactionUpdatedWebhookEvent.Builder method(JsonField<Payment.Method> method)
Sets Builder.method to an arbitrary JSON value.
You should usually call Builder.method with a well-typed Payment.Method value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
methodAttributes
final PaymentTransactionUpdatedWebhookEvent.Builder methodAttributes(Payment.MethodAttributes methodAttributes)
Method-specific attributes
-
methodAttributes
final PaymentTransactionUpdatedWebhookEvent.Builder methodAttributes(JsonField<Payment.MethodAttributes> methodAttributes)
Sets Builder.methodAttributes to an arbitrary JSON value.
You should usually call Builder.methodAttributes with a well-typed Payment.MethodAttributes value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
methodAttributes
final PaymentTransactionUpdatedWebhookEvent.Builder methodAttributes(Payment.MethodAttributes.AchMethodAttributes ach)
Alias for calling methodAttributes with
Payment.MethodAttributes.ofAch(ach).
-
methodAttributes
final PaymentTransactionUpdatedWebhookEvent.Builder methodAttributes(Payment.MethodAttributes.WireMethodAttributes wire)
Alias for calling methodAttributes with
Payment.MethodAttributes.ofWire(wire).
-
pendingAmount
final PaymentTransactionUpdatedWebhookEvent.Builder pendingAmount(Long pendingAmount)
Pending amount in cents
-
pendingAmount
final PaymentTransactionUpdatedWebhookEvent.Builder pendingAmount(JsonField<Long> pendingAmount)
Sets Builder.pendingAmount to an arbitrary JSON value.
You should usually call Builder.pendingAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
relatedAccountTokens
final PaymentTransactionUpdatedWebhookEvent.Builder relatedAccountTokens(Payment.RelatedAccountTokens relatedAccountTokens)
Account tokens related to a payment transaction
-
relatedAccountTokens
final PaymentTransactionUpdatedWebhookEvent.Builder relatedAccountTokens(Optional<Payment.RelatedAccountTokens> relatedAccountTokens)
Alias for calling Builder.relatedAccountTokens with
relatedAccountTokens.orElse(null).
-
relatedAccountTokens
final PaymentTransactionUpdatedWebhookEvent.Builder relatedAccountTokens(JsonField<Payment.RelatedAccountTokens> relatedAccountTokens)
Sets Builder.relatedAccountTokens to an arbitrary JSON value.
You should usually call Builder.relatedAccountTokens with a well-typed Payment.RelatedAccountTokens value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
result
final PaymentTransactionUpdatedWebhookEvent.Builder result(Payment.TransactionResult result)
Transaction result
-
result
final PaymentTransactionUpdatedWebhookEvent.Builder result(JsonField<Payment.TransactionResult> result)
Sets Builder.result to an arbitrary JSON value.
You should usually call Builder.result with a well-typed Payment.TransactionResult value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
settledAmount
final PaymentTransactionUpdatedWebhookEvent.Builder settledAmount(Long settledAmount)
Settled amount in cents
-
settledAmount
final PaymentTransactionUpdatedWebhookEvent.Builder settledAmount(JsonField<Long> settledAmount)
Sets Builder.settledAmount to an arbitrary JSON value.
You should usually call Builder.settledAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
source
final PaymentTransactionUpdatedWebhookEvent.Builder source(Payment.Source source)
Transaction source
-
source
final PaymentTransactionUpdatedWebhookEvent.Builder source(JsonField<Payment.Source> source)
Sets Builder.source to an arbitrary JSON value.
You should usually call Builder.source with a well-typed Payment.Source value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final PaymentTransactionUpdatedWebhookEvent.Builder status(Payment.TransactionStatus status)
The status of the transaction
-
status
final PaymentTransactionUpdatedWebhookEvent.Builder status(JsonField<Payment.TransactionStatus> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Payment.TransactionStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updated
final PaymentTransactionUpdatedWebhookEvent.Builder updated(OffsetDateTime updated)
ISO 8601 timestamp of when the transaction was last updated
-
updated
final PaymentTransactionUpdatedWebhookEvent.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final PaymentTransactionUpdatedWebhookEvent.Builder currency(String currency)
Currency of the transaction in ISO 4217 format
-
currency
final PaymentTransactionUpdatedWebhookEvent.Builder currency(JsonField<String> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
expectedReleaseDate
final PaymentTransactionUpdatedWebhookEvent.Builder expectedReleaseDate(LocalDate expectedReleaseDate)
Expected release date for the transaction
-
expectedReleaseDate
final PaymentTransactionUpdatedWebhookEvent.Builder expectedReleaseDate(Optional<LocalDate> expectedReleaseDate)
Alias for calling Builder.expectedReleaseDate with
expectedReleaseDate.orElse(null).
-
expectedReleaseDate
final PaymentTransactionUpdatedWebhookEvent.Builder expectedReleaseDate(JsonField<LocalDate> expectedReleaseDate)
Sets Builder.expectedReleaseDate to an arbitrary JSON value.
You should usually call Builder.expectedReleaseDate with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
externalBankAccountToken
final PaymentTransactionUpdatedWebhookEvent.Builder externalBankAccountToken(String externalBankAccountToken)
External bank account token
-
externalBankAccountToken
final PaymentTransactionUpdatedWebhookEvent.Builder externalBankAccountToken(Optional<String> externalBankAccountToken)
Alias for calling Builder.externalBankAccountToken with
externalBankAccountToken.orElse(null).
-
externalBankAccountToken
final PaymentTransactionUpdatedWebhookEvent.Builder externalBankAccountToken(JsonField<String> externalBankAccountToken)
Sets Builder.externalBankAccountToken to an arbitrary JSON value.
You should usually call Builder.externalBankAccountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final PaymentTransactionUpdatedWebhookEvent.Builder type(Payment.TransferType type)
-
type
final PaymentTransactionUpdatedWebhookEvent.Builder type(JsonField<Payment.TransferType> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Payment.TransferType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
userDefinedId
final PaymentTransactionUpdatedWebhookEvent.Builder userDefinedId(String userDefinedId)
User-defined identifier
-
userDefinedId
final PaymentTransactionUpdatedWebhookEvent.Builder userDefinedId(Optional<String> userDefinedId)
Alias for calling Builder.userDefinedId with
userDefinedId.orElse(null).
-
userDefinedId
final PaymentTransactionUpdatedWebhookEvent.Builder userDefinedId(JsonField<String> userDefinedId)
Sets Builder.userDefinedId to an arbitrary JSON value.
You should usually call Builder.userDefinedId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final PaymentTransactionUpdatedWebhookEvent.Builder eventType(PaymentTransactionUpdatedWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final PaymentTransactionUpdatedWebhookEvent.Builder eventType(JsonField<PaymentTransactionUpdatedWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PaymentTransactionUpdatedWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PaymentTransactionUpdatedWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PaymentTransactionUpdatedWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PaymentTransactionUpdatedWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PaymentTransactionUpdatedWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PaymentTransactionUpdatedWebhookEvent build()
Returns an immutable instance of PaymentTransactionUpdatedWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .category() .created() .descriptor() .direction() .events() .family() .financialAccountToken() .method() .methodAttributes() .pendingAmount() .relatedAccountTokens() .result() .settledAmount() .source() .status() .updated() .eventType()
-
-
-
-