Package com.lithic.api.models
Class ReportStats.Example.Action.ResultAuthentication3dsAction
-
- All Implemented Interfaces:
public final class ReportStats.Example.Action.ResultAuthentication3dsAction
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classReportStats.Example.Action.ResultAuthentication3dsAction.BuilderA builder for ResultAuthentication3dsAction.
public final classReportStats.Example.Action.ResultAuthentication3dsAction.Authentication3dsAction
-
Method Summary
Modifier and Type Method Description final ReportStats.Example.Action.ResultAuthentication3dsAction.Authentication3dsActiontype()final JsonField<ReportStats.Example.Action.ResultAuthentication3dsAction.Authentication3dsAction>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final ReportStats.Example.Action.ResultAuthentication3dsAction.BuildertoBuilder()final ReportStats.Example.Action.ResultAuthentication3dsActionvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ReportStats.Example.Action.ResultAuthentication3dsAction.Builderbuilder()Returns a mutable builder for constructing an instance of ResultAuthentication3dsAction. -
-
Method Detail
-
_type
final JsonField<ReportStats.Example.Action.ResultAuthentication3dsAction.Authentication3dsAction> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ReportStats.Example.Action.ResultAuthentication3dsAction.Builder toBuilder()
-
validate
final ReportStats.Example.Action.ResultAuthentication3dsAction validate()
-
builder
final static ReportStats.Example.Action.ResultAuthentication3dsAction.Builder builder()
Returns a mutable builder for constructing an instance of ResultAuthentication3dsAction.
The following fields are required:
.type()
-
-
-
-