Class RequiredDocument
-
- All Implemented Interfaces:
public final class RequiredDocument
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRequiredDocument.BuilderA builder for RequiredDocument.
-
Method Summary
Modifier and Type Method Description final StringentityToken()Globally unique identifier for an entity. final List<String>statusReasons()Provides the status reasons that will be satisfied by providing one of the valid documents. final List<String>validDocuments()A list of valid documents that will satisfy the KYC requirements for the specified entity. final JsonField<String>_entityToken()Returns the raw JSON value of entityToken. final JsonField<List<String>>_statusReasons()Returns the raw JSON value of statusReasons. final JsonField<List<String>>_validDocuments()Returns the raw JSON value of validDocuments. final Map<String, JsonValue>_additionalProperties()final RequiredDocument.BuildertoBuilder()final RequiredDocumentvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RequiredDocument.Builderbuilder()Returns a mutable builder for constructing an instance of RequiredDocument. -
-
Method Detail
-
entityToken
final String entityToken()
Globally unique identifier for an entity.
-
statusReasons
final List<String> statusReasons()
Provides the status reasons that will be satisfied by providing one of the valid documents.
-
validDocuments
final List<String> validDocuments()
A list of valid documents that will satisfy the KYC requirements for the specified entity.
-
_entityToken
final JsonField<String> _entityToken()
Returns the raw JSON value of entityToken.
Unlike entityToken, this method doesn't throw if the JSON field has an unexpected type.
-
_statusReasons
final JsonField<List<String>> _statusReasons()
Returns the raw JSON value of statusReasons.
Unlike statusReasons, this method doesn't throw if the JSON field has an unexpected type.
-
_validDocuments
final JsonField<List<String>> _validDocuments()
Returns the raw JSON value of validDocuments.
Unlike validDocuments, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RequiredDocument.Builder toBuilder()
-
validate
final RequiredDocument validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RequiredDocument.Builder builder()
Returns a mutable builder for constructing an instance of RequiredDocument.
The following fields are required:
.entityToken() .statusReasons() .validDocuments()
-
-
-
-