Package com.lithic.api.models
Class RequiredDocument.Builder
-
- All Implemented Interfaces:
public final class RequiredDocument.BuilderA builder for RequiredDocument.
-
-
Method Summary
Modifier and Type Method Description final RequiredDocument.BuilderentityToken(String entityToken)Globally unique identifier for an entity. final RequiredDocument.BuilderentityToken(JsonField<String> entityToken)Globally unique identifier for an entity. final RequiredDocument.BuilderstatusReasons(List<String> statusReasons)rovides the status reasons that will be satisfied by providing one of the valid documents. final RequiredDocument.BuilderstatusReasons(JsonField<List<String>> statusReasons)rovides the status reasons that will be satisfied by providing one of the valid documents. final RequiredDocument.BuilderaddStatusReason(String statusReason)rovides the status reasons that will be satisfied by providing one of the valid documents. final RequiredDocument.BuildervalidDocuments(List<String> validDocuments)A list of valid documents that will satisfy the KYC requirements for the specified entity. final RequiredDocument.BuildervalidDocuments(JsonField<List<String>> validDocuments)A list of valid documents that will satisfy the KYC requirements for the specified entity. final RequiredDocument.BuilderaddValidDocument(String validDocument)A list of valid documents that will satisfy the KYC requirements for the specified entity. final RequiredDocument.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final RequiredDocument.BuilderputAdditionalProperty(String key, JsonValue value)final RequiredDocument.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final RequiredDocument.BuilderremoveAdditionalProperty(String key)final RequiredDocument.BuilderremoveAllAdditionalProperties(Set<String> keys)final RequiredDocumentbuild()-
-
Method Detail
-
entityToken
final RequiredDocument.Builder entityToken(String entityToken)
Globally unique identifier for an entity.
-
entityToken
final RequiredDocument.Builder entityToken(JsonField<String> entityToken)
Globally unique identifier for an entity.
-
statusReasons
final RequiredDocument.Builder statusReasons(List<String> statusReasons)
rovides the status reasons that will be satisfied by providing one of the valid documents.
-
statusReasons
final RequiredDocument.Builder statusReasons(JsonField<List<String>> statusReasons)
rovides the status reasons that will be satisfied by providing one of the valid documents.
-
addStatusReason
final RequiredDocument.Builder addStatusReason(String statusReason)
rovides the status reasons that will be satisfied by providing one of the valid documents.
-
validDocuments
final RequiredDocument.Builder validDocuments(List<String> validDocuments)
A list of valid documents that will satisfy the KYC requirements for the specified entity.
-
validDocuments
final RequiredDocument.Builder validDocuments(JsonField<List<String>> validDocuments)
A list of valid documents that will satisfy the KYC requirements for the specified entity.
-
addValidDocument
final RequiredDocument.Builder addValidDocument(String validDocument)
A list of valid documents that will satisfy the KYC requirements for the specified entity.
-
additionalProperties
final RequiredDocument.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RequiredDocument.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RequiredDocument.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RequiredDocument.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RequiredDocument.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RequiredDocument build()
-
-
-
-