Package com.lithic.api.models
Class ResponderEndpointCreateParams.Body
-
- All Implemented Interfaces:
public final class ResponderEndpointCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classResponderEndpointCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<ResponderEndpointCreateParams.Type>type()The type of the endpoint. final Optional<String>url()The URL for the responder endpoint (must be http(s)). final JsonField<ResponderEndpointCreateParams.Type>_type()Returns the raw JSON value of type. final JsonField<String>_url()Returns the raw JSON value of url. final Map<String, JsonValue>_additionalProperties()final ResponderEndpointCreateParams.Body.BuildertoBuilder()final ResponderEndpointCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ResponderEndpointCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
type
final Optional<ResponderEndpointCreateParams.Type> type()
The type of the endpoint.
-
_type
final JsonField<ResponderEndpointCreateParams.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ResponderEndpointCreateParams.Body.Builder toBuilder()
-
validate
final ResponderEndpointCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ResponderEndpointCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-