Class RuleFeature.TransactionHistorySignalsFeature
-
- All Implemented Interfaces:
public final class RuleFeature.TransactionHistorySignalsFeature
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRuleFeature.TransactionHistorySignalsFeature.BuilderA builder for TransactionHistorySignalsFeature.
public final classRuleFeature.TransactionHistorySignalsFeature.ScopeThe entity scope to load transaction history signals for.
public final classRuleFeature.TransactionHistorySignalsFeature.Type
-
Method Summary
-
-
Method Detail
-
scope
final RuleFeature.TransactionHistorySignalsFeature.Scope scope()
The entity scope to load transaction history signals for.
-
type
final RuleFeature.TransactionHistorySignalsFeature.Type type()
-
name
final Optional<String> name()
The variable name for this feature in the rule function signature
-
_scope
final JsonField<RuleFeature.TransactionHistorySignalsFeature.Scope> _scope()
Returns the raw JSON value of scope.
Unlike scope, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<RuleFeature.TransactionHistorySignalsFeature.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RuleFeature.TransactionHistorySignalsFeature.Builder toBuilder()
-
validate
final RuleFeature.TransactionHistorySignalsFeature validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RuleFeature.TransactionHistorySignalsFeature.Builder builder()
Returns a mutable builder for constructing an instance of TransactionHistorySignalsFeature.
The following fields are required:
.scope() .type()
-
-
-
-