Class RuleStats.Builder
-
- All Implemented Interfaces:
public final class RuleStats.BuilderA builder for RuleStats.
-
-
Method Summary
Modifier and Type Method Description final RuleStats.Builderapproved(Long approved)The total number of historical transactions approved by this rule during the relevant period, or the number of transactions that would have been approved if the rule was evaluated in shadow mode. final RuleStats.Builderapproved(JsonField<Long> approved)Sets Builder.approved to an arbitrary JSON value. final RuleStats.Builderchallenged(Long challenged)The total number of historical transactions challenged by this rule during the relevant period, or the number of transactions that would have been challenged if the rule was evaluated in shadow mode. final RuleStats.Builderchallenged(JsonField<Long> challenged)Sets Builder.challenged to an arbitrary JSON value. final RuleStats.Builderdeclined(Long declined)The total number of historical transactions declined by this rule during the relevant period, or the number of transactions that would have been declined if the rule was evaluated in shadow mode. final RuleStats.Builderdeclined(JsonField<Long> declined)Sets Builder.declined to an arbitrary JSON value. final RuleStats.Builderexamples(List<RuleStats.Example> examples)Example events and their outcomes. final RuleStats.Builderexamples(JsonField<List<RuleStats.Example>> examples)Sets Builder.examples to an arbitrary JSON value. final RuleStats.BuilderaddExample(RuleStats.Example example)Adds a single Example to examples. final RuleStats.Builderversion(Long version)The version of the rule, this is incremented whenever the rule's parameters change. final RuleStats.Builderversion(JsonField<Long> version)Sets Builder.version to an arbitrary JSON value. final RuleStats.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final RuleStats.BuilderputAdditionalProperty(String key, JsonValue value)final RuleStats.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final RuleStats.BuilderremoveAdditionalProperty(String key)final RuleStats.BuilderremoveAllAdditionalProperties(Set<String> keys)final RuleStatsbuild()Returns an immutable instance of RuleStats. -
-
Method Detail
-
approved
final RuleStats.Builder approved(Long approved)
The total number of historical transactions approved by this rule during the relevant period, or the number of transactions that would have been approved if the rule was evaluated in shadow mode.
-
approved
final RuleStats.Builder approved(JsonField<Long> approved)
Sets Builder.approved to an arbitrary JSON value.
You should usually call Builder.approved with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
challenged
final RuleStats.Builder challenged(Long challenged)
The total number of historical transactions challenged by this rule during the relevant period, or the number of transactions that would have been challenged if the rule was evaluated in shadow mode. Currently applicable only for 3DS Auth Rules.
-
challenged
final RuleStats.Builder challenged(JsonField<Long> challenged)
Sets Builder.challenged to an arbitrary JSON value.
You should usually call Builder.challenged with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
declined
final RuleStats.Builder declined(Long declined)
The total number of historical transactions declined by this rule during the relevant period, or the number of transactions that would have been declined if the rule was evaluated in shadow mode.
-
declined
final RuleStats.Builder declined(JsonField<Long> declined)
Sets Builder.declined to an arbitrary JSON value.
You should usually call Builder.declined with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
examples
final RuleStats.Builder examples(List<RuleStats.Example> examples)
Example events and their outcomes.
-
examples
final RuleStats.Builder examples(JsonField<List<RuleStats.Example>> examples)
Sets Builder.examples to an arbitrary JSON value.
You should usually call Builder.examples with a well-typed
List<Example>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addExample
final RuleStats.Builder addExample(RuleStats.Example example)
-
version
final RuleStats.Builder version(Long version)
The version of the rule, this is incremented whenever the rule's parameters change.
-
version
final RuleStats.Builder version(JsonField<Long> version)
Sets Builder.version to an arbitrary JSON value.
You should usually call Builder.version with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RuleStats.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RuleStats.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RuleStats.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RuleStats.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RuleStats.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-