Class ShippingAddress
-
- All Implemented Interfaces:
public final class ShippingAddress
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classShippingAddress.BuilderA builder for ShippingAddress.
-
Method Summary
Modifier and Type Method Description final Stringaddress1()Valid USPS routable address. final Stringcity()City final Stringcountry()Uppercase ISO 3166-1 alpha-3 three character abbreviation. final StringfirstName()Customer's first name. final StringlastName()Customer's surname (family name). final StringpostalCode()Postal code (formerly zipcode). final Stringstate()Uppercase ISO 3166-2 two character abbreviation for US and CA. final Optional<String>address2()Unit number (if applicable). final Optional<String>email()Email address to be contacted for expedited shipping process purposes. final Optional<String>line2Text()Text to be printed on line two of the physical card. final Optional<String>phoneNumber()Cardholder's phone number in E.164 format to be contacted for expedited shipping process purposes. final JsonField<String>_address1()Returns the raw JSON value of address1. final JsonField<String>_city()Returns the raw JSON value of city. final JsonField<String>_country()Returns the raw JSON value of country. final JsonField<String>_firstName()Returns the raw JSON value of firstName. final JsonField<String>_lastName()Returns the raw JSON value of lastName. final JsonField<String>_postalCode()Returns the raw JSON value of postalCode. final JsonField<String>_state()Returns the raw JSON value of state. final JsonField<String>_address2()Returns the raw JSON value of address2. final JsonField<String>_email()Returns the raw JSON value of email. final JsonField<String>_line2Text()Returns the raw JSON value of line2Text. final JsonField<String>_phoneNumber()Returns the raw JSON value of phoneNumber. final Map<String, JsonValue>_additionalProperties()final ShippingAddress.BuildertoBuilder()final ShippingAddressvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ShippingAddress.Builderbuilder()Returns a mutable builder for constructing an instance of ShippingAddress. -
-
Method Detail
-
firstName
final String firstName()
Customer's first name. This will be the first name printed on the physical card. The combined length of
first_nameandlast_namemay not exceed 25 characters.
-
lastName
final String lastName()
Customer's surname (family name). This will be the last name printed on the physical card. The combined length of
first_nameandlast_namemay not exceed 25 characters.
-
postalCode
final String postalCode()
Postal code (formerly zipcode). For US addresses, either five-digit postal code or nine-digit postal code (ZIP+4) using the format 12345-1234.
-
state
final String state()
Uppercase ISO 3166-2 two character abbreviation for US and CA. Optional with a limit of 24 characters for other countries.
-
email
final Optional<String> email()
Email address to be contacted for expedited shipping process purposes. Required if
shipping_methodisEXPEDITED.
-
line2Text
final Optional<String> line2Text()
Text to be printed on line two of the physical card. Use of this field requires additional permissions.
-
phoneNumber
final Optional<String> phoneNumber()
Cardholder's phone number in E.164 format to be contacted for expedited shipping process purposes. Required if
shipping_methodisEXPEDITED.
-
_address1
final JsonField<String> _address1()
Returns the raw JSON value of address1.
Unlike address1, this method doesn't throw if the JSON field has an unexpected type.
-
_city
final JsonField<String> _city()
Returns the raw JSON value of city.
Unlike city, this method doesn't throw if the JSON field has an unexpected type.
-
_country
final JsonField<String> _country()
Returns the raw JSON value of country.
Unlike country, this method doesn't throw if the JSON field has an unexpected type.
-
_firstName
final JsonField<String> _firstName()
Returns the raw JSON value of firstName.
Unlike firstName, this method doesn't throw if the JSON field has an unexpected type.
-
_lastName
final JsonField<String> _lastName()
Returns the raw JSON value of lastName.
Unlike lastName, this method doesn't throw if the JSON field has an unexpected type.
-
_postalCode
final JsonField<String> _postalCode()
Returns the raw JSON value of postalCode.
Unlike postalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<String> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_address2
final JsonField<String> _address2()
Returns the raw JSON value of address2.
Unlike address2, this method doesn't throw if the JSON field has an unexpected type.
-
_email
final JsonField<String> _email()
Returns the raw JSON value of email.
Unlike email, this method doesn't throw if the JSON field has an unexpected type.
-
_line2Text
final JsonField<String> _line2Text()
Returns the raw JSON value of line2Text.
Unlike line2Text, this method doesn't throw if the JSON field has an unexpected type.
-
_phoneNumber
final JsonField<String> _phoneNumber()
Returns the raw JSON value of phoneNumber.
Unlike phoneNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ShippingAddress.Builder toBuilder()
-
validate
final ShippingAddress validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ShippingAddress.Builder builder()
Returns a mutable builder for constructing an instance of ShippingAddress.
The following fields are required:
.address1() .city() .country() .firstName() .lastName() .postalCode() .state()
-
-
-
-