Class ShippingAddress.Builder
-
- All Implemented Interfaces:
public final class ShippingAddress.BuilderA builder for ShippingAddress.
-
-
Method Summary
Modifier and Type Method Description final ShippingAddress.Builderaddress1(String address1)Valid USPS routable address. final ShippingAddress.Builderaddress1(JsonField<String> address1)Sets Builder.address1 to an arbitrary JSON value. final ShippingAddress.Buildercity(String city)City final ShippingAddress.Buildercity(JsonField<String> city)Sets Builder.city to an arbitrary JSON value. final ShippingAddress.Buildercountry(String country)Uppercase ISO 3166-1 alpha-3 three character abbreviation. final ShippingAddress.Buildercountry(JsonField<String> country)Sets Builder.country to an arbitrary JSON value. final ShippingAddress.BuilderfirstName(String firstName)Customer's first name. final ShippingAddress.BuilderfirstName(JsonField<String> firstName)Sets Builder.firstName to an arbitrary JSON value. final ShippingAddress.BuilderlastName(String lastName)Customer's surname (family name). final ShippingAddress.BuilderlastName(JsonField<String> lastName)Sets Builder.lastName to an arbitrary JSON value. final ShippingAddress.BuilderpostalCode(String postalCode)Postal code (formerly zipcode). final ShippingAddress.BuilderpostalCode(JsonField<String> postalCode)Sets Builder.postalCode to an arbitrary JSON value. final ShippingAddress.Builderstate(String state)Uppercase ISO 3166-2 two character abbreviation for US and CA. final ShippingAddress.Builderstate(JsonField<String> state)Sets Builder.state to an arbitrary JSON value. final ShippingAddress.Builderaddress2(String address2)Unit number (if applicable). final ShippingAddress.Builderaddress2(JsonField<String> address2)Sets Builder.address2 to an arbitrary JSON value. final ShippingAddress.Builderemail(String email)Email address to be contacted for expedited shipping process purposes. final ShippingAddress.Builderemail(JsonField<String> email)Sets Builder.email to an arbitrary JSON value. final ShippingAddress.Builderline2Text(String line2Text)Text to be printed on line two of the physical card. final ShippingAddress.Builderline2Text(JsonField<String> line2Text)Sets Builder.line2Text to an arbitrary JSON value. final ShippingAddress.BuilderphoneNumber(String phoneNumber)Cardholder's phone number in E.164 format to be contacted for expedited shipping process purposes. final ShippingAddress.BuilderphoneNumber(JsonField<String> phoneNumber)Sets Builder.phoneNumber to an arbitrary JSON value. final ShippingAddress.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final ShippingAddress.BuilderputAdditionalProperty(String key, JsonValue value)final ShippingAddress.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final ShippingAddress.BuilderremoveAdditionalProperty(String key)final ShippingAddress.BuilderremoveAllAdditionalProperties(Set<String> keys)final ShippingAddressbuild()Returns an immutable instance of ShippingAddress. -
-
Method Detail
-
address1
final ShippingAddress.Builder address1(String address1)
Valid USPS routable address.
-
address1
final ShippingAddress.Builder address1(JsonField<String> address1)
Sets Builder.address1 to an arbitrary JSON value.
You should usually call Builder.address1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
city
final ShippingAddress.Builder city(String city)
City
-
city
final ShippingAddress.Builder city(JsonField<String> city)
Sets Builder.city to an arbitrary JSON value.
You should usually call Builder.city with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
country
final ShippingAddress.Builder country(String country)
Uppercase ISO 3166-1 alpha-3 three character abbreviation.
-
country
final ShippingAddress.Builder country(JsonField<String> country)
Sets Builder.country to an arbitrary JSON value.
You should usually call Builder.country with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
firstName
final ShippingAddress.Builder firstName(String firstName)
Customer's first name. This will be the first name printed on the physical card. The combined length of
first_nameandlast_namemay not exceed 25 characters.
-
firstName
final ShippingAddress.Builder firstName(JsonField<String> firstName)
Sets Builder.firstName to an arbitrary JSON value.
You should usually call Builder.firstName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastName
final ShippingAddress.Builder lastName(String lastName)
Customer's surname (family name). This will be the last name printed on the physical card. The combined length of
first_nameandlast_namemay not exceed 25 characters.
-
lastName
final ShippingAddress.Builder lastName(JsonField<String> lastName)
Sets Builder.lastName to an arbitrary JSON value.
You should usually call Builder.lastName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
postalCode
final ShippingAddress.Builder postalCode(String postalCode)
Postal code (formerly zipcode). For US addresses, either five-digit postal code or nine-digit postal code (ZIP+4) using the format 12345-1234.
-
postalCode
final ShippingAddress.Builder postalCode(JsonField<String> postalCode)
Sets Builder.postalCode to an arbitrary JSON value.
You should usually call Builder.postalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
state
final ShippingAddress.Builder state(String state)
Uppercase ISO 3166-2 two character abbreviation for US and CA. Optional with a limit of 24 characters for other countries.
-
state
final ShippingAddress.Builder state(JsonField<String> state)
Sets Builder.state to an arbitrary JSON value.
You should usually call Builder.state with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
address2
final ShippingAddress.Builder address2(String address2)
Unit number (if applicable).
-
address2
final ShippingAddress.Builder address2(JsonField<String> address2)
Sets Builder.address2 to an arbitrary JSON value.
You should usually call Builder.address2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
email
final ShippingAddress.Builder email(String email)
Email address to be contacted for expedited shipping process purposes. Required if
shipping_methodisEXPEDITED.
-
email
final ShippingAddress.Builder email(JsonField<String> email)
Sets Builder.email to an arbitrary JSON value.
You should usually call Builder.email with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
line2Text
final ShippingAddress.Builder line2Text(String line2Text)
Text to be printed on line two of the physical card. Use of this field requires additional permissions.
-
line2Text
final ShippingAddress.Builder line2Text(JsonField<String> line2Text)
Sets Builder.line2Text to an arbitrary JSON value.
You should usually call Builder.line2Text with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
phoneNumber
final ShippingAddress.Builder phoneNumber(String phoneNumber)
Cardholder's phone number in E.164 format to be contacted for expedited shipping process purposes. Required if
shipping_methodisEXPEDITED.
-
phoneNumber
final ShippingAddress.Builder phoneNumber(JsonField<String> phoneNumber)
Sets Builder.phoneNumber to an arbitrary JSON value.
You should usually call Builder.phoneNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ShippingAddress.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ShippingAddress.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ShippingAddress.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ShippingAddress.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ShippingAddress.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ShippingAddress build()
Returns an immutable instance of ShippingAddress.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.address1() .city() .country() .firstName() .lastName() .postalCode() .state()
-
-
-
-