Class Statement
-
- All Implemented Interfaces:
public final class Statement
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStatement.BuilderA builder for Statement.
public final classStatement.AccountStandingpublic final classStatement.AmountDuepublic final classStatement.StatementTotalspublic final classStatement.StatementTypepublic final classStatement.InterestDetails
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier for a statement final Statement.AccountStandingaccountStanding()final Statement.AmountDueamountDue()final LongavailableCredit()Amount of credit available to spend in cents final OffsetDateTimecreated()Timestamp of when the statement was created final LongcreditLimit()This is the maximum credit balance extended by the lender in cents final StringcreditProductToken()Globally unique identifier for a credit product final LongdaysInBillingCycle()Number of days in the billing cycle final LongendingBalance()Balance at the end of the billing period. final StringfinancialAccountToken()Globally unique identifier for a financial account final LocalDatepaymentDueDate()Date when the payment is due final Statement.StatementTotalsperiodTotals()final LongstartingBalance()Balance at the start of the billing period final LocalDatestatementEndDate()Date when the billing period ended final LocalDatestatementStartDate()Date when the billing period began final Statement.StatementTypestatementType()final OffsetDateTimeupdated()Timestamp of when the statement was updated final Statement.StatementTotalsytdTotals()final Optional<Statement.InterestDetails>interestDetails()final Optional<LocalDate>nextPaymentDueDate()Date when the next payment is due final Optional<LocalDate>nextStatementEndDate()Date when the next billing period will end final JsonField<String>_token()Globally unique identifier for a statement final JsonField<Statement.AccountStanding>_accountStanding()final JsonField<Statement.AmountDue>_amountDue()final JsonField<Long>_availableCredit()Amount of credit available to spend in cents final JsonField<OffsetDateTime>_created()Timestamp of when the statement was created final JsonField<Long>_creditLimit()This is the maximum credit balance extended by the lender in cents final JsonField<String>_creditProductToken()Globally unique identifier for a credit product final JsonField<Long>_daysInBillingCycle()Number of days in the billing cycle final JsonField<Long>_endingBalance()Balance at the end of the billing period. final JsonField<String>_financialAccountToken()Globally unique identifier for a financial account final JsonField<LocalDate>_paymentDueDate()Date when the payment is due final JsonField<Statement.StatementTotals>_periodTotals()final JsonField<Long>_startingBalance()Balance at the start of the billing period final JsonField<LocalDate>_statementEndDate()Date when the billing period ended final JsonField<LocalDate>_statementStartDate()Date when the billing period began final JsonField<Statement.StatementType>_statementType()final JsonField<OffsetDateTime>_updated()Timestamp of when the statement was updated final JsonField<Statement.StatementTotals>_ytdTotals()final JsonField<Statement.InterestDetails>_interestDetails()final JsonField<LocalDate>_nextPaymentDueDate()Date when the next payment is due final JsonField<LocalDate>_nextStatementEndDate()Date when the next billing period will end final Map<String, JsonValue>_additionalProperties()final Statementvalidate()final Statement.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Statement.Builderbuilder()Returns a mutable builder for constructing an instance of Statement. -
-
Method Detail
-
accountStanding
final Statement.AccountStanding accountStanding()
-
amountDue
final Statement.AmountDue amountDue()
-
availableCredit
final Long availableCredit()
Amount of credit available to spend in cents
-
created
final OffsetDateTime created()
Timestamp of when the statement was created
-
creditLimit
final Long creditLimit()
This is the maximum credit balance extended by the lender in cents
-
creditProductToken
final String creditProductToken()
Globally unique identifier for a credit product
-
daysInBillingCycle
final Long daysInBillingCycle()
Number of days in the billing cycle
-
endingBalance
final Long endingBalance()
Balance at the end of the billing period. For charge cards, this should be the same at the statement amount due in cents
-
financialAccountToken
final String financialAccountToken()
Globally unique identifier for a financial account
-
paymentDueDate
final LocalDate paymentDueDate()
Date when the payment is due
-
periodTotals
final Statement.StatementTotals periodTotals()
-
startingBalance
final Long startingBalance()
Balance at the start of the billing period
-
statementEndDate
final LocalDate statementEndDate()
Date when the billing period ended
-
statementStartDate
final LocalDate statementStartDate()
Date when the billing period began
-
statementType
final Statement.StatementType statementType()
-
updated
final OffsetDateTime updated()
Timestamp of when the statement was updated
-
ytdTotals
final Statement.StatementTotals ytdTotals()
-
interestDetails
final Optional<Statement.InterestDetails> interestDetails()
-
nextPaymentDueDate
final Optional<LocalDate> nextPaymentDueDate()
Date when the next payment is due
-
nextStatementEndDate
final Optional<LocalDate> nextStatementEndDate()
Date when the next billing period will end
-
_accountStanding
final JsonField<Statement.AccountStanding> _accountStanding()
-
_amountDue
final JsonField<Statement.AmountDue> _amountDue()
-
_availableCredit
final JsonField<Long> _availableCredit()
Amount of credit available to spend in cents
-
_created
final JsonField<OffsetDateTime> _created()
Timestamp of when the statement was created
-
_creditLimit
final JsonField<Long> _creditLimit()
This is the maximum credit balance extended by the lender in cents
-
_creditProductToken
final JsonField<String> _creditProductToken()
Globally unique identifier for a credit product
-
_daysInBillingCycle
final JsonField<Long> _daysInBillingCycle()
Number of days in the billing cycle
-
_endingBalance
final JsonField<Long> _endingBalance()
Balance at the end of the billing period. For charge cards, this should be the same at the statement amount due in cents
-
_financialAccountToken
final JsonField<String> _financialAccountToken()
Globally unique identifier for a financial account
-
_paymentDueDate
final JsonField<LocalDate> _paymentDueDate()
Date when the payment is due
-
_periodTotals
final JsonField<Statement.StatementTotals> _periodTotals()
-
_startingBalance
final JsonField<Long> _startingBalance()
Balance at the start of the billing period
-
_statementEndDate
final JsonField<LocalDate> _statementEndDate()
Date when the billing period ended
-
_statementStartDate
final JsonField<LocalDate> _statementStartDate()
Date when the billing period began
-
_statementType
final JsonField<Statement.StatementType> _statementType()
-
_updated
final JsonField<OffsetDateTime> _updated()
Timestamp of when the statement was updated
-
_ytdTotals
final JsonField<Statement.StatementTotals> _ytdTotals()
-
_interestDetails
final JsonField<Statement.InterestDetails> _interestDetails()
-
_nextPaymentDueDate
final JsonField<LocalDate> _nextPaymentDueDate()
Date when the next payment is due
-
_nextStatementEndDate
final JsonField<LocalDate> _nextStatementEndDate()
Date when the next billing period will end
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Statement.Builder toBuilder()
-
builder
final static Statement.Builder builder()
Returns a mutable builder for constructing an instance of Statement.
The following fields are required:
.token() .accountStanding() .amountDue() .availableCredit() .created() .creditLimit() .creditProductToken() .daysInBillingCycle() .endingBalance() .financialAccountToken() .paymentDueDate() .periodTotals() .startingBalance() .statementEndDate() .statementStartDate() .statementType() .updated() .ytdTotals()
-
-
-
-