Package com.lithic.api.models
Class Statement.AccountStanding
-
- All Implemented Interfaces:
public final class Statement.AccountStanding
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStatement.AccountStanding.BuilderA builder for AccountStanding.
public final classStatement.AccountStanding.PeriodState
-
Method Summary
Modifier and Type Method Description final LongconsecutiveFullPaymentsMade()Number of consecutive full payments made final LongconsecutiveMinimumPaymentsMade()Number of consecutive minimum payments made final LongconsecutiveMinimumPaymentsMissed()Number of consecutive minimum payments missed final LongdaysPastDue()Number of days past due final BooleanhasGrace()Whether the account currently has grace or not final LongperiodNumber()Current overall period number final Statement.AccountStanding.PeriodStateperiodState()final JsonField<Long>_consecutiveFullPaymentsMade()Number of consecutive full payments made final JsonField<Long>_consecutiveMinimumPaymentsMade()Number of consecutive minimum payments made final JsonField<Long>_consecutiveMinimumPaymentsMissed()Number of consecutive minimum payments missed final JsonField<Long>_daysPastDue()Number of days past due final JsonField<Boolean>_hasGrace()Whether the account currently has grace or not final JsonField<Long>_periodNumber()Current overall period number final JsonField<Statement.AccountStanding.PeriodState>_periodState()final Map<String, JsonValue>_additionalProperties()final Statement.AccountStandingvalidate()final Statement.AccountStanding.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Statement.AccountStanding.Builderbuilder()Returns a mutable builder for constructing an instance of AccountStanding. -
-
Method Detail
-
consecutiveFullPaymentsMade
final Long consecutiveFullPaymentsMade()
Number of consecutive full payments made
-
consecutiveMinimumPaymentsMade
final Long consecutiveMinimumPaymentsMade()
Number of consecutive minimum payments made
-
consecutiveMinimumPaymentsMissed
final Long consecutiveMinimumPaymentsMissed()
Number of consecutive minimum payments missed
-
daysPastDue
final Long daysPastDue()
Number of days past due
-
periodNumber
final Long periodNumber()
Current overall period number
-
periodState
final Statement.AccountStanding.PeriodState periodState()
-
_consecutiveFullPaymentsMade
final JsonField<Long> _consecutiveFullPaymentsMade()
Number of consecutive full payments made
-
_consecutiveMinimumPaymentsMade
final JsonField<Long> _consecutiveMinimumPaymentsMade()
Number of consecutive minimum payments made
-
_consecutiveMinimumPaymentsMissed
final JsonField<Long> _consecutiveMinimumPaymentsMissed()
Number of consecutive minimum payments missed
-
_daysPastDue
final JsonField<Long> _daysPastDue()
Number of days past due
-
_periodNumber
final JsonField<Long> _periodNumber()
Current overall period number
-
_periodState
final JsonField<Statement.AccountStanding.PeriodState> _periodState()
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Statement.AccountStanding validate()
-
toBuilder
final Statement.AccountStanding.Builder toBuilder()
-
builder
final static Statement.AccountStanding.Builder builder()
Returns a mutable builder for constructing an instance of AccountStanding.
The following fields are required:
.consecutiveFullPaymentsMade() .consecutiveMinimumPaymentsMade() .consecutiveMinimumPaymentsMissed() .daysPastDue() .hasGrace() .periodNumber() .periodState()
-
-
-
-