Class Statement.AccountStanding.FinancialAccountState.Builder
-
- All Implemented Interfaces:
public final class Statement.AccountStanding.FinancialAccountState.BuilderA builder for FinancialAccountState.
-
-
Method Summary
-
-
Method Detail
-
status
final Statement.AccountStanding.FinancialAccountState.Builder status(Statement.AccountStanding.FinancialAccountState.FinancialAccountStatus status)
Status of the financial account
-
status
final Statement.AccountStanding.FinancialAccountState.Builder status(JsonField<Statement.AccountStanding.FinancialAccountState.FinancialAccountStatus> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed FinancialAccountStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
substatus
final Statement.AccountStanding.FinancialAccountState.Builder substatus(Statement.AccountStanding.FinancialAccountState.FinancialAccountSubstatus substatus)
Substatus for the financial account
-
substatus
final Statement.AccountStanding.FinancialAccountState.Builder substatus(Optional<Statement.AccountStanding.FinancialAccountState.FinancialAccountSubstatus> substatus)
Alias for calling Builder.substatus with
substatus.orElse(null).
-
substatus
final Statement.AccountStanding.FinancialAccountState.Builder substatus(JsonField<Statement.AccountStanding.FinancialAccountState.FinancialAccountSubstatus> substatus)
Sets Builder.substatus to an arbitrary JSON value.
You should usually call Builder.substatus with a well-typed FinancialAccountSubstatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Statement.AccountStanding.FinancialAccountState.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Statement.AccountStanding.FinancialAccountState.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Statement.AccountStanding.FinancialAccountState.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Statement.AccountStanding.FinancialAccountState.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Statement.AccountStanding.FinancialAccountState.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Statement.AccountStanding.FinancialAccountState build()
Returns an immutable instance of FinancialAccountState.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.status()
-
-
-
-