Class Statement.Builder
-
- All Implemented Interfaces:
public final class Statement.BuilderA builder for Statement.
-
-
Method Summary
Modifier and Type Method Description final Statement.Buildertoken(String token)Globally unique identifier for a statement final Statement.Buildertoken(JsonField<String> token)Globally unique identifier for a statement final Statement.BuilderaccountStanding(Statement.AccountStanding accountStanding)final Statement.BuilderaccountStanding(JsonField<Statement.AccountStanding> accountStanding)final Statement.BuilderamountDue(Statement.AmountDue amountDue)final Statement.BuilderamountDue(JsonField<Statement.AmountDue> amountDue)final Statement.BuilderavailableCredit(Long availableCredit)Amount of credit available to spend in cents final Statement.BuilderavailableCredit(JsonField<Long> availableCredit)Amount of credit available to spend in cents final Statement.Buildercreated(OffsetDateTime created)Timestamp of when the statement was created final Statement.Buildercreated(JsonField<OffsetDateTime> created)Timestamp of when the statement was created final Statement.BuildercreditLimit(Long creditLimit)This is the maximum credit balance extended by the lender in cents final Statement.BuildercreditLimit(JsonField<Long> creditLimit)This is the maximum credit balance extended by the lender in cents final Statement.BuildercreditProductToken(String creditProductToken)Globally unique identifier for a credit product final Statement.BuildercreditProductToken(JsonField<String> creditProductToken)Globally unique identifier for a credit product final Statement.BuilderdaysInBillingCycle(Long daysInBillingCycle)Number of days in the billing cycle final Statement.BuilderdaysInBillingCycle(JsonField<Long> daysInBillingCycle)Number of days in the billing cycle final Statement.BuilderendingBalance(Long endingBalance)Balance at the end of the billing period. final Statement.BuilderendingBalance(JsonField<Long> endingBalance)Balance at the end of the billing period. final Statement.BuilderfinancialAccountToken(String financialAccountToken)Globally unique identifier for a financial account final Statement.BuilderfinancialAccountToken(JsonField<String> financialAccountToken)Globally unique identifier for a financial account final Statement.BuilderpaymentDueDate(LocalDate paymentDueDate)Date when the payment is due final Statement.BuilderpaymentDueDate(JsonField<LocalDate> paymentDueDate)Date when the payment is due final Statement.BuilderperiodTotals(Statement.StatementTotals periodTotals)final Statement.BuilderperiodTotals(JsonField<Statement.StatementTotals> periodTotals)final Statement.BuilderstartingBalance(Long startingBalance)Balance at the start of the billing period final Statement.BuilderstartingBalance(JsonField<Long> startingBalance)Balance at the start of the billing period final Statement.BuilderstatementEndDate(LocalDate statementEndDate)Date when the billing period ended final Statement.BuilderstatementEndDate(JsonField<LocalDate> statementEndDate)Date when the billing period ended final Statement.BuilderstatementStartDate(LocalDate statementStartDate)Date when the billing period began final Statement.BuilderstatementStartDate(JsonField<LocalDate> statementStartDate)Date when the billing period began final Statement.BuilderstatementType(Statement.StatementType statementType)final Statement.BuilderstatementType(JsonField<Statement.StatementType> statementType)final Statement.Builderupdated(OffsetDateTime updated)Timestamp of when the statement was updated final Statement.Builderupdated(JsonField<OffsetDateTime> updated)Timestamp of when the statement was updated final Statement.BuilderytdTotals(Statement.StatementTotals ytdTotals)final Statement.BuilderytdTotals(JsonField<Statement.StatementTotals> ytdTotals)final Statement.BuilderinterestDetails(Statement.InterestDetails interestDetails)final Statement.BuilderinterestDetails(Optional<Statement.InterestDetails> interestDetails)final Statement.BuilderinterestDetails(JsonField<Statement.InterestDetails> interestDetails)final Statement.BuildernextPaymentDueDate(LocalDate nextPaymentDueDate)Date when the next payment is due final Statement.BuildernextPaymentDueDate(JsonField<LocalDate> nextPaymentDueDate)Date when the next payment is due final Statement.BuildernextStatementEndDate(LocalDate nextStatementEndDate)Date when the next billing period will end final Statement.BuildernextStatementEndDate(JsonField<LocalDate> nextStatementEndDate)Date when the next billing period will end final Statement.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Statement.BuilderputAdditionalProperty(String key, JsonValue value)final Statement.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Statement.BuilderremoveAdditionalProperty(String key)final Statement.BuilderremoveAllAdditionalProperties(Set<String> keys)final Statementbuild()-
-
Method Detail
-
token
final Statement.Builder token(String token)
Globally unique identifier for a statement
-
token
final Statement.Builder token(JsonField<String> token)
Globally unique identifier for a statement
-
accountStanding
final Statement.Builder accountStanding(Statement.AccountStanding accountStanding)
-
accountStanding
final Statement.Builder accountStanding(JsonField<Statement.AccountStanding> accountStanding)
-
amountDue
final Statement.Builder amountDue(Statement.AmountDue amountDue)
-
amountDue
final Statement.Builder amountDue(JsonField<Statement.AmountDue> amountDue)
-
availableCredit
final Statement.Builder availableCredit(Long availableCredit)
Amount of credit available to spend in cents
-
availableCredit
final Statement.Builder availableCredit(JsonField<Long> availableCredit)
Amount of credit available to spend in cents
-
created
final Statement.Builder created(OffsetDateTime created)
Timestamp of when the statement was created
-
created
final Statement.Builder created(JsonField<OffsetDateTime> created)
Timestamp of when the statement was created
-
creditLimit
final Statement.Builder creditLimit(Long creditLimit)
This is the maximum credit balance extended by the lender in cents
-
creditLimit
final Statement.Builder creditLimit(JsonField<Long> creditLimit)
This is the maximum credit balance extended by the lender in cents
-
creditProductToken
final Statement.Builder creditProductToken(String creditProductToken)
Globally unique identifier for a credit product
-
creditProductToken
final Statement.Builder creditProductToken(JsonField<String> creditProductToken)
Globally unique identifier for a credit product
-
daysInBillingCycle
final Statement.Builder daysInBillingCycle(Long daysInBillingCycle)
Number of days in the billing cycle
-
daysInBillingCycle
final Statement.Builder daysInBillingCycle(JsonField<Long> daysInBillingCycle)
Number of days in the billing cycle
-
endingBalance
final Statement.Builder endingBalance(Long endingBalance)
Balance at the end of the billing period. For charge cards, this should be the same at the statement amount due in cents
-
endingBalance
final Statement.Builder endingBalance(JsonField<Long> endingBalance)
Balance at the end of the billing period. For charge cards, this should be the same at the statement amount due in cents
-
financialAccountToken
final Statement.Builder financialAccountToken(String financialAccountToken)
Globally unique identifier for a financial account
-
financialAccountToken
final Statement.Builder financialAccountToken(JsonField<String> financialAccountToken)
Globally unique identifier for a financial account
-
paymentDueDate
final Statement.Builder paymentDueDate(LocalDate paymentDueDate)
Date when the payment is due
-
paymentDueDate
final Statement.Builder paymentDueDate(JsonField<LocalDate> paymentDueDate)
Date when the payment is due
-
periodTotals
final Statement.Builder periodTotals(Statement.StatementTotals periodTotals)
-
periodTotals
final Statement.Builder periodTotals(JsonField<Statement.StatementTotals> periodTotals)
-
startingBalance
final Statement.Builder startingBalance(Long startingBalance)
Balance at the start of the billing period
-
startingBalance
final Statement.Builder startingBalance(JsonField<Long> startingBalance)
Balance at the start of the billing period
-
statementEndDate
final Statement.Builder statementEndDate(LocalDate statementEndDate)
Date when the billing period ended
-
statementEndDate
final Statement.Builder statementEndDate(JsonField<LocalDate> statementEndDate)
Date when the billing period ended
-
statementStartDate
final Statement.Builder statementStartDate(LocalDate statementStartDate)
Date when the billing period began
-
statementStartDate
final Statement.Builder statementStartDate(JsonField<LocalDate> statementStartDate)
Date when the billing period began
-
statementType
final Statement.Builder statementType(Statement.StatementType statementType)
-
statementType
final Statement.Builder statementType(JsonField<Statement.StatementType> statementType)
-
updated
final Statement.Builder updated(OffsetDateTime updated)
Timestamp of when the statement was updated
-
updated
final Statement.Builder updated(JsonField<OffsetDateTime> updated)
Timestamp of when the statement was updated
-
ytdTotals
final Statement.Builder ytdTotals(Statement.StatementTotals ytdTotals)
-
ytdTotals
final Statement.Builder ytdTotals(JsonField<Statement.StatementTotals> ytdTotals)
-
interestDetails
final Statement.Builder interestDetails(Statement.InterestDetails interestDetails)
-
interestDetails
final Statement.Builder interestDetails(Optional<Statement.InterestDetails> interestDetails)
-
interestDetails
final Statement.Builder interestDetails(JsonField<Statement.InterestDetails> interestDetails)
-
nextPaymentDueDate
final Statement.Builder nextPaymentDueDate(LocalDate nextPaymentDueDate)
Date when the next payment is due
-
nextPaymentDueDate
final Statement.Builder nextPaymentDueDate(JsonField<LocalDate> nextPaymentDueDate)
Date when the next payment is due
-
nextStatementEndDate
final Statement.Builder nextStatementEndDate(LocalDate nextStatementEndDate)
Date when the next billing period will end
-
nextStatementEndDate
final Statement.Builder nextStatementEndDate(JsonField<LocalDate> nextStatementEndDate)
Date when the next billing period will end
-
additionalProperties
final Statement.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Statement.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Statement.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Statement.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Statement.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-