Class Statement.StatementTotals
-
- All Implemented Interfaces:
public final class Statement.StatementTotals
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStatement.StatementTotals.BuilderA builder for StatementTotals.
-
Method Summary
Modifier and Type Method Description final LongbalanceTransfers()Opening balance transferred from previous account in cents final LongcashAdvances()ATM and cashback transactions in cents final Longcredits()Volume of credit management operation transactions less any balance transfers in cents final Longfees()Volume of debit management operation transactions less any interest in cents final Longinterest()Interest accrued in cents final Longpayments()Any funds transfers which affective the balance in cents final Longpurchases()Net card transaction volume less any cash advances in cents final JsonField<Long>_balanceTransfers()Returns the raw JSON value of balanceTransfers. final JsonField<Long>_cashAdvances()Returns the raw JSON value of cashAdvances. final JsonField<Long>_credits()Returns the raw JSON value of credits. final JsonField<Long>_fees()Returns the raw JSON value of fees. final JsonField<Long>_interest()Returns the raw JSON value of interest. final JsonField<Long>_payments()Returns the raw JSON value of payments. final JsonField<Long>_purchases()Returns the raw JSON value of purchases. final Map<String, JsonValue>_additionalProperties()final Statement.StatementTotals.BuildertoBuilder()final Statement.StatementTotalsvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Statement.StatementTotals.Builderbuilder()Returns a mutable builder for constructing an instance of StatementTotals. -
-
Method Detail
-
balanceTransfers
final Long balanceTransfers()
Opening balance transferred from previous account in cents
-
cashAdvances
final Long cashAdvances()
ATM and cashback transactions in cents
-
credits
final Long credits()
Volume of credit management operation transactions less any balance transfers in cents
-
_balanceTransfers
final JsonField<Long> _balanceTransfers()
Returns the raw JSON value of balanceTransfers.
Unlike balanceTransfers, this method doesn't throw if the JSON field has an unexpected type.
-
_cashAdvances
final JsonField<Long> _cashAdvances()
Returns the raw JSON value of cashAdvances.
Unlike cashAdvances, this method doesn't throw if the JSON field has an unexpected type.
-
_credits
final JsonField<Long> _credits()
Returns the raw JSON value of credits.
Unlike credits, this method doesn't throw if the JSON field has an unexpected type.
-
_fees
final JsonField<Long> _fees()
Returns the raw JSON value of fees.
Unlike fees, this method doesn't throw if the JSON field has an unexpected type.
-
_interest
final JsonField<Long> _interest()
Returns the raw JSON value of interest.
Unlike interest, this method doesn't throw if the JSON field has an unexpected type.
-
_payments
final JsonField<Long> _payments()
Returns the raw JSON value of payments.
Unlike payments, this method doesn't throw if the JSON field has an unexpected type.
-
_purchases
final JsonField<Long> _purchases()
Returns the raw JSON value of purchases.
Unlike purchases, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Statement.StatementTotals.Builder toBuilder()
-
validate
final Statement.StatementTotals validate()
-
builder
final static Statement.StatementTotals.Builder builder()
Returns a mutable builder for constructing an instance of StatementTotals.
The following fields are required:
.balanceTransfers() .cashAdvances() .credits() .fees() .interest() .payments() .purchases()
-
-
-
-