Class StatementTotals
-
- All Implemented Interfaces:
public final class StatementTotals
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStatementTotals.BuilderA builder for StatementTotals.
-
Method Summary
Modifier and Type Method Description final LongbalanceTransfers()Opening balance transferred from previous account in cents final LongcashAdvances()ATM and cashback transactions in cents final Longcredits()Volume of credit management operation transactions less any balance transfers in cents final Longdebits()Volume of debit management operation transactions less any interest in cents final Longfees()Volume of debit management operation transactions less any interest in cents final Longinterest()Interest accrued in cents final Longpayments()Any funds transfers which affective the balance in cents final Longpurchases()Net card transaction volume less any cash advances in cents final JsonValue_creditDetails()Breakdown of creditsThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = statementTotals.creditDetails().convert(MyClass.class);final JsonValue_debitDetails()Breakdown of debitsThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = statementTotals.debitDetails().convert(MyClass.class);final JsonValue_paymentDetails()Breakdown of paymentsThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = statementTotals.paymentDetails().convert(MyClass.class);final JsonField<Long>_balanceTransfers()Returns the raw JSON value of balanceTransfers. final JsonField<Long>_cashAdvances()Returns the raw JSON value of cashAdvances. final JsonField<Long>_credits()Returns the raw JSON value of credits. final JsonField<Long>_debits()Returns the raw JSON value of debits. final JsonField<Long>_fees()Returns the raw JSON value of fees. final JsonField<Long>_interest()Returns the raw JSON value of interest. final JsonField<Long>_payments()Returns the raw JSON value of payments. final JsonField<Long>_purchases()Returns the raw JSON value of purchases. final Map<String, JsonValue>_additionalProperties()final StatementTotals.BuildertoBuilder()final StatementTotalsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static StatementTotals.Builderbuilder()Returns a mutable builder for constructing an instance of StatementTotals. -
-
Method Detail
-
balanceTransfers
final Long balanceTransfers()
Opening balance transferred from previous account in cents
-
cashAdvances
final Long cashAdvances()
ATM and cashback transactions in cents
-
credits
final Long credits()
Volume of credit management operation transactions less any balance transfers in cents
-
debits
final Long debits()
Volume of debit management operation transactions less any interest in cents
-
_creditDetails
final JsonValue _creditDetails()
Breakdown of credits
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = statementTotals.creditDetails().convert(MyClass.class);
-
_debitDetails
final JsonValue _debitDetails()
Breakdown of debits
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = statementTotals.debitDetails().convert(MyClass.class);
-
_paymentDetails
final JsonValue _paymentDetails()
Breakdown of payments
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = statementTotals.paymentDetails().convert(MyClass.class);
-
_balanceTransfers
final JsonField<Long> _balanceTransfers()
Returns the raw JSON value of balanceTransfers.
Unlike balanceTransfers, this method doesn't throw if the JSON field has an unexpected type.
-
_cashAdvances
final JsonField<Long> _cashAdvances()
Returns the raw JSON value of cashAdvances.
Unlike cashAdvances, this method doesn't throw if the JSON field has an unexpected type.
-
_credits
final JsonField<Long> _credits()
Returns the raw JSON value of credits.
Unlike credits, this method doesn't throw if the JSON field has an unexpected type.
-
_debits
final JsonField<Long> _debits()
Returns the raw JSON value of debits.
Unlike debits, this method doesn't throw if the JSON field has an unexpected type.
-
_fees
final JsonField<Long> _fees()
Returns the raw JSON value of fees.
Unlike fees, this method doesn't throw if the JSON field has an unexpected type.
-
_interest
final JsonField<Long> _interest()
Returns the raw JSON value of interest.
Unlike interest, this method doesn't throw if the JSON field has an unexpected type.
-
_payments
final JsonField<Long> _payments()
Returns the raw JSON value of payments.
Unlike payments, this method doesn't throw if the JSON field has an unexpected type.
-
_purchases
final JsonField<Long> _purchases()
Returns the raw JSON value of purchases.
Unlike purchases, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final StatementTotals.Builder toBuilder()
-
validate
final StatementTotals validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static StatementTotals.Builder builder()
Returns a mutable builder for constructing an instance of StatementTotals.
The following fields are required:
.balanceTransfers() .cashAdvances() .credits() .debits() .fees() .interest() .payments() .purchases()
-
-
-
-