Package com.lithic.api.models
Class SubscriptionRetrieveSecretResponse
-
- All Implemented Interfaces:
public final class SubscriptionRetrieveSecretResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSubscriptionRetrieveSecretResponse.BuilderA builder for SubscriptionRetrieveSecretResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>secret()The secret for the event subscription. final JsonField<String>_secret()Returns the raw JSON value of secret. final Map<String, JsonValue>_additionalProperties()final SubscriptionRetrieveSecretResponse.BuildertoBuilder()final SubscriptionRetrieveSecretResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SubscriptionRetrieveSecretResponse.Builderbuilder()Returns a mutable builder for constructing an instance of SubscriptionRetrieveSecretResponse. -
-
Method Detail
-
_secret
final JsonField<String> _secret()
Returns the raw JSON value of secret.
Unlike secret, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SubscriptionRetrieveSecretResponse.Builder toBuilder()
-
validate
final SubscriptionRetrieveSecretResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SubscriptionRetrieveSecretResponse.Builder builder()
Returns a mutable builder for constructing an instance of SubscriptionRetrieveSecretResponse.
-
-
-
-