Class ThreeDSAuthenticationChallengeWebhookEvent
-
- All Implemented Interfaces:
public final class ThreeDSAuthenticationChallengeWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classThreeDSAuthenticationChallengeWebhookEvent.BuilderA builder for ThreeDSAuthenticationChallengeWebhookEvent.
public final classThreeDSAuthenticationChallengeWebhookEvent.ChallengeRepresents a challenge object for 3DS authentication
public final classThreeDSAuthenticationChallengeWebhookEvent.EventType
-
Method Summary
-
-
Method Detail
-
authenticationObject
final ThreeDSAuthentication authenticationObject()
Represents a 3DS authentication
-
challenge
final ThreeDSAuthenticationChallengeWebhookEvent.Challenge challenge()
Represents a challenge object for 3DS authentication
-
eventType
final ThreeDSAuthenticationChallengeWebhookEvent.EventType eventType()
-
_authenticationObject
final JsonField<ThreeDSAuthentication> _authenticationObject()
Returns the raw JSON value of authenticationObject.
Unlike authenticationObject, this method doesn't throw if the JSON field has an unexpected type.
-
_challenge
final JsonField<ThreeDSAuthenticationChallengeWebhookEvent.Challenge> _challenge()
Returns the raw JSON value of challenge.
Unlike challenge, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<ThreeDSAuthenticationChallengeWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ThreeDSAuthenticationChallengeWebhookEvent.Builder toBuilder()
-
validate
final ThreeDSAuthenticationChallengeWebhookEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ThreeDSAuthenticationChallengeWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of ThreeDSAuthenticationChallengeWebhookEvent.
The following fields are required:
.authenticationObject() .challenge() .eventType()
-
-
-
-