Class Tokenization.Builder
-
- All Implemented Interfaces:
public final class Tokenization.BuilderA builder for Tokenization.
-
-
Method Summary
Modifier and Type Method Description final Tokenization.Buildertoken(String token)Globally unique identifier for a Tokenization final Tokenization.Buildertoken(JsonField<String> token)Globally unique identifier for a Tokenization final Tokenization.BuilderaccountToken(String accountToken)The account token associated with the card being tokenized. final Tokenization.BuilderaccountToken(JsonField<String> accountToken)The account token associated with the card being tokenized. final Tokenization.BuildercardToken(String cardToken)The card token associated with the card being tokenized. final Tokenization.BuildercardToken(JsonField<String> cardToken)The card token associated with the card being tokenized. final Tokenization.BuildercreatedAt(OffsetDateTime createdAt)Date and time when the tokenization first occurred. final Tokenization.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Date and time when the tokenization first occurred. final Tokenization.Builderdpan(String dpan)The dynamic pan assigned to the token by the network. final Tokenization.Builderdpan(Optional<String> dpan)The dynamic pan assigned to the token by the network. final Tokenization.Builderdpan(JsonField<String> dpan)The dynamic pan assigned to the token by the network. final Tokenization.Builderstatus(Tokenization.Status status)The status of the tokenization request final Tokenization.Builderstatus(JsonField<Tokenization.Status> status)The status of the tokenization request final Tokenization.BuildertokenRequestorName(Tokenization.TokenRequestorName tokenRequestorName)The entity that requested the tokenization. final Tokenization.BuildertokenRequestorName(JsonField<Tokenization.TokenRequestorName> tokenRequestorName)The entity that requested the tokenization. final Tokenization.BuildertokenUniqueReference(String tokenUniqueReference)The network's unique reference for the tokenization. final Tokenization.BuildertokenUniqueReference(JsonField<String> tokenUniqueReference)The network's unique reference for the tokenization. final Tokenization.BuildertokenizationChannel(Tokenization.TokenizationChannel tokenizationChannel)The channel through which the tokenization was made. final Tokenization.BuildertokenizationChannel(JsonField<Tokenization.TokenizationChannel> tokenizationChannel)The channel through which the tokenization was made. final Tokenization.BuilderupdatedAt(OffsetDateTime updatedAt)Latest date and time when the tokenization was updated. final Tokenization.BuilderupdatedAt(JsonField<OffsetDateTime> updatedAt)Latest date and time when the tokenization was updated. final Tokenization.BuilderdigitalCardArtToken(String digitalCardArtToken)Specifies the digital card art displayed in the user’s digital wallet after tokenization. final Tokenization.BuilderdigitalCardArtToken(JsonField<String> digitalCardArtToken)Specifies the digital card art displayed in the user’s digital wallet after tokenization. final Tokenization.Builderevents(List<Tokenization.TokenizationEvent> events)A list of events related to the tokenization. final Tokenization.Builderevents(JsonField<List<Tokenization.TokenizationEvent>> events)A list of events related to the tokenization. final Tokenization.BuilderaddEvent(Tokenization.TokenizationEvent event)A list of events related to the tokenization. final Tokenization.BuilderpaymentAccountReferenceId(String paymentAccountReferenceId)The network's unique reference for the card that is tokenized. final Tokenization.BuilderpaymentAccountReferenceId(Optional<String> paymentAccountReferenceId)The network's unique reference for the card that is tokenized. final Tokenization.BuilderpaymentAccountReferenceId(JsonField<String> paymentAccountReferenceId)The network's unique reference for the card that is tokenized. final Tokenization.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Tokenization.BuilderputAdditionalProperty(String key, JsonValue value)final Tokenization.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Tokenization.BuilderremoveAdditionalProperty(String key)final Tokenization.BuilderremoveAllAdditionalProperties(Set<String> keys)final Tokenizationbuild()-
-
Method Detail
-
token
final Tokenization.Builder token(String token)
Globally unique identifier for a Tokenization
-
token
final Tokenization.Builder token(JsonField<String> token)
Globally unique identifier for a Tokenization
-
accountToken
final Tokenization.Builder accountToken(String accountToken)
The account token associated with the card being tokenized.
-
accountToken
final Tokenization.Builder accountToken(JsonField<String> accountToken)
The account token associated with the card being tokenized.
-
cardToken
final Tokenization.Builder cardToken(String cardToken)
The card token associated with the card being tokenized.
-
cardToken
final Tokenization.Builder cardToken(JsonField<String> cardToken)
The card token associated with the card being tokenized.
-
createdAt
final Tokenization.Builder createdAt(OffsetDateTime createdAt)
Date and time when the tokenization first occurred. UTC time zone.
-
createdAt
final Tokenization.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Date and time when the tokenization first occurred. UTC time zone.
-
dpan
final Tokenization.Builder dpan(String dpan)
The dynamic pan assigned to the token by the network.
-
dpan
final Tokenization.Builder dpan(Optional<String> dpan)
The dynamic pan assigned to the token by the network.
-
dpan
final Tokenization.Builder dpan(JsonField<String> dpan)
The dynamic pan assigned to the token by the network.
-
status
final Tokenization.Builder status(Tokenization.Status status)
The status of the tokenization request
-
status
final Tokenization.Builder status(JsonField<Tokenization.Status> status)
The status of the tokenization request
-
tokenRequestorName
final Tokenization.Builder tokenRequestorName(Tokenization.TokenRequestorName tokenRequestorName)
The entity that requested the tokenization. Represents a Digital Wallet or merchant.
-
tokenRequestorName
final Tokenization.Builder tokenRequestorName(JsonField<Tokenization.TokenRequestorName> tokenRequestorName)
The entity that requested the tokenization. Represents a Digital Wallet or merchant.
-
tokenUniqueReference
final Tokenization.Builder tokenUniqueReference(String tokenUniqueReference)
The network's unique reference for the tokenization.
-
tokenUniqueReference
final Tokenization.Builder tokenUniqueReference(JsonField<String> tokenUniqueReference)
The network's unique reference for the tokenization.
-
tokenizationChannel
final Tokenization.Builder tokenizationChannel(Tokenization.TokenizationChannel tokenizationChannel)
The channel through which the tokenization was made.
-
tokenizationChannel
final Tokenization.Builder tokenizationChannel(JsonField<Tokenization.TokenizationChannel> tokenizationChannel)
The channel through which the tokenization was made.
-
updatedAt
final Tokenization.Builder updatedAt(OffsetDateTime updatedAt)
Latest date and time when the tokenization was updated. UTC time zone.
-
updatedAt
final Tokenization.Builder updatedAt(JsonField<OffsetDateTime> updatedAt)
Latest date and time when the tokenization was updated. UTC time zone.
-
digitalCardArtToken
final Tokenization.Builder digitalCardArtToken(String digitalCardArtToken)
Specifies the digital card art displayed in the user’s digital wallet after tokenization. This will be null if the tokenization was created without an associated digital card art. See Flexible Card Art Guide.
-
digitalCardArtToken
final Tokenization.Builder digitalCardArtToken(JsonField<String> digitalCardArtToken)
Specifies the digital card art displayed in the user’s digital wallet after tokenization. This will be null if the tokenization was created without an associated digital card art. See Flexible Card Art Guide.
-
events
final Tokenization.Builder events(List<Tokenization.TokenizationEvent> events)
A list of events related to the tokenization.
-
events
final Tokenization.Builder events(JsonField<List<Tokenization.TokenizationEvent>> events)
A list of events related to the tokenization.
-
addEvent
final Tokenization.Builder addEvent(Tokenization.TokenizationEvent event)
A list of events related to the tokenization.
-
paymentAccountReferenceId
final Tokenization.Builder paymentAccountReferenceId(String paymentAccountReferenceId)
The network's unique reference for the card that is tokenized.
-
paymentAccountReferenceId
final Tokenization.Builder paymentAccountReferenceId(Optional<String> paymentAccountReferenceId)
The network's unique reference for the card that is tokenized.
-
paymentAccountReferenceId
final Tokenization.Builder paymentAccountReferenceId(JsonField<String> paymentAccountReferenceId)
The network's unique reference for the card that is tokenized.
-
additionalProperties
final Tokenization.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Tokenization.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Tokenization.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Tokenization.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Tokenization.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Tokenization build()
-
-
-
-