Class Tokenization.TokenizationEvent
-
- All Implemented Interfaces:
public final class Tokenization.TokenizationEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTokenization.TokenizationEvent.BuilderA builder for TokenizationEvent.
public final classTokenization.TokenizationEvent.TokenizationEventOutcomeEnum representing the result of the tokenization event
public final classTokenization.TokenizationEvent.TypeEnum representing the type of tokenization event that occurred
-
Method Summary
-
-
Method Detail
-
createdAt
final Optional<OffsetDateTime> createdAt()
Date and time when the tokenization event first occurred. UTC time zone.
-
result
final Optional<Tokenization.TokenizationEvent.TokenizationEventOutcome> result()
Enum representing the result of the tokenization event
-
ruleResults
final Optional<List<TokenizationRuleResult>> ruleResults()
Results from rules that were evaluated for this tokenization
-
tokenizationDeclineReasons
final Optional<List<TokenizationDeclineReason>> tokenizationDeclineReasons()
List of reasons why the tokenization was declined
-
tokenizationTfaReasons
final Optional<List<TokenizationTfaReason>> tokenizationTfaReasons()
List of reasons why two-factor authentication was required
-
type
final Optional<Tokenization.TokenizationEvent.Type> type()
Enum representing the type of tokenization event that occurred
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_result
final JsonField<Tokenization.TokenizationEvent.TokenizationEventOutcome> _result()
Returns the raw JSON value of result.
Unlike result, this method doesn't throw if the JSON field has an unexpected type.
-
_ruleResults
final JsonField<List<TokenizationRuleResult>> _ruleResults()
Returns the raw JSON value of ruleResults.
Unlike ruleResults, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenizationDeclineReasons
final JsonField<List<TokenizationDeclineReason>> _tokenizationDeclineReasons()
Returns the raw JSON value of tokenizationDeclineReasons.
Unlike tokenizationDeclineReasons, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenizationTfaReasons
final JsonField<List<TokenizationTfaReason>> _tokenizationTfaReasons()
Returns the raw JSON value of tokenizationTfaReasons.
Unlike tokenizationTfaReasons, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<Tokenization.TokenizationEvent.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Tokenization.TokenizationEvent.Builder toBuilder()
-
validate
final Tokenization.TokenizationEvent validate()
-
builder
final static Tokenization.TokenizationEvent.Builder builder()
Returns a mutable builder for constructing an instance of TokenizationEvent.
-
-
-
-