Class Tokenization.TokenizationEvent.TokenizationRuleResult
-
- All Implemented Interfaces:
public final class Tokenization.TokenizationEvent.TokenizationRuleResult
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTokenization.TokenizationEvent.TokenizationRuleResult.BuilderA builder for TokenizationRuleResult.
public final classTokenization.TokenizationEvent.TokenizationRuleResult.ResultThe result associated with this rule
-
Method Summary
-
-
Method Detail
-
authRuleToken
final Optional<String> authRuleToken()
The Auth Rule Token associated with the rule. If this is set to null, then the result was not associated with a customer-configured rule. This may happen in cases where a tokenization is declined or requires TFA due to a Lithic-configured security or compliance rule, for example.
-
explanation
final Optional<String> explanation()
A human-readable explanation outlining the motivation for the rule's result
-
result
final Tokenization.TokenizationEvent.TokenizationRuleResult.Result result()
The result associated with this rule
-
_authRuleToken
final JsonField<String> _authRuleToken()
Returns the raw JSON value of authRuleToken.
Unlike authRuleToken, this method doesn't throw if the JSON field has an unexpected type.
-
_explanation
final JsonField<String> _explanation()
Returns the raw JSON value of explanation.
Unlike explanation, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_result
final JsonField<Tokenization.TokenizationEvent.TokenizationRuleResult.Result> _result()
Returns the raw JSON value of result.
Unlike result, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Tokenization.TokenizationEvent.TokenizationRuleResult.Builder toBuilder()
-
validate
final Tokenization.TokenizationEvent.TokenizationRuleResult validate()
-
builder
final static Tokenization.TokenizationEvent.TokenizationRuleResult.Builder builder()
Returns a mutable builder for constructing an instance of TokenizationRuleResult.
The following fields are required:
.authRuleToken() .explanation() .name() .result()
-
-
-
-