Class TokenizationApprovalRequestWebhookEvent
-
- All Implemented Interfaces:
public final class TokenizationApprovalRequestWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTokenizationApprovalRequestWebhookEvent.BuilderA builder for TokenizationApprovalRequestWebhookEvent.
public final classTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecisionContains the metadata for the customer tokenization decision.
public final classTokenizationApprovalRequestWebhookEvent.EventTypeThe name of this event
public final classTokenizationApprovalRequestWebhookEvent.IssuerDecisionWhether Lithic decisioned on the token, and if so, what the decision was. APPROVED/VERIFICATION_REQUIRED/DENIED.
public final classTokenizationApprovalRequestWebhookEvent.TokenizationChannelThe channel through which the tokenization was made.
public final classTokenizationApprovalRequestWebhookEvent.TokenizationSourceThe source of the tokenization.
-
Method Summary
-
-
Method Detail
-
accountToken
final String accountToken()
Unique identifier for the user tokenizing a card
-
created
final OffsetDateTime created()
Indicate when the request was received from Mastercard or Visa
-
customerTokenizationDecision
final Optional<TokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision> customerTokenizationDecision()
Contains the metadata for the customer tokenization decision.
-
eventType
final TokenizationApprovalRequestWebhookEvent.EventType eventType()
The name of this event
-
issuerDecision
final TokenizationApprovalRequestWebhookEvent.IssuerDecision issuerDecision()
Whether Lithic decisioned on the token, and if so, what the decision was. APPROVED/VERIFICATION_REQUIRED/DENIED.
-
tokenMetadata
final TokenMetadata tokenMetadata()
Contains the metadata for the digital wallet being tokenized.
-
tokenizationChannel
final TokenizationApprovalRequestWebhookEvent.TokenizationChannel tokenizationChannel()
The channel through which the tokenization was made.
-
tokenizationToken
final String tokenizationToken()
Unique identifier for the digital wallet token attempt
-
walletDecisioningInfo
final WalletDecisioningInfo walletDecisioningInfo()
-
ruleResults
final Optional<List<TokenizationRuleResult>> ruleResults()
Results from rules that were evaluated for this tokenization
-
tokenizationDeclineReasons
final Optional<List<TokenizationDeclineReason>> tokenizationDeclineReasons()
List of reasons why the tokenization was declined
-
tokenizationSource
final Optional<TokenizationApprovalRequestWebhookEvent.TokenizationSource> tokenizationSource()
The source of the tokenization.
-
tokenizationTfaReasons
final Optional<List<TokenizationTfaReason>> tokenizationTfaReasons()
List of reasons why two-factor authentication was required
-
_accountToken
final JsonField<String> _accountToken()
Returns the raw JSON value of accountToken.
Unlike accountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_cardToken
final JsonField<String> _cardToken()
Returns the raw JSON value of cardToken.
Unlike cardToken, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_customerTokenizationDecision
final JsonField<TokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision> _customerTokenizationDecision()
Returns the raw JSON value of customerTokenizationDecision.
Unlike customerTokenizationDecision, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<TokenizationApprovalRequestWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_issuerDecision
final JsonField<TokenizationApprovalRequestWebhookEvent.IssuerDecision> _issuerDecision()
Returns the raw JSON value of issuerDecision.
Unlike issuerDecision, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenMetadata
final JsonField<TokenMetadata> _tokenMetadata()
Returns the raw JSON value of tokenMetadata.
Unlike tokenMetadata, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenizationChannel
final JsonField<TokenizationApprovalRequestWebhookEvent.TokenizationChannel> _tokenizationChannel()
Returns the raw JSON value of tokenizationChannel.
Unlike tokenizationChannel, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenizationToken
final JsonField<String> _tokenizationToken()
Returns the raw JSON value of tokenizationToken.
Unlike tokenizationToken, this method doesn't throw if the JSON field has an unexpected type.
-
_walletDecisioningInfo
final JsonField<WalletDecisioningInfo> _walletDecisioningInfo()
Returns the raw JSON value of walletDecisioningInfo.
Unlike walletDecisioningInfo, this method doesn't throw if the JSON field has an unexpected type.
-
_device
final JsonField<Device> _device()
Returns the raw JSON value of device.
Unlike device, this method doesn't throw if the JSON field has an unexpected type.
-
_ruleResults
final JsonField<List<TokenizationRuleResult>> _ruleResults()
Returns the raw JSON value of ruleResults.
Unlike ruleResults, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenizationDeclineReasons
final JsonField<List<TokenizationDeclineReason>> _tokenizationDeclineReasons()
Returns the raw JSON value of tokenizationDeclineReasons.
Unlike tokenizationDeclineReasons, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenizationSource
final JsonField<TokenizationApprovalRequestWebhookEvent.TokenizationSource> _tokenizationSource()
Returns the raw JSON value of tokenizationSource.
Unlike tokenizationSource, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenizationTfaReasons
final JsonField<List<TokenizationTfaReason>> _tokenizationTfaReasons()
Returns the raw JSON value of tokenizationTfaReasons.
Unlike tokenizationTfaReasons, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TokenizationApprovalRequestWebhookEvent.Builder toBuilder()
-
validate
final TokenizationApprovalRequestWebhookEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TokenizationApprovalRequestWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of TokenizationApprovalRequestWebhookEvent.
The following fields are required:
.accountToken() .cardToken() .created() .customerTokenizationDecision() .eventType() .issuerDecision() .tokenMetadata() .tokenizationChannel() .tokenizationToken() .walletDecisioningInfo()
-
-
-
-