Class TokenizationDecisioningRequestWebhookEvent
-
- All Implemented Interfaces:
public final class TokenizationDecisioningRequestWebhookEventA webhook for tokenization decisioning sent to the customer's responder endpoint
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTokenizationDecisioningRequestWebhookEvent.BuilderA builder for TokenizationDecisioningRequestWebhookEvent.
public final classTokenizationDecisioningRequestWebhookEvent.EventTypeThe name of this event
public final classTokenizationDecisioningRequestWebhookEvent.IssuerDecisionWhether Lithic decisioned on the token, and if so, what the decision was. APPROVED/VERIFICATION_REQUIRED/DENIED.
public final classTokenizationDecisioningRequestWebhookEvent.TokenizationChannelThe channel through which the tokenization was made.
public final classTokenizationDecisioningRequestWebhookEvent.TokenizationSourceThe source of the tokenization.
-
Method Summary
-
-
Method Detail
-
accountToken
final String accountToken()
Unique identifier for the user tokenizing a card
-
created
final OffsetDateTime created()
Indicate when the request was received from Mastercard or Visa
-
digitalWalletTokenMetadata
final TokenMetadata digitalWalletTokenMetadata()
Contains the metadata for the digital wallet being tokenized.
-
eventType
final TokenizationDecisioningRequestWebhookEvent.EventType eventType()
The name of this event
-
issuerDecision
final TokenizationDecisioningRequestWebhookEvent.IssuerDecision issuerDecision()
Whether Lithic decisioned on the token, and if so, what the decision was. APPROVED/VERIFICATION_REQUIRED/DENIED.
-
tokenizationChannel
final TokenizationDecisioningRequestWebhookEvent.TokenizationChannel tokenizationChannel()
The channel through which the tokenization was made.
-
tokenizationToken
final String tokenizationToken()
Unique identifier for the digital wallet token attempt
-
walletDecisioningInfo
final WalletDecisioningInfo walletDecisioningInfo()
-
tokenizationSource
final Optional<TokenizationDecisioningRequestWebhookEvent.TokenizationSource> tokenizationSource()
The source of the tokenization.
-
_accountToken
final JsonField<String> _accountToken()
Returns the raw JSON value of accountToken.
Unlike accountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_cardToken
final JsonField<String> _cardToken()
Returns the raw JSON value of cardToken.
Unlike cardToken, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_digitalWalletTokenMetadata
final JsonField<TokenMetadata> _digitalWalletTokenMetadata()
Returns the raw JSON value of digitalWalletTokenMetadata.
Unlike digitalWalletTokenMetadata, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<TokenizationDecisioningRequestWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_issuerDecision
final JsonField<TokenizationDecisioningRequestWebhookEvent.IssuerDecision> _issuerDecision()
Returns the raw JSON value of issuerDecision.
Unlike issuerDecision, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenizationChannel
final JsonField<TokenizationDecisioningRequestWebhookEvent.TokenizationChannel> _tokenizationChannel()
Returns the raw JSON value of tokenizationChannel.
Unlike tokenizationChannel, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenizationToken
final JsonField<String> _tokenizationToken()
Returns the raw JSON value of tokenizationToken.
Unlike tokenizationToken, this method doesn't throw if the JSON field has an unexpected type.
-
_walletDecisioningInfo
final JsonField<WalletDecisioningInfo> _walletDecisioningInfo()
Returns the raw JSON value of walletDecisioningInfo.
Unlike walletDecisioningInfo, this method doesn't throw if the JSON field has an unexpected type.
-
_device
final JsonField<Device> _device()
Returns the raw JSON value of device.
Unlike device, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenizationSource
final JsonField<TokenizationDecisioningRequestWebhookEvent.TokenizationSource> _tokenizationSource()
Returns the raw JSON value of tokenizationSource.
Unlike tokenizationSource, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TokenizationDecisioningRequestWebhookEvent.Builder toBuilder()
-
validate
final TokenizationDecisioningRequestWebhookEvent validate()
-
builder
final static TokenizationDecisioningRequestWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of TokenizationDecisioningRequestWebhookEvent.
The following fields are required:
.accountToken() .cardToken() .created() .digitalWalletTokenMetadata() .eventType() .issuerDecision() .tokenizationChannel() .tokenizationToken() .walletDecisioningInfo()
-
-
-
-