Package com.lithic.api.models
Class TokenizationDecisioningRotateSecretResponse
-
- All Implemented Interfaces:
public final class TokenizationDecisioningRotateSecretResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTokenizationDecisioningRotateSecretResponse.BuilderA builder for TokenizationDecisioningRotateSecretResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>secret()The new Tokenization Decisioning HMAC secret final JsonField<String>_secret()Returns the raw JSON value of secret. final Map<String, JsonValue>_additionalProperties()final TokenizationDecisioningRotateSecretResponse.BuildertoBuilder()final TokenizationDecisioningRotateSecretResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TokenizationDecisioningRotateSecretResponse.Builderbuilder()Returns a mutable builder for constructing an instance of TokenizationDecisioningRotateSecretResponse. -
-
Method Detail
-
_secret
final JsonField<String> _secret()
Returns the raw JSON value of secret.
Unlike secret, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TokenizationDecisioningRotateSecretResponse.Builder toBuilder()
-
validate
final TokenizationDecisioningRotateSecretResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TokenizationDecisioningRotateSecretResponse.Builder builder()
Returns a mutable builder for constructing an instance of TokenizationDecisioningRotateSecretResponse.
-
-
-
-