Package com.lithic.api.models
Class TokenizationListPage
-
- All Implemented Interfaces:
public final class TokenizationListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTokenizationListPage.BuilderA builder for TokenizationListPage.
public final classTokenizationListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<Tokenization>data()Delegates to TokenizationListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to TokenizationListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<TokenizationListParams>getNextPageParams()final Optional<TokenizationListPage>getNextPage()final TokenizationListPage.AutoPagerautoPager()final TokenizationListParamsparams()The parameters that were used to request this page. final TokenizationListPageResponseresponse()The response that this page was parsed from. final TokenizationListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TokenizationListPage.Builderbuilder()Returns a mutable builder for constructing an instance of TokenizationListPage. -
-
Method Detail
-
data
final List<Tokenization> data()
Delegates to TokenizationListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to TokenizationListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<TokenizationListParams> getNextPageParams()
-
getNextPage
final Optional<TokenizationListPage> getNextPage()
-
autoPager
final TokenizationListPage.AutoPager autoPager()
-
params
final TokenizationListParams params()
The parameters that were used to request this page.
-
response
final TokenizationListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final TokenizationListPage.Builder toBuilder()
-
builder
final static TokenizationListPage.Builder builder()
Returns a mutable builder for constructing an instance of TokenizationListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-