Package com.lithic.api.models
Class TokenizationListPageAsync
-
- All Implemented Interfaces:
public final class TokenizationListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTokenizationListPageAsync.BuilderA builder for TokenizationListPageAsync.
public final classTokenizationListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<Tokenization>data()Delegates to TokenizationListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to TokenizationListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<TokenizationListParams>getNextPageParams()final CompletableFuture<Optional<TokenizationListPageAsync>>getNextPage()final TokenizationListPageAsync.AutoPagerautoPager()final TokenizationListParamsparams()The parameters that were used to request this page. final TokenizationListPageResponseresponse()The response that this page was parsed from. final TokenizationListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TokenizationListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of TokenizationListPageAsync. -
-
Method Detail
-
data
final List<Tokenization> data()
Delegates to TokenizationListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to TokenizationListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<TokenizationListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<TokenizationListPageAsync>> getNextPage()
-
autoPager
final TokenizationListPageAsync.AutoPager autoPager()
-
params
final TokenizationListParams params()
The parameters that were used to request this page.
-
response
final TokenizationListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final TokenizationListPageAsync.Builder toBuilder()
-
builder
final static TokenizationListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of TokenizationListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-