Package com.lithic.api.models
Class TokenizationListPageAsync.Builder
-
- All Implemented Interfaces:
public final class TokenizationListPageAsync.BuilderA builder for TokenizationListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final TokenizationListPageAsync.Builderservice(TokenizationServiceAsync service)final TokenizationListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final TokenizationListPageAsync.Builderparams(TokenizationListParams params)The parameters that were used to request this page. final TokenizationListPageAsync.Builderresponse(TokenizationListPageResponse response)The response that this page was parsed from. final TokenizationListPageAsyncbuild()Returns an immutable instance of TokenizationListPageAsync. -
-
Method Detail
-
service
final TokenizationListPageAsync.Builder service(TokenizationServiceAsync service)
-
streamHandlerExecutor
final TokenizationListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final TokenizationListPageAsync.Builder params(TokenizationListParams params)
The parameters that were used to request this page.
-
response
final TokenizationListPageAsync.Builder response(TokenizationListPageResponse response)
The response that this page was parsed from.
-
build
final TokenizationListPageAsync build()
Returns an immutable instance of TokenizationListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-