Package com.lithic.api.models
Class TokenizationListPageResponse.Builder
-
- All Implemented Interfaces:
public final class TokenizationListPageResponse.BuilderA builder for TokenizationListPageResponse.
-
-
Method Summary
-
-
Method Detail
-
data
final TokenizationListPageResponse.Builder data(List<Tokenization> data)
-
data
final TokenizationListPageResponse.Builder data(JsonField<List<Tokenization>> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed
List<Tokenization>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addData
final TokenizationListPageResponse.Builder addData(Tokenization data)
Adds a single Tokenization to Builder.data.
-
hasMore
final TokenizationListPageResponse.Builder hasMore(Boolean hasMore)
-
hasMore
final TokenizationListPageResponse.Builder hasMore(JsonField<Boolean> hasMore)
Sets Builder.hasMore to an arbitrary JSON value.
You should usually call Builder.hasMore with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final TokenizationListPageResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final TokenizationListPageResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final TokenizationListPageResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final TokenizationListPageResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final TokenizationListPageResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final TokenizationListPageResponse build()
Returns an immutable instance of TokenizationListPageResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-