Class TokenizationRuleResult
-
- All Implemented Interfaces:
public final class TokenizationRuleResult
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTokenizationRuleResult.BuilderA builder for TokenizationRuleResult.
public final classTokenizationRuleResult.ResultThe result associated with this rule
-
Method Summary
Modifier and Type Method Description final Optional<String>authRuleToken()The Auth Rule Token associated with the rule. final Optional<String>explanation()A human-readable explanation outlining the motivation for the rule's result final Optional<String>name()The name for the rule, if any was configured final TokenizationRuleResult.Resultresult()The result associated with this rule final JsonField<String>_authRuleToken()Returns the raw JSON value of authRuleToken. final JsonField<String>_explanation()Returns the raw JSON value of explanation. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<TokenizationRuleResult.Result>_result()Returns the raw JSON value of result. final Map<String, JsonValue>_additionalProperties()final TokenizationRuleResult.BuildertoBuilder()final TokenizationRuleResultvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TokenizationRuleResult.Builderbuilder()Returns a mutable builder for constructing an instance of TokenizationRuleResult. -
-
Method Detail
-
authRuleToken
final Optional<String> authRuleToken()
The Auth Rule Token associated with the rule. If this is set to null, then the result was not associated with a customer-configured rule. This may happen in cases where a tokenization is declined or requires TFA due to a Lithic-configured security or compliance rule, for example.
-
explanation
final Optional<String> explanation()
A human-readable explanation outlining the motivation for the rule's result
-
result
final TokenizationRuleResult.Result result()
The result associated with this rule
-
_authRuleToken
final JsonField<String> _authRuleToken()
Returns the raw JSON value of authRuleToken.
Unlike authRuleToken, this method doesn't throw if the JSON field has an unexpected type.
-
_explanation
final JsonField<String> _explanation()
Returns the raw JSON value of explanation.
Unlike explanation, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_result
final JsonField<TokenizationRuleResult.Result> _result()
Returns the raw JSON value of result.
Unlike result, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TokenizationRuleResult.Builder toBuilder()
-
validate
final TokenizationRuleResult validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TokenizationRuleResult.Builder builder()
Returns a mutable builder for constructing an instance of TokenizationRuleResult.
The following fields are required:
.authRuleToken() .explanation() .name() .result()
-
-
-
-