Class TokenizationRuleResult.Builder
-
- All Implemented Interfaces:
public final class TokenizationRuleResult.BuilderA builder for TokenizationRuleResult.
-
-
Method Summary
-
-
Method Detail
-
authRuleToken
final TokenizationRuleResult.Builder authRuleToken(String authRuleToken)
The Auth Rule Token associated with the rule. If this is set to null, then the result was not associated with a customer-configured rule. This may happen in cases where a tokenization is declined or requires TFA due to a Lithic-configured security or compliance rule, for example.
-
authRuleToken
final TokenizationRuleResult.Builder authRuleToken(Optional<String> authRuleToken)
Alias for calling Builder.authRuleToken with
authRuleToken.orElse(null).
-
authRuleToken
final TokenizationRuleResult.Builder authRuleToken(JsonField<String> authRuleToken)
Sets Builder.authRuleToken to an arbitrary JSON value.
You should usually call Builder.authRuleToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
explanation
final TokenizationRuleResult.Builder explanation(String explanation)
A human-readable explanation outlining the motivation for the rule's result
-
explanation
final TokenizationRuleResult.Builder explanation(Optional<String> explanation)
Alias for calling Builder.explanation with
explanation.orElse(null).
-
explanation
final TokenizationRuleResult.Builder explanation(JsonField<String> explanation)
Sets Builder.explanation to an arbitrary JSON value.
You should usually call Builder.explanation with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final TokenizationRuleResult.Builder name(String name)
The name for the rule, if any was configured
-
name
final TokenizationRuleResult.Builder name(Optional<String> name)
Alias for calling Builder.name with
name.orElse(null).
-
name
final TokenizationRuleResult.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
result
final TokenizationRuleResult.Builder result(TokenizationRuleResult.Result result)
The result associated with this rule
-
result
final TokenizationRuleResult.Builder result(JsonField<TokenizationRuleResult.Result> result)
Sets Builder.result to an arbitrary JSON value.
You should usually call Builder.result with a well-typed Result value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final TokenizationRuleResult.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final TokenizationRuleResult.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final TokenizationRuleResult.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final TokenizationRuleResult.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final TokenizationRuleResult.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final TokenizationRuleResult build()
Returns an immutable instance of TokenizationRuleResult.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.authRuleToken() .explanation() .name() .result()
-
-
-
-