Package com.lithic.api.models
Class TokenizationSecret
-
- All Implemented Interfaces:
public final class TokenizationSecret
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTokenizationSecret.BuilderA builder for TokenizationSecret.
-
Method Summary
Modifier and Type Method Description final Optional<String>secret()The Tokenization Decisioning HMAC secret final JsonField<String>_secret()Returns the raw JSON value of secret. final Map<String, JsonValue>_additionalProperties()final TokenizationSecret.BuildertoBuilder()final TokenizationSecretvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TokenizationSecret.Builderbuilder()Returns a mutable builder for constructing an instance of TokenizationSecret. -
-
Method Detail
-
_secret
final JsonField<String> _secret()
Returns the raw JSON value of secret.
Unlike secret, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TokenizationSecret.Builder toBuilder()
-
validate
final TokenizationSecret validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TokenizationSecret.Builder builder()
Returns a mutable builder for constructing an instance of TokenizationSecret.
-
-
-
-