Class TokenizationSimulateParams.Body
-
- All Implemented Interfaces:
public final class TokenizationSimulateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTokenizationSimulateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringcvv()The three digit cvv for the card. final StringexpirationDate()The expiration date of the card in 'MM/YY' format. final Stringpan()The sixteen digit card number. final TokenizationSimulateParams.TokenizationSourcetokenizationSource()The source of the tokenization request. final Optional<Long>accountScore()The account score (1-5) that represents how the Digital Wallet's view on how reputable an end user's account is. final Optional<Long>deviceScore()The device score (1-5) that represents how the Digital Wallet's view on how reputable an end user's device is. final Optional<String>entity()Optional field to specify the token requestor name for a merchant token simulation. final Optional<TokenizationSimulateParams.WalletRecommendedDecision>walletRecommendedDecision()The decision that the Digital Wallet's recommend final JsonField<String>_cvv()Returns the raw JSON value of cvv. final JsonField<String>_expirationDate()Returns the raw JSON value of expirationDate. final JsonField<String>_pan()Returns the raw JSON value of pan. final JsonField<TokenizationSimulateParams.TokenizationSource>_tokenizationSource()Returns the raw JSON value of tokenizationSource. final JsonField<Long>_accountScore()Returns the raw JSON value of accountScore. final JsonField<Long>_deviceScore()Returns the raw JSON value of deviceScore. final JsonField<String>_entity()Returns the raw JSON value of entity. final JsonField<TokenizationSimulateParams.WalletRecommendedDecision>_walletRecommendedDecision()Returns the raw JSON value of walletRecommendedDecision. final Map<String, JsonValue>_additionalProperties()final TokenizationSimulateParams.Body.BuildertoBuilder()final TokenizationSimulateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TokenizationSimulateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
expirationDate
final String expirationDate()
The expiration date of the card in 'MM/YY' format.
-
tokenizationSource
final TokenizationSimulateParams.TokenizationSource tokenizationSource()
The source of the tokenization request.
-
accountScore
final Optional<Long> accountScore()
The account score (1-5) that represents how the Digital Wallet's view on how reputable an end user's account is.
-
deviceScore
final Optional<Long> deviceScore()
The device score (1-5) that represents how the Digital Wallet's view on how reputable an end user's device is.
-
entity
final Optional<String> entity()
Optional field to specify the token requestor name for a merchant token simulation. Ignored when tokenization_source is not MERCHANT.
-
walletRecommendedDecision
final Optional<TokenizationSimulateParams.WalletRecommendedDecision> walletRecommendedDecision()
The decision that the Digital Wallet's recommend
-
_cvv
final JsonField<String> _cvv()
Returns the raw JSON value of cvv.
Unlike cvv, this method doesn't throw if the JSON field has an unexpected type.
-
_expirationDate
final JsonField<String> _expirationDate()
Returns the raw JSON value of expirationDate.
Unlike expirationDate, this method doesn't throw if the JSON field has an unexpected type.
-
_pan
final JsonField<String> _pan()
Returns the raw JSON value of pan.
Unlike pan, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenizationSource
final JsonField<TokenizationSimulateParams.TokenizationSource> _tokenizationSource()
Returns the raw JSON value of tokenizationSource.
Unlike tokenizationSource, this method doesn't throw if the JSON field has an unexpected type.
-
_accountScore
final JsonField<Long> _accountScore()
Returns the raw JSON value of accountScore.
Unlike accountScore, this method doesn't throw if the JSON field has an unexpected type.
-
_deviceScore
final JsonField<Long> _deviceScore()
Returns the raw JSON value of deviceScore.
Unlike deviceScore, this method doesn't throw if the JSON field has an unexpected type.
-
_entity
final JsonField<String> _entity()
Returns the raw JSON value of entity.
Unlike entity, this method doesn't throw if the JSON field has an unexpected type.
-
_walletRecommendedDecision
final JsonField<TokenizationSimulateParams.WalletRecommendedDecision> _walletRecommendedDecision()
Returns the raw JSON value of walletRecommendedDecision.
Unlike walletRecommendedDecision, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TokenizationSimulateParams.Body.Builder toBuilder()
-
validate
final TokenizationSimulateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TokenizationSimulateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.cvv() .expirationDate() .pan() .tokenizationSource()
-
-
-
-