Class TokenizationTwoFactorAuthenticationCodeSentWebhookEvent
-
- All Implemented Interfaces:
public final class TokenizationTwoFactorAuthenticationCodeSentWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTokenizationTwoFactorAuthenticationCodeSentWebhookEvent.BuilderA builder for TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.
public final classTokenizationTwoFactorAuthenticationCodeSentWebhookEvent.ActivationMethodpublic final classTokenizationTwoFactorAuthenticationCodeSentWebhookEvent.EventTypeThe type of event that occurred.
-
Method Summary
-
-
Method Detail
-
accountToken
final String accountToken()
Unique identifier for the user tokenizing a card
-
activationMethod
final TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.ActivationMethod activationMethod()
-
created
final OffsetDateTime created()
Indicate when the request was received from Mastercard or Visa
-
eventType
final TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.EventType eventType()
The type of event that occurred.
-
tokenizationToken
final String tokenizationToken()
Unique identifier for the tokenization
-
_accountToken
final JsonField<String> _accountToken()
Returns the raw JSON value of accountToken.
Unlike accountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_activationMethod
final JsonField<TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.ActivationMethod> _activationMethod()
Returns the raw JSON value of activationMethod.
Unlike activationMethod, this method doesn't throw if the JSON field has an unexpected type.
-
_cardToken
final JsonField<String> _cardToken()
Returns the raw JSON value of cardToken.
Unlike cardToken, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenizationToken
final JsonField<String> _tokenizationToken()
Returns the raw JSON value of tokenizationToken.
Unlike tokenizationToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.Builder toBuilder()
-
validate
final TokenizationTwoFactorAuthenticationCodeSentWebhookEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.
The following fields are required:
.accountToken() .activationMethod() .cardToken() .created() .eventType() .tokenizationToken()
-
-
-
-