Package com.lithic.api.models
Class Transaction.Avs
-
- All Implemented Interfaces:
public final class Transaction.Avs
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Avs.BuilderA builder for Avs.
-
Method Summary
Modifier and Type Method Description final Stringaddress()Cardholder address final Stringzipcode()Cardholder ZIP code final JsonField<String>_address()Returns the raw JSON value of address. final JsonField<String>_zipcode()Returns the raw JSON value of zipcode. final Map<String, JsonValue>_additionalProperties()final Transaction.Avs.BuildertoBuilder()final Transaction.Avsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Avs.Builderbuilder()Returns a mutable builder for constructing an instance of Avs. -
-
Method Detail
-
_address
final JsonField<String> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_zipcode
final JsonField<String> _zipcode()
Returns the raw JSON value of zipcode.
Unlike zipcode, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Avs.Builder toBuilder()
-
validate
final Transaction.Avs validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Transaction.Avs.Builder builder()
Returns a mutable builder for constructing an instance of Avs.
The following fields are required:
.address() .zipcode()
-
-
-
-