Class Transaction.Builder
-
- All Implemented Interfaces:
public final class Transaction.BuilderA builder for Transaction.
-
-
Method Summary
Modifier and Type Method Description final Transaction.Buildertoken(String token)Globally unique identifier. final Transaction.Buildertoken(JsonField<String> token)Globally unique identifier. final Transaction.BuilderaccountToken(String accountToken)The token for the account associated with this transaction. final Transaction.BuilderaccountToken(JsonField<String> accountToken)The token for the account associated with this transaction. final Transaction.BuilderacquirerFee(Long acquirerFee)Fee assessed by the merchant and paid for by the cardholder in the smallest unit of the currency. final Transaction.BuilderacquirerFee(Long acquirerFee)Fee assessed by the merchant and paid for by the cardholder in the smallest unit of the currency. final Transaction.BuilderacquirerFee(Optional<Long> acquirerFee)Fee assessed by the merchant and paid for by the cardholder in the smallest unit of the currency. final Transaction.BuilderacquirerFee(JsonField<Long> acquirerFee)Fee assessed by the merchant and paid for by the cardholder in the smallest unit of the currency. final Transaction.BuilderacquirerReferenceNumber(String acquirerReferenceNumber)Unique identifier assigned to a transaction by the acquirer that can be used in dispute and chargeback filing. final Transaction.BuilderacquirerReferenceNumber(Optional<String> acquirerReferenceNumber)Unique identifier assigned to a transaction by the acquirer that can be used in dispute and chargeback filing. final Transaction.BuilderacquirerReferenceNumber(JsonField<String> acquirerReferenceNumber)Unique identifier assigned to a transaction by the acquirer that can be used in dispute and chargeback filing. final Transaction.Builderamount(Long amount)When the transaction is pending, this represents the authorization amount of the transaction in the anticipated settlement currency. final Transaction.Builderamount(JsonField<Long> amount)When the transaction is pending, this represents the authorization amount of the transaction in the anticipated settlement currency. final Transaction.Builderamounts(Transaction.TransactionAmounts amounts)final Transaction.Builderamounts(JsonField<Transaction.TransactionAmounts> amounts)final Transaction.BuilderauthorizationAmount(Long authorizationAmount)The authorization amount of the transaction in the anticipated settlement currency. final Transaction.BuilderauthorizationAmount(Long authorizationAmount)The authorization amount of the transaction in the anticipated settlement currency. final Transaction.BuilderauthorizationAmount(Optional<Long> authorizationAmount)The authorization amount of the transaction in the anticipated settlement currency. final Transaction.BuilderauthorizationAmount(JsonField<Long> authorizationAmount)The authorization amount of the transaction in the anticipated settlement currency. final Transaction.BuilderauthorizationCode(String authorizationCode)A fixed-width 6-digit numeric identifier that can be used to identify a transaction with networks. final Transaction.BuilderauthorizationCode(Optional<String> authorizationCode)A fixed-width 6-digit numeric identifier that can be used to identify a transaction with networks. final Transaction.BuilderauthorizationCode(JsonField<String> authorizationCode)A fixed-width 6-digit numeric identifier that can be used to identify a transaction with networks. final Transaction.Builderavs(Transaction.Avs avs)final Transaction.Builderavs(Optional<Transaction.Avs> avs)final Transaction.Builderavs(JsonField<Transaction.Avs> avs)final Transaction.BuildercardToken(String cardToken)Token for the card used in this transaction. final Transaction.BuildercardToken(JsonField<String> cardToken)Token for the card used in this transaction. final Transaction.BuildercardholderAuthentication(Transaction.CardholderAuthentication cardholderAuthentication)final Transaction.BuildercardholderAuthentication(Optional<Transaction.CardholderAuthentication> cardholderAuthentication)final Transaction.BuildercardholderAuthentication(JsonField<Transaction.CardholderAuthentication> cardholderAuthentication)final Transaction.Buildercreated(OffsetDateTime created)Date and time when the transaction first occurred. final Transaction.Buildercreated(JsonField<OffsetDateTime> created)Date and time when the transaction first occurred. final Transaction.Buildermerchant(Transaction.Merchant merchant)final Transaction.Buildermerchant(JsonField<Transaction.Merchant> merchant)final Transaction.BuildermerchantAmount(Long merchantAmount)Analogous to the 'amount', but in the merchant currency. final Transaction.BuildermerchantAmount(Long merchantAmount)Analogous to the 'amount', but in the merchant currency. final Transaction.BuildermerchantAmount(Optional<Long> merchantAmount)Analogous to the 'amount', but in the merchant currency. final Transaction.BuildermerchantAmount(JsonField<Long> merchantAmount)Analogous to the 'amount', but in the merchant currency. final Transaction.BuildermerchantAuthorizationAmount(Long merchantAuthorizationAmount)Analogous to the 'authorization_amount', but in the merchant currency. final Transaction.BuildermerchantAuthorizationAmount(Long merchantAuthorizationAmount)Analogous to the 'authorization_amount', but in the merchant currency. final Transaction.BuildermerchantAuthorizationAmount(Optional<Long> merchantAuthorizationAmount)Analogous to the 'authorization_amount', but in the merchant currency. final Transaction.BuildermerchantAuthorizationAmount(JsonField<Long> merchantAuthorizationAmount)Analogous to the 'authorization_amount', but in the merchant currency. final Transaction.BuildermerchantCurrency(String merchantCurrency)3-character alphabetic ISO 4217 code for the local currency of the transaction. final Transaction.BuildermerchantCurrency(JsonField<String> merchantCurrency)3-character alphabetic ISO 4217 code for the local currency of the transaction. final Transaction.Buildernetwork(Transaction.Network network)Card network of the authorization. final Transaction.Buildernetwork(Optional<Transaction.Network> network)Card network of the authorization. final Transaction.Buildernetwork(JsonField<Transaction.Network> network)Card network of the authorization. final Transaction.BuildernetworkRiskScore(Long networkRiskScore)Network-provided score assessing risk level associated with a given authorization. final Transaction.BuildernetworkRiskScore(Long networkRiskScore)Network-provided score assessing risk level associated with a given authorization. final Transaction.BuildernetworkRiskScore(Optional<Long> networkRiskScore)Network-provided score assessing risk level associated with a given authorization. final Transaction.BuildernetworkRiskScore(JsonField<Long> networkRiskScore)Network-provided score assessing risk level associated with a given authorization. final Transaction.Builderpos(Transaction.Pos pos)final Transaction.Builderpos(JsonField<Transaction.Pos> pos)final Transaction.Builderresult(Transaction.DeclineResult result)final Transaction.Builderresult(JsonField<Transaction.DeclineResult> result)final Transaction.BuildersettledAmount(Long settledAmount)The settled amount of the transaction in the settlement currency. final Transaction.BuildersettledAmount(JsonField<Long> settledAmount)The settled amount of the transaction in the settlement currency. final Transaction.Builderstatus(Transaction.Status status)Status of the transaction. final Transaction.Builderstatus(JsonField<Transaction.Status> status)Status of the transaction. final Transaction.BuildertokenInfo(Transaction.TokenInfo tokenInfo)final Transaction.BuildertokenInfo(Optional<Transaction.TokenInfo> tokenInfo)final Transaction.BuildertokenInfo(JsonField<Transaction.TokenInfo> tokenInfo)final Transaction.Builderupdated(OffsetDateTime updated)Date and time when the transaction last updated. final Transaction.Builderupdated(JsonField<OffsetDateTime> updated)Date and time when the transaction last updated. final Transaction.Builderevents(List<Transaction.TransactionEvent> events)final Transaction.Builderevents(JsonField<List<Transaction.TransactionEvent>> events)final Transaction.BuilderaddEvent(Transaction.TransactionEvent event)final Transaction.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Transaction.BuilderputAdditionalProperty(String key, JsonValue value)final Transaction.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Transaction.BuilderremoveAdditionalProperty(String key)final Transaction.BuilderremoveAllAdditionalProperties(Set<String> keys)final Transactionbuild()-
-
Method Detail
-
token
final Transaction.Builder token(String token)
Globally unique identifier.
-
token
final Transaction.Builder token(JsonField<String> token)
Globally unique identifier.
-
accountToken
final Transaction.Builder accountToken(String accountToken)
The token for the account associated with this transaction.
-
accountToken
final Transaction.Builder accountToken(JsonField<String> accountToken)
The token for the account associated with this transaction.
-
acquirerFee
final Transaction.Builder acquirerFee(Long acquirerFee)
Fee assessed by the merchant and paid for by the cardholder in the smallest unit of the currency. Will be zero if no fee is assessed. Rebates may be transmitted as a negative value to indicate credited fees.
-
acquirerFee
final Transaction.Builder acquirerFee(Long acquirerFee)
Fee assessed by the merchant and paid for by the cardholder in the smallest unit of the currency. Will be zero if no fee is assessed. Rebates may be transmitted as a negative value to indicate credited fees.
-
acquirerFee
final Transaction.Builder acquirerFee(Optional<Long> acquirerFee)
Fee assessed by the merchant and paid for by the cardholder in the smallest unit of the currency. Will be zero if no fee is assessed. Rebates may be transmitted as a negative value to indicate credited fees.
-
acquirerFee
final Transaction.Builder acquirerFee(JsonField<Long> acquirerFee)
Fee assessed by the merchant and paid for by the cardholder in the smallest unit of the currency. Will be zero if no fee is assessed. Rebates may be transmitted as a negative value to indicate credited fees.
-
acquirerReferenceNumber
@Deprecated(message = "deprecated") final Transaction.Builder acquirerReferenceNumber(String acquirerReferenceNumber)
Unique identifier assigned to a transaction by the acquirer that can be used in dispute and chargeback filing.
-
acquirerReferenceNumber
@Deprecated(message = "deprecated") final Transaction.Builder acquirerReferenceNumber(Optional<String> acquirerReferenceNumber)
Unique identifier assigned to a transaction by the acquirer that can be used in dispute and chargeback filing.
-
acquirerReferenceNumber
@Deprecated(message = "deprecated") final Transaction.Builder acquirerReferenceNumber(JsonField<String> acquirerReferenceNumber)
Unique identifier assigned to a transaction by the acquirer that can be used in dispute and chargeback filing.
-
amount
@Deprecated(message = "deprecated") final Transaction.Builder amount(Long amount)
When the transaction is pending, this represents the authorization amount of the transaction in the anticipated settlement currency. Once the transaction has settled, this field represents the settled amount in the settlement currency.
-
amount
@Deprecated(message = "deprecated") final Transaction.Builder amount(JsonField<Long> amount)
When the transaction is pending, this represents the authorization amount of the transaction in the anticipated settlement currency. Once the transaction has settled, this field represents the settled amount in the settlement currency.
-
amounts
final Transaction.Builder amounts(Transaction.TransactionAmounts amounts)
-
amounts
final Transaction.Builder amounts(JsonField<Transaction.TransactionAmounts> amounts)
-
authorizationAmount
@Deprecated(message = "deprecated") final Transaction.Builder authorizationAmount(Long authorizationAmount)
The authorization amount of the transaction in the anticipated settlement currency.
-
authorizationAmount
@Deprecated(message = "deprecated") final Transaction.Builder authorizationAmount(Long authorizationAmount)
The authorization amount of the transaction in the anticipated settlement currency.
-
authorizationAmount
@Deprecated(message = "deprecated") final Transaction.Builder authorizationAmount(Optional<Long> authorizationAmount)
The authorization amount of the transaction in the anticipated settlement currency.
-
authorizationAmount
@Deprecated(message = "deprecated") final Transaction.Builder authorizationAmount(JsonField<Long> authorizationAmount)
The authorization amount of the transaction in the anticipated settlement currency.
-
authorizationCode
final Transaction.Builder authorizationCode(String authorizationCode)
A fixed-width 6-digit numeric identifier that can be used to identify a transaction with networks.
-
authorizationCode
final Transaction.Builder authorizationCode(Optional<String> authorizationCode)
A fixed-width 6-digit numeric identifier that can be used to identify a transaction with networks.
-
authorizationCode
final Transaction.Builder authorizationCode(JsonField<String> authorizationCode)
A fixed-width 6-digit numeric identifier that can be used to identify a transaction with networks.
-
avs
final Transaction.Builder avs(Transaction.Avs avs)
-
avs
final Transaction.Builder avs(Optional<Transaction.Avs> avs)
-
avs
final Transaction.Builder avs(JsonField<Transaction.Avs> avs)
-
cardToken
final Transaction.Builder cardToken(String cardToken)
Token for the card used in this transaction.
-
cardToken
final Transaction.Builder cardToken(JsonField<String> cardToken)
Token for the card used in this transaction.
-
cardholderAuthentication
final Transaction.Builder cardholderAuthentication(Transaction.CardholderAuthentication cardholderAuthentication)
-
cardholderAuthentication
final Transaction.Builder cardholderAuthentication(Optional<Transaction.CardholderAuthentication> cardholderAuthentication)
-
cardholderAuthentication
final Transaction.Builder cardholderAuthentication(JsonField<Transaction.CardholderAuthentication> cardholderAuthentication)
-
created
final Transaction.Builder created(OffsetDateTime created)
Date and time when the transaction first occurred. UTC time zone.
-
created
final Transaction.Builder created(JsonField<OffsetDateTime> created)
Date and time when the transaction first occurred. UTC time zone.
-
merchant
final Transaction.Builder merchant(Transaction.Merchant merchant)
-
merchant
final Transaction.Builder merchant(JsonField<Transaction.Merchant> merchant)
-
merchantAmount
@Deprecated(message = "deprecated") final Transaction.Builder merchantAmount(Long merchantAmount)
Analogous to the 'amount', but in the merchant currency.
-
merchantAmount
@Deprecated(message = "deprecated") final Transaction.Builder merchantAmount(Long merchantAmount)
Analogous to the 'amount', but in the merchant currency.
-
merchantAmount
@Deprecated(message = "deprecated") final Transaction.Builder merchantAmount(Optional<Long> merchantAmount)
Analogous to the 'amount', but in the merchant currency.
-
merchantAmount
@Deprecated(message = "deprecated") final Transaction.Builder merchantAmount(JsonField<Long> merchantAmount)
Analogous to the 'amount', but in the merchant currency.
-
merchantAuthorizationAmount
@Deprecated(message = "deprecated") final Transaction.Builder merchantAuthorizationAmount(Long merchantAuthorizationAmount)
Analogous to the 'authorization_amount', but in the merchant currency.
-
merchantAuthorizationAmount
@Deprecated(message = "deprecated") final Transaction.Builder merchantAuthorizationAmount(Long merchantAuthorizationAmount)
Analogous to the 'authorization_amount', but in the merchant currency.
-
merchantAuthorizationAmount
@Deprecated(message = "deprecated") final Transaction.Builder merchantAuthorizationAmount(Optional<Long> merchantAuthorizationAmount)
Analogous to the 'authorization_amount', but in the merchant currency.
-
merchantAuthorizationAmount
@Deprecated(message = "deprecated") final Transaction.Builder merchantAuthorizationAmount(JsonField<Long> merchantAuthorizationAmount)
Analogous to the 'authorization_amount', but in the merchant currency.
-
merchantCurrency
@Deprecated(message = "deprecated") final Transaction.Builder merchantCurrency(String merchantCurrency)
3-character alphabetic ISO 4217 code for the local currency of the transaction.
-
merchantCurrency
@Deprecated(message = "deprecated") final Transaction.Builder merchantCurrency(JsonField<String> merchantCurrency)
3-character alphabetic ISO 4217 code for the local currency of the transaction.
-
network
final Transaction.Builder network(Transaction.Network network)
Card network of the authorization. Can be
INTERLINK,MAESTRO,MASTERCARD,VISA, orUNKNOWN. Value isUNKNOWNwhen Lithic cannot determine the network code from the upstream provider.
-
network
final Transaction.Builder network(Optional<Transaction.Network> network)
Card network of the authorization. Can be
INTERLINK,MAESTRO,MASTERCARD,VISA, orUNKNOWN. Value isUNKNOWNwhen Lithic cannot determine the network code from the upstream provider.
-
network
final Transaction.Builder network(JsonField<Transaction.Network> network)
Card network of the authorization. Can be
INTERLINK,MAESTRO,MASTERCARD,VISA, orUNKNOWN. Value isUNKNOWNwhen Lithic cannot determine the network code from the upstream provider.
-
networkRiskScore
final Transaction.Builder networkRiskScore(Long networkRiskScore)
Network-provided score assessing risk level associated with a given authorization. Scores are on a range of 0-999, with 0 representing the lowest risk and 999 representing the highest risk. For Visa transactions, where the raw score has a range of 0-99, Lithic will normalize the score by multiplying the raw score by 10x.
-
networkRiskScore
final Transaction.Builder networkRiskScore(Long networkRiskScore)
Network-provided score assessing risk level associated with a given authorization. Scores are on a range of 0-999, with 0 representing the lowest risk and 999 representing the highest risk. For Visa transactions, where the raw score has a range of 0-99, Lithic will normalize the score by multiplying the raw score by 10x.
-
networkRiskScore
final Transaction.Builder networkRiskScore(Optional<Long> networkRiskScore)
Network-provided score assessing risk level associated with a given authorization. Scores are on a range of 0-999, with 0 representing the lowest risk and 999 representing the highest risk. For Visa transactions, where the raw score has a range of 0-99, Lithic will normalize the score by multiplying the raw score by 10x.
-
networkRiskScore
final Transaction.Builder networkRiskScore(JsonField<Long> networkRiskScore)
Network-provided score assessing risk level associated with a given authorization. Scores are on a range of 0-999, with 0 representing the lowest risk and 999 representing the highest risk. For Visa transactions, where the raw score has a range of 0-99, Lithic will normalize the score by multiplying the raw score by 10x.
-
pos
final Transaction.Builder pos(Transaction.Pos pos)
-
pos
final Transaction.Builder pos(JsonField<Transaction.Pos> pos)
-
result
final Transaction.Builder result(Transaction.DeclineResult result)
-
result
final Transaction.Builder result(JsonField<Transaction.DeclineResult> result)
-
settledAmount
@Deprecated(message = "deprecated") final Transaction.Builder settledAmount(Long settledAmount)
The settled amount of the transaction in the settlement currency.
-
settledAmount
@Deprecated(message = "deprecated") final Transaction.Builder settledAmount(JsonField<Long> settledAmount)
The settled amount of the transaction in the settlement currency.
-
status
final Transaction.Builder status(Transaction.Status status)
Status of the transaction.
-
status
final Transaction.Builder status(JsonField<Transaction.Status> status)
Status of the transaction.
-
tokenInfo
final Transaction.Builder tokenInfo(Transaction.TokenInfo tokenInfo)
-
tokenInfo
final Transaction.Builder tokenInfo(Optional<Transaction.TokenInfo> tokenInfo)
-
tokenInfo
final Transaction.Builder tokenInfo(JsonField<Transaction.TokenInfo> tokenInfo)
-
updated
final Transaction.Builder updated(OffsetDateTime updated)
Date and time when the transaction last updated. UTC time zone.
-
updated
final Transaction.Builder updated(JsonField<OffsetDateTime> updated)
Date and time when the transaction last updated. UTC time zone.
-
events
final Transaction.Builder events(List<Transaction.TransactionEvent> events)
-
events
final Transaction.Builder events(JsonField<List<Transaction.TransactionEvent>> events)
-
addEvent
final Transaction.Builder addEvent(Transaction.TransactionEvent event)
-
additionalProperties
final Transaction.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction build()
-
-
-
-