Class Transaction.CardholderAuthentication
-
- All Implemented Interfaces:
public final class Transaction.CardholderAuthentication
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.CardholderAuthentication.BuilderA builder for CardholderAuthentication.
public final classTransaction.CardholderAuthentication.AuthenticationMethodIndicates the method used to authenticate the cardholder.
public final classTransaction.CardholderAuthentication.AuthenticationResultIndicates the outcome of the 3DS authentication process.
public final classTransaction.CardholderAuthentication.DecisionMadeByIndicates which party made the 3DS authentication decision.
public final classTransaction.CardholderAuthentication.LiabilityShiftIndicates whether chargeback liability shift applies to the transaction. Possible enum values:
3DS_AUTHENTICATED: The transaction was fully authenticated through a 3-D Secure flow, chargeback liability shift applies.NONE: Chargeback liability shift has not shifted to the issuer, i.e. the merchant is liable.TOKEN_AUTHENTICATED: The transaction was a tokenized payment with validated cryptography, possibly recurring. Chargeback liability shift to the issuer applies.
-
Method Summary
-
-
Method Detail
-
authenticationMethod
final Transaction.CardholderAuthentication.AuthenticationMethod authenticationMethod()
Indicates the method used to authenticate the cardholder.
-
authenticationResult
final Transaction.CardholderAuthentication.AuthenticationResult authenticationResult()
Indicates the outcome of the 3DS authentication process.
-
decisionMadeBy
final Transaction.CardholderAuthentication.DecisionMadeBy decisionMadeBy()
Indicates which party made the 3DS authentication decision.
-
liabilityShift
final Transaction.CardholderAuthentication.LiabilityShift liabilityShift()
Indicates whether chargeback liability shift applies to the transaction. Possible enum values:
3DS_AUTHENTICATED: The transaction was fully authenticated through a 3-D Secure flow, chargeback liability shift applies.NONE: Chargeback liability shift has not shifted to the issuer, i.e. the merchant is liable.TOKEN_AUTHENTICATED: The transaction was a tokenized payment with validated cryptography, possibly recurring. Chargeback liability shift to the issuer applies.
-
threeDSAuthenticationToken
final Optional<String> threeDSAuthenticationToken()
Unique identifier you can use to match a given 3DS authentication (available via the three_ds_authentication.created event webhook) and the transaction. Note that in cases where liability shift does not occur, this token is matched to the transaction on a best-effort basis.
-
_authenticationMethod
final JsonField<Transaction.CardholderAuthentication.AuthenticationMethod> _authenticationMethod()
Returns the raw JSON value of authenticationMethod.
Unlike authenticationMethod, this method doesn't throw if the JSON field has an unexpected type.
-
_authenticationResult
final JsonField<Transaction.CardholderAuthentication.AuthenticationResult> _authenticationResult()
Returns the raw JSON value of authenticationResult.
Unlike authenticationResult, this method doesn't throw if the JSON field has an unexpected type.
-
_decisionMadeBy
final JsonField<Transaction.CardholderAuthentication.DecisionMadeBy> _decisionMadeBy()
Returns the raw JSON value of decisionMadeBy.
Unlike decisionMadeBy, this method doesn't throw if the JSON field has an unexpected type.
-
_liabilityShift
final JsonField<Transaction.CardholderAuthentication.LiabilityShift> _liabilityShift()
Returns the raw JSON value of liabilityShift.
Unlike liabilityShift, this method doesn't throw if the JSON field has an unexpected type.
-
_threeDSAuthenticationToken
final JsonField<String> _threeDSAuthenticationToken()
Returns the raw JSON value of threeDSAuthenticationToken.
Unlike threeDSAuthenticationToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.CardholderAuthentication.Builder toBuilder()
-
validate
final Transaction.CardholderAuthentication validate()
-
builder
final static Transaction.CardholderAuthentication.Builder builder()
Returns a mutable builder for constructing an instance of CardholderAuthentication.
The following fields are required:
.authenticationMethod() .authenticationResult() .decisionMadeBy() .liabilityShift() .threeDSAuthenticationToken()
-
-
-
-