Class Transaction.CardholderAuthentication.Builder
-
- All Implemented Interfaces:
public final class Transaction.CardholderAuthentication.BuilderA builder for CardholderAuthentication.
-
-
Method Summary
-
-
Method Detail
-
authenticationMethod
final Transaction.CardholderAuthentication.Builder authenticationMethod(Transaction.CardholderAuthentication.AuthenticationMethod authenticationMethod)
Indicates the method used to authenticate the cardholder.
-
authenticationMethod
final Transaction.CardholderAuthentication.Builder authenticationMethod(JsonField<Transaction.CardholderAuthentication.AuthenticationMethod> authenticationMethod)
Sets Builder.authenticationMethod to an arbitrary JSON value.
You should usually call Builder.authenticationMethod with a well-typed AuthenticationMethod value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
authenticationResult
final Transaction.CardholderAuthentication.Builder authenticationResult(Transaction.CardholderAuthentication.AuthenticationResult authenticationResult)
Indicates the outcome of the 3DS authentication process.
-
authenticationResult
final Transaction.CardholderAuthentication.Builder authenticationResult(JsonField<Transaction.CardholderAuthentication.AuthenticationResult> authenticationResult)
Sets Builder.authenticationResult to an arbitrary JSON value.
You should usually call Builder.authenticationResult with a well-typed AuthenticationResult value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
decisionMadeBy
final Transaction.CardholderAuthentication.Builder decisionMadeBy(Transaction.CardholderAuthentication.DecisionMadeBy decisionMadeBy)
Indicates which party made the 3DS authentication decision.
-
decisionMadeBy
final Transaction.CardholderAuthentication.Builder decisionMadeBy(JsonField<Transaction.CardholderAuthentication.DecisionMadeBy> decisionMadeBy)
Sets Builder.decisionMadeBy to an arbitrary JSON value.
You should usually call Builder.decisionMadeBy with a well-typed DecisionMadeBy value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
liabilityShift
final Transaction.CardholderAuthentication.Builder liabilityShift(Transaction.CardholderAuthentication.LiabilityShift liabilityShift)
Indicates whether chargeback liability shift applies to the transaction. Possible enum values:
3DS_AUTHENTICATED: The transaction was fully authenticated through a 3-D Secure flow, chargeback liability shift applies.NONE: Chargeback liability shift has not shifted to the issuer, i.e. the merchant is liable.TOKEN_AUTHENTICATED: The transaction was a tokenized payment with validated cryptography, possibly recurring. Chargeback liability shift to the issuer applies.
-
liabilityShift
final Transaction.CardholderAuthentication.Builder liabilityShift(JsonField<Transaction.CardholderAuthentication.LiabilityShift> liabilityShift)
Sets Builder.liabilityShift to an arbitrary JSON value.
You should usually call Builder.liabilityShift with a well-typed LiabilityShift value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
threeDSAuthenticationToken
final Transaction.CardholderAuthentication.Builder threeDSAuthenticationToken(String threeDSAuthenticationToken)
Unique identifier you can use to match a given 3DS authentication (available via the three_ds_authentication.created event webhook) and the transaction. Note that in cases where liability shift does not occur, this token is matched to the transaction on a best-effort basis.
-
threeDSAuthenticationToken
final Transaction.CardholderAuthentication.Builder threeDSAuthenticationToken(Optional<String> threeDSAuthenticationToken)
Alias for calling Builder.threeDSAuthenticationToken with
threeDSAuthenticationToken.orElse(null).
-
threeDSAuthenticationToken
final Transaction.CardholderAuthentication.Builder threeDSAuthenticationToken(JsonField<String> threeDSAuthenticationToken)
Sets Builder.threeDSAuthenticationToken to an arbitrary JSON value.
You should usually call Builder.threeDSAuthenticationToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.CardholderAuthentication.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.CardholderAuthentication.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.CardholderAuthentication.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.CardholderAuthentication.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.CardholderAuthentication.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.CardholderAuthentication build()
Returns an immutable instance of CardholderAuthentication.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.authenticationMethod() .authenticationResult() .decisionMadeBy() .liabilityShift() .threeDSAuthenticationToken()
-
-
-
-