Class Transaction.ServiceLocation

  • All Implemented Interfaces:

    
    public final class Transaction.ServiceLocation
    
                        

    Where the cardholder received the service, when different from the card acceptor location. This is populated from network data elements such as Mastercard DE-122 SE1 SF9-14 and Visa F34 DS02.