Package com.lithic.api.models
Class Transaction.TokenInfo.Builder
-
- All Implemented Interfaces:
public final class Transaction.TokenInfo.BuilderA builder for TokenInfo.
-
-
Method Summary
Modifier and Type Method Description final Transaction.TokenInfo.BuilderwalletType(Transaction.TokenInfo.WalletType walletType)The wallet_type field will indicate the source of the token. final Transaction.TokenInfo.BuilderwalletType(JsonField<Transaction.TokenInfo.WalletType> walletType)Sets Builder.walletType to an arbitrary JSON value. final Transaction.TokenInfo.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Transaction.TokenInfo.BuilderputAdditionalProperty(String key, JsonValue value)final Transaction.TokenInfo.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Transaction.TokenInfo.BuilderremoveAdditionalProperty(String key)final Transaction.TokenInfo.BuilderremoveAllAdditionalProperties(Set<String> keys)final Transaction.TokenInfobuild()Returns an immutable instance of TokenInfo. -
-
Method Detail
-
walletType
final Transaction.TokenInfo.Builder walletType(Transaction.TokenInfo.WalletType walletType)
The wallet_type field will indicate the source of the token. Possible token sources include digital wallets (Apple, Google, or Samsung Pay), merchant tokenization, and “other” sources like in-flight commerce. Masterpass is not currently supported and is included for future use.
-
walletType
final Transaction.TokenInfo.Builder walletType(JsonField<Transaction.TokenInfo.WalletType> walletType)
Sets Builder.walletType to an arbitrary JSON value.
You should usually call Builder.walletType with a well-typed WalletType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.TokenInfo.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.TokenInfo.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.TokenInfo.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.TokenInfo.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.TokenInfo.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.TokenInfo build()
Returns an immutable instance of TokenInfo.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.walletType()
-
-
-
-