Package com.lithic.api.models
Class Transaction.TransactionAmounts.Cardholder
-
- All Implemented Interfaces:
public final class Transaction.TransactionAmounts.Cardholder
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.TransactionAmounts.Cardholder.BuilderA builder for Cardholder.
-
Method Summary
Modifier and Type Method Description final Longamount()The estimated settled amount of the transaction in the cardholder billing currency. final StringconversionRate()The exchange rate used to convert the merchant amount to the cardholder billing amount. final Stringcurrency()3-character alphabetic ISO 4217 currency final JsonField<Long>_amount()The estimated settled amount of the transaction in the cardholder billing currency. final JsonField<String>_conversionRate()The exchange rate used to convert the merchant amount to the cardholder billing amount. final JsonField<String>_currency()3-character alphabetic ISO 4217 currency final Map<String, JsonValue>_additionalProperties()final Transaction.TransactionAmounts.Cardholdervalidate()final Transaction.TransactionAmounts.Cardholder.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.TransactionAmounts.Cardholder.Builderbuilder()Returns a mutable builder for constructing an instance of Cardholder. -
-
Method Detail
-
amount
final Long amount()
The estimated settled amount of the transaction in the cardholder billing currency.
-
conversionRate
final String conversionRate()
The exchange rate used to convert the merchant amount to the cardholder billing amount.
-
_amount
final JsonField<Long> _amount()
The estimated settled amount of the transaction in the cardholder billing currency.
-
_conversionRate
final JsonField<String> _conversionRate()
The exchange rate used to convert the merchant amount to the cardholder billing amount.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.TransactionAmounts.Cardholder validate()
-
toBuilder
final Transaction.TransactionAmounts.Cardholder.Builder toBuilder()
-
builder
final static Transaction.TransactionAmounts.Cardholder.Builder builder()
Returns a mutable builder for constructing an instance of Cardholder.
The following fields are required:
.amount() .conversionRate() .currency()
-
-
-
-