Package com.lithic.api.models
Class Transaction.TransactionAmounts.Hold
-
- All Implemented Interfaces:
public final class Transaction.TransactionAmounts.Hold
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.TransactionAmounts.Hold.BuilderA builder for Hold.
-
Method Summary
Modifier and Type Method Description final Longamount()The pending amount of the transaction in the anticipated settlement currency. final Stringcurrency()3-character alphabetic ISO 4217 currency final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_currency()Returns the raw JSON value of currency. final Map<String, JsonValue>_additionalProperties()final Transaction.TransactionAmounts.Hold.BuildertoBuilder()final Transaction.TransactionAmounts.Holdvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.TransactionAmounts.Hold.Builderbuilder()Returns a mutable builder for constructing an instance of Hold. -
-
Method Detail
-
amount
final Long amount()
The pending amount of the transaction in the anticipated settlement currency.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.TransactionAmounts.Hold.Builder toBuilder()
-
validate
final Transaction.TransactionAmounts.Hold validate()
-
builder
final static Transaction.TransactionAmounts.Hold.Builder builder()
Returns a mutable builder for constructing an instance of Hold.
The following fields are required:
.amount() .currency()
-
-
-
-