Package com.lithic.api.models
Class Transaction.TransactionAmounts.Merchant
-
- All Implemented Interfaces:
public final class Transaction.TransactionAmounts.Merchant
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.TransactionAmounts.Merchant.BuilderA builder for Merchant.
-
Method Summary
Modifier and Type Method Description final Longamount()The settled amount of the transaction in the merchant currency. final Stringcurrency()3-character alphabetic ISO 4217 currency final JsonField<Long>_amount()The settled amount of the transaction in the merchant currency. final JsonField<String>_currency()3-character alphabetic ISO 4217 currency final Map<String, JsonValue>_additionalProperties()final Transaction.TransactionAmounts.Merchantvalidate()final Transaction.TransactionAmounts.Merchant.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.TransactionAmounts.Merchant.Builderbuilder()Returns a mutable builder for constructing an instance of Merchant. -
-
Method Detail
-
_amount
final JsonField<Long> _amount()
The settled amount of the transaction in the merchant currency.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.TransactionAmounts.Merchant validate()
-
toBuilder
final Transaction.TransactionAmounts.Merchant.Builder toBuilder()
-
builder
final static Transaction.TransactionAmounts.Merchant.Builder builder()
Returns a mutable builder for constructing an instance of Merchant.
The following fields are required:
.amount() .currency()
-
-
-
-