Class Transaction.TransactionEvent.NetworkInfo.Amex.Builder
-
- All Implemented Interfaces:
public final class Transaction.TransactionEvent.NetworkInfo.Amex.BuilderA builder for Amex.
-
-
Method Summary
-
-
Method Detail
-
originalTransactionId
final Transaction.TransactionEvent.NetworkInfo.Amex.Builder originalTransactionId(String originalTransactionId)
Identifier assigned by American Express. Matches the
transaction_idof a prior related event. May be populated in incremental authorizations (authorization requests that augment a previously authorized amount), authorization advices, financial authorizations, and clearings.
-
originalTransactionId
final Transaction.TransactionEvent.NetworkInfo.Amex.Builder originalTransactionId(Optional<String> originalTransactionId)
Alias for calling Builder.originalTransactionId with
originalTransactionId.orElse(null).
-
originalTransactionId
final Transaction.TransactionEvent.NetworkInfo.Amex.Builder originalTransactionId(JsonField<String> originalTransactionId)
Sets Builder.originalTransactionId to an arbitrary JSON value.
You should usually call Builder.originalTransactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionId
final Transaction.TransactionEvent.NetworkInfo.Amex.Builder transactionId(String transactionId)
Identifier assigned by American Express to link original messages to subsequent messages. Guaranteed by American Express to be unique for each original authorization and financial authorization.
-
transactionId
final Transaction.TransactionEvent.NetworkInfo.Amex.Builder transactionId(Optional<String> transactionId)
Alias for calling Builder.transactionId with
transactionId.orElse(null).
-
transactionId
final Transaction.TransactionEvent.NetworkInfo.Amex.Builder transactionId(JsonField<String> transactionId)
Sets Builder.transactionId to an arbitrary JSON value.
You should usually call Builder.transactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.TransactionEvent.NetworkInfo.Amex.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.TransactionEvent.NetworkInfo.Amex.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.TransactionEvent.NetworkInfo.Amex.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.TransactionEvent.NetworkInfo.Amex.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.TransactionEvent.NetworkInfo.Amex.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.TransactionEvent.NetworkInfo.Amex build()
Returns an immutable instance of Amex.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.originalTransactionId() .transactionId()
-
-
-
-