Class Transaction.TransactionEvent.NetworkInfo.Mastercard

    • Constructor Detail

    • Method Detail

      • banknetReferenceNumber

         final Optional<String> banknetReferenceNumber()

        Identifier assigned by Mastercard. Guaranteed by Mastercard to be unique for any transaction within a specific financial network on any processing day.

      • originalBanknetReferenceNumber

         final Optional<String> originalBanknetReferenceNumber()

        Identifier assigned by Mastercard. Matches the banknet_reference_number of a prior related event. May be populated in authorization reversals, incremental authorizations (authorization requests that augment a previously authorized amount), automated fuel dispenser authorization advices and clearings, and financial authorizations. If the original banknet reference number contains all zeroes, then no actual reference number could be found by the network or acquirer. If Mastercard converts a transaction from dual-message to single-message, such as for certain ATM transactions, it will populate the original banknet reference number in the resulting financial authorization with the banknet reference number of the initial authorization, which Lithic does not receive.

      • originalSwitchSerialNumber

         final Optional<String> originalSwitchSerialNumber()

        Identifier assigned by Mastercard. Matches the switch_serial_number of a prior related event. May be populated in returns and return reversals. Applicable to single-message transactions only.

      • _banknetReferenceNumber

         final JsonField<String> _banknetReferenceNumber()

        Identifier assigned by Mastercard. Guaranteed by Mastercard to be unique for any transaction within a specific financial network on any processing day.

      • _originalBanknetReferenceNumber

         final JsonField<String> _originalBanknetReferenceNumber()

        Identifier assigned by Mastercard. Matches the banknet_reference_number of a prior related event. May be populated in authorization reversals, incremental authorizations (authorization requests that augment a previously authorized amount), automated fuel dispenser authorization advices and clearings, and financial authorizations. If the original banknet reference number contains all zeroes, then no actual reference number could be found by the network or acquirer. If Mastercard converts a transaction from dual-message to single-message, such as for certain ATM transactions, it will populate the original banknet reference number in the resulting financial authorization with the banknet reference number of the initial authorization, which Lithic does not receive.

      • _originalSwitchSerialNumber

         final JsonField<String> _originalSwitchSerialNumber()

        Identifier assigned by Mastercard. Matches the switch_serial_number of a prior related event. May be populated in returns and return reversals. Applicable to single-message transactions only.