Class Transaction.TransactionEvent.TransactionEventAmounts.Settlement.Builder
-
- All Implemented Interfaces:
public final class Transaction.TransactionEvent.TransactionEventAmounts.Settlement.BuilderA builder for Settlement.
-
-
Method Summary
-
-
Method Detail
-
amount
final Transaction.TransactionEvent.TransactionEventAmounts.Settlement.Builder amount(Long amount)
Amount of the event, if it is financial, in the settlement currency. Non-financial events do not contain this amount because they do not move funds.
-
amount
final Transaction.TransactionEvent.TransactionEventAmounts.Settlement.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
conversionRate
final Transaction.TransactionEvent.TransactionEventAmounts.Settlement.Builder conversionRate(String conversionRate)
Exchange rate used to convert the merchant amount to the settlement amount.
-
conversionRate
final Transaction.TransactionEvent.TransactionEventAmounts.Settlement.Builder conversionRate(JsonField<String> conversionRate)
Sets Builder.conversionRate to an arbitrary JSON value.
You should usually call Builder.conversionRate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final Transaction.TransactionEvent.TransactionEventAmounts.Settlement.Builder currency(String currency)
3-character alphabetic ISO 4217 currency
-
currency
final Transaction.TransactionEvent.TransactionEventAmounts.Settlement.Builder currency(JsonField<String> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.TransactionEvent.TransactionEventAmounts.Settlement.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.TransactionEvent.TransactionEventAmounts.Settlement.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.TransactionEvent.TransactionEventAmounts.Settlement.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.TransactionEvent.TransactionEventAmounts.Settlement.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.TransactionEvent.TransactionEventAmounts.Settlement.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.TransactionEvent.TransactionEventAmounts.Settlement build()
Returns an immutable instance of Settlement.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.amount() .conversionRate() .currency()
-
-
-
-