Class Transaction.TransactionMerchant
-
- All Implemented Interfaces:
public final class Transaction.TransactionMerchantMerchant information including full location details.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.TransactionMerchant.BuilderA builder for TransactionMerchant.
-
Method Summary
Modifier and Type Method Description final MerchanttoMerchant()final StringacceptorId()Unique alphanumeric identifier for the payment card acceptor (merchant). final StringacquiringInstitutionId()Unique numeric identifier of the acquiring institution. final Stringcity()City of card acceptor. final Stringcountry()Country or entity of card acceptor. final Stringdescriptor()Short description of card acceptor. final Stringmcc()Merchant category code (MCC). final Stringstate()Geographic state of card acceptor. final Optional<String>phoneNumber()Phone number of card acceptor. final Optional<String>postalCode()Postal code of card acceptor. final Optional<String>streetAddress()Street address of card acceptor. final JsonField<String>_acceptorId()Returns the raw JSON value of acceptorId. final JsonField<String>_acquiringInstitutionId()Returns the raw JSON value of acquiringInstitutionId. final JsonField<String>_city()Returns the raw JSON value of city. final JsonField<String>_country()Returns the raw JSON value of country. final JsonField<String>_descriptor()Returns the raw JSON value of descriptor. final JsonField<String>_mcc()Returns the raw JSON value of mcc. final JsonField<String>_state()Returns the raw JSON value of state. final JsonField<String>_phoneNumber()Returns the raw JSON value of phoneNumber. final JsonField<String>_postalCode()Returns the raw JSON value of postalCode. final JsonField<String>_streetAddress()Returns the raw JSON value of streetAddress. final Map<String, JsonValue>_additionalProperties()final Transaction.TransactionMerchant.BuildertoBuilder()final Transaction.TransactionMerchantvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.TransactionMerchant.Builderbuilder()Returns a mutable builder for constructing an instance of TransactionMerchant. -
-
Method Detail
-
toMerchant
final Merchant toMerchant()
-
acceptorId
final String acceptorId()
Unique alphanumeric identifier for the payment card acceptor (merchant).
-
acquiringInstitutionId
final String acquiringInstitutionId()
Unique numeric identifier of the acquiring institution.
-
city
final String city()
City of card acceptor. Note that in many cases, particularly in card-not-present transactions, merchants may send through a phone number or URL in this field.
-
country
final String country()
Country or entity of card acceptor. Possible values are: (1) all ISO 3166-1 alpha-3 country codes, (2) QZZ for Kosovo, and (3) ANT for Netherlands Antilles.
-
descriptor
final String descriptor()
Short description of card acceptor.
-
mcc
final String mcc()
Merchant category code (MCC). A four-digit number listed in ISO 18245. An MCC is used to classify a business by the types of goods or services it provides.
-
phoneNumber
final Optional<String> phoneNumber()
Phone number of card acceptor.
-
postalCode
final Optional<String> postalCode()
Postal code of card acceptor.
-
streetAddress
final Optional<String> streetAddress()
Street address of card acceptor.
-
_acceptorId
final JsonField<String> _acceptorId()
Returns the raw JSON value of acceptorId.
Unlike acceptorId, this method doesn't throw if the JSON field has an unexpected type.
-
_acquiringInstitutionId
final JsonField<String> _acquiringInstitutionId()
Returns the raw JSON value of acquiringInstitutionId.
Unlike acquiringInstitutionId, this method doesn't throw if the JSON field has an unexpected type.
-
_city
final JsonField<String> _city()
Returns the raw JSON value of city.
Unlike city, this method doesn't throw if the JSON field has an unexpected type.
-
_country
final JsonField<String> _country()
Returns the raw JSON value of country.
Unlike country, this method doesn't throw if the JSON field has an unexpected type.
-
_descriptor
final JsonField<String> _descriptor()
Returns the raw JSON value of descriptor.
Unlike descriptor, this method doesn't throw if the JSON field has an unexpected type.
-
_mcc
final JsonField<String> _mcc()
Returns the raw JSON value of mcc.
Unlike mcc, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<String> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_phoneNumber
final JsonField<String> _phoneNumber()
Returns the raw JSON value of phoneNumber.
Unlike phoneNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_postalCode
final JsonField<String> _postalCode()
Returns the raw JSON value of postalCode.
Unlike postalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_streetAddress
final JsonField<String> _streetAddress()
Returns the raw JSON value of streetAddress.
Unlike streetAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.TransactionMerchant.Builder toBuilder()
-
validate
final Transaction.TransactionMerchant validate()
-
builder
final static Transaction.TransactionMerchant.Builder builder()
Returns a mutable builder for constructing an instance of TransactionMerchant.
The following fields are required:
.acceptorId() .acquiringInstitutionId() .city() .country() .descriptor() .mcc() .state() .phoneNumber() .postalCode() .streetAddress()
-
-
-
-