Class Transaction.TransactionMerchant.Builder
-
- All Implemented Interfaces:
public final class Transaction.TransactionMerchant.BuilderA builder for TransactionMerchant.
-
-
Method Summary
-
-
Method Detail
-
acceptorId
final Transaction.TransactionMerchant.Builder acceptorId(String acceptorId)
Unique alphanumeric identifier for the payment card acceptor (merchant).
-
acceptorId
final Transaction.TransactionMerchant.Builder acceptorId(JsonField<String> acceptorId)
Sets Builder.acceptorId to an arbitrary JSON value.
You should usually call Builder.acceptorId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
acquiringInstitutionId
final Transaction.TransactionMerchant.Builder acquiringInstitutionId(String acquiringInstitutionId)
Unique numeric identifier of the acquiring institution.
-
acquiringInstitutionId
final Transaction.TransactionMerchant.Builder acquiringInstitutionId(JsonField<String> acquiringInstitutionId)
Sets Builder.acquiringInstitutionId to an arbitrary JSON value.
You should usually call Builder.acquiringInstitutionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
city
final Transaction.TransactionMerchant.Builder city(String city)
City of card acceptor. Note that in many cases, particularly in card-not-present transactions, merchants may send through a phone number or URL in this field.
-
city
final Transaction.TransactionMerchant.Builder city(JsonField<String> city)
Sets Builder.city to an arbitrary JSON value.
You should usually call Builder.city with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
country
final Transaction.TransactionMerchant.Builder country(String country)
Country or entity of card acceptor. Possible values are: (1) all ISO 3166-1 alpha-3 country codes, (2) QZZ for Kosovo, and (3) ANT for Netherlands Antilles.
-
country
final Transaction.TransactionMerchant.Builder country(JsonField<String> country)
Sets Builder.country to an arbitrary JSON value.
You should usually call Builder.country with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
descriptor
final Transaction.TransactionMerchant.Builder descriptor(String descriptor)
Short description of card acceptor.
-
descriptor
final Transaction.TransactionMerchant.Builder descriptor(JsonField<String> descriptor)
Sets Builder.descriptor to an arbitrary JSON value.
You should usually call Builder.descriptor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
mcc
final Transaction.TransactionMerchant.Builder mcc(String mcc)
Merchant category code (MCC). A four-digit number listed in ISO 18245. An MCC is used to classify a business by the types of goods or services it provides.
-
mcc
final Transaction.TransactionMerchant.Builder mcc(JsonField<String> mcc)
Sets Builder.mcc to an arbitrary JSON value.
You should usually call Builder.mcc with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
state
final Transaction.TransactionMerchant.Builder state(String state)
Geographic state of card acceptor.
-
state
final Transaction.TransactionMerchant.Builder state(JsonField<String> state)
Sets Builder.state to an arbitrary JSON value.
You should usually call Builder.state with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
phoneNumber
final Transaction.TransactionMerchant.Builder phoneNumber(String phoneNumber)
Phone number of card acceptor.
-
phoneNumber
final Transaction.TransactionMerchant.Builder phoneNumber(Optional<String> phoneNumber)
Alias for calling Builder.phoneNumber with
phoneNumber.orElse(null).
-
phoneNumber
final Transaction.TransactionMerchant.Builder phoneNumber(JsonField<String> phoneNumber)
Sets Builder.phoneNumber to an arbitrary JSON value.
You should usually call Builder.phoneNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
postalCode
final Transaction.TransactionMerchant.Builder postalCode(String postalCode)
Postal code of card acceptor.
-
postalCode
final Transaction.TransactionMerchant.Builder postalCode(Optional<String> postalCode)
Alias for calling Builder.postalCode with
postalCode.orElse(null).
-
postalCode
final Transaction.TransactionMerchant.Builder postalCode(JsonField<String> postalCode)
Sets Builder.postalCode to an arbitrary JSON value.
You should usually call Builder.postalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
streetAddress
final Transaction.TransactionMerchant.Builder streetAddress(String streetAddress)
Street address of card acceptor.
-
streetAddress
final Transaction.TransactionMerchant.Builder streetAddress(Optional<String> streetAddress)
Alias for calling Builder.streetAddress with
streetAddress.orElse(null).
-
streetAddress
final Transaction.TransactionMerchant.Builder streetAddress(JsonField<String> streetAddress)
Sets Builder.streetAddress to an arbitrary JSON value.
You should usually call Builder.streetAddress with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.TransactionMerchant.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.TransactionMerchant.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.TransactionMerchant.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.TransactionMerchant.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.TransactionMerchant.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.TransactionMerchant build()
Returns an immutable instance of TransactionMerchant.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.acceptorId() .acquiringInstitutionId() .city() .country() .descriptor() .mcc() .state() .phoneNumber() .postalCode() .streetAddress()
-
-
-
-