Package com.lithic.api.models
Class TransactionListPage
-
- All Implemented Interfaces:
public final class TransactionListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionListPage.BuilderA builder for TransactionListPage.
public final classTransactionListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<Transaction>data()Delegates to TransactionListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to TransactionListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<TransactionListParams>getNextPageParams()final Optional<TransactionListPage>getNextPage()final TransactionListPage.AutoPagerautoPager()final TransactionListParamsparams()The parameters that were used to request this page. final TransactionListPageResponseresponse()The response that this page was parsed from. final TransactionListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionListPage.Builderbuilder()Returns a mutable builder for constructing an instance of TransactionListPage. -
-
Method Detail
-
data
final List<Transaction> data()
Delegates to TransactionListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to TransactionListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<TransactionListParams> getNextPageParams()
-
getNextPage
final Optional<TransactionListPage> getNextPage()
-
autoPager
final TransactionListPage.AutoPager autoPager()
-
params
final TransactionListParams params()
The parameters that were used to request this page.
-
response
final TransactionListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final TransactionListPage.Builder toBuilder()
-
builder
final static TransactionListPage.Builder builder()
Returns a mutable builder for constructing an instance of TransactionListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-