Package com.lithic.api.models
Class TransactionListPageAsync
-
- All Implemented Interfaces:
public final class TransactionListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionListPageAsync.BuilderA builder for TransactionListPageAsync.
public final classTransactionListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<Transaction>data()Delegates to TransactionListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to TransactionListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<TransactionListParams>getNextPageParams()final CompletableFuture<Optional<TransactionListPageAsync>>getNextPage()final TransactionListPageAsync.AutoPagerautoPager()final TransactionListParamsparams()The parameters that were used to request this page. final TransactionListPageResponseresponse()The response that this page was parsed from. final TransactionListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of TransactionListPageAsync. -
-
Method Detail
-
data
final List<Transaction> data()
Delegates to TransactionListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to TransactionListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<TransactionListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<TransactionListPageAsync>> getNextPage()
-
autoPager
final TransactionListPageAsync.AutoPager autoPager()
-
params
final TransactionListParams params()
The parameters that were used to request this page.
-
response
final TransactionListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final TransactionListPageAsync.Builder toBuilder()
-
builder
final static TransactionListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of TransactionListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-