Package com.lithic.api.models
Class TransactionListPageAsync.Builder
-
- All Implemented Interfaces:
public final class TransactionListPageAsync.BuilderA builder for TransactionListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final TransactionListPageAsync.Builderservice(TransactionServiceAsync service)final TransactionListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final TransactionListPageAsync.Builderparams(TransactionListParams params)The parameters that were used to request this page. final TransactionListPageAsync.Builderresponse(TransactionListPageResponse response)The response that this page was parsed from. final TransactionListPageAsyncbuild()Returns an immutable instance of TransactionListPageAsync. -
-
Method Detail
-
service
final TransactionListPageAsync.Builder service(TransactionServiceAsync service)
-
streamHandlerExecutor
final TransactionListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final TransactionListPageAsync.Builder params(TransactionListParams params)
The parameters that were used to request this page.
-
response
final TransactionListPageAsync.Builder response(TransactionListPageResponse response)
The response that this page was parsed from.
-
build
final TransactionListPageAsync build()
Returns an immutable instance of TransactionListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-