Package com.lithic.api.models
Class TransactionSimulateAuthorizationResponse
-
- All Implemented Interfaces:
public final class TransactionSimulateAuthorizationResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionSimulateAuthorizationResponse.BuilderA builder for TransactionSimulateAuthorizationResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>token()A unique token to reference this transaction with later calls to void or clear the authorization. final Optional<String>debuggingRequestId()Debugging request ID to share with Lithic Support team. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<String>_debuggingRequestId()Returns the raw JSON value of debuggingRequestId. final Map<String, JsonValue>_additionalProperties()final TransactionSimulateAuthorizationResponse.BuildertoBuilder()final TransactionSimulateAuthorizationResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionSimulateAuthorizationResponse.Builderbuilder()Returns a mutable builder for constructing an instance of TransactionSimulateAuthorizationResponse. -
-
Method Detail
-
token
final Optional<String> token()
A unique token to reference this transaction with later calls to void or clear the authorization.
-
debuggingRequestId
final Optional<String> debuggingRequestId()
Debugging request ID to share with Lithic Support team.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_debuggingRequestId
final JsonField<String> _debuggingRequestId()
Returns the raw JSON value of debuggingRequestId.
Unlike debuggingRequestId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TransactionSimulateAuthorizationResponse.Builder toBuilder()
-
validate
final TransactionSimulateAuthorizationResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TransactionSimulateAuthorizationResponse.Builder builder()
Returns a mutable builder for constructing an instance of TransactionSimulateAuthorizationResponse.
-
-
-
-