Class Transfer
-
- All Implemented Interfaces:
public final class Transfer
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransfer.BuilderA builder for Transfer.
public final classTransfer.CategoryStatus types:
TRANSFER- Internal transfer of funds between financial accounts in your program.
public final classTransfer.FinancialEventpublic final classTransfer.ResultAPPROVED transactions were successful while DECLINED transactions were declined by user, Lithic, or the network.
public final classTransfer.StatusStatus types:
DECLINED- The transfer was declined.EXPIRED- The transfer was held in pending for too long and expired.PENDING- The transfer is pending release from a hold.SETTLED- The transfer is completed.VOIDED- The transfer was reversed before it settled.
-
Method Summary
Modifier and Type Method Description final Optional<String>token()Globally unique identifier for the transfer event. final Optional<Transfer.Category>category()Status types: TRANSFER- Internal transfer of funds between financial accounts in your program.
final Optional<OffsetDateTime>created()Date and time when the transfer occurred. final Optional<String>currency()3-character alphabetic ISO 4217 code for the settling currency of the transaction. final Optional<String>descriptor()A string that provides a description of the transfer; may be useful to display to users. final Optional<List<Transfer.FinancialEvent>>events()A list of all financial events that have modified this trasnfer. final Optional<List<Balance>>fromBalance()The updated balance of the sending financial account. final Optional<Long>pendingAmount()Pending amount of the transaction in the currency's smallest unit (e.g., cents), including any acquirer fees. final Optional<Transfer.Result>result()APPROVED transactions were successful while DECLINED transactions were declined by user, Lithic, or the network. final Optional<Long>settledAmount()Amount of the transaction that has been settled in the currency's smallest unit (e.g., cents). final Optional<Transfer.Status>status()Status types: DECLINED- The transfer was declined.EXPIRED- The transfer was held in pending for too long and expired.PENDING- The transfer is pending release from a hold.SETTLED- The transfer is completed.VOIDED- The transfer was reversed before it settled.
final Optional<List<Balance>>toBalance()The updated balance of the receiving financial account. final Optional<OffsetDateTime>updated()Date and time when the financial transaction was last updated. final JsonField<String>_token()Globally unique identifier for the transfer event. final JsonField<Transfer.Category>_category()Status types: TRANSFER- Internal transfer of funds between financial accounts in your program.
final JsonField<OffsetDateTime>_created()Date and time when the transfer occurred. final JsonField<String>_currency()3-character alphabetic ISO 4217 code for the settling currency of the transaction. final JsonField<String>_descriptor()A string that provides a description of the transfer; may be useful to display to users. final JsonField<List<Transfer.FinancialEvent>>_events()A list of all financial events that have modified this trasnfer. final JsonField<List<Balance>>_fromBalance()The updated balance of the sending financial account. final JsonField<Long>_pendingAmount()Pending amount of the transaction in the currency's smallest unit (e.g., cents), including any acquirer fees. final JsonField<Transfer.Result>_result()APPROVED transactions were successful while DECLINED transactions were declined by user, Lithic, or the network. final JsonField<Long>_settledAmount()Amount of the transaction that has been settled in the currency's smallest unit (e.g., cents). final JsonField<Transfer.Status>_status()Status types: DECLINED- The transfer was declined.EXPIRED- The transfer was held in pending for too long and expired.PENDING- The transfer is pending release from a hold.SETTLED- The transfer is completed.VOIDED- The transfer was reversed before it settled.
final JsonField<List<Balance>>_toBalance()The updated balance of the receiving financial account. final JsonField<OffsetDateTime>_updated()Date and time when the financial transaction was last updated. final Map<String, JsonValue>_additionalProperties()final Transfervalidate()final Transfer.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transfer.Builderbuilder()Returns a mutable builder for constructing an instance of Transfer. -
-
Method Detail
-
category
final Optional<Transfer.Category> category()
Status types:
TRANSFER- Internal transfer of funds between financial accounts in your program.
-
created
final Optional<OffsetDateTime> created()
Date and time when the transfer occurred. UTC time zone.
-
currency
final Optional<String> currency()
3-character alphabetic ISO 4217 code for the settling currency of the transaction.
-
descriptor
final Optional<String> descriptor()
A string that provides a description of the transfer; may be useful to display to users.
-
events
final Optional<List<Transfer.FinancialEvent>> events()
A list of all financial events that have modified this trasnfer.
-
fromBalance
final Optional<List<Balance>> fromBalance()
The updated balance of the sending financial account.
-
pendingAmount
final Optional<Long> pendingAmount()
Pending amount of the transaction in the currency's smallest unit (e.g., cents), including any acquirer fees. The value of this field will go to zero over time once the financial transaction is settled.
-
result
final Optional<Transfer.Result> result()
APPROVED transactions were successful while DECLINED transactions were declined by user, Lithic, or the network.
-
settledAmount
final Optional<Long> settledAmount()
Amount of the transaction that has been settled in the currency's smallest unit (e.g., cents).
-
status
final Optional<Transfer.Status> status()
Status types:
DECLINED- The transfer was declined.EXPIRED- The transfer was held in pending for too long and expired.PENDING- The transfer is pending release from a hold.SETTLED- The transfer is completed.VOIDED- The transfer was reversed before it settled.
-
toBalance
final Optional<List<Balance>> toBalance()
The updated balance of the receiving financial account.
-
updated
final Optional<OffsetDateTime> updated()
Date and time when the financial transaction was last updated. UTC time zone.
-
_category
final JsonField<Transfer.Category> _category()
Status types:
TRANSFER- Internal transfer of funds between financial accounts in your program.
-
_created
final JsonField<OffsetDateTime> _created()
Date and time when the transfer occurred. UTC time zone.
-
_currency
final JsonField<String> _currency()
3-character alphabetic ISO 4217 code for the settling currency of the transaction.
-
_descriptor
final JsonField<String> _descriptor()
A string that provides a description of the transfer; may be useful to display to users.
-
_events
final JsonField<List<Transfer.FinancialEvent>> _events()
A list of all financial events that have modified this trasnfer.
-
_fromBalance
final JsonField<List<Balance>> _fromBalance()
The updated balance of the sending financial account.
-
_pendingAmount
final JsonField<Long> _pendingAmount()
Pending amount of the transaction in the currency's smallest unit (e.g., cents), including any acquirer fees. The value of this field will go to zero over time once the financial transaction is settled.
-
_result
final JsonField<Transfer.Result> _result()
APPROVED transactions were successful while DECLINED transactions were declined by user, Lithic, or the network.
-
_settledAmount
final JsonField<Long> _settledAmount()
Amount of the transaction that has been settled in the currency's smallest unit (e.g., cents).
-
_status
final JsonField<Transfer.Status> _status()
Status types:
DECLINED- The transfer was declined.EXPIRED- The transfer was held in pending for too long and expired.PENDING- The transfer is pending release from a hold.SETTLED- The transfer is completed.VOIDED- The transfer was reversed before it settled.
-
_toBalance
final JsonField<List<Balance>> _toBalance()
The updated balance of the receiving financial account.
-
_updated
final JsonField<OffsetDateTime> _updated()
Date and time when the financial transaction was last updated. UTC time zone.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transfer.Builder toBuilder()
-
builder
final static Transfer.Builder builder()
Returns a mutable builder for constructing an instance of Transfer.
-
-
-