Class Transfer.Builder
-
- All Implemented Interfaces:
public final class Transfer.BuilderA builder for Transfer.
-
-
Method Summary
Modifier and Type Method Description final Transfer.Buildertoken(String token)Globally unique identifier for the transfer event. final Transfer.Buildertoken(JsonField<String> token)Globally unique identifier for the transfer event. final Transfer.Buildercategory(Transfer.Category category)Status types: TRANSFER- Internal transfer of funds between financial accounts in your program.
final Transfer.Buildercategory(JsonField<Transfer.Category> category)Status types: TRANSFER- Internal transfer of funds between financial accounts in your program.
final Transfer.Buildercreated(OffsetDateTime created)Date and time when the transfer occurred. final Transfer.Buildercreated(JsonField<OffsetDateTime> created)Date and time when the transfer occurred. final Transfer.Buildercurrency(String currency)3-character alphabetic ISO 4217 code for the settling currency of the transaction. final Transfer.Buildercurrency(JsonField<String> currency)3-character alphabetic ISO 4217 code for the settling currency of the transaction. final Transfer.Builderdescriptor(String descriptor)A string that provides a description of the transfer; may be useful to display to users. final Transfer.Builderdescriptor(JsonField<String> descriptor)A string that provides a description of the transfer; may be useful to display to users. final Transfer.Builderevents(List<Transfer.FinancialEvent> events)A list of all financial events that have modified this trasnfer. final Transfer.Builderevents(JsonField<List<Transfer.FinancialEvent>> events)A list of all financial events that have modified this trasnfer. final Transfer.BuilderaddEvent(Transfer.FinancialEvent event)A list of all financial events that have modified this trasnfer. final Transfer.BuilderfromBalance(List<Balance> fromBalance)The updated balance of the sending financial account. final Transfer.BuilderfromBalance(JsonField<List<Balance>> fromBalance)The updated balance of the sending financial account. final Transfer.BuilderaddFromBalance(Balance fromBalance)The updated balance of the sending financial account. final Transfer.BuilderpendingAmount(Long pendingAmount)Pending amount of the transaction in the currency's smallest unit (e.g., cents), including any acquirer fees. final Transfer.BuilderpendingAmount(JsonField<Long> pendingAmount)Pending amount of the transaction in the currency's smallest unit (e.g., cents), including any acquirer fees. final Transfer.Builderresult(Transfer.Result result)APPROVED transactions were successful while DECLINED transactions were declined by user, Lithic, or the network. final Transfer.Builderresult(JsonField<Transfer.Result> result)APPROVED transactions were successful while DECLINED transactions were declined by user, Lithic, or the network. final Transfer.BuildersettledAmount(Long settledAmount)Amount of the transaction that has been settled in the currency's smallest unit (e.g., cents). final Transfer.BuildersettledAmount(JsonField<Long> settledAmount)Amount of the transaction that has been settled in the currency's smallest unit (e.g., cents). final Transfer.Builderstatus(Transfer.Status status)Status types: DECLINED- The transfer was declined.EXPIRED- The transfer was held in pending for too long and expired.PENDING- The transfer is pending release from a hold.SETTLED- The transfer is completed.VOIDED- The transfer was reversed before it settled.
final Transfer.Builderstatus(JsonField<Transfer.Status> status)Status types: DECLINED- The transfer was declined.EXPIRED- The transfer was held in pending for too long and expired.PENDING- The transfer is pending release from a hold.SETTLED- The transfer is completed.VOIDED- The transfer was reversed before it settled.
final Transfer.BuildertoBalance(List<Balance> toBalance)The updated balance of the receiving financial account. final Transfer.BuildertoBalance(JsonField<List<Balance>> toBalance)The updated balance of the receiving financial account. final Transfer.BuilderaddToBalance(Balance toBalance)The updated balance of the receiving financial account. final Transfer.Builderupdated(OffsetDateTime updated)Date and time when the financial transaction was last updated. final Transfer.Builderupdated(JsonField<OffsetDateTime> updated)Date and time when the financial transaction was last updated. final Transfer.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Transfer.BuilderputAdditionalProperty(String key, JsonValue value)final Transfer.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Transfer.BuilderremoveAdditionalProperty(String key)final Transfer.BuilderremoveAllAdditionalProperties(Set<String> keys)final Transferbuild()-
-
Method Detail
-
token
final Transfer.Builder token(String token)
Globally unique identifier for the transfer event.
-
token
final Transfer.Builder token(JsonField<String> token)
Globally unique identifier for the transfer event.
-
category
final Transfer.Builder category(Transfer.Category category)
Status types:
TRANSFER- Internal transfer of funds between financial accounts in your program.
-
category
final Transfer.Builder category(JsonField<Transfer.Category> category)
Status types:
TRANSFER- Internal transfer of funds between financial accounts in your program.
-
created
final Transfer.Builder created(OffsetDateTime created)
Date and time when the transfer occurred. UTC time zone.
-
created
final Transfer.Builder created(JsonField<OffsetDateTime> created)
Date and time when the transfer occurred. UTC time zone.
-
currency
final Transfer.Builder currency(String currency)
3-character alphabetic ISO 4217 code for the settling currency of the transaction.
-
currency
final Transfer.Builder currency(JsonField<String> currency)
3-character alphabetic ISO 4217 code for the settling currency of the transaction.
-
descriptor
final Transfer.Builder descriptor(String descriptor)
A string that provides a description of the transfer; may be useful to display to users.
-
descriptor
final Transfer.Builder descriptor(JsonField<String> descriptor)
A string that provides a description of the transfer; may be useful to display to users.
-
events
final Transfer.Builder events(List<Transfer.FinancialEvent> events)
A list of all financial events that have modified this trasnfer.
-
events
final Transfer.Builder events(JsonField<List<Transfer.FinancialEvent>> events)
A list of all financial events that have modified this trasnfer.
-
addEvent
final Transfer.Builder addEvent(Transfer.FinancialEvent event)
A list of all financial events that have modified this trasnfer.
-
fromBalance
final Transfer.Builder fromBalance(List<Balance> fromBalance)
The updated balance of the sending financial account.
-
fromBalance
final Transfer.Builder fromBalance(JsonField<List<Balance>> fromBalance)
The updated balance of the sending financial account.
-
addFromBalance
final Transfer.Builder addFromBalance(Balance fromBalance)
The updated balance of the sending financial account.
-
pendingAmount
final Transfer.Builder pendingAmount(Long pendingAmount)
Pending amount of the transaction in the currency's smallest unit (e.g., cents), including any acquirer fees. The value of this field will go to zero over time once the financial transaction is settled.
-
pendingAmount
final Transfer.Builder pendingAmount(JsonField<Long> pendingAmount)
Pending amount of the transaction in the currency's smallest unit (e.g., cents), including any acquirer fees. The value of this field will go to zero over time once the financial transaction is settled.
-
result
final Transfer.Builder result(Transfer.Result result)
APPROVED transactions were successful while DECLINED transactions were declined by user, Lithic, or the network.
-
result
final Transfer.Builder result(JsonField<Transfer.Result> result)
APPROVED transactions were successful while DECLINED transactions were declined by user, Lithic, or the network.
-
settledAmount
final Transfer.Builder settledAmount(Long settledAmount)
Amount of the transaction that has been settled in the currency's smallest unit (e.g., cents).
-
settledAmount
final Transfer.Builder settledAmount(JsonField<Long> settledAmount)
Amount of the transaction that has been settled in the currency's smallest unit (e.g., cents).
-
status
final Transfer.Builder status(Transfer.Status status)
Status types:
DECLINED- The transfer was declined.EXPIRED- The transfer was held in pending for too long and expired.PENDING- The transfer is pending release from a hold.SETTLED- The transfer is completed.VOIDED- The transfer was reversed before it settled.
-
status
final Transfer.Builder status(JsonField<Transfer.Status> status)
Status types:
DECLINED- The transfer was declined.EXPIRED- The transfer was held in pending for too long and expired.PENDING- The transfer is pending release from a hold.SETTLED- The transfer is completed.VOIDED- The transfer was reversed before it settled.
-
toBalance
final Transfer.Builder toBalance(List<Balance> toBalance)
The updated balance of the receiving financial account.
-
toBalance
final Transfer.Builder toBalance(JsonField<List<Balance>> toBalance)
The updated balance of the receiving financial account.
-
addToBalance
final Transfer.Builder addToBalance(Balance toBalance)
The updated balance of the receiving financial account.
-
updated
final Transfer.Builder updated(OffsetDateTime updated)
Date and time when the financial transaction was last updated. UTC time zone.
-
updated
final Transfer.Builder updated(JsonField<OffsetDateTime> updated)
Date and time when the financial transaction was last updated. UTC time zone.
-
additionalProperties
final Transfer.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transfer.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transfer.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transfer.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transfer.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-