Class Transfer.FinancialEvent
-
- All Implemented Interfaces:
public final class Transfer.FinancialEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransfer.FinancialEvent.BuilderA builder for FinancialEvent.
public final classTransfer.FinancialEvent.ResultAPPROVED financial events were successful while DECLINED financial events were declined by user, Lithic, or the network.
public final classTransfer.FinancialEvent.FinancialEventType
-
Method Summary
Modifier and Type Method Description final Optional<String>token()Globally unique identifier. final Optional<Long>amount()Amount of the financial event that has been settled in the currency's smallest unit (e.g., cents). final Optional<OffsetDateTime>created()Date and time when the financial event occurred. final Optional<Transfer.FinancialEvent.Result>result()APPROVED financial events were successful while DECLINED financial events were declined by user, Lithic, or the network. final Optional<Transfer.FinancialEvent.FinancialEventType>type()final JsonField<String>_token()Globally unique identifier. final JsonField<Long>_amount()Amount of the financial event that has been settled in the currency's smallest unit (e.g., cents). final JsonField<OffsetDateTime>_created()Date and time when the financial event occurred. final JsonField<Transfer.FinancialEvent.Result>_result()APPROVED financial events were successful while DECLINED financial events were declined by user, Lithic, or the network. final JsonField<Transfer.FinancialEvent.FinancialEventType>_type()final Map<String, JsonValue>_additionalProperties()final Transfer.FinancialEventvalidate()final Transfer.FinancialEvent.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transfer.FinancialEvent.Builderbuilder()Returns a mutable builder for constructing an instance of FinancialEvent. -
-
Method Detail
-
amount
final Optional<Long> amount()
Amount of the financial event that has been settled in the currency's smallest unit (e.g., cents).
-
created
final Optional<OffsetDateTime> created()
Date and time when the financial event occurred. UTC time zone.
-
result
final Optional<Transfer.FinancialEvent.Result> result()
APPROVED financial events were successful while DECLINED financial events were declined by user, Lithic, or the network.
-
type
final Optional<Transfer.FinancialEvent.FinancialEventType> type()
-
_amount
final JsonField<Long> _amount()
Amount of the financial event that has been settled in the currency's smallest unit (e.g., cents).
-
_created
final JsonField<OffsetDateTime> _created()
Date and time when the financial event occurred. UTC time zone.
-
_result
final JsonField<Transfer.FinancialEvent.Result> _result()
APPROVED financial events were successful while DECLINED financial events were declined by user, Lithic, or the network.
-
_type
final JsonField<Transfer.FinancialEvent.FinancialEventType> _type()
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transfer.FinancialEvent validate()
-
toBuilder
final Transfer.FinancialEvent.Builder toBuilder()
-
builder
final static Transfer.FinancialEvent.Builder builder()
Returns a mutable builder for constructing an instance of FinancialEvent.
-
-
-
-