Class TransferCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class TransferCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
Modifier and Type Method Description final TransferCreateParams.Body.Builderfrom(String from)Globally unique identifier for the financial account or card that will send the funds. final TransferCreateParams.Body.Builderfrom(JsonField<String> from)Globally unique identifier for the financial account or card that will send the funds. final TransferCreateParams.Body.Builderamount(Long amount)Amount to be transferred in the currency’s smallest unit (e.g., cents for USD). final TransferCreateParams.Body.Builderamount(JsonField<Long> amount)Amount to be transferred in the currency’s smallest unit (e.g., cents for USD). final TransferCreateParams.Body.Builderto(String to)Globally unique identifier for the financial account or card that will receive the funds. final TransferCreateParams.Body.Builderto(JsonField<String> to)Globally unique identifier for the financial account or card that will receive the funds. final TransferCreateParams.Body.Buildertoken(String token)Customer-provided token that will serve as an idempotency token. final TransferCreateParams.Body.Buildertoken(JsonField<String> token)Customer-provided token that will serve as an idempotency token. final TransferCreateParams.Body.Buildermemo(String memo)Optional descriptor for the transfer. final TransferCreateParams.Body.Buildermemo(JsonField<String> memo)Optional descriptor for the transfer. final TransferCreateParams.Body.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final TransferCreateParams.Body.BuilderputAdditionalProperty(String key, JsonValue value)final TransferCreateParams.Body.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final TransferCreateParams.Body.BuilderremoveAdditionalProperty(String key)final TransferCreateParams.Body.BuilderremoveAllAdditionalProperties(Set<String> keys)final TransferCreateParams.Bodybuild()-
-
Method Detail
-
from
final TransferCreateParams.Body.Builder from(String from)
Globally unique identifier for the financial account or card that will send the funds. Accepted type dependent on the program's use case.
-
from
final TransferCreateParams.Body.Builder from(JsonField<String> from)
Globally unique identifier for the financial account or card that will send the funds. Accepted type dependent on the program's use case.
-
amount
final TransferCreateParams.Body.Builder amount(Long amount)
Amount to be transferred in the currency’s smallest unit (e.g., cents for USD). This should always be a positive value.
-
amount
final TransferCreateParams.Body.Builder amount(JsonField<Long> amount)
Amount to be transferred in the currency’s smallest unit (e.g., cents for USD). This should always be a positive value.
-
to
final TransferCreateParams.Body.Builder to(String to)
Globally unique identifier for the financial account or card that will receive the funds. Accepted type dependent on the program's use case.
-
to
final TransferCreateParams.Body.Builder to(JsonField<String> to)
Globally unique identifier for the financial account or card that will receive the funds. Accepted type dependent on the program's use case.
-
token
final TransferCreateParams.Body.Builder token(String token)
Customer-provided token that will serve as an idempotency token. This token will become the transaction token.
-
token
final TransferCreateParams.Body.Builder token(JsonField<String> token)
Customer-provided token that will serve as an idempotency token. This token will become the transaction token.
-
memo
final TransferCreateParams.Body.Builder memo(String memo)
Optional descriptor for the transfer.
-
memo
final TransferCreateParams.Body.Builder memo(JsonField<String> memo)
Optional descriptor for the transfer.
-
additionalProperties
final TransferCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final TransferCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final TransferCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final TransferCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final TransferCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final TransferCreateParams.Body build()
-
-
-
-