Package com.lithic.api.models
Class V2DraftResponse
-
- All Implemented Interfaces:
public final class V2DraftResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV2DraftResponse.BuilderA builder for V2DraftResponse.
public final classV2DraftResponse.CurrentVersionpublic final classV2DraftResponse.DraftVersionpublic final classV2DraftResponse.AuthRuleStateThe state of the Auth Rule
public final classV2DraftResponse.AuthRuleTypeThe type of Auth Rule
-
Method Summary
Modifier and Type Method Description final Stringtoken()Auth Rule Token final List<String>accountTokens()Account tokens to which the Auth Rule applies. final List<String>cardTokens()Card tokens to which the Auth Rule applies. final Optional<V2DraftResponse.CurrentVersion>currentVersion()final Optional<V2DraftResponse.DraftVersion>draftVersion()final Optional<String>name()Auth Rule Name final BooleanprogramLevel()Whether the Auth Rule applies to all authorizations on the card program. final V2DraftResponse.AuthRuleStatestate()The state of the Auth Rule final V2DraftResponse.AuthRuleTypetype()The type of Auth Rule final Optional<List<String>>excludedCardTokens()Card tokens to which the Auth Rule does not apply. final JsonField<String>_token()Auth Rule Token final JsonField<List<String>>_accountTokens()Account tokens to which the Auth Rule applies. final JsonField<List<String>>_cardTokens()Card tokens to which the Auth Rule applies. final JsonField<V2DraftResponse.CurrentVersion>_currentVersion()final JsonField<V2DraftResponse.DraftVersion>_draftVersion()final JsonField<String>_name()Auth Rule Name final JsonField<Boolean>_programLevel()Whether the Auth Rule applies to all authorizations on the card program. final JsonField<V2DraftResponse.AuthRuleState>_state()The state of the Auth Rule final JsonField<V2DraftResponse.AuthRuleType>_type()The type of Auth Rule final JsonField<List<String>>_excludedCardTokens()Card tokens to which the Auth Rule does not apply. final Map<String, JsonValue>_additionalProperties()final V2DraftResponsevalidate()final V2DraftResponse.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V2DraftResponse.Builderbuilder()Returns a mutable builder for constructing an instance of V2DraftResponse. -
-
Method Detail
-
accountTokens
final List<String> accountTokens()
Account tokens to which the Auth Rule applies.
-
cardTokens
final List<String> cardTokens()
Card tokens to which the Auth Rule applies.
-
currentVersion
final Optional<V2DraftResponse.CurrentVersion> currentVersion()
-
draftVersion
final Optional<V2DraftResponse.DraftVersion> draftVersion()
-
programLevel
final Boolean programLevel()
Whether the Auth Rule applies to all authorizations on the card program.
-
state
final V2DraftResponse.AuthRuleState state()
The state of the Auth Rule
-
type
final V2DraftResponse.AuthRuleType type()
The type of Auth Rule
-
excludedCardTokens
final Optional<List<String>> excludedCardTokens()
Card tokens to which the Auth Rule does not apply.
-
_accountTokens
final JsonField<List<String>> _accountTokens()
Account tokens to which the Auth Rule applies.
-
_cardTokens
final JsonField<List<String>> _cardTokens()
Card tokens to which the Auth Rule applies.
-
_currentVersion
final JsonField<V2DraftResponse.CurrentVersion> _currentVersion()
-
_draftVersion
final JsonField<V2DraftResponse.DraftVersion> _draftVersion()
-
_programLevel
final JsonField<Boolean> _programLevel()
Whether the Auth Rule applies to all authorizations on the card program.
-
_state
final JsonField<V2DraftResponse.AuthRuleState> _state()
The state of the Auth Rule
-
_type
final JsonField<V2DraftResponse.AuthRuleType> _type()
The type of Auth Rule
-
_excludedCardTokens
final JsonField<List<String>> _excludedCardTokens()
Card tokens to which the Auth Rule does not apply.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final V2DraftResponse validate()
-
toBuilder
final V2DraftResponse.Builder toBuilder()
-
builder
final static V2DraftResponse.Builder builder()
Returns a mutable builder for constructing an instance of V2DraftResponse.
The following fields are required:
.token() .accountTokens() .cardTokens() .currentVersion() .draftVersion() .name() .programLevel() .state() .type()
-
-
-
-