Class V2ListResultsResponse.CardTransactionUpdateResult
-
- All Implemented Interfaces:
public final class V2ListResultsResponse.CardTransactionUpdateResult
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV2ListResultsResponse.CardTransactionUpdateResult.BuilderA builder for CardTransactionUpdateResult.
public final classV2ListResultsResponse.CardTransactionUpdateResult.Actionpublic final classV2ListResultsResponse.CardTransactionUpdateResult.EventStreamThe event stream during which the rule was evaluated
public final classV2ListResultsResponse.CardTransactionUpdateResult.AuthRuleStateThe state of the Auth Rule
-
Method Summary
-
-
Method Detail
-
actions
final List<V2ListResultsResponse.CardTransactionUpdateResult.Action> actions()
Actions returned by the rule evaluation
-
authRuleToken
final String authRuleToken()
The Auth Rule token
-
evaluationTime
final OffsetDateTime evaluationTime()
Timestamp of the rule evaluation
-
eventStream
final V2ListResultsResponse.CardTransactionUpdateResult.EventStream eventStream()
The event stream during which the rule was evaluated
-
eventToken
final String eventToken()
Token of the event that triggered the evaluation
-
mode
final V2ListResultsResponse.CardTransactionUpdateResult.AuthRuleState mode()
The state of the Auth Rule
-
ruleVersion
final Long ruleVersion()
Version of the rule that was evaluated
-
transactionToken
final Optional<String> transactionToken()
The token of the transaction that triggered the rule evaluation
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_actions
final JsonField<List<V2ListResultsResponse.CardTransactionUpdateResult.Action>> _actions()
Returns the raw JSON value of actions.
Unlike actions, this method doesn't throw if the JSON field has an unexpected type.
-
_authRuleToken
final JsonField<String> _authRuleToken()
Returns the raw JSON value of authRuleToken.
Unlike authRuleToken, this method doesn't throw if the JSON field has an unexpected type.
-
_evaluationTime
final JsonField<OffsetDateTime> _evaluationTime()
Returns the raw JSON value of evaluationTime.
Unlike evaluationTime, this method doesn't throw if the JSON field has an unexpected type.
-
_eventStream
final JsonField<V2ListResultsResponse.CardTransactionUpdateResult.EventStream> _eventStream()
Returns the raw JSON value of eventStream.
Unlike eventStream, this method doesn't throw if the JSON field has an unexpected type.
-
_eventToken
final JsonField<String> _eventToken()
Returns the raw JSON value of eventToken.
Unlike eventToken, this method doesn't throw if the JSON field has an unexpected type.
-
_mode
final JsonField<V2ListResultsResponse.CardTransactionUpdateResult.AuthRuleState> _mode()
Returns the raw JSON value of mode.
Unlike mode, this method doesn't throw if the JSON field has an unexpected type.
-
_ruleVersion
final JsonField<Long> _ruleVersion()
Returns the raw JSON value of ruleVersion.
Unlike ruleVersion, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionToken
final JsonField<String> _transactionToken()
Returns the raw JSON value of transactionToken.
Unlike transactionToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V2ListResultsResponse.CardTransactionUpdateResult.Builder toBuilder()
-
validate
final V2ListResultsResponse.CardTransactionUpdateResult validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V2ListResultsResponse.CardTransactionUpdateResult.Builder builder()
Returns a mutable builder for constructing an instance of CardTransactionUpdateResult.
The following fields are required:
.token() .actions() .authRuleToken() .evaluationTime() .eventStream() .eventToken() .mode() .ruleVersion() .transactionToken()
-
-
-
-