Package com.lithic.api.models
Class V2PromoteResponse
-
- All Implemented Interfaces:
public final class V2PromoteResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV2PromoteResponse.BuilderA builder for V2PromoteResponse.
public final classV2PromoteResponse.CurrentVersionpublic final classV2PromoteResponse.DraftVersionpublic final classV2PromoteResponse.AuthRuleStateThe state of the Auth Rule
public final classV2PromoteResponse.AuthRuleTypeThe type of Auth Rule
-
Method Summary
Modifier and Type Method Description final Stringtoken()Auth Rule Token final List<String>accountTokens()Account tokens to which the Auth Rule applies. final List<String>cardTokens()Card tokens to which the Auth Rule applies. final Optional<V2PromoteResponse.CurrentVersion>currentVersion()final Optional<V2PromoteResponse.DraftVersion>draftVersion()final Optional<String>name()Auth Rule Name final BooleanprogramLevel()Whether the Auth Rule applies to all authorizations on the card program. final V2PromoteResponse.AuthRuleStatestate()The state of the Auth Rule final V2PromoteResponse.AuthRuleTypetype()The type of Auth Rule final Optional<List<String>>excludedCardTokens()Card tokens to which the Auth Rule does not apply. final JsonField<String>_token()Auth Rule Token final JsonField<List<String>>_accountTokens()Account tokens to which the Auth Rule applies. final JsonField<List<String>>_cardTokens()Card tokens to which the Auth Rule applies. final JsonField<V2PromoteResponse.CurrentVersion>_currentVersion()final JsonField<V2PromoteResponse.DraftVersion>_draftVersion()final JsonField<String>_name()Auth Rule Name final JsonField<Boolean>_programLevel()Whether the Auth Rule applies to all authorizations on the card program. final JsonField<V2PromoteResponse.AuthRuleState>_state()The state of the Auth Rule final JsonField<V2PromoteResponse.AuthRuleType>_type()The type of Auth Rule final JsonField<List<String>>_excludedCardTokens()Card tokens to which the Auth Rule does not apply. final Map<String, JsonValue>_additionalProperties()final V2PromoteResponsevalidate()final V2PromoteResponse.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V2PromoteResponse.Builderbuilder()Returns a mutable builder for constructing an instance of V2PromoteResponse. -
-
Method Detail
-
accountTokens
final List<String> accountTokens()
Account tokens to which the Auth Rule applies.
-
cardTokens
final List<String> cardTokens()
Card tokens to which the Auth Rule applies.
-
currentVersion
final Optional<V2PromoteResponse.CurrentVersion> currentVersion()
-
draftVersion
final Optional<V2PromoteResponse.DraftVersion> draftVersion()
-
programLevel
final Boolean programLevel()
Whether the Auth Rule applies to all authorizations on the card program.
-
state
final V2PromoteResponse.AuthRuleState state()
The state of the Auth Rule
-
type
final V2PromoteResponse.AuthRuleType type()
The type of Auth Rule
-
excludedCardTokens
final Optional<List<String>> excludedCardTokens()
Card tokens to which the Auth Rule does not apply.
-
_accountTokens
final JsonField<List<String>> _accountTokens()
Account tokens to which the Auth Rule applies.
-
_cardTokens
final JsonField<List<String>> _cardTokens()
Card tokens to which the Auth Rule applies.
-
_currentVersion
final JsonField<V2PromoteResponse.CurrentVersion> _currentVersion()
-
_draftVersion
final JsonField<V2PromoteResponse.DraftVersion> _draftVersion()
-
_programLevel
final JsonField<Boolean> _programLevel()
Whether the Auth Rule applies to all authorizations on the card program.
-
_state
final JsonField<V2PromoteResponse.AuthRuleState> _state()
The state of the Auth Rule
-
_type
final JsonField<V2PromoteResponse.AuthRuleType> _type()
The type of Auth Rule
-
_excludedCardTokens
final JsonField<List<String>> _excludedCardTokens()
Card tokens to which the Auth Rule does not apply.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final V2PromoteResponse validate()
-
toBuilder
final V2PromoteResponse.Builder toBuilder()
-
builder
final static V2PromoteResponse.Builder builder()
Returns a mutable builder for constructing an instance of V2PromoteResponse.
The following fields are required:
.token() .accountTokens() .cardTokens() .currentVersion() .draftVersion() .name() .programLevel() .state() .type()
-
-
-
-