Package com.lithic.api.models
Class V2ReportResponse.Builder
-
- All Implemented Interfaces:
public final class V2ReportResponse.BuilderA builder for V2ReportResponse.
-
-
Method Summary
Modifier and Type Method Description final V2ReportResponse.BuilderreportToken(String reportToken)final V2ReportResponse.BuilderreportToken(JsonField<String> reportToken)Sets Builder.reportToken to an arbitrary JSON value. final V2ReportResponse.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final V2ReportResponse.BuilderputAdditionalProperty(String key, JsonValue value)final V2ReportResponse.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final V2ReportResponse.BuilderremoveAdditionalProperty(String key)final V2ReportResponse.BuilderremoveAllAdditionalProperties(Set<String> keys)final V2ReportResponsebuild()Returns an immutable instance of V2ReportResponse. -
-
Method Detail
-
reportToken
final V2ReportResponse.Builder reportToken(String reportToken)
-
reportToken
final V2ReportResponse.Builder reportToken(JsonField<String> reportToken)
Sets Builder.reportToken to an arbitrary JSON value.
You should usually call Builder.reportToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V2ReportResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V2ReportResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V2ReportResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V2ReportResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V2ReportResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V2ReportResponse build()
Returns an immutable instance of V2ReportResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-