Package com.lithic.api.models
Class V2RetrieveFeaturesResponse
-
- All Implemented Interfaces:
public final class V2RetrieveFeaturesResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV2RetrieveFeaturesResponse.BuilderA builder for V2RetrieveFeaturesResponse.
public final classV2RetrieveFeaturesResponse.SpendFeatureState
-
Method Summary
Modifier and Type Method Description final OffsetDateTimeevaluated()Timestamp at which the Features were evaluated final List<V2RetrieveFeaturesResponse.SpendFeatureState>features()Calculated Features used for evaluation of the provided Auth Rule final JsonField<OffsetDateTime>_evaluated()Returns the raw JSON value of evaluated. final JsonField<List<V2RetrieveFeaturesResponse.SpendFeatureState>>_features()Returns the raw JSON value of features. final Map<String, JsonValue>_additionalProperties()final V2RetrieveFeaturesResponse.BuildertoBuilder()final V2RetrieveFeaturesResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V2RetrieveFeaturesResponse.Builderbuilder()Returns a mutable builder for constructing an instance of V2RetrieveFeaturesResponse. -
-
Method Detail
-
evaluated
final OffsetDateTime evaluated()
Timestamp at which the Features were evaluated
-
features
final List<V2RetrieveFeaturesResponse.SpendFeatureState> features()
Calculated Features used for evaluation of the provided Auth Rule
-
_evaluated
final JsonField<OffsetDateTime> _evaluated()
Returns the raw JSON value of evaluated.
Unlike evaluated, this method doesn't throw if the JSON field has an unexpected type.
-
_features
final JsonField<List<V2RetrieveFeaturesResponse.SpendFeatureState>> _features()
Returns the raw JSON value of features.
Unlike features, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V2RetrieveFeaturesResponse.Builder toBuilder()
-
validate
final V2RetrieveFeaturesResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V2RetrieveFeaturesResponse.Builder builder()
Returns a mutable builder for constructing an instance of V2RetrieveFeaturesResponse.
The following fields are required:
.evaluated() .features()
-
-
-
-