Class V2RetrieveFeaturesResponse.SpendFeatureState.Builder
-
- All Implemented Interfaces:
public final class V2RetrieveFeaturesResponse.SpendFeatureState.BuilderA builder for SpendFeatureState.
-
-
Method Summary
-
-
Method Detail
-
filters
final V2RetrieveFeaturesResponse.SpendFeatureState.Builder filters(V2RetrieveFeaturesResponse.SpendFeatureState.VelocityLimitFilters filters)
-
filters
final V2RetrieveFeaturesResponse.SpendFeatureState.Builder filters(JsonField<V2RetrieveFeaturesResponse.SpendFeatureState.VelocityLimitFilters> filters)
Sets Builder.filters to an arbitrary JSON value.
You should usually call Builder.filters with a well-typed VelocityLimitFilters value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
period
final V2RetrieveFeaturesResponse.SpendFeatureState.Builder period(VelocityLimitPeriod period)
Velocity over the current day since 00:00 / 12 AM in Eastern Time
-
period
final V2RetrieveFeaturesResponse.SpendFeatureState.Builder period(JsonField<VelocityLimitPeriod> period)
Sets Builder.period to an arbitrary JSON value.
You should usually call Builder.period with a well-typed VelocityLimitPeriod value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
period
final V2RetrieveFeaturesResponse.SpendFeatureState.Builder period(VelocityLimitPeriod.TrailingWindowObject trailingWindowObject)
Alias for calling period with
VelocityLimitPeriod.ofTrailingWindowObject(trailingWindowObject).
-
period
final V2RetrieveFeaturesResponse.SpendFeatureState.Builder period(VelocityLimitPeriod.FixedWindowDay fixedWindowDay)
Alias for calling period with
VelocityLimitPeriod.ofFixedWindowDay(fixedWindowDay).
-
period
final V2RetrieveFeaturesResponse.SpendFeatureState.Builder period(VelocityLimitPeriod.FixedWindowWeek fixedWindowWeek)
Alias for calling period with
VelocityLimitPeriod.ofFixedWindowWeek(fixedWindowWeek).
-
period
final V2RetrieveFeaturesResponse.SpendFeatureState.Builder period(VelocityLimitPeriod.FixedWindowMonth fixedWindowMonth)
Alias for calling period with
VelocityLimitPeriod.ofFixedWindowMonth(fixedWindowMonth).
-
period
final V2RetrieveFeaturesResponse.SpendFeatureState.Builder period(VelocityLimitPeriod.FixedWindowYear fixedWindowYear)
Alias for calling period with
VelocityLimitPeriod.ofFixedWindowYear(fixedWindowYear).
-
scope
final V2RetrieveFeaturesResponse.SpendFeatureState.Builder scope(V2RetrieveFeaturesResponse.SpendFeatureState.VelocityScope scope)
The scope the velocity is calculated for
-
scope
final V2RetrieveFeaturesResponse.SpendFeatureState.Builder scope(JsonField<V2RetrieveFeaturesResponse.SpendFeatureState.VelocityScope> scope)
Sets Builder.scope to an arbitrary JSON value.
You should usually call Builder.scope with a well-typed VelocityScope value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
value
final V2RetrieveFeaturesResponse.SpendFeatureState.Builder value(V2RetrieveFeaturesResponse.SpendFeatureState.Value value)
-
value
final V2RetrieveFeaturesResponse.SpendFeatureState.Builder value(JsonField<V2RetrieveFeaturesResponse.SpendFeatureState.Value> value)
Sets Builder.value to an arbitrary JSON value.
You should usually call Builder.value with a well-typed Value value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V2RetrieveFeaturesResponse.SpendFeatureState.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V2RetrieveFeaturesResponse.SpendFeatureState.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V2RetrieveFeaturesResponse.SpendFeatureState.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V2RetrieveFeaturesResponse.SpendFeatureState.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V2RetrieveFeaturesResponse.SpendFeatureState.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V2RetrieveFeaturesResponse.SpendFeatureState build()
Returns an immutable instance of SpendFeatureState.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.filters() .period() .scope() .value()
-
-
-
-