Package com.lithic.api.models
Class V2RetrieveReportResponse.DailyStatistic
-
- All Implemented Interfaces:
public final class V2RetrieveReportResponse.DailyStatistic
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV2RetrieveReportResponse.DailyStatistic.BuilderA builder for DailyStatistic.
-
Method Summary
-
-
Method Detail
-
currentVersionStatistics
final Optional<RuleStats> currentVersionStatistics()
Detailed statistics for the current version of the rule.
-
draftVersionStatistics
final Optional<RuleStats> draftVersionStatistics()
Detailed statistics for the draft version of the rule.
-
_currentVersionStatistics
final JsonField<RuleStats> _currentVersionStatistics()
Returns the raw JSON value of currentVersionStatistics.
Unlike currentVersionStatistics, this method doesn't throw if the JSON field has an unexpected type.
-
_date
final JsonField<LocalDate> _date()
Returns the raw JSON value of date.
Unlike date, this method doesn't throw if the JSON field has an unexpected type.
-
_draftVersionStatistics
final JsonField<RuleStats> _draftVersionStatistics()
Returns the raw JSON value of draftVersionStatistics.
Unlike draftVersionStatistics, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V2RetrieveReportResponse.DailyStatistic.Builder toBuilder()
-
validate
final V2RetrieveReportResponse.DailyStatistic validate()
-
builder
final static V2RetrieveReportResponse.DailyStatistic.Builder builder()
Returns a mutable builder for constructing an instance of DailyStatistic.
The following fields are required:
.currentVersionStatistics() .date() .draftVersionStatistics()
-
-
-
-