Class V2RetrieveReportResponse.DailyStatistic.ReportStatsV2
-
- All Implemented Interfaces:
public final class V2RetrieveReportResponse.DailyStatistic.ReportStatsV2
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV2RetrieveReportResponse.DailyStatistic.ReportStatsV2.BuilderA builder for ReportStatsV2.
public final classV2RetrieveReportResponse.DailyStatistic.ReportStatsV2.ActionCountsA mapping of action types to the number of times that action was returned by this version during the relevant period. Actions are the possible outcomes of a rule evaluation, such as DECLINE, CHALLENGE, REQUIRE_TFA, etc. In case rule didn't trigger any action, it's counted under NO_ACTION key.
public final classV2RetrieveReportResponse.DailyStatistic.ReportStatsV2.Examplepublic final classV2RetrieveReportResponse.DailyStatistic.ReportStatsV2.AuthRuleVersionStateThe evaluation mode of this version during the reported period.
-
Method Summary
-
-
Method Detail
-
actionCounts
final V2RetrieveReportResponse.DailyStatistic.ReportStatsV2.ActionCounts actionCounts()
A mapping of action types to the number of times that action was returned by this version during the relevant period. Actions are the possible outcomes of a rule evaluation, such as DECLINE, CHALLENGE, REQUIRE_TFA, etc. In case rule didn't trigger any action, it's counted under NO_ACTION key.
-
examples
final List<V2RetrieveReportResponse.DailyStatistic.ReportStatsV2.Example> examples()
Example events and their outcomes for this version.
-
state
final V2RetrieveReportResponse.DailyStatistic.ReportStatsV2.AuthRuleVersionState state()
The evaluation mode of this version during the reported period.
-
_actionCounts
final JsonField<V2RetrieveReportResponse.DailyStatistic.ReportStatsV2.ActionCounts> _actionCounts()
Returns the raw JSON value of actionCounts.
Unlike actionCounts, this method doesn't throw if the JSON field has an unexpected type.
-
_examples
final JsonField<List<V2RetrieveReportResponse.DailyStatistic.ReportStatsV2.Example>> _examples()
Returns the raw JSON value of examples.
Unlike examples, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<V2RetrieveReportResponse.DailyStatistic.ReportStatsV2.AuthRuleVersionState> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_version
final JsonField<Long> _version()
Returns the raw JSON value of version.
Unlike version, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V2RetrieveReportResponse.DailyStatistic.ReportStatsV2.Builder toBuilder()
-
validate
final V2RetrieveReportResponse.DailyStatistic.ReportStatsV2 validate()
-
builder
final static V2RetrieveReportResponse.DailyStatistic.ReportStatsV2.Builder builder()
Returns a mutable builder for constructing an instance of ReportStatsV2.
The following fields are required:
.actionCounts() .examples() .state() .version()
-
-
-
-