Package com.lithic.api.models
Class V2RetrieveResponse
-
- All Implemented Interfaces:
public final class V2RetrieveResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV2RetrieveResponse.BuilderA builder for V2RetrieveResponse.
public final classV2RetrieveResponse.CurrentVersionpublic final classV2RetrieveResponse.DraftVersionpublic final classV2RetrieveResponse.AuthRuleStateThe state of the Auth Rule
public final classV2RetrieveResponse.AuthRuleTypeThe type of Auth Rule
-
Method Summary
Modifier and Type Method Description final Stringtoken()Auth Rule Token final List<String>accountTokens()Account tokens to which the Auth Rule applies. final List<String>cardTokens()Card tokens to which the Auth Rule applies. final Optional<V2RetrieveResponse.CurrentVersion>currentVersion()final Optional<V2RetrieveResponse.DraftVersion>draftVersion()final Optional<String>name()Auth Rule Name final BooleanprogramLevel()Whether the Auth Rule applies to all authorizations on the card program. final V2RetrieveResponse.AuthRuleStatestate()The state of the Auth Rule final V2RetrieveResponse.AuthRuleTypetype()The type of Auth Rule final Optional<List<String>>excludedCardTokens()Card tokens to which the Auth Rule does not apply. final JsonField<String>_token()Auth Rule Token final JsonField<List<String>>_accountTokens()Account tokens to which the Auth Rule applies. final JsonField<List<String>>_cardTokens()Card tokens to which the Auth Rule applies. final JsonField<V2RetrieveResponse.CurrentVersion>_currentVersion()final JsonField<V2RetrieveResponse.DraftVersion>_draftVersion()final JsonField<String>_name()Auth Rule Name final JsonField<Boolean>_programLevel()Whether the Auth Rule applies to all authorizations on the card program. final JsonField<V2RetrieveResponse.AuthRuleState>_state()The state of the Auth Rule final JsonField<V2RetrieveResponse.AuthRuleType>_type()The type of Auth Rule final JsonField<List<String>>_excludedCardTokens()Card tokens to which the Auth Rule does not apply. final Map<String, JsonValue>_additionalProperties()final V2RetrieveResponsevalidate()final V2RetrieveResponse.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V2RetrieveResponse.Builderbuilder()Returns a mutable builder for constructing an instance of V2RetrieveResponse. -
-
Method Detail
-
accountTokens
final List<String> accountTokens()
Account tokens to which the Auth Rule applies.
-
cardTokens
final List<String> cardTokens()
Card tokens to which the Auth Rule applies.
-
currentVersion
final Optional<V2RetrieveResponse.CurrentVersion> currentVersion()
-
draftVersion
final Optional<V2RetrieveResponse.DraftVersion> draftVersion()
-
programLevel
final Boolean programLevel()
Whether the Auth Rule applies to all authorizations on the card program.
-
state
final V2RetrieveResponse.AuthRuleState state()
The state of the Auth Rule
-
type
final V2RetrieveResponse.AuthRuleType type()
The type of Auth Rule
-
excludedCardTokens
final Optional<List<String>> excludedCardTokens()
Card tokens to which the Auth Rule does not apply.
-
_accountTokens
final JsonField<List<String>> _accountTokens()
Account tokens to which the Auth Rule applies.
-
_cardTokens
final JsonField<List<String>> _cardTokens()
Card tokens to which the Auth Rule applies.
-
_currentVersion
final JsonField<V2RetrieveResponse.CurrentVersion> _currentVersion()
-
_draftVersion
final JsonField<V2RetrieveResponse.DraftVersion> _draftVersion()
-
_programLevel
final JsonField<Boolean> _programLevel()
Whether the Auth Rule applies to all authorizations on the card program.
-
_state
final JsonField<V2RetrieveResponse.AuthRuleState> _state()
The state of the Auth Rule
-
_type
final JsonField<V2RetrieveResponse.AuthRuleType> _type()
The type of Auth Rule
-
_excludedCardTokens
final JsonField<List<String>> _excludedCardTokens()
Card tokens to which the Auth Rule does not apply.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final V2RetrieveResponse validate()
-
toBuilder
final V2RetrieveResponse.Builder toBuilder()
-
builder
final static V2RetrieveResponse.Builder builder()
Returns a mutable builder for constructing an instance of V2RetrieveResponse.
The following fields are required:
.token() .accountTokens() .cardTokens() .currentVersion() .draftVersion() .name() .programLevel() .state() .type()
-
-
-
-