Class V2UpdateResponse
-
- All Implemented Interfaces:
public final class V2UpdateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV2UpdateResponse.BuilderA builder for V2UpdateResponse.
public final classV2UpdateResponse.CurrentVersionpublic final classV2UpdateResponse.DraftVersionpublic final classV2UpdateResponse.AuthRuleStateThe state of the Auth Rule
public final classV2UpdateResponse.AuthRuleTypeThe type of Auth Rule
-
Method Summary
Modifier and Type Method Description final Stringtoken()Auth Rule Token final List<String>accountTokens()Account tokens to which the Auth Rule applies. final List<String>cardTokens()Card tokens to which the Auth Rule applies. final Optional<V2UpdateResponse.CurrentVersion>currentVersion()final Optional<V2UpdateResponse.DraftVersion>draftVersion()final Optional<String>name()Auth Rule Name final BooleanprogramLevel()Whether the Auth Rule applies to all authorizations on the card program. final V2UpdateResponse.AuthRuleStatestate()The state of the Auth Rule final V2UpdateResponse.AuthRuleTypetype()The type of Auth Rule final Optional<List<String>>excludedCardTokens()Card tokens to which the Auth Rule does not apply. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<List<String>>_accountTokens()Returns the raw JSON value of accountTokens. final JsonField<List<String>>_cardTokens()Returns the raw JSON value of cardTokens. final JsonField<V2UpdateResponse.CurrentVersion>_currentVersion()Returns the raw JSON value of currentVersion. final JsonField<V2UpdateResponse.DraftVersion>_draftVersion()Returns the raw JSON value of draftVersion. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<Boolean>_programLevel()Returns the raw JSON value of programLevel. final JsonField<V2UpdateResponse.AuthRuleState>_state()Returns the raw JSON value of state. final JsonField<V2UpdateResponse.AuthRuleType>_type()Returns the raw JSON value of type. final JsonField<List<String>>_excludedCardTokens()Returns the raw JSON value of excludedCardTokens. final Map<String, JsonValue>_additionalProperties()final V2UpdateResponse.BuildertoBuilder()final V2UpdateResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V2UpdateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of V2UpdateResponse. -
-
Method Detail
-
accountTokens
final List<String> accountTokens()
Account tokens to which the Auth Rule applies.
-
cardTokens
final List<String> cardTokens()
Card tokens to which the Auth Rule applies.
-
currentVersion
final Optional<V2UpdateResponse.CurrentVersion> currentVersion()
-
draftVersion
final Optional<V2UpdateResponse.DraftVersion> draftVersion()
-
programLevel
final Boolean programLevel()
Whether the Auth Rule applies to all authorizations on the card program.
-
state
final V2UpdateResponse.AuthRuleState state()
The state of the Auth Rule
-
type
final V2UpdateResponse.AuthRuleType type()
The type of Auth Rule
-
excludedCardTokens
final Optional<List<String>> excludedCardTokens()
Card tokens to which the Auth Rule does not apply.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_accountTokens
final JsonField<List<String>> _accountTokens()
Returns the raw JSON value of accountTokens.
Unlike accountTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_cardTokens
final JsonField<List<String>> _cardTokens()
Returns the raw JSON value of cardTokens.
Unlike cardTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_currentVersion
final JsonField<V2UpdateResponse.CurrentVersion> _currentVersion()
Returns the raw JSON value of currentVersion.
Unlike currentVersion, this method doesn't throw if the JSON field has an unexpected type.
-
_draftVersion
final JsonField<V2UpdateResponse.DraftVersion> _draftVersion()
Returns the raw JSON value of draftVersion.
Unlike draftVersion, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_programLevel
final JsonField<Boolean> _programLevel()
Returns the raw JSON value of programLevel.
Unlike programLevel, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<V2UpdateResponse.AuthRuleState> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<V2UpdateResponse.AuthRuleType> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_excludedCardTokens
final JsonField<List<String>> _excludedCardTokens()
Returns the raw JSON value of excludedCardTokens.
Unlike excludedCardTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V2UpdateResponse.Builder toBuilder()
-
validate
final V2UpdateResponse validate()
-
builder
final static V2UpdateResponse.Builder builder()
Returns a mutable builder for constructing an instance of V2UpdateResponse.
The following fields are required:
.token() .accountTokens() .cardTokens() .currentVersion() .draftVersion() .name() .programLevel() .state() .type()
-
-
-
-