Class VelocityLimitParamsPeriodWindow
-
- All Implemented Interfaces:
public final class VelocityLimitParamsPeriodWindowThe size of the trailing window to calculate Spend Velocity over in seconds. The minimum value is 10 seconds, and the maximum value is 2678400 seconds (31 days).
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceVelocityLimitParamsPeriodWindow.VisitorAn interface that defines how to map each variant of VelocityLimitParamsPeriodWindow to a value of type T.
public final classVelocityLimitParamsPeriodWindow.FixedWindowThe window of time to calculate Spend Velocity over.
DAY: Velocity over the current day since midnight Eastern Time.WEEK: Velocity over the current week since 00:00 / 12 AM on Monday in Eastern Time.MONTH: Velocity over the current month since 00:00 / 12 AM on the first of the month in Eastern Time.YEAR: Velocity over the current year since 00:00 / 12 AM on January 1st in Eastern Time.
public final classVelocityLimitParamsPeriodWindow.TrailingWindowObjectpublic final classVelocityLimitParamsPeriodWindow.FixedWindowDayVelocity over the current day since 00:00 / 12 AM in Eastern Time
public final classVelocityLimitParamsPeriodWindow.FixedWindowWeekVelocity over the current week since 00:00 / 12 AM in Eastern Time on specified
day_of_weekpublic final classVelocityLimitParamsPeriodWindow.FixedWindowMonthVelocity over the current month since 00:00 / 12 AM in Eastern Time on specified
day_of_month.public final classVelocityLimitParamsPeriodWindow.FixedWindowYearVelocity over the current year since 00:00 / 12 AM in Eastern Time on specified
monthandday_of_month. This validates the month and day of the year to start from is a real date. In the event that February 29th is selected, in non-leap years, the window will start from February 28th.
-
Method Summary
Modifier and Type Method Description final Optional<Long>trailing()The size of the trailing window to calculate Spend Velocity over in seconds. final Optional<VelocityLimitParamsPeriodWindow.FixedWindow>fixed()The window of time to calculate Spend Velocity over. final Optional<VelocityLimitParamsPeriodWindow.TrailingWindowObject>trailingWindowObject()final Optional<VelocityLimitParamsPeriodWindow.FixedWindowDay>fixedWindowDay()Velocity over the current day since 00:00 / 12 AM in Eastern Time final Optional<VelocityLimitParamsPeriodWindow.FixedWindowWeek>fixedWindowWeek()Velocity over the current week since 00:00 / 12 AM in Eastern Time on specified day_of_weekfinal Optional<VelocityLimitParamsPeriodWindow.FixedWindowMonth>fixedWindowMonth()Velocity over the current month since 00:00 / 12 AM in Eastern Time on specified day_of_month.final Optional<VelocityLimitParamsPeriodWindow.FixedWindowYear>fixedWindowYear()Velocity over the current year since 00:00 / 12 AM in Eastern Time on specified monthandday_of_month.final BooleanisTrailing()final BooleanisFixed()final BooleanisTrailingWindowObject()final BooleanisFixedWindowDay()final BooleanisFixedWindowWeek()final BooleanisFixedWindowMonth()final BooleanisFixedWindowYear()final LongasTrailing()The size of the trailing window to calculate Spend Velocity over in seconds. final VelocityLimitParamsPeriodWindow.FixedWindowasFixed()The window of time to calculate Spend Velocity over. final VelocityLimitParamsPeriodWindow.TrailingWindowObjectasTrailingWindowObject()final VelocityLimitParamsPeriodWindow.FixedWindowDayasFixedWindowDay()Velocity over the current day since 00:00 / 12 AM in Eastern Time final VelocityLimitParamsPeriodWindow.FixedWindowWeekasFixedWindowWeek()Velocity over the current week since 00:00 / 12 AM in Eastern Time on specified day_of_weekfinal VelocityLimitParamsPeriodWindow.FixedWindowMonthasFixedWindowMonth()Velocity over the current month since 00:00 / 12 AM in Eastern Time on specified day_of_month.final VelocityLimitParamsPeriodWindow.FixedWindowYearasFixedWindowYear()Velocity over the current year since 00:00 / 12 AM in Eastern Time on specified monthandday_of_month.final Optional<JsonValue>_json()final <T extends Any> Taccept(VelocityLimitParamsPeriodWindow.Visitor<T> visitor)final VelocityLimitParamsPeriodWindowvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VelocityLimitParamsPeriodWindowofTrailing(Long trailing)The size of the trailing window to calculate Spend Velocity over in seconds. final static VelocityLimitParamsPeriodWindowofFixed(VelocityLimitParamsPeriodWindow.FixedWindow fixed)The window of time to calculate Spend Velocity over. final static VelocityLimitParamsPeriodWindowofTrailingWindowObject(VelocityLimitParamsPeriodWindow.TrailingWindowObject trailingWindowObject)final static VelocityLimitParamsPeriodWindowofFixedWindowDay(VelocityLimitParamsPeriodWindow.FixedWindowDay fixedWindowDay)Velocity over the current day since 00:00 / 12 AM in Eastern Time final static VelocityLimitParamsPeriodWindowofFixedWindowWeek(VelocityLimitParamsPeriodWindow.FixedWindowWeek fixedWindowWeek)Velocity over the current week since 00:00 / 12 AM in Eastern Time on specified day_of_weekfinal static VelocityLimitParamsPeriodWindowofFixedWindowMonth(VelocityLimitParamsPeriodWindow.FixedWindowMonth fixedWindowMonth)Velocity over the current month since 00:00 / 12 AM in Eastern Time on specified day_of_month.final static VelocityLimitParamsPeriodWindowofFixedWindowYear(VelocityLimitParamsPeriodWindow.FixedWindowYear fixedWindowYear)Velocity over the current year since 00:00 / 12 AM in Eastern Time on specified monthandday_of_month.-
-
Method Detail
-
trailing
final Optional<Long> trailing()
The size of the trailing window to calculate Spend Velocity over in seconds. The minimum value is 10 seconds, and the maximum value is 2678400 seconds (31 days).
-
fixed
final Optional<VelocityLimitParamsPeriodWindow.FixedWindow> fixed()
The window of time to calculate Spend Velocity over.
DAY: Velocity over the current day since midnight Eastern Time.WEEK: Velocity over the current week since 00:00 / 12 AM on Monday in Eastern Time.MONTH: Velocity over the current month since 00:00 / 12 AM on the first of the month in Eastern Time.YEAR: Velocity over the current year since 00:00 / 12 AM on January 1st in Eastern Time.
-
trailingWindowObject
final Optional<VelocityLimitParamsPeriodWindow.TrailingWindowObject> trailingWindowObject()
-
fixedWindowDay
final Optional<VelocityLimitParamsPeriodWindow.FixedWindowDay> fixedWindowDay()
Velocity over the current day since 00:00 / 12 AM in Eastern Time
-
fixedWindowWeek
final Optional<VelocityLimitParamsPeriodWindow.FixedWindowWeek> fixedWindowWeek()
Velocity over the current week since 00:00 / 12 AM in Eastern Time on specified
day_of_week
-
fixedWindowMonth
final Optional<VelocityLimitParamsPeriodWindow.FixedWindowMonth> fixedWindowMonth()
Velocity over the current month since 00:00 / 12 AM in Eastern Time on specified
day_of_month.
-
fixedWindowYear
final Optional<VelocityLimitParamsPeriodWindow.FixedWindowYear> fixedWindowYear()
Velocity over the current year since 00:00 / 12 AM in Eastern Time on specified
monthandday_of_month. This validates the month and day of the year to start from is a real date. In the event that February 29th is selected, in non-leap years, the window will start from February 28th.
-
isTrailing
final Boolean isTrailing()
-
isTrailingWindowObject
final Boolean isTrailingWindowObject()
-
isFixedWindowDay
final Boolean isFixedWindowDay()
-
isFixedWindowWeek
final Boolean isFixedWindowWeek()
-
isFixedWindowMonth
final Boolean isFixedWindowMonth()
-
isFixedWindowYear
final Boolean isFixedWindowYear()
-
asTrailing
final Long asTrailing()
The size of the trailing window to calculate Spend Velocity over in seconds. The minimum value is 10 seconds, and the maximum value is 2678400 seconds (31 days).
-
asFixed
final VelocityLimitParamsPeriodWindow.FixedWindow asFixed()
The window of time to calculate Spend Velocity over.
DAY: Velocity over the current day since midnight Eastern Time.WEEK: Velocity over the current week since 00:00 / 12 AM on Monday in Eastern Time.MONTH: Velocity over the current month since 00:00 / 12 AM on the first of the month in Eastern Time.YEAR: Velocity over the current year since 00:00 / 12 AM on January 1st in Eastern Time.
-
asTrailingWindowObject
final VelocityLimitParamsPeriodWindow.TrailingWindowObject asTrailingWindowObject()
-
asFixedWindowDay
final VelocityLimitParamsPeriodWindow.FixedWindowDay asFixedWindowDay()
Velocity over the current day since 00:00 / 12 AM in Eastern Time
-
asFixedWindowWeek
final VelocityLimitParamsPeriodWindow.FixedWindowWeek asFixedWindowWeek()
Velocity over the current week since 00:00 / 12 AM in Eastern Time on specified
day_of_week
-
asFixedWindowMonth
final VelocityLimitParamsPeriodWindow.FixedWindowMonth asFixedWindowMonth()
Velocity over the current month since 00:00 / 12 AM in Eastern Time on specified
day_of_month.
-
asFixedWindowYear
final VelocityLimitParamsPeriodWindow.FixedWindowYear asFixedWindowYear()
Velocity over the current year since 00:00 / 12 AM in Eastern Time on specified
monthandday_of_month. This validates the month and day of the year to start from is a real date. In the event that February 29th is selected, in non-leap years, the window will start from February 28th.
-
accept
final <T extends Any> T accept(VelocityLimitParamsPeriodWindow.Visitor<T> visitor)
-
validate
final VelocityLimitParamsPeriodWindow validate()
-
ofTrailing
final static VelocityLimitParamsPeriodWindow ofTrailing(Long trailing)
The size of the trailing window to calculate Spend Velocity over in seconds. The minimum value is 10 seconds, and the maximum value is 2678400 seconds (31 days).
-
ofFixed
final static VelocityLimitParamsPeriodWindow ofFixed(VelocityLimitParamsPeriodWindow.FixedWindow fixed)
The window of time to calculate Spend Velocity over.
DAY: Velocity over the current day since midnight Eastern Time.WEEK: Velocity over the current week since 00:00 / 12 AM on Monday in Eastern Time.MONTH: Velocity over the current month since 00:00 / 12 AM on the first of the month in Eastern Time.YEAR: Velocity over the current year since 00:00 / 12 AM on January 1st in Eastern Time.
-
ofTrailingWindowObject
final static VelocityLimitParamsPeriodWindow ofTrailingWindowObject(VelocityLimitParamsPeriodWindow.TrailingWindowObject trailingWindowObject)
-
ofFixedWindowDay
final static VelocityLimitParamsPeriodWindow ofFixedWindowDay(VelocityLimitParamsPeriodWindow.FixedWindowDay fixedWindowDay)
Velocity over the current day since 00:00 / 12 AM in Eastern Time
-
ofFixedWindowWeek
final static VelocityLimitParamsPeriodWindow ofFixedWindowWeek(VelocityLimitParamsPeriodWindow.FixedWindowWeek fixedWindowWeek)
Velocity over the current week since 00:00 / 12 AM in Eastern Time on specified
day_of_week
-
ofFixedWindowMonth
final static VelocityLimitParamsPeriodWindow ofFixedWindowMonth(VelocityLimitParamsPeriodWindow.FixedWindowMonth fixedWindowMonth)
Velocity over the current month since 00:00 / 12 AM in Eastern Time on specified
day_of_month.
-
ofFixedWindowYear
final static VelocityLimitParamsPeriodWindow ofFixedWindowYear(VelocityLimitParamsPeriodWindow.FixedWindowYear fixedWindowYear)
Velocity over the current year since 00:00 / 12 AM in Eastern Time on specified
monthandday_of_month. This validates the month and day of the year to start from is a real date. In the event that February 29th is selected, in non-leap years, the window will start from February 28th.
-
-
-
-