Package com.lithic.api.models
Enum VelocityLimitParamsPeriodWindow.FixedWindow.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum VelocityLimitParamsPeriodWindow.FixedWindow.Known extends Enum<VelocityLimitParamsPeriodWindow.FixedWindow.Known>
An enum containing FixedWindow's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<VelocityLimitParamsPeriodWindow.FixedWindow.Known>entries
-
Method Summary
Modifier and Type Method Description final VelocityLimitParamsPeriodWindow.FixedWindow.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<VelocityLimitParamsPeriodWindow.FixedWindow.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<VelocityLimitParamsPeriodWindow.FixedWindow.Known>getEntries()An enum containing FixedWindow's known values. -
-
Method Detail
-
valueOf
final VelocityLimitParamsPeriodWindow.FixedWindow.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<VelocityLimitParamsPeriodWindow.FixedWindow.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<VelocityLimitParamsPeriodWindow.FixedWindow.Known> getEntries()
An enum containing FixedWindow's known values.
-
-
-
-