Package com.lithic.api.models
Class VelocityLimitParamsPeriodWindow.FixedWindowMonth
-
- All Implemented Interfaces:
public final class VelocityLimitParamsPeriodWindow.FixedWindowMonthVelocity over the current month since 00:00 / 12 AM in Eastern Time on specified
day_of_month.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVelocityLimitParamsPeriodWindow.FixedWindowMonth.BuilderA builder for FixedWindowMonth.
public final classVelocityLimitParamsPeriodWindow.FixedWindowMonth.Type
-
Method Summary
Modifier and Type Method Description final Optional<Long>dayOfMonth()The day of the month to start from. final Optional<VelocityLimitParamsPeriodWindow.FixedWindowMonth.Type>type()final JsonField<Long>_dayOfMonth()Returns the raw JSON value of dayOfMonth. final JsonField<VelocityLimitParamsPeriodWindow.FixedWindowMonth.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final VelocityLimitParamsPeriodWindow.FixedWindowMonth.BuildertoBuilder()final VelocityLimitParamsPeriodWindow.FixedWindowMonthvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VelocityLimitParamsPeriodWindow.FixedWindowMonth.Builderbuilder()Returns a mutable builder for constructing an instance of FixedWindowMonth. -
-
Method Detail
-
dayOfMonth
final Optional<Long> dayOfMonth()
The day of the month to start from. Accepts values from 1 to 31, and will reset at the end of the month if the day exceeds the number of days in the month. Defaults to the 1st of the month if not specified.
-
_dayOfMonth
final JsonField<Long> _dayOfMonth()
Returns the raw JSON value of dayOfMonth.
Unlike dayOfMonth, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<VelocityLimitParamsPeriodWindow.FixedWindowMonth.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VelocityLimitParamsPeriodWindow.FixedWindowMonth.Builder toBuilder()
-
validate
final VelocityLimitParamsPeriodWindow.FixedWindowMonth validate()
-
builder
final static VelocityLimitParamsPeriodWindow.FixedWindowMonth.Builder builder()
Returns a mutable builder for constructing an instance of FixedWindowMonth.
-
-
-
-