Package com.lithic.api.models
Class VelocityLimitParamsPeriodWindow.TrailingWindowObject
-
- All Implemented Interfaces:
public final class VelocityLimitParamsPeriodWindow.TrailingWindowObject
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVelocityLimitParamsPeriodWindow.TrailingWindowObject.BuilderA builder for TrailingWindowObject.
public final classVelocityLimitParamsPeriodWindow.TrailingWindowObject.Type
-
Method Summary
Modifier and Type Method Description final Longduration()The size of the trailing window to calculate Spend Velocity over in seconds. final VelocityLimitParamsPeriodWindow.TrailingWindowObject.Typetype()final JsonField<Long>_duration()Returns the raw JSON value of duration. final JsonField<VelocityLimitParamsPeriodWindow.TrailingWindowObject.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final VelocityLimitParamsPeriodWindow.TrailingWindowObject.BuildertoBuilder()final VelocityLimitParamsPeriodWindow.TrailingWindowObjectvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VelocityLimitParamsPeriodWindow.TrailingWindowObject.Builderbuilder()Returns a mutable builder for constructing an instance of TrailingWindowObject. -
-
Method Detail
-
duration
final Long duration()
The size of the trailing window to calculate Spend Velocity over in seconds. The minimum value is 10 seconds, and the maximum value is 2678400 seconds (31 days).
-
_duration
final JsonField<Long> _duration()
Returns the raw JSON value of duration.
Unlike duration, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<VelocityLimitParamsPeriodWindow.TrailingWindowObject.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VelocityLimitParamsPeriodWindow.TrailingWindowObject.Builder toBuilder()
-
validate
final VelocityLimitParamsPeriodWindow.TrailingWindowObject validate()
-
builder
final static VelocityLimitParamsPeriodWindow.TrailingWindowObject.Builder builder()
Returns a mutable builder for constructing an instance of TrailingWindowObject.
The following fields are required:
.duration() .type()
-
-
-
-