Package com.lithic.api.models
Class VelocityLimitPeriod.FixedWindowDay
-
- All Implemented Interfaces:
public final class VelocityLimitPeriod.FixedWindowDayVelocity over the current day since 00:00 / 12 AM in Eastern Time
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVelocityLimitPeriod.FixedWindowDay.BuilderA builder for FixedWindowDay.
public final classVelocityLimitPeriod.FixedWindowDay.Type
-
Method Summary
Modifier and Type Method Description final VelocityLimitPeriod.FixedWindowDay.Typetype()final JsonField<VelocityLimitPeriod.FixedWindowDay.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final VelocityLimitPeriod.FixedWindowDay.BuildertoBuilder()final VelocityLimitPeriod.FixedWindowDayvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VelocityLimitPeriod.FixedWindowDay.Builderbuilder()Returns a mutable builder for constructing an instance of FixedWindowDay. -
-
Method Detail
-
type
final VelocityLimitPeriod.FixedWindowDay.Type type()
-
_type
final JsonField<VelocityLimitPeriod.FixedWindowDay.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VelocityLimitPeriod.FixedWindowDay.Builder toBuilder()
-
validate
final VelocityLimitPeriod.FixedWindowDay validate()
-
builder
final static VelocityLimitPeriod.FixedWindowDay.Builder builder()
Returns a mutable builder for constructing an instance of FixedWindowDay.
The following fields are required:
.type()
-
-
-
-