Class VelocityLimitPeriod.FixedWindowYear

  • All Implemented Interfaces:

    
    public final class VelocityLimitPeriod.FixedWindowYear
    
                        

    Velocity over the current year since 00:00 / 12 AM in Eastern Time on specified month and day_of_month. This validates the month and day of the year to start from is a real date. In the event that February 29th is selected, in non-leap years, the window will start from February 28th.