Class WirePartyDetails
-
- All Implemented Interfaces:
public final class WirePartyDetails
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWirePartyDetails.BuilderA builder for WirePartyDetails.
-
Method Summary
Modifier and Type Method Description final Optional<String>accountNumber()Account number final Optional<String>agentId()Routing number or BIC of the financial institution final Optional<String>agentName()Name of the financial institution final Optional<String>name()Name of the person or company final JsonField<String>_accountNumber()Returns the raw JSON value of accountNumber. final JsonField<String>_agentId()Returns the raw JSON value of agentId. final JsonField<String>_agentName()Returns the raw JSON value of agentName. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final WirePartyDetails.BuildertoBuilder()final WirePartyDetailsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WirePartyDetails.Builderbuilder()Returns a mutable builder for constructing an instance of WirePartyDetails. -
-
Method Detail
-
accountNumber
final Optional<String> accountNumber()
Account number
-
_accountNumber
final JsonField<String> _accountNumber()
Returns the raw JSON value of accountNumber.
Unlike accountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_agentId
final JsonField<String> _agentId()
Returns the raw JSON value of agentId.
Unlike agentId, this method doesn't throw if the JSON field has an unexpected type.
-
_agentName
final JsonField<String> _agentName()
Returns the raw JSON value of agentName.
Unlike agentName, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WirePartyDetails.Builder toBuilder()
-
validate
final WirePartyDetails validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static WirePartyDetails.Builder builder()
Returns a mutable builder for constructing an instance of WirePartyDetails.
-
-
-
-