Package com.lithic.api.services.async
Interface DigitalCardArtServiceAsync
-
- All Implemented Interfaces:
public interface DigitalCardArtServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceDigitalCardArtServiceAsync.WithRawResponseA view of DigitalCardArtServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract DigitalCardArtServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<DigitalCardArt>retrieve(DigitalCardArtRetrieveParams params)Get digital card art by token. abstract CompletableFuture<DigitalCardArt>retrieve(DigitalCardArtRetrieveParams params, RequestOptions requestOptions)CompletableFuture<DigitalCardArtListPageAsync>list()List digital card art. abstract CompletableFuture<DigitalCardArtListPageAsync>list(DigitalCardArtListParams params, RequestOptions requestOptions)CompletableFuture<DigitalCardArtListPageAsync>list(DigitalCardArtListParams params)CompletableFuture<DigitalCardArtListPageAsync>list(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract DigitalCardArtServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<DigitalCardArt> retrieve(DigitalCardArtRetrieveParams params)
Get digital card art by token.
-
retrieve
abstract CompletableFuture<DigitalCardArt> retrieve(DigitalCardArtRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<DigitalCardArtListPageAsync> list()
List digital card art.
-
list
abstract CompletableFuture<DigitalCardArtListPageAsync> list(DigitalCardArtListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<DigitalCardArtListPageAsync> list(RequestOptions requestOptions)
-
-
-
-