Package com.lithic.api.services.async
Interface DisputesV2ServiceAsync
-
- All Implemented Interfaces:
public interface DisputesV2ServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceDisputesV2ServiceAsync.WithRawResponseA view of DisputesV2ServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract DisputesV2ServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract DisputesV2ServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<DisputeV2> retrieve(String disputeToken)
Retrieves a specific dispute by its token.
-
retrieve
CompletableFuture<DisputeV2> retrieve(String disputeToken, DisputesV2RetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<DisputeV2> retrieve(String disputeToken, DisputesV2RetrieveParams params)
-
retrieve
abstract CompletableFuture<DisputeV2> retrieve(DisputesV2RetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<DisputeV2> retrieve(DisputesV2RetrieveParams params)
-
retrieve
CompletableFuture<DisputeV2> retrieve(String disputeToken, RequestOptions requestOptions)
-
list
CompletableFuture<DisputesV2ListPageAsync> list()
Returns a paginated list of disputes.
-
list
abstract CompletableFuture<DisputesV2ListPageAsync> list(DisputesV2ListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<DisputesV2ListPageAsync> list(DisputesV2ListParams params)
-
list
CompletableFuture<DisputesV2ListPageAsync> list(RequestOptions requestOptions)
-
-
-
-