Package com.lithic.api.services.async
Interface ExternalBankAccountServiceAsync
-
- All Implemented Interfaces:
public interface ExternalBankAccountServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceExternalBankAccountServiceAsync.WithRawResponseA view of ExternalBankAccountServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract ExternalBankAccountServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
microDeposits
abstract MicroDepositServiceAsync microDeposits()
-
create
CompletableFuture<ExternalBankAccountCreateResponse> create()
Creates an external bank account within a program or Lithic account.
-
create
abstract CompletableFuture<ExternalBankAccountCreateResponse> create(ExternalBankAccountCreateParams params, RequestOptions requestOptions)
-
create
CompletableFuture<ExternalBankAccountCreateResponse> create(ExternalBankAccountCreateParams params)
-
create
CompletableFuture<ExternalBankAccountCreateResponse> create(RequestOptions requestOptions)
-
retrieve
CompletableFuture<ExternalBankAccountRetrieveResponse> retrieve(ExternalBankAccountRetrieveParams params)
Get the external bank account by token.
-
retrieve
abstract CompletableFuture<ExternalBankAccountRetrieveResponse> retrieve(ExternalBankAccountRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<ExternalBankAccountUpdateResponse> update(ExternalBankAccountUpdateParams params)
Update the external bank account by token.
-
update
abstract CompletableFuture<ExternalBankAccountUpdateResponse> update(ExternalBankAccountUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<ExternalBankAccountListPageAsync> list()
List all the external bank accounts for the provided search criteria.
-
list
abstract CompletableFuture<ExternalBankAccountListPageAsync> list(ExternalBankAccountListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<ExternalBankAccountListPageAsync> list(RequestOptions requestOptions)
-
retryMicroDeposits
CompletableFuture<ExternalBankAccountRetryMicroDepositsResponse> retryMicroDeposits(ExternalBankAccountRetryMicroDepositsParams params)
Retry external bank account micro deposit verification.
-
retryMicroDeposits
abstract CompletableFuture<ExternalBankAccountRetryMicroDepositsResponse> retryMicroDeposits(ExternalBankAccountRetryMicroDepositsParams params, RequestOptions requestOptions)
-
retryPrenote
CompletableFuture<ExternalBankAccountRetryPrenoteResponse> retryPrenote(ExternalBankAccountRetryPrenoteParams params)
Retry external bank account prenote verification.
-
retryPrenote
abstract CompletableFuture<ExternalBankAccountRetryPrenoteResponse> retryPrenote(ExternalBankAccountRetryPrenoteParams params, RequestOptions requestOptions)
-
-
-
-