Package com.lithic.api.services.async
Class ExternalBankAccountServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.async.ExternalBankAccountServiceAsync
public final class ExternalBankAccountServiceAsyncImpl implements ExternalBankAccountServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalBankAccountServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class com.lithic.api.services.async.ExternalBankAccountServiceAsync
create, create, create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, retryMicroDeposits, retryMicroDeposits, retryMicroDeposits, retryMicroDeposits, retryMicroDeposits, retryPrenote, retryPrenote, retryPrenote, retryPrenote, retryPrenote, unpause, unpause, unpause, unpause, unpause, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
ExternalBankAccountServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ExternalBankAccountServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
microDeposits
MicroDepositServiceAsync microDeposits()
-
create
CompletableFuture<ExternalBankAccountCreateResponse> create(ExternalBankAccountCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<ExternalBankAccountRetrieveResponse> retrieve(ExternalBankAccountRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<ExternalBankAccountUpdateResponse> update(ExternalBankAccountUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<ExternalBankAccountListPageAsync> list(ExternalBankAccountListParams params, RequestOptions requestOptions)
-
retryMicroDeposits
CompletableFuture<ExternalBankAccountRetryMicroDepositsResponse> retryMicroDeposits(ExternalBankAccountRetryMicroDepositsParams params, RequestOptions requestOptions)
-
retryPrenote
CompletableFuture<ExternalBankAccountRetryPrenoteResponse> retryPrenote(ExternalBankAccountRetryPrenoteParams params, RequestOptions requestOptions)
-
unpause
CompletableFuture<ExternalBankAccountUnpauseResponse> unpause(ExternalBankAccountUnpauseParams params, RequestOptions requestOptions)
-
-
-
-