Interface AggregateBalanceServiceAsync
-
- All Implemented Interfaces:
public interface AggregateBalanceServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAggregateBalanceServiceAsync.WithRawResponseA view of AggregateBalanceServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AggregateBalanceServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<CardAggregateBalanceListPageAsync>list()Get the aggregated card balance across all end-user accounts. abstract CompletableFuture<CardAggregateBalanceListPageAsync>list(CardAggregateBalanceListParams params, RequestOptions requestOptions)CompletableFuture<CardAggregateBalanceListPageAsync>list(CardAggregateBalanceListParams params)CompletableFuture<CardAggregateBalanceListPageAsync>list(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract AggregateBalanceServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
list
CompletableFuture<CardAggregateBalanceListPageAsync> list()
Get the aggregated card balance across all end-user accounts.
-
list
abstract CompletableFuture<CardAggregateBalanceListPageAsync> list(CardAggregateBalanceListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<CardAggregateBalanceListPageAsync> list(CardAggregateBalanceListParams params)
-
list
CompletableFuture<CardAggregateBalanceListPageAsync> list(RequestOptions requestOptions)
-
-
-
-