Class AggregateBalanceServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.async.cards.AggregateBalanceServiceAsync.WithRawResponse
public final class AggregateBalanceServiceAsyncImpl.WithRawResponseImpl implements AggregateBalanceServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description AggregateBalanceServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<CardAggregateBalanceListPageAsync>>list(CardAggregateBalanceListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
AggregateBalanceServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<HttpResponseFor<CardAggregateBalanceListPageAsync>> list(CardAggregateBalanceListParams params, RequestOptions requestOptions)
-
-
-
-