Interface BalanceServiceAsync
-
- All Implemented Interfaces:
public interface BalanceServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceBalanceServiceAsync.WithRawResponseA view of BalanceServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract BalanceServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract BalanceServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CardBalanceListPageAsync>list(String cardToken)Get the balances for a given card. CompletableFuture<CardBalanceListPageAsync>list(String cardToken, CardBalanceListParams params, RequestOptions requestOptions)CompletableFuture<CardBalanceListPageAsync>list(String cardToken, CardBalanceListParams params)abstract CompletableFuture<CardBalanceListPageAsync>list(CardBalanceListParams params, RequestOptions requestOptions)CompletableFuture<CardBalanceListPageAsync>list(CardBalanceListParams params)CompletableFuture<CardBalanceListPageAsync>list(String cardToken, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract BalanceServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract BalanceServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<CardBalanceListPageAsync> list(String cardToken)
Get the balances for a given card.
-
list
CompletableFuture<CardBalanceListPageAsync> list(String cardToken, CardBalanceListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<CardBalanceListPageAsync> list(String cardToken, CardBalanceListParams params)
-
list
abstract CompletableFuture<CardBalanceListPageAsync> list(CardBalanceListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<CardBalanceListPageAsync> list(CardBalanceListParams params)
-
list
CompletableFuture<CardBalanceListPageAsync> list(String cardToken, RequestOptions requestOptions)
-
-
-
-