Interface FinancialTransactionServiceAsync
-
- All Implemented Interfaces:
public interface FinancialTransactionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceFinancialTransactionServiceAsync.WithRawResponseA view of FinancialTransactionServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract FinancialTransactionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<FinancialTransaction>retrieve(CardFinancialTransactionRetrieveParams params)Get the card financial transaction for the provided token. abstract CompletableFuture<FinancialTransaction>retrieve(CardFinancialTransactionRetrieveParams params, RequestOptions requestOptions)CompletableFuture<CardFinancialTransactionListPageAsync>list(CardFinancialTransactionListParams params)List the financial transactions for a given card. abstract CompletableFuture<CardFinancialTransactionListPageAsync>list(CardFinancialTransactionListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract FinancialTransactionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<FinancialTransaction> retrieve(CardFinancialTransactionRetrieveParams params)
Get the card financial transaction for the provided token.
-
retrieve
abstract CompletableFuture<FinancialTransaction> retrieve(CardFinancialTransactionRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<CardFinancialTransactionListPageAsync> list(CardFinancialTransactionListParams params)
List the financial transactions for a given card.
-
list
abstract CompletableFuture<CardFinancialTransactionListPageAsync> list(CardFinancialTransactionListParams params, RequestOptions requestOptions)
-
-
-
-