Interface EventSubscriptionServiceAsync
-
- All Implemented Interfaces:
public interface EventSubscriptionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceEventSubscriptionServiceAsync.WithRawResponseA view of EventSubscriptionServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract EventSubscriptionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract EventSubscriptionServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Void>resend(String eventSubscriptionToken, EventEventSubscriptionResendParams params)Resend an event to an event subscription. CompletableFuture<Void>resend(String eventSubscriptionToken, EventEventSubscriptionResendParams params, RequestOptions requestOptions)CompletableFuture<Void>resend(EventEventSubscriptionResendParams params)abstract CompletableFuture<Void>resend(EventEventSubscriptionResendParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract EventSubscriptionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract EventSubscriptionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
resend
CompletableFuture<Void> resend(String eventSubscriptionToken, EventEventSubscriptionResendParams params)
Resend an event to an event subscription.
-
resend
CompletableFuture<Void> resend(String eventSubscriptionToken, EventEventSubscriptionResendParams params, RequestOptions requestOptions)
-
resend
CompletableFuture<Void> resend(EventEventSubscriptionResendParams params)
-
resend
abstract CompletableFuture<Void> resend(EventEventSubscriptionResendParams params, RequestOptions requestOptions)
-
-
-
-