Interface EventSubscriptionServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface EventSubscriptionServiceAsync.WithRawResponseA view of EventSubscriptionServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract EventSubscriptionServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponse>resend(String eventSubscriptionToken, EventEventSubscriptionResendParams params)Returns a raw HTTP response for post /v1/events/{event_token}/event_subscriptions/{event_subscription_token}/resend, but is otherwise the same as EventSubscriptionServiceAsync.resend.CompletableFuture<HttpResponse>resend(String eventSubscriptionToken, EventEventSubscriptionResendParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>resend(EventEventSubscriptionResendParams params)abstract CompletableFuture<HttpResponse>resend(EventEventSubscriptionResendParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract EventSubscriptionServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
resend
CompletableFuture<HttpResponse> resend(String eventSubscriptionToken, EventEventSubscriptionResendParams params)
Returns a raw HTTP response for
post /v1/events/{event_token}/event_subscriptions/{event_subscription_token}/resend, but is otherwise the same as EventSubscriptionServiceAsync.resend.
-
resend
CompletableFuture<HttpResponse> resend(String eventSubscriptionToken, EventEventSubscriptionResendParams params, RequestOptions requestOptions)
-
resend
CompletableFuture<HttpResponse> resend(EventEventSubscriptionResendParams params)
-
resend
abstract CompletableFuture<HttpResponse> resend(EventEventSubscriptionResendParams params, RequestOptions requestOptions)
-
-
-
-