Class EventSubscriptionServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.async.events.EventSubscriptionServiceAsync.WithRawResponse
public final class EventSubscriptionServiceAsyncImpl.WithRawResponseImpl implements EventSubscriptionServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description EventSubscriptionServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponse>resend(EventEventSubscriptionResendParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
EventSubscriptionServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
resend
CompletableFuture<HttpResponse> resend(EventEventSubscriptionResendParams params, RequestOptions requestOptions)
-
-
-
-