Class SubscriptionServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.async.events.SubscriptionServiceAsync
public final class SubscriptionServiceAsyncImpl implements SubscriptionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSubscriptionServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class com.lithic.api.services.async.events.SubscriptionServiceAsync
create, delete, list, list, list, listAttempts, recover, replayMissing, retrieve, retrieveSecret, rotateSecret, sendSimulatedExample, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
SubscriptionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<EventSubscription> create(EventSubscriptionCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<EventSubscription> retrieve(EventSubscriptionRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<EventSubscription> update(EventSubscriptionUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<EventSubscriptionListPageAsync> list(EventSubscriptionListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(EventSubscriptionDeleteParams params, RequestOptions requestOptions)
-
listAttempts
CompletableFuture<EventSubscriptionListAttemptsPageAsync> listAttempts(EventSubscriptionListAttemptsParams params, RequestOptions requestOptions)
-
recover
CompletableFuture<Void> recover(EventSubscriptionRecoverParams params, RequestOptions requestOptions)
-
replayMissing
CompletableFuture<Void> replayMissing(EventSubscriptionReplayMissingParams params, RequestOptions requestOptions)
-
retrieveSecret
CompletableFuture<SubscriptionRetrieveSecretResponse> retrieveSecret(EventSubscriptionRetrieveSecretParams params, RequestOptions requestOptions)
-
rotateSecret
CompletableFuture<Void> rotateSecret(EventSubscriptionRotateSecretParams params, RequestOptions requestOptions)
-
sendSimulatedExample
CompletableFuture<Void> sendSimulatedExample(EventSubscriptionSendSimulatedExampleParams params, RequestOptions requestOptions)
-
-
-
-