Class SubscriptionServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.async.events.SubscriptionServiceAsync.WithRawResponse
public final class SubscriptionServiceAsyncImpl.WithRawResponseImpl implements SubscriptionServiceAsync.WithRawResponse
-
-
Method Summary
-
Methods inherited from class com.lithic.api.services.async.events.SubscriptionServiceAsync.WithRawResponse
create, delete, delete, delete, delete, delete, list, list, list, listAttempts, listAttempts, listAttempts, listAttempts, listAttempts, recover, recover, recover, recover, recover, replayMissing, replayMissing, replayMissing, replayMissing, replayMissing, retrieve, retrieve, retrieve, retrieve, retrieve, retrieveSecret, retrieveSecret, retrieveSecret, retrieveSecret, retrieveSecret, rotateSecret, rotateSecret, rotateSecret, rotateSecret, rotateSecret, sendSimulatedExample, sendSimulatedExample, sendSimulatedExample, sendSimulatedExample, sendSimulatedExample, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
SubscriptionServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<EventSubscription>> create(EventSubscriptionCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<HttpResponseFor<EventSubscription>> retrieve(EventSubscriptionRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<HttpResponseFor<EventSubscription>> update(EventSubscriptionUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<EventSubscriptionListPageAsync>> list(EventSubscriptionListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<HttpResponse> delete(EventSubscriptionDeleteParams params, RequestOptions requestOptions)
-
listAttempts
CompletableFuture<HttpResponseFor<EventSubscriptionListAttemptsPageAsync>> listAttempts(EventSubscriptionListAttemptsParams params, RequestOptions requestOptions)
-
recover
CompletableFuture<HttpResponse> recover(EventSubscriptionRecoverParams params, RequestOptions requestOptions)
-
replayMissing
CompletableFuture<HttpResponse> replayMissing(EventSubscriptionReplayMissingParams params, RequestOptions requestOptions)
-
retrieveSecret
CompletableFuture<HttpResponseFor<SubscriptionRetrieveSecretResponse>> retrieveSecret(EventSubscriptionRetrieveSecretParams params, RequestOptions requestOptions)
-
rotateSecret
CompletableFuture<HttpResponse> rotateSecret(EventSubscriptionRotateSecretParams params, RequestOptions requestOptions)
-
sendSimulatedExample
CompletableFuture<HttpResponse> sendSimulatedExample(EventSubscriptionSendSimulatedExampleParams params, RequestOptions requestOptions)
-
-
-
-