Class MicroDepositServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.async.externalBankAccounts.MicroDepositServiceAsync
public final class MicroDepositServiceAsyncImpl implements MicroDepositServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMicroDepositServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description MicroDepositServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<MicroDepositCreateResponse>create(ExternalBankAccountMicroDepositCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
MicroDepositServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<MicroDepositCreateResponse> create(ExternalBankAccountMicroDepositCreateParams params, RequestOptions requestOptions)
-
-
-
-