Class CreditConfigurationServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.async.financialAccounts.CreditConfigurationServiceAsync
public final class CreditConfigurationServiceAsyncImpl implements CreditConfigurationServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCreditConfigurationServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CreditConfigurationServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CreditConfigurationServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<FinancialAccountCreditConfig>retrieve(FinancialAccountCreditConfigurationRetrieveParams params, RequestOptions requestOptions)CompletableFuture<FinancialAccountCreditConfig>update(FinancialAccountCreditConfigurationUpdateParams params, RequestOptions requestOptions)-
Methods inherited from class com.lithic.api.services.async.financialAccounts.CreditConfigurationServiceAsync
retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
CreditConfigurationServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CreditConfigurationServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<FinancialAccountCreditConfig> retrieve(FinancialAccountCreditConfigurationRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<FinancialAccountCreditConfig> update(FinancialAccountCreditConfigurationUpdateParams params, RequestOptions requestOptions)
-
-
-
-