Class FinancialTransactionServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.async.financialAccounts.FinancialTransactionServiceAsync
public final class FinancialTransactionServiceAsyncImpl implements FinancialTransactionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinancialTransactionServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description FinancialTransactionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. FinancialTransactionServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<FinancialTransaction>retrieve(FinancialTransactionRetrieveParams params, RequestOptions requestOptions)CompletableFuture<FinancialTransactionListPageAsync>list(FinancialTransactionListParams params, RequestOptions requestOptions)-
Methods inherited from class com.lithic.api.services.async.financialAccounts.FinancialTransactionServiceAsync
list, list, list, list, list, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
FinancialTransactionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
FinancialTransactionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<FinancialTransaction> retrieve(FinancialTransactionRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<FinancialTransactionListPageAsync> list(FinancialTransactionListParams params, RequestOptions requestOptions)
-
-
-
-