Interface AccountHolderService
-
- All Implemented Interfaces:
public interface AccountHolderService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAccountHolderService.WithRawResponseA view of AccountHolderService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract AccountHolderService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract AccountHolderService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
entities
abstract EntityService entities()
-
create
AccountHolderCreateResponse create(AccountHolderCreateParams params)
Create an account holder and initiate the appropriate onboarding workflow. Account holders and accounts have a 1:1 relationship. When an account holder is successfully created an associated account is also created. All calls to this endpoint will return a synchronous response. The response time will depend on the workflow. In some cases, the response may indicate the workflow is under review or further action will be needed to complete the account creation process. This endpoint can only be used on accounts that are part of the program that the calling API key manages.
-
create
abstract AccountHolderCreateResponse create(AccountHolderCreateParams params, RequestOptions requestOptions)
-
create
AccountHolderCreateResponse create(AccountHolderCreateParams.Body body, RequestOptions requestOptions)
-
create
AccountHolderCreateResponse create(Kyb kyb, RequestOptions requestOptions)
-
create
AccountHolderCreateResponse create(Kyb kyb)
-
create
AccountHolderCreateResponse create(AccountHolderCreateParams.Body.KybDelegated kybDelegated, RequestOptions requestOptions)
-
create
AccountHolderCreateResponse create(AccountHolderCreateParams.Body.KybDelegated kybDelegated)
-
create
AccountHolderCreateResponse create(Kyc kyc, RequestOptions requestOptions)
-
create
AccountHolderCreateResponse create(Kyc kyc)
-
create
AccountHolderCreateResponse create(KycExempt kycExempt, RequestOptions requestOptions)
-
create
AccountHolderCreateResponse create(KycExempt kycExempt)
-
retrieve
AccountHolder retrieve(String accountHolderToken)
Get an Individual or Business Account Holder and/or their KYC or KYB evaluation status.
-
retrieve
AccountHolder retrieve(String accountHolderToken, AccountHolderRetrieveParams params, RequestOptions requestOptions)
-
retrieve
AccountHolder retrieve(String accountHolderToken, AccountHolderRetrieveParams params)
-
retrieve
abstract AccountHolder retrieve(AccountHolderRetrieveParams params, RequestOptions requestOptions)
-
retrieve
AccountHolder retrieve(AccountHolderRetrieveParams params)
-
retrieve
AccountHolder retrieve(String accountHolderToken, RequestOptions requestOptions)
-
update
AccountHolderUpdateResponse update(String accountHolderToken, AccountHolderUpdateParams params)
Update the information associated with a particular account holder (including business owners and control persons associated to a business account). If Lithic is performing KYB or KYC and additional verification is required we will run the individual's or business's updated information again and return whether the status is accepted or pending (i.e., further action required). All calls to this endpoint will return a synchronous response. The response time will depend on the workflow. In some cases, the response may indicate the workflow is under review or further action will be needed to complete the account creation process. This endpoint can only be used on existing accounts that are part of the program that the calling API key manages.
-
update
AccountHolderUpdateResponse update(String accountHolderToken, AccountHolderUpdateParams params, RequestOptions requestOptions)
-
update
AccountHolderUpdateResponse update(AccountHolderUpdateParams params)
-
update
abstract AccountHolderUpdateResponse update(AccountHolderUpdateParams params, RequestOptions requestOptions)
-
list
AccountHolderListPage list()
Get a list of individual or business account holders and their KYC or KYB evaluation status.
-
list
abstract AccountHolderListPage list(AccountHolderListParams params, RequestOptions requestOptions)
-
list
AccountHolderListPage list(AccountHolderListParams params)
-
list
AccountHolderListPage list(RequestOptions requestOptions)
-
listDocuments
AccountHolderListDocumentsResponse listDocuments(String accountHolderToken)
Retrieve the status of account holder document uploads, or retrieve the upload URLs to process your image uploads.
Note that this is not equivalent to checking the status of the KYC evaluation overall (a document may be successfully uploaded but not be sufficient for KYC to pass).
In the event your upload URLs have expired, calling this endpoint will refresh them. Similarly, in the event a previous account holder document upload has failed, you can use this endpoint to get a new upload URL for the failed image upload.
When a new document upload is generated for a failed attempt, the response will show an additional entry in the
required_document_uploadslist in aPENDINGstate for the correspondingimage_type.
-
listDocuments
AccountHolderListDocumentsResponse listDocuments(String accountHolderToken, AccountHolderListDocumentsParams params, RequestOptions requestOptions)
-
listDocuments
AccountHolderListDocumentsResponse listDocuments(String accountHolderToken, AccountHolderListDocumentsParams params)
-
listDocuments
abstract AccountHolderListDocumentsResponse listDocuments(AccountHolderListDocumentsParams params, RequestOptions requestOptions)
-
listDocuments
AccountHolderListDocumentsResponse listDocuments(AccountHolderListDocumentsParams params)
-
listDocuments
AccountHolderListDocumentsResponse listDocuments(String accountHolderToken, RequestOptions requestOptions)
-
retrieveDocument
Document retrieveDocument(String documentToken, AccountHolderRetrieveDocumentParams params)
Check the status of an account holder document upload, or retrieve the upload URLs to process your image uploads.
Note that this is not equivalent to checking the status of the KYC evaluation overall (a document may be successfully uploaded but not be sufficient for KYC to pass).
In the event your upload URLs have expired, calling this endpoint will refresh them. Similarly, in the event a document upload has failed, you can use this endpoint to get a new upload URL for the failed image upload.
When a new account holder document upload is generated for a failed attempt, the response will show an additional entry in the
required_document_uploadsarray in aPENDINGstate for the correspondingimage_type.
-
retrieveDocument
Document retrieveDocument(String documentToken, AccountHolderRetrieveDocumentParams params, RequestOptions requestOptions)
-
retrieveDocument
Document retrieveDocument(AccountHolderRetrieveDocumentParams params)
-
retrieveDocument
abstract Document retrieveDocument(AccountHolderRetrieveDocumentParams params, RequestOptions requestOptions)
-
simulateEnrollmentDocumentReview
Document simulateEnrollmentDocumentReview(AccountHolderSimulateEnrollmentDocumentReviewParams params)
Simulates a review for an account holder document upload.
-
simulateEnrollmentDocumentReview
abstract Document simulateEnrollmentDocumentReview(AccountHolderSimulateEnrollmentDocumentReviewParams params, RequestOptions requestOptions)
-
simulateEnrollmentReview
AccountHolderSimulateEnrollmentReviewResponse simulateEnrollmentReview()
Simulates an enrollment review for an account holder. This endpoint is only applicable for workflows that may required intervention such as
KYB_BASIC.
-
simulateEnrollmentReview
abstract AccountHolderSimulateEnrollmentReviewResponse simulateEnrollmentReview(AccountHolderSimulateEnrollmentReviewParams params, RequestOptions requestOptions)
-
simulateEnrollmentReview
AccountHolderSimulateEnrollmentReviewResponse simulateEnrollmentReview(AccountHolderSimulateEnrollmentReviewParams params)
-
simulateEnrollmentReview
AccountHolderSimulateEnrollmentReviewResponse simulateEnrollmentReview(RequestOptions requestOptions)
-
uploadDocument
Document uploadDocument(String accountHolderToken, AccountHolderUploadDocumentParams params)
Use this endpoint to identify which type of supported government-issued documentation you will upload for further verification. It will return two URLs to upload your document images to - one for the front image and one for the back image.
This endpoint is only valid for evaluations in a
PENDING_DOCUMENTstate.Supported file types include
jpg,png, andpdf. Each file must be less than 15 MiB. Once both required uploads have been successfully completed, your document will be run through KYC verification.If you have registered a webhook, you will receive evaluation updates for any document submission evaluations, as well as for any failed document uploads.
Two document submission attempts are permitted via this endpoint before a
REJECTEDstatus is returned and the account creation process is ended. Currently only one type of account holder document is supported per KYC verification.
-
uploadDocument
Document uploadDocument(String accountHolderToken, AccountHolderUploadDocumentParams params, RequestOptions requestOptions)
-
uploadDocument
Document uploadDocument(AccountHolderUploadDocumentParams params)
-
uploadDocument
abstract Document uploadDocument(AccountHolderUploadDocumentParams params, RequestOptions requestOptions)
-
-
-
-