Package com.lithic.api.services.blocking
Interface AccountService
-
- All Implemented Interfaces:
public interface AccountService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAccountService.WithRawResponseA view of AccountService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AccountService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. Accountretrieve(AccountRetrieveParams params)Get account configuration such as spend limits. abstract Accountretrieve(AccountRetrieveParams params, RequestOptions requestOptions)Accountupdate(AccountUpdateParams params)Update account configuration such as state or spend limits. abstract Accountupdate(AccountUpdateParams params, RequestOptions requestOptions)AccountListPagelist()List account configurations. abstract AccountListPagelist(AccountListParams params, RequestOptions requestOptions)AccountListPagelist(AccountListParams params)AccountListPagelist(RequestOptions requestOptions)AccountSpendLimitsretrieveSpendLimits(AccountRetrieveSpendLimitsParams params)Get an Account's available spend limits, which is based on the spend limit configured on the Account and the amount already spent over the spend limit's duration. abstract AccountSpendLimitsretrieveSpendLimits(AccountRetrieveSpendLimitsParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract AccountService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
Account retrieve(AccountRetrieveParams params)
Get account configuration such as spend limits.
-
retrieve
abstract Account retrieve(AccountRetrieveParams params, RequestOptions requestOptions)
-
update
Account update(AccountUpdateParams params)
Update account configuration such as state or spend limits. Can only be run on accounts that are part of the program managed by this API key. Accounts that are in the
PAUSEDstate will not be able to transact or create new cards.
-
update
abstract Account update(AccountUpdateParams params, RequestOptions requestOptions)
-
list
AccountListPage list()
List account configurations.
-
list
abstract AccountListPage list(AccountListParams params, RequestOptions requestOptions)
-
list
AccountListPage list(AccountListParams params)
-
list
AccountListPage list(RequestOptions requestOptions)
-
retrieveSpendLimits
AccountSpendLimits retrieveSpendLimits(AccountRetrieveSpendLimitsParams params)
Get an Account's available spend limits, which is based on the spend limit configured on the Account and the amount already spent over the spend limit's duration. For example, if the Account has a daily spend limit of
$1000 configured, and has spent $
600 in the last 24 hours, the available spend limit returned would be $400.
-
retrieveSpendLimits
abstract AccountSpendLimits retrieveSpendLimits(AccountRetrieveSpendLimitsParams params, RequestOptions requestOptions)
-
-
-
-