Package com.lithic.api.services.blocking
Class AccountServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.AccountService.WithRawResponse
public final class AccountServiceImpl.WithRawResponseImpl implements AccountService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description AccountService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<Account>retrieve(AccountRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<Account>update(AccountUpdateParams params, RequestOptions requestOptions)HttpResponseFor<AccountListPage>list(AccountListParams params, RequestOptions requestOptions)HttpResponseFor<AccountSpendLimits>retrieveSpendLimits(AccountRetrieveSpendLimitsParams params, RequestOptions requestOptions)-
Methods inherited from class com.lithic.api.services.blocking.AccountService.WithRawResponse
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, retrieveSpendLimits, retrieveSpendLimits, retrieveSpendLimits, retrieveSpendLimits, retrieveSpendLimits, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
AccountService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
HttpResponseFor<Account> retrieve(AccountRetrieveParams params, RequestOptions requestOptions)
-
update
HttpResponseFor<Account> update(AccountUpdateParams params, RequestOptions requestOptions)
-
list
HttpResponseFor<AccountListPage> list(AccountListParams params, RequestOptions requestOptions)
-
retrieveSpendLimits
HttpResponseFor<AccountSpendLimits> retrieveSpendLimits(AccountRetrieveSpendLimitsParams params, RequestOptions requestOptions)
-
-
-
-