Package com.lithic.api.services.blocking
Class AggregateBalanceServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.AggregateBalanceService
public final class AggregateBalanceServiceImpl implements AggregateBalanceService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAggregateBalanceServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AggregateBalanceService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AggregateBalanceListPagelist(AggregateBalanceListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
AggregateBalanceService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
list
AggregateBalanceListPage list(AggregateBalanceListParams params, RequestOptions requestOptions)
-
-
-
-