Package com.lithic.api.services.blocking
Class BalanceServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.BalanceService
public final class BalanceServiceImpl implements BalanceService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBalanceServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description BalanceService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. BalanceServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. BalanceListPagelist(BalanceListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
BalanceService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
BalanceService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
BalanceListPage list(BalanceListParams params, RequestOptions requestOptions)
-
-
-
-