Package com.lithic.api.services.blocking
Interface CardProgramService
-
- All Implemented Interfaces:
public interface CardProgramService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardProgramService.WithRawResponseA view of CardProgramService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardProgramService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardProgramretrieve(String cardProgramToken)Get card program. CardProgramretrieve(String cardProgramToken, CardProgramRetrieveParams params, RequestOptions requestOptions)CardProgramretrieve(String cardProgramToken, CardProgramRetrieveParams params)abstract CardProgramretrieve(CardProgramRetrieveParams params, RequestOptions requestOptions)CardProgramretrieve(CardProgramRetrieveParams params)CardProgramretrieve(String cardProgramToken, RequestOptions requestOptions)CardProgramListPagelist()List card programs. abstract CardProgramListPagelist(CardProgramListParams params, RequestOptions requestOptions)CardProgramListPagelist(CardProgramListParams params)CardProgramListPagelist(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CardProgramService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CardProgram retrieve(String cardProgramToken)
Get card program.
-
retrieve
CardProgram retrieve(String cardProgramToken, CardProgramRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CardProgram retrieve(String cardProgramToken, CardProgramRetrieveParams params)
-
retrieve
abstract CardProgram retrieve(CardProgramRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CardProgram retrieve(CardProgramRetrieveParams params)
-
retrieve
CardProgram retrieve(String cardProgramToken, RequestOptions requestOptions)
-
list
CardProgramListPage list()
List card programs.
-
list
abstract CardProgramListPage list(CardProgramListParams params, RequestOptions requestOptions)
-
list
CardProgramListPage list(CardProgramListParams params)
-
list
CardProgramListPage list(RequestOptions requestOptions)
-
-
-
-