Package com.lithic.api.services.blocking
Class CardServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.CardService
public final class CardServiceImpl implements CardService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardServiceImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class com.lithic.api.services.blocking.CardService
convertPhysical, create, embed, list, list, list, provision, reissue, renew, retrieve, retrieveSpendLimits, searchByPan, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
CardService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
aggregateBalances
AggregateBalanceService aggregateBalances()
-
balances
BalanceService balances()
-
financialTransactions
FinancialTransactionService financialTransactions()
-
create
Card create(CardCreateParams params, RequestOptions requestOptions)
-
retrieve
Card retrieve(CardRetrieveParams params, RequestOptions requestOptions)
-
update
Card update(CardUpdateParams params, RequestOptions requestOptions)
-
list
CardListPage list(CardListParams params, RequestOptions requestOptions)
-
convertPhysical
Card convertPhysical(CardConvertPhysicalParams params, RequestOptions requestOptions)
-
embed
String embed(CardEmbedParams params, RequestOptions requestOptions)
-
provision
CardProvisionResponse provision(CardProvisionParams params, RequestOptions requestOptions)
-
reissue
Card reissue(CardReissueParams params, RequestOptions requestOptions)
-
renew
Card renew(CardRenewParams params, RequestOptions requestOptions)
-
retrieveSpendLimits
CardSpendLimits retrieveSpendLimits(CardRetrieveSpendLimitsParams params, RequestOptions requestOptions)
-
searchByPan
Card searchByPan(CardSearchByPanParams params, RequestOptions requestOptions)
-
getEmbedHtml
String getEmbedHtml(CardGetEmbedHtmlParams params, RequestOptions requestOptions)
-
getEmbedUrl
String getEmbedUrl(CardGetEmbedUrlParams params, RequestOptions requestOptions)
-
-
-
-