Package com.lithic.api.services.blocking
Interface EventService
-
- All Implemented Interfaces:
public interface EventService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceEventService.WithRawResponseA view of EventService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract EventService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract SubscriptionServicesubscriptions()abstract EventSubscriptionServiceeventSubscriptions()Eventretrieve(EventRetrieveParams params)Get an event. abstract Eventretrieve(EventRetrieveParams params, RequestOptions requestOptions)EventListPagelist()List all events. abstract EventListPagelist(EventListParams params, RequestOptions requestOptions)EventListPagelist(EventListParams params)EventListPagelist(RequestOptions requestOptions)EventListAttemptsPagelistAttempts(EventListAttemptsParams params)List all the message attempts for a given event. abstract EventListAttemptsPagelistAttempts(EventListAttemptsParams params, RequestOptions requestOptions)abstract Unitresend(String eventToken, String eventSubscriptionToken, JsonValue body)-
-
Method Detail
-
withRawResponse
abstract EventService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
subscriptions
abstract SubscriptionService subscriptions()
-
eventSubscriptions
abstract EventSubscriptionService eventSubscriptions()
-
retrieve
Event retrieve(EventRetrieveParams params)
Get an event.
-
retrieve
abstract Event retrieve(EventRetrieveParams params, RequestOptions requestOptions)
-
list
EventListPage list()
List all events.
-
list
abstract EventListPage list(EventListParams params, RequestOptions requestOptions)
-
list
EventListPage list(EventListParams params)
-
list
EventListPage list(RequestOptions requestOptions)
-
listAttempts
EventListAttemptsPage listAttempts(EventListAttemptsParams params)
List all the message attempts for a given event.
-
listAttempts
abstract EventListAttemptsPage listAttempts(EventListAttemptsParams params, RequestOptions requestOptions)
-
-
-
-