Package com.lithic.api.services.blocking
Class ExternalBankAccountServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.ExternalBankAccountService
public final class ExternalBankAccountServiceImpl implements ExternalBankAccountService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalBankAccountServiceImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class com.lithic.api.services.blocking.ExternalBankAccountService
create, create, create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, retryMicroDeposits, retryMicroDeposits, retryMicroDeposits, retryMicroDeposits, retryMicroDeposits, retryPrenote, retryPrenote, retryPrenote, retryPrenote, retryPrenote, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
ExternalBankAccountService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ExternalBankAccountService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
microDeposits
MicroDepositService microDeposits()
-
create
ExternalBankAccountCreateResponse create(ExternalBankAccountCreateParams params, RequestOptions requestOptions)
-
retrieve
ExternalBankAccountRetrieveResponse retrieve(ExternalBankAccountRetrieveParams params, RequestOptions requestOptions)
-
update
ExternalBankAccountUpdateResponse update(ExternalBankAccountUpdateParams params, RequestOptions requestOptions)
-
list
ExternalBankAccountListPage list(ExternalBankAccountListParams params, RequestOptions requestOptions)
-
retryMicroDeposits
ExternalBankAccountRetryMicroDepositsResponse retryMicroDeposits(ExternalBankAccountRetryMicroDepositsParams params, RequestOptions requestOptions)
-
retryPrenote
ExternalBankAccountRetryPrenoteResponse retryPrenote(ExternalBankAccountRetryPrenoteParams params, RequestOptions requestOptions)
-
-
-
-