Package com.lithic.api.services.blocking
Interface FinancialAccountService
-
- All Implemented Interfaces:
public interface FinancialAccountService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceFinancialAccountService.WithRawResponseA view of FinancialAccountService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract FinancialAccountService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
balances
abstract BalanceService balances()
-
financialTransactions
abstract FinancialTransactionService financialTransactions()
-
creditConfiguration
abstract CreditConfigurationService creditConfiguration()
-
statements
abstract StatementService statements()
-
loanTapes
abstract LoanTapeService loanTapes()
-
create
FinancialAccount create(FinancialAccountCreateParams params)
Create a new financial account
-
create
abstract FinancialAccount create(FinancialAccountCreateParams params, RequestOptions requestOptions)
-
retrieve
FinancialAccount retrieve(FinancialAccountRetrieveParams params)
Get a financial account
-
retrieve
abstract FinancialAccount retrieve(FinancialAccountRetrieveParams params, RequestOptions requestOptions)
-
update
FinancialAccount update(FinancialAccountUpdateParams params)
Update a financial account
-
update
abstract FinancialAccount update(FinancialAccountUpdateParams params, RequestOptions requestOptions)
-
list
FinancialAccountListPage list()
Retrieve information on your financial accounts including routing and account number.
-
list
abstract FinancialAccountListPage list(FinancialAccountListParams params, RequestOptions requestOptions)
-
list
FinancialAccountListPage list(FinancialAccountListParams params)
-
list
FinancialAccountListPage list(RequestOptions requestOptions)
-
updateStatus
FinancialAccount updateStatus(FinancialAccountUpdateStatusParams params)
Update financial account status
-
updateStatus
abstract FinancialAccount updateStatus(FinancialAccountUpdateStatusParams params, RequestOptions requestOptions)
-
-
-
-