Package com.lithic.api.services.blocking
Class FinancialAccountServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.FinancialAccountService
public final class FinancialAccountServiceImpl implements FinancialAccountService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinancialAccountServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description FinancialAccountService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. BalanceServicebalances()FinancialTransactionServicefinancialTransactions()CreditConfigurationServicecreditConfiguration()StatementServicestatements()LoanTapeServiceloanTapes()FinancialAccountcreate(FinancialAccountCreateParams params, RequestOptions requestOptions)FinancialAccountretrieve(FinancialAccountRetrieveParams params, RequestOptions requestOptions)FinancialAccountupdate(FinancialAccountUpdateParams params, RequestOptions requestOptions)FinancialAccountListPagelist(FinancialAccountListParams params, RequestOptions requestOptions)FinancialAccountupdateStatus(FinancialAccountUpdateStatusParams params, RequestOptions requestOptions)-
Methods inherited from class com.lithic.api.services.blocking.FinancialAccountService
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update, updateStatus, updateStatus, updateStatus -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
FinancialAccountService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
balances
BalanceService balances()
-
financialTransactions
FinancialTransactionService financialTransactions()
-
creditConfiguration
CreditConfigurationService creditConfiguration()
-
statements
StatementService statements()
-
loanTapes
LoanTapeService loanTapes()
-
create
FinancialAccount create(FinancialAccountCreateParams params, RequestOptions requestOptions)
-
retrieve
FinancialAccount retrieve(FinancialAccountRetrieveParams params, RequestOptions requestOptions)
-
update
FinancialAccount update(FinancialAccountUpdateParams params, RequestOptions requestOptions)
-
list
FinancialAccountListPage list(FinancialAccountListParams params, RequestOptions requestOptions)
-
updateStatus
FinancialAccount updateStatus(FinancialAccountUpdateStatusParams params, RequestOptions requestOptions)
-
-
-
-