Package com.lithic.api.services.blocking
Class InternalTransactionServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.InternalTransactionService
public final class InternalTransactionServiceImpl implements InternalTransactionService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInternalTransactionServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InternalTransactionService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InternalTransactionServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. -
-
Method Detail
-
withRawResponse
InternalTransactionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InternalTransactionService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-