Package com.lithic.api.services.blocking
Class InternalTransactionServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.InternalTransactionService.WithRawResponse
public final class InternalTransactionServiceImpl.WithRawResponseImpl implements InternalTransactionService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description InternalTransactionService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. -
-
Method Detail
-
withOptions
InternalTransactionService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-