Package com.lithic.api.services.blocking
Interface ManagementOperationService
-
- All Implemented Interfaces:
public interface ManagementOperationService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceManagementOperationService.WithRawResponseA view of ManagementOperationService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract ManagementOperationService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
ManagementOperationTransaction create(ManagementOperationCreateParams params)
Create management operation
-
create
abstract ManagementOperationTransaction create(ManagementOperationCreateParams params, RequestOptions requestOptions)
-
retrieve
ManagementOperationTransaction retrieve(ManagementOperationRetrieveParams params)
Get management operation
-
retrieve
abstract ManagementOperationTransaction retrieve(ManagementOperationRetrieveParams params, RequestOptions requestOptions)
-
list
ManagementOperationListPage list()
List management operations
-
list
abstract ManagementOperationListPage list(ManagementOperationListParams params, RequestOptions requestOptions)
-
list
ManagementOperationListPage list(ManagementOperationListParams params)
-
list
ManagementOperationListPage list(RequestOptions requestOptions)
-
reverse
ManagementOperationTransaction reverse(ManagementOperationReverseParams params)
Reverse a management operation
-
reverse
abstract ManagementOperationTransaction reverse(ManagementOperationReverseParams params, RequestOptions requestOptions)
-
-
-
-