Package com.lithic.api.services.blocking
Class ReportServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.ReportService
public final class ReportServiceImpl implements ReportService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classReportServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ReportService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SettlementServicesettlement()-
-
Method Detail
-
withRawResponse
ReportService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
settlement
SettlementService settlement()
-
-
-
-