Package com.lithic.api.services.blocking
Interface TransferService
-
- All Implemented Interfaces:
public interface TransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceTransferService.WithRawResponseA view of TransferService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract TransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. Transfercreate(TransferCreateParams params)Transfer funds between two financial accounts or between a financial account and card abstract Transfercreate(TransferCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract TransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
Transfer create(TransferCreateParams params)
Transfer funds between two financial accounts or between a financial account and card
-
create
abstract Transfer create(TransferCreateParams params, RequestOptions requestOptions)
-
-
-
-