Interface AggregateBalanceService
-
- All Implemented Interfaces:
public interface AggregateBalanceService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAggregateBalanceService.WithRawResponseA view of AggregateBalanceService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AggregateBalanceService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardAggregateBalanceListPagelist()Get the aggregated card balance across all end-user accounts. abstract CardAggregateBalanceListPagelist(CardAggregateBalanceListParams params, RequestOptions requestOptions)CardAggregateBalanceListPagelist(CardAggregateBalanceListParams params)CardAggregateBalanceListPagelist(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract AggregateBalanceService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
list
CardAggregateBalanceListPage list()
Get the aggregated card balance across all end-user accounts.
-
list
abstract CardAggregateBalanceListPage list(CardAggregateBalanceListParams params, RequestOptions requestOptions)
-
list
CardAggregateBalanceListPage list(RequestOptions requestOptions)
-
-
-
-