Interface FinancialTransactionService
-
- All Implemented Interfaces:
public interface FinancialTransactionService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceFinancialTransactionService.WithRawResponseA view of FinancialTransactionService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract FinancialTransactionService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. FinancialTransactionretrieve(CardFinancialTransactionRetrieveParams params)Get the card financial transaction for the provided token. abstract FinancialTransactionretrieve(CardFinancialTransactionRetrieveParams params, RequestOptions requestOptions)CardFinancialTransactionListPagelist(CardFinancialTransactionListParams params)List the financial transactions for a given card. abstract CardFinancialTransactionListPagelist(CardFinancialTransactionListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract FinancialTransactionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
FinancialTransaction retrieve(CardFinancialTransactionRetrieveParams params)
Get the card financial transaction for the provided token.
-
retrieve
abstract FinancialTransaction retrieve(CardFinancialTransactionRetrieveParams params, RequestOptions requestOptions)
-
list
CardFinancialTransactionListPage list(CardFinancialTransactionListParams params)
List the financial transactions for a given card.
-
list
abstract CardFinancialTransactionListPage list(CardFinancialTransactionListParams params, RequestOptions requestOptions)
-
-
-
-