Interface EventSubscriptionService
-
- All Implemented Interfaces:
public interface EventSubscriptionService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceEventSubscriptionService.WithRawResponseA view of EventSubscriptionService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract EventSubscriptionService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. Unitresend(String eventSubscriptionToken, EventEventSubscriptionResendParams params)Resend an event to an event subscription. Unitresend(String eventSubscriptionToken, EventEventSubscriptionResendParams params, RequestOptions requestOptions)Unitresend(EventEventSubscriptionResendParams params)abstract Unitresend(EventEventSubscriptionResendParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract EventSubscriptionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
resend
Unit resend(String eventSubscriptionToken, EventEventSubscriptionResendParams params)
Resend an event to an event subscription.
-
resend
Unit resend(String eventSubscriptionToken, EventEventSubscriptionResendParams params, RequestOptions requestOptions)
-
resend
Unit resend(EventEventSubscriptionResendParams params)
-
resend
abstract Unit resend(EventEventSubscriptionResendParams params, RequestOptions requestOptions)
-
-
-
-