Interface EventSubscriptionService.WithRawResponse
-
- All Implemented Interfaces:
public interface EventSubscriptionService.WithRawResponseA view of EventSubscriptionService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract EventSubscriptionService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseresend(String eventSubscriptionToken, EventEventSubscriptionResendParams params)Returns a raw HTTP response for post /v1/events/{event_token}/event_subscriptions/{event_subscription_token}/resend, but is otherwise the same as EventSubscriptionService.resend.HttpResponseresend(String eventSubscriptionToken, EventEventSubscriptionResendParams params, RequestOptions requestOptions)HttpResponseresend(EventEventSubscriptionResendParams params)abstract HttpResponseresend(EventEventSubscriptionResendParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract EventSubscriptionService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
resend
@MustBeClosed() HttpResponse resend(String eventSubscriptionToken, EventEventSubscriptionResendParams params)
Returns a raw HTTP response for
post /v1/events/{event_token}/event_subscriptions/{event_subscription_token}/resend, but is otherwise the same as EventSubscriptionService.resend.
-
resend
@MustBeClosed() HttpResponse resend(String eventSubscriptionToken, EventEventSubscriptionResendParams params, RequestOptions requestOptions)
-
resend
@MustBeClosed() HttpResponse resend(EventEventSubscriptionResendParams params)
-
resend
@MustBeClosed() abstract HttpResponse resend(EventEventSubscriptionResendParams params, RequestOptions requestOptions)
-
-
-
-