Class EventSubscriptionServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.events.EventSubscriptionService
public final class EventSubscriptionServiceImpl implements EventSubscriptionService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventSubscriptionServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description EventSubscriptionService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. EventSubscriptionServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Unitresend(EventEventSubscriptionResendParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
EventSubscriptionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
EventSubscriptionService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
resend
Unit resend(EventEventSubscriptionResendParams params, RequestOptions requestOptions)
-
-
-
-