Class EventSubscriptionServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.events.EventSubscriptionService.WithRawResponse
public final class EventSubscriptionServiceImpl.WithRawResponseImpl implements EventSubscriptionService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description EventSubscriptionService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseresend(EventEventSubscriptionResendParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
EventSubscriptionService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
resend
HttpResponse resend(EventEventSubscriptionResendParams params, RequestOptions requestOptions)
-
-
-
-