Interface SubscriptionService
-
- All Implemented Interfaces:
public interface SubscriptionService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSubscriptionService.WithRawResponseA view of SubscriptionService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract SubscriptionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract SubscriptionService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
EventSubscription create(EventSubscriptionCreateParams params)
Create a new event subscription.
-
create
abstract EventSubscription create(EventSubscriptionCreateParams params, RequestOptions requestOptions)
-
retrieve
EventSubscription retrieve(String eventSubscriptionToken)
Get an event subscription.
-
retrieve
EventSubscription retrieve(String eventSubscriptionToken, EventSubscriptionRetrieveParams params, RequestOptions requestOptions)
-
retrieve
EventSubscription retrieve(String eventSubscriptionToken, EventSubscriptionRetrieveParams params)
-
retrieve
abstract EventSubscription retrieve(EventSubscriptionRetrieveParams params, RequestOptions requestOptions)
-
retrieve
EventSubscription retrieve(EventSubscriptionRetrieveParams params)
-
retrieve
EventSubscription retrieve(String eventSubscriptionToken, RequestOptions requestOptions)
-
update
EventSubscription update(String eventSubscriptionToken, EventSubscriptionUpdateParams params)
Update an event subscription.
-
update
EventSubscription update(String eventSubscriptionToken, EventSubscriptionUpdateParams params, RequestOptions requestOptions)
-
update
EventSubscription update(EventSubscriptionUpdateParams params)
-
update
abstract EventSubscription update(EventSubscriptionUpdateParams params, RequestOptions requestOptions)
-
list
EventSubscriptionListPage list()
List all the event subscriptions.
-
list
abstract EventSubscriptionListPage list(EventSubscriptionListParams params, RequestOptions requestOptions)
-
list
EventSubscriptionListPage list(EventSubscriptionListParams params)
-
list
EventSubscriptionListPage list(RequestOptions requestOptions)
-
delete
Unit delete(String eventSubscriptionToken, EventSubscriptionDeleteParams params, RequestOptions requestOptions)
-
delete
Unit delete(String eventSubscriptionToken, EventSubscriptionDeleteParams params)
-
delete
abstract Unit delete(EventSubscriptionDeleteParams params, RequestOptions requestOptions)
-
delete
Unit delete(EventSubscriptionDeleteParams params)
-
delete
Unit delete(String eventSubscriptionToken, RequestOptions requestOptions)
-
listAttempts
EventSubscriptionListAttemptsPage listAttempts(String eventSubscriptionToken)
List all the message attempts for a given event subscription.
-
listAttempts
EventSubscriptionListAttemptsPage listAttempts(String eventSubscriptionToken, EventSubscriptionListAttemptsParams params, RequestOptions requestOptions)
-
listAttempts
EventSubscriptionListAttemptsPage listAttempts(String eventSubscriptionToken, EventSubscriptionListAttemptsParams params)
-
listAttempts
abstract EventSubscriptionListAttemptsPage listAttempts(EventSubscriptionListAttemptsParams params, RequestOptions requestOptions)
-
listAttempts
EventSubscriptionListAttemptsPage listAttempts(EventSubscriptionListAttemptsParams params)
-
listAttempts
EventSubscriptionListAttemptsPage listAttempts(String eventSubscriptionToken, RequestOptions requestOptions)
-
recover
Unit recover(String eventSubscriptionToken, EventSubscriptionRecoverParams params, RequestOptions requestOptions)
-
recover
Unit recover(String eventSubscriptionToken, EventSubscriptionRecoverParams params)
-
recover
abstract Unit recover(EventSubscriptionRecoverParams params, RequestOptions requestOptions)
-
recover
Unit recover(EventSubscriptionRecoverParams params)
-
recover
Unit recover(String eventSubscriptionToken, RequestOptions requestOptions)
-
replayMissing
Unit replayMissing(String eventSubscriptionToken)
Replays messages to the endpoint. Only messages that were created after
beginwill be sent. Messages that were previously sent to the endpoint are not resent. Message will be retried if endpoint responds with a non-2xx status code. See Retry Schedule for details.
-
replayMissing
Unit replayMissing(String eventSubscriptionToken, EventSubscriptionReplayMissingParams params, RequestOptions requestOptions)
-
replayMissing
Unit replayMissing(String eventSubscriptionToken, EventSubscriptionReplayMissingParams params)
-
replayMissing
abstract Unit replayMissing(EventSubscriptionReplayMissingParams params, RequestOptions requestOptions)
-
replayMissing
Unit replayMissing(EventSubscriptionReplayMissingParams params)
-
replayMissing
Unit replayMissing(String eventSubscriptionToken, RequestOptions requestOptions)
-
retrieveSecret
SubscriptionRetrieveSecretResponse retrieveSecret(String eventSubscriptionToken)
Get the secret for an event subscription.
-
retrieveSecret
SubscriptionRetrieveSecretResponse retrieveSecret(String eventSubscriptionToken, EventSubscriptionRetrieveSecretParams params, RequestOptions requestOptions)
-
retrieveSecret
SubscriptionRetrieveSecretResponse retrieveSecret(String eventSubscriptionToken, EventSubscriptionRetrieveSecretParams params)
-
retrieveSecret
abstract SubscriptionRetrieveSecretResponse retrieveSecret(EventSubscriptionRetrieveSecretParams params, RequestOptions requestOptions)
-
retrieveSecret
SubscriptionRetrieveSecretResponse retrieveSecret(EventSubscriptionRetrieveSecretParams params)
-
retrieveSecret
SubscriptionRetrieveSecretResponse retrieveSecret(String eventSubscriptionToken, RequestOptions requestOptions)
-
rotateSecret
Unit rotateSecret(String eventSubscriptionToken)
Rotate the secret for an event subscription. The previous secret will be valid for the next 24 hours.
-
rotateSecret
Unit rotateSecret(String eventSubscriptionToken, EventSubscriptionRotateSecretParams params, RequestOptions requestOptions)
-
rotateSecret
Unit rotateSecret(String eventSubscriptionToken, EventSubscriptionRotateSecretParams params)
-
rotateSecret
abstract Unit rotateSecret(EventSubscriptionRotateSecretParams params, RequestOptions requestOptions)
-
rotateSecret
Unit rotateSecret(EventSubscriptionRotateSecretParams params)
-
rotateSecret
Unit rotateSecret(String eventSubscriptionToken, RequestOptions requestOptions)
-
sendSimulatedExample
Unit sendSimulatedExample(String eventSubscriptionToken)
Send an example message for event.
-
sendSimulatedExample
Unit sendSimulatedExample(String eventSubscriptionToken, EventSubscriptionSendSimulatedExampleParams params, RequestOptions requestOptions)
-
sendSimulatedExample
Unit sendSimulatedExample(String eventSubscriptionToken, EventSubscriptionSendSimulatedExampleParams params)
-
sendSimulatedExample
abstract Unit sendSimulatedExample(EventSubscriptionSendSimulatedExampleParams params, RequestOptions requestOptions)
-
sendSimulatedExample
Unit sendSimulatedExample(EventSubscriptionSendSimulatedExampleParams params)
-
sendSimulatedExample
Unit sendSimulatedExample(String eventSubscriptionToken, RequestOptions requestOptions)
-
-
-
-