Class SubscriptionServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.events.SubscriptionService
public final class SubscriptionServiceImpl implements SubscriptionService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSubscriptionServiceImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class com.lithic.api.services.blocking.events.SubscriptionService
create, delete, delete, delete, delete, delete, list, list, list, listAttempts, listAttempts, listAttempts, listAttempts, listAttempts, recover, recover, recover, recover, recover, replayMissing, replayMissing, replayMissing, replayMissing, replayMissing, retrieve, retrieve, retrieve, retrieve, retrieve, retrieveSecret, retrieveSecret, retrieveSecret, retrieveSecret, retrieveSecret, rotateSecret, rotateSecret, rotateSecret, rotateSecret, rotateSecret, sendSimulatedExample, sendSimulatedExample, sendSimulatedExample, sendSimulatedExample, sendSimulatedExample, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
SubscriptionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SubscriptionService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
EventSubscription create(EventSubscriptionCreateParams params, RequestOptions requestOptions)
-
retrieve
EventSubscription retrieve(EventSubscriptionRetrieveParams params, RequestOptions requestOptions)
-
update
EventSubscription update(EventSubscriptionUpdateParams params, RequestOptions requestOptions)
-
list
EventSubscriptionListPage list(EventSubscriptionListParams params, RequestOptions requestOptions)
-
delete
Unit delete(EventSubscriptionDeleteParams params, RequestOptions requestOptions)
-
listAttempts
EventSubscriptionListAttemptsPage listAttempts(EventSubscriptionListAttemptsParams params, RequestOptions requestOptions)
-
recover
Unit recover(EventSubscriptionRecoverParams params, RequestOptions requestOptions)
-
replayMissing
Unit replayMissing(EventSubscriptionReplayMissingParams params, RequestOptions requestOptions)
-
retrieveSecret
SubscriptionRetrieveSecretResponse retrieveSecret(EventSubscriptionRetrieveSecretParams params, RequestOptions requestOptions)
-
rotateSecret
Unit rotateSecret(EventSubscriptionRotateSecretParams params, RequestOptions requestOptions)
-
sendSimulatedExample
Unit sendSimulatedExample(EventSubscriptionSendSimulatedExampleParams params, RequestOptions requestOptions)
-
-
-
-