Class SubscriptionServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.events.SubscriptionService.WithRawResponse
public final class SubscriptionServiceImpl.WithRawResponseImpl implements SubscriptionService.WithRawResponse
-
-
Method Summary
-
Methods inherited from class com.lithic.api.services.blocking.events.SubscriptionService.WithRawResponse
create, delete, delete, delete, delete, delete, list, list, list, listAttempts, listAttempts, listAttempts, listAttempts, listAttempts, recover, recover, recover, recover, recover, replayMissing, replayMissing, replayMissing, replayMissing, replayMissing, retrieve, retrieve, retrieve, retrieve, retrieve, retrieveSecret, retrieveSecret, retrieveSecret, retrieveSecret, retrieveSecret, rotateSecret, rotateSecret, rotateSecret, rotateSecret, rotateSecret, sendSimulatedExample, sendSimulatedExample, sendSimulatedExample, sendSimulatedExample, sendSimulatedExample, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
SubscriptionService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponseFor<EventSubscription> create(EventSubscriptionCreateParams params, RequestOptions requestOptions)
-
retrieve
HttpResponseFor<EventSubscription> retrieve(EventSubscriptionRetrieveParams params, RequestOptions requestOptions)
-
update
HttpResponseFor<EventSubscription> update(EventSubscriptionUpdateParams params, RequestOptions requestOptions)
-
list
HttpResponseFor<EventSubscriptionListPage> list(EventSubscriptionListParams params, RequestOptions requestOptions)
-
delete
HttpResponse delete(EventSubscriptionDeleteParams params, RequestOptions requestOptions)
-
listAttempts
HttpResponseFor<EventSubscriptionListAttemptsPage> listAttempts(EventSubscriptionListAttemptsParams params, RequestOptions requestOptions)
-
recover
HttpResponse recover(EventSubscriptionRecoverParams params, RequestOptions requestOptions)
-
replayMissing
HttpResponse replayMissing(EventSubscriptionReplayMissingParams params, RequestOptions requestOptions)
-
retrieveSecret
HttpResponseFor<SubscriptionRetrieveSecretResponse> retrieveSecret(EventSubscriptionRetrieveSecretParams params, RequestOptions requestOptions)
-
rotateSecret
HttpResponse rotateSecret(EventSubscriptionRotateSecretParams params, RequestOptions requestOptions)
-
sendSimulatedExample
HttpResponse sendSimulatedExample(EventSubscriptionSendSimulatedExampleParams params, RequestOptions requestOptions)
-
-
-
-