Interface MicroDepositService
-
- All Implemented Interfaces:
public interface MicroDepositService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceMicroDepositService.WithRawResponseA view of MicroDepositService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract MicroDepositService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract MicroDepositServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. MicroDepositCreateResponsecreate(String externalBankAccountToken, ExternalBankAccountMicroDepositCreateParams params)Verify the external bank account by providing the micro deposit amounts. MicroDepositCreateResponsecreate(String externalBankAccountToken, ExternalBankAccountMicroDepositCreateParams params, RequestOptions requestOptions)MicroDepositCreateResponsecreate(ExternalBankAccountMicroDepositCreateParams params)abstract MicroDepositCreateResponsecreate(ExternalBankAccountMicroDepositCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract MicroDepositService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract MicroDepositService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
MicroDepositCreateResponse create(String externalBankAccountToken, ExternalBankAccountMicroDepositCreateParams params)
Verify the external bank account by providing the micro deposit amounts.
-
create
MicroDepositCreateResponse create(String externalBankAccountToken, ExternalBankAccountMicroDepositCreateParams params, RequestOptions requestOptions)
-
create
abstract MicroDepositCreateResponse create(ExternalBankAccountMicroDepositCreateParams params, RequestOptions requestOptions)
-
-
-
-