Class MicroDepositServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.externalBankAccounts.MicroDepositService
public final class MicroDepositServiceImpl implements MicroDepositService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMicroDepositServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description MicroDepositService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. MicroDepositServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. MicroDepositCreateResponsecreate(ExternalBankAccountMicroDepositCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
MicroDepositService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
MicroDepositService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
MicroDepositCreateResponse create(ExternalBankAccountMicroDepositCreateParams params, RequestOptions requestOptions)
-
-
-
-