Class CreditConfigurationServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.financialAccounts.CreditConfigurationService
public final class CreditConfigurationServiceImpl implements CreditConfigurationService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCreditConfigurationServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CreditConfigurationService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CreditConfigurationServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. FinancialAccountCreditConfigretrieve(FinancialAccountCreditConfigurationRetrieveParams params, RequestOptions requestOptions)FinancialAccountCreditConfigupdate(FinancialAccountCreditConfigurationUpdateParams params, RequestOptions requestOptions)-
Methods inherited from class com.lithic.api.services.blocking.financialAccounts.CreditConfigurationService
retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
CreditConfigurationService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CreditConfigurationService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
FinancialAccountCreditConfig retrieve(FinancialAccountCreditConfigurationRetrieveParams params, RequestOptions requestOptions)
-
update
FinancialAccountCreditConfig update(FinancialAccountCreditConfigurationUpdateParams params, RequestOptions requestOptions)
-
-
-
-