Class StatementServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.financialAccounts.StatementService
public final class StatementServiceImpl implements StatementService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStatementServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description StatementService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. StatementServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. LineItemServicelineItems()Statementretrieve(FinancialAccountStatementRetrieveParams params, RequestOptions requestOptions)FinancialAccountStatementListPagelist(FinancialAccountStatementListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
StatementService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
StatementService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
lineItems
LineItemService lineItems()
-
retrieve
Statement retrieve(FinancialAccountStatementRetrieveParams params, RequestOptions requestOptions)
-
list
FinancialAccountStatementListPage list(FinancialAccountStatementListParams params, RequestOptions requestOptions)
-
-
-
-