Class AuthenticationServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.threeDS.AuthenticationService
public final class AuthenticationServiceImpl implements AuthenticationService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAuthenticationServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AuthenticationService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AuthenticationRetrieveResponseretrieve(ThreeDSAuthenticationRetrieveParams params, RequestOptions requestOptions)AuthenticationSimulateResponsesimulate(ThreeDSAuthenticationSimulateParams params, RequestOptions requestOptions)UnitsimulateOtpEntry(ThreeDSAuthenticationSimulateOtpEntryParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
AuthenticationService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
AuthenticationRetrieveResponse retrieve(ThreeDSAuthenticationRetrieveParams params, RequestOptions requestOptions)
-
simulate
AuthenticationSimulateResponse simulate(ThreeDSAuthenticationSimulateParams params, RequestOptions requestOptions)
-
simulateOtpEntry
Unit simulateOtpEntry(ThreeDSAuthenticationSimulateOtpEntryParams params, RequestOptions requestOptions)
-
-
-
-