Interface DecisioningService
-
- All Implemented Interfaces:
public interface DecisioningService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceDecisioningService.WithRawResponseA view of DecisioningService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract DecisioningService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract DecisioningService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
challengeResponse
Unit challengeResponse(ThreeDSDecisioningChallengeResponseParams params)
Card program's response to a 3DS Challenge Request. Challenge Request is emitted as a webhook three_ds_authentication.challenge and your Card Program needs to be configured with Out of Band (OOB) Challenges in order to receive it (see https://docs.lithic.com/docs/3ds-challenge-flow for more information).
-
challengeResponse
abstract Unit challengeResponse(ThreeDSDecisioningChallengeResponseParams params, RequestOptions requestOptions)
-
challengeResponse
Unit challengeResponse(ChallengeResponse challengeResponse, RequestOptions requestOptions)
-
challengeResponse
Unit challengeResponse(ChallengeResponse challengeResponse)
-
retrieveSecret
DecisioningRetrieveSecretResponse retrieveSecret()
Retrieve the 3DS Decisioning HMAC secret key. If one does not exist for your program yet, calling this endpoint will create one for you. The headers (which you can use to verify 3DS Decisioning requests) will begin appearing shortly after calling this endpoint for the first time. See this page for more detail about verifying 3DS Decisioning requests.
-
retrieveSecret
abstract DecisioningRetrieveSecretResponse retrieveSecret(ThreeDSDecisioningRetrieveSecretParams params, RequestOptions requestOptions)
-
retrieveSecret
DecisioningRetrieveSecretResponse retrieveSecret(ThreeDSDecisioningRetrieveSecretParams params)
-
retrieveSecret
DecisioningRetrieveSecretResponse retrieveSecret(RequestOptions requestOptions)
-
rotateSecret
Unit rotateSecret()
Generate a new 3DS Decisioning HMAC secret key. The old secret key will be deactivated 24 hours after a successful request to this endpoint. Make a
GET /three_ds_decisioning/secretrequest to retrieve the new secret key.
-
rotateSecret
abstract Unit rotateSecret(ThreeDSDecisioningRotateSecretParams params, RequestOptions requestOptions)
-
rotateSecret
Unit rotateSecret(ThreeDSDecisioningRotateSecretParams params)
-
rotateSecret
Unit rotateSecret(RequestOptions requestOptions)
-
-
-
-