Class DecisioningServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.threeDS.DecisioningService
public final class DecisioningServiceImpl implements DecisioningService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDecisioningServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description DecisioningService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. DecisioningServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. UnitchallengeResponse(ThreeDSDecisioningChallengeResponseParams params, RequestOptions requestOptions)DecisioningRetrieveSecretResponseretrieveSecret(ThreeDSDecisioningRetrieveSecretParams params, RequestOptions requestOptions)UnitrotateSecret(ThreeDSDecisioningRotateSecretParams params, RequestOptions requestOptions)-
Methods inherited from class com.lithic.api.services.blocking.threeDS.DecisioningService
challengeResponse, retrieveSecret, retrieveSecret, retrieveSecret, rotateSecret, rotateSecret, rotateSecret -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
DecisioningService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
DecisioningService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
challengeResponse
Unit challengeResponse(ThreeDSDecisioningChallengeResponseParams params, RequestOptions requestOptions)
-
retrieveSecret
DecisioningRetrieveSecretResponse retrieveSecret(ThreeDSDecisioningRetrieveSecretParams params, RequestOptions requestOptions)
-
rotateSecret
Unit rotateSecret(ThreeDSDecisioningRotateSecretParams params, RequestOptions requestOptions)
-
-
-
-