Interface EventService
-
- All Implemented Interfaces:
public interface EventService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceEventService.WithRawResponseA view of EventService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract EventService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract EnhancedCommercialDataServiceenhancedCommercialData()-
-
Method Detail
-
withRawResponse
abstract EventService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
enhancedCommercialData
abstract EnhancedCommercialDataService enhancedCommercialData()
-
-
-
-