Class EventServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.transactions.EventService
public final class EventServiceImpl implements EventService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description EventService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. EnhancedCommercialDataServiceenhancedCommercialData()-
-
Method Detail
-
withRawResponse
EventService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
enhancedCommercialData
EnhancedCommercialDataService enhancedCommercialData()
-
-
-
-