Class Account
-
- All Implemented Interfaces:
public final class Account
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccount.BuilderA builder for Account.
public final classAccount.SpendLimitSpend limit information for the user containing the daily, monthly, and lifetime spend limit of the account. Any charges to a card owned by this account will be declined once their transaction volume has surpassed the value in the applicable time limit (rolling). A lifetime limit of 0 indicates that the lifetime limit feature is disabled.
public final classAccount.StateAccount state:
ACTIVE- Account is able to transact and create new cards.PAUSED- Account will not be able to transact or create new cards. It can be set back toACTIVE.CLOSED- Account will not be able to transact or create new cards.CLOSEDaccounts are also unable to be transitioned toACTIVEorPAUSEDstates.CLOSEDaccounts result from failing to pass KYB/KYC or Lithic closing for risk/compliance reasons. Please contact [email protected] if you believe this was in error.
public final classAccount.AccountHolderpublic final classAccount.VerificationAddress
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier for the account. final Optional<OffsetDateTime>created()Timestamp of when the account was created. final Account.SpendLimitspendLimit()Spend limit information for the user containing the daily, monthly, and lifetime spend limit of the account. final Account.Statestate()Account state: ACTIVE- Account is able to transact and create new cards.PAUSED- Account will not be able to transact or create new cards. It can be set back toACTIVE.CLOSED- Account will not be able to transact or create new cards.CLOSEDaccounts are also unable to be transitioned toACTIVEorPAUSEDstates.CLOSEDaccounts result from failing to pass KYB/KYC or Lithic closing for risk/compliance reasons. Please contact [email protected] if you believe this was in error.
final Optional<Account.AccountHolder>accountHolder()final Optional<List<String>>authRuleTokens()List of identifiers for the Auth Rule(s) that are applied on the account. final Optional<String>cardholderCurrency()3-character alphabetic ISO 4217 code for the currency of the cardholder. final Optional<Account.VerificationAddress>verificationAddress()final JsonField<String>_token()Globally unique identifier for the account. final JsonField<OffsetDateTime>_created()Timestamp of when the account was created. final JsonField<Account.SpendLimit>_spendLimit()Spend limit information for the user containing the daily, monthly, and lifetime spend limit of the account. final JsonField<Account.State>_state()Account state: ACTIVE- Account is able to transact and create new cards.PAUSED- Account will not be able to transact or create new cards. It can be set back toACTIVE.CLOSED- Account will not be able to transact or create new cards.CLOSEDaccounts are also unable to be transitioned toACTIVEorPAUSEDstates.CLOSEDaccounts result from failing to pass KYB/KYC or Lithic closing for risk/compliance reasons. Please contact [email protected] if you believe this was in error.
final JsonField<Account.AccountHolder>_accountHolder()final JsonField<List<String>>_authRuleTokens()List of identifiers for the Auth Rule(s) that are applied on the account. final JsonField<String>_cardholderCurrency()3-character alphabetic ISO 4217 code for the currency of the cardholder. final JsonField<Account.VerificationAddress>_verificationAddress()final Map<String, JsonValue>_additionalProperties()final Accountvalidate()final Account.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Account.Builderbuilder()Returns a mutable builder for constructing an instance of Account. -
-
Method Detail
-
token
final String token()
Globally unique identifier for the account. This is the same as the account_token returned by the enroll endpoint. If using this parameter, do not include pagination.
-
created
final Optional<OffsetDateTime> created()
Timestamp of when the account was created. For accounts created before 2023-05-11, this field will be null.
-
spendLimit
final Account.SpendLimit spendLimit()
Spend limit information for the user containing the daily, monthly, and lifetime spend limit of the account. Any charges to a card owned by this account will be declined once their transaction volume has surpassed the value in the applicable time limit (rolling). A lifetime limit of 0 indicates that the lifetime limit feature is disabled.
-
state
final Account.State state()
Account state:
ACTIVE- Account is able to transact and create new cards.PAUSED- Account will not be able to transact or create new cards. It can be set back toACTIVE.CLOSED- Account will not be able to transact or create new cards.CLOSEDaccounts are also unable to be transitioned toACTIVEorPAUSEDstates.CLOSEDaccounts result from failing to pass KYB/KYC or Lithic closing for risk/compliance reasons. Please contact [email protected] if you believe this was in error.
-
accountHolder
final Optional<Account.AccountHolder> accountHolder()
-
authRuleTokens
@Deprecated(message = "deprecated") final Optional<List<String>> authRuleTokens()
List of identifiers for the Auth Rule(s) that are applied on the account. This field is deprecated and will no longer be populated in the
account_holderobject. The key will be removed from the schema in a future release. Use the/auth_rulesendpoints to fetch Auth Rule information instead.
-
cardholderCurrency
final Optional<String> cardholderCurrency()
3-character alphabetic ISO 4217 code for the currency of the cardholder.
-
verificationAddress
@Deprecated(message = "deprecated") final Optional<Account.VerificationAddress> verificationAddress()
-
_token
final JsonField<String> _token()
Globally unique identifier for the account. This is the same as the account_token returned by the enroll endpoint. If using this parameter, do not include pagination.
-
_created
final JsonField<OffsetDateTime> _created()
Timestamp of when the account was created. For accounts created before 2023-05-11, this field will be null.
-
_spendLimit
final JsonField<Account.SpendLimit> _spendLimit()
Spend limit information for the user containing the daily, monthly, and lifetime spend limit of the account. Any charges to a card owned by this account will be declined once their transaction volume has surpassed the value in the applicable time limit (rolling). A lifetime limit of 0 indicates that the lifetime limit feature is disabled.
-
_state
final JsonField<Account.State> _state()
Account state:
ACTIVE- Account is able to transact and create new cards.PAUSED- Account will not be able to transact or create new cards. It can be set back toACTIVE.CLOSED- Account will not be able to transact or create new cards.CLOSEDaccounts are also unable to be transitioned toACTIVEorPAUSEDstates.CLOSEDaccounts result from failing to pass KYB/KYC or Lithic closing for risk/compliance reasons. Please contact [email protected] if you believe this was in error.
-
_accountHolder
final JsonField<Account.AccountHolder> _accountHolder()
-
_authRuleTokens
@Deprecated(message = "deprecated") final JsonField<List<String>> _authRuleTokens()
List of identifiers for the Auth Rule(s) that are applied on the account. This field is deprecated and will no longer be populated in the
account_holderobject. The key will be removed from the schema in a future release. Use the/auth_rulesendpoints to fetch Auth Rule information instead.
-
_cardholderCurrency
final JsonField<String> _cardholderCurrency()
3-character alphabetic ISO 4217 code for the currency of the cardholder.
-
_verificationAddress
@Deprecated(message = "deprecated") final JsonField<Account.VerificationAddress> _verificationAddress()
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Account.Builder toBuilder()
-
builder
final static Account.Builder builder()
Returns a mutable builder for constructing an instance of Account.
The following fields are required:
.token() .created() .spendLimit() .state()
-
-
-