Class Account.Builder
-
- All Implemented Interfaces:
public final class Account.BuilderA builder for Account.
-
-
Method Summary
Modifier and Type Method Description final Account.Buildertoken(String token)Globally unique identifier for the account. final Account.Buildertoken(JsonField<String> token)Sets Builder.token to an arbitrary JSON value. final Account.Buildercreated(OffsetDateTime created)Timestamp of when the account was created. final Account.Buildercreated(Optional<OffsetDateTime> created)Alias for calling Builder.created with created.orElse(null).final Account.Buildercreated(JsonField<OffsetDateTime> created)Sets Builder.created to an arbitrary JSON value. final Account.BuilderspendLimit(Account.SpendLimit spendLimit)Spend limit information for the user containing the daily, monthly, and lifetime spend limit of the account. final Account.BuilderspendLimit(JsonField<Account.SpendLimit> spendLimit)Sets Builder.spendLimit to an arbitrary JSON value. final Account.Builderstate(Account.State state)Account state: ACTIVE- Account is able to transact and create new cards.PAUSED- Account will not be able to transact or create new cards. It can be set back toACTIVE.CLOSED- Account will not be able to transact or create new cards.CLOSEDaccounts are also unable to be transitioned toACTIVEorPAUSEDstates.CLOSEDaccounts result from failing to pass KYB/KYC or Lithic closing for risk/compliance reasons. Please contact [email protected] if you believe this was in error.
final Account.Builderstate(JsonField<Account.State> state)Sets Builder.state to an arbitrary JSON value. final Account.BuilderaccountHolder(Account.AccountHolder accountHolder)final Account.BuilderaccountHolder(JsonField<Account.AccountHolder> accountHolder)Sets Builder.accountHolder to an arbitrary JSON value. final Account.BuilderauthRuleTokens(List<String> authRuleTokens)List of identifiers for the Auth Rule(s) that are applied on the account. final Account.BuilderauthRuleTokens(JsonField<List<String>> authRuleTokens)Sets Builder.authRuleTokens to an arbitrary JSON value. final Account.BuilderaddAuthRuleToken(String authRuleToken)Adds a single String to authRuleTokens. final Account.BuildercardholderCurrency(String cardholderCurrency)3-character alphabetic ISO 4217 code for the currency of the cardholder. final Account.BuildercardholderCurrency(JsonField<String> cardholderCurrency)Sets Builder.cardholderCurrency to an arbitrary JSON value. final Account.BuilderverificationAddress(Account.VerificationAddress verificationAddress)final Account.BuilderverificationAddress(JsonField<Account.VerificationAddress> verificationAddress)Sets Builder.verificationAddress to an arbitrary JSON value. final Account.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Account.BuilderputAdditionalProperty(String key, JsonValue value)final Account.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Account.BuilderremoveAdditionalProperty(String key)final Account.BuilderremoveAllAdditionalProperties(Set<String> keys)final Accountbuild()Returns an immutable instance of Account. -
-
Method Detail
-
token
final Account.Builder token(String token)
Globally unique identifier for the account. This is the same as the account_token returned by the enroll endpoint. If using this parameter, do not include pagination.
-
token
final Account.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final Account.Builder created(OffsetDateTime created)
Timestamp of when the account was created.
-
created
final Account.Builder created(Optional<OffsetDateTime> created)
Alias for calling Builder.created with
created.orElse(null).
-
created
final Account.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
spendLimit
final Account.Builder spendLimit(Account.SpendLimit spendLimit)
Spend limit information for the user containing the daily, monthly, and lifetime spend limit of the account. Any charges to a card owned by this account will be declined once their transaction volume has surpassed the value in the applicable time limit (rolling). A lifetime limit of 0 indicates that the lifetime limit feature is disabled.
-
spendLimit
final Account.Builder spendLimit(JsonField<Account.SpendLimit> spendLimit)
Sets Builder.spendLimit to an arbitrary JSON value.
You should usually call Builder.spendLimit with a well-typed SpendLimit value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
state
final Account.Builder state(Account.State state)
Account state:
ACTIVE- Account is able to transact and create new cards.PAUSED- Account will not be able to transact or create new cards. It can be set back toACTIVE.CLOSED- Account will not be able to transact or create new cards.CLOSEDaccounts are also unable to be transitioned toACTIVEorPAUSEDstates.CLOSEDaccounts result from failing to pass KYB/KYC or Lithic closing for risk/compliance reasons. Please contact [email protected] if you believe this was in error.
-
state
final Account.Builder state(JsonField<Account.State> state)
Sets Builder.state to an arbitrary JSON value.
You should usually call Builder.state with a well-typed State value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountHolder
final Account.Builder accountHolder(Account.AccountHolder accountHolder)
-
accountHolder
final Account.Builder accountHolder(JsonField<Account.AccountHolder> accountHolder)
Sets Builder.accountHolder to an arbitrary JSON value.
You should usually call Builder.accountHolder with a well-typed AccountHolder value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
authRuleTokens
@Deprecated(message = "deprecated") final Account.Builder authRuleTokens(List<String> authRuleTokens)
List of identifiers for the Auth Rule(s) that are applied on the account. This field is deprecated and will no longer be populated in the
account_holderobject. The key will be removed from the schema in a future release. Use the/auth_rulesendpoints to fetch Auth Rule information instead.
-
authRuleTokens
@Deprecated(message = "deprecated") final Account.Builder authRuleTokens(JsonField<List<String>> authRuleTokens)
Sets Builder.authRuleTokens to an arbitrary JSON value.
You should usually call Builder.authRuleTokens with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addAuthRuleToken
@Deprecated(message = "deprecated") final Account.Builder addAuthRuleToken(String authRuleToken)
Adds a single String to authRuleTokens.
-
cardholderCurrency
final Account.Builder cardholderCurrency(String cardholderCurrency)
3-character alphabetic ISO 4217 code for the currency of the cardholder.
-
cardholderCurrency
final Account.Builder cardholderCurrency(JsonField<String> cardholderCurrency)
Sets Builder.cardholderCurrency to an arbitrary JSON value.
You should usually call Builder.cardholderCurrency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
verificationAddress
@Deprecated(message = "deprecated") final Account.Builder verificationAddress(Account.VerificationAddress verificationAddress)
-
verificationAddress
@Deprecated(message = "deprecated") final Account.Builder verificationAddress(JsonField<Account.VerificationAddress> verificationAddress)
Sets Builder.verificationAddress to an arbitrary JSON value.
You should usually call Builder.verificationAddress with a well-typed VerificationAddress value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Account.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Account.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Account.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Account.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Account.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-