Class Account.SpendLimit
-
- All Implemented Interfaces:
public final class Account.SpendLimitSpend limit information for the user containing the daily, monthly, and lifetime spend limit of the account. Any charges to a card owned by this account will be declined once their transaction volume has surpassed the value in the applicable time limit (rolling). A lifetime limit of 0 indicates that the lifetime limit feature is disabled.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccount.SpendLimit.BuilderA builder for SpendLimit.
-
Method Summary
Modifier and Type Method Description final Longdaily()Daily spend limit (in cents). final Longlifetime()Total spend limit over account lifetime (in cents). final Longmonthly()Monthly spend limit (in cents). final JsonField<Long>_daily()Returns the raw JSON value of daily. final JsonField<Long>_lifetime()Returns the raw JSON value of lifetime. final JsonField<Long>_monthly()Returns the raw JSON value of monthly. final Map<String, JsonValue>_additionalProperties()final Account.SpendLimit.BuildertoBuilder()final Account.SpendLimitvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Account.SpendLimit.Builderbuilder()Returns a mutable builder for constructing an instance of SpendLimit. -
-
Method Detail
-
_daily
final JsonField<Long> _daily()
Returns the raw JSON value of daily.
Unlike daily, this method doesn't throw if the JSON field has an unexpected type.
-
_lifetime
final JsonField<Long> _lifetime()
Returns the raw JSON value of lifetime.
Unlike lifetime, this method doesn't throw if the JSON field has an unexpected type.
-
_monthly
final JsonField<Long> _monthly()
Returns the raw JSON value of monthly.
Unlike monthly, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Account.SpendLimit.Builder toBuilder()
-
validate
final Account.SpendLimit validate()
-
builder
final static Account.SpendLimit.Builder builder()
Returns a mutable builder for constructing an instance of SpendLimit.
The following fields are required:
.daily() .lifetime() .monthly()
-
-
-
-