Package com.lithic.api.models
Class Account.SpendLimit
-
- All Implemented Interfaces:
public final class Account.SpendLimitSpend limit information for the user containing the daily, monthly, and lifetime spend limit of the account. Any charges to a card owned by this account will be declined once their transaction volume has surpassed the value in the applicable time limit (rolling). A lifetime limit of 0 indicates that the lifetime limit feature is disabled.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccount.SpendLimit.BuilderA builder for SpendLimit.
-
Method Summary
Modifier and Type Method Description final Longdaily()Daily spend limit (in cents). final Longlifetime()Total spend limit over account lifetime (in cents). final Longmonthly()Monthly spend limit (in cents). final JsonField<Long>_daily()Daily spend limit (in cents). final JsonField<Long>_lifetime()Total spend limit over account lifetime (in cents). final JsonField<Long>_monthly()Monthly spend limit (in cents). final Map<String, JsonValue>_additionalProperties()final Account.SpendLimitvalidate()final Account.SpendLimit.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Account.SpendLimit.Builderbuilder()Returns a mutable builder for constructing an instance of SpendLimit. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Account.SpendLimit validate()
-
toBuilder
final Account.SpendLimit.Builder toBuilder()
-
builder
final static Account.SpendLimit.Builder builder()
Returns a mutable builder for constructing an instance of SpendLimit.
The following fields are required:
.daily() .lifetime() .monthly()
-
-
-
-