Class AccountHolder
-
- All Implemented Interfaces:
public final class AccountHolder
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountHolder.BuilderA builder for AccountHolder.
public final classAccountHolder.AccountHolderIndividualResponseInformation about an individual associated with an account holder. A subset of the information provided via KYC. For example, we do not return the government id.
public final classAccountHolder.AccountHolderBusinessResponseOnly present when user_type == "BUSINESS". Information about the business for which the account is being opened and KYB is being run.
public final classAccountHolder.ExemptionTypeThe type of KYC exemption for a KYC-Exempt Account Holder.
public final classAccountHolder.Status(Deprecated. Use verification_application.status instead)
KYC and KYB evaluation states.
Note:
PENDING_REVIEWis only applicable for theKYB_BASICworkflow.
public final classAccountHolder.StatusReasonpublic final classAccountHolder.UserTypeThe type of Account Holder. If the type is "INDIVIDUAL", the "individual" attribute will be present. If the type is "BUSINESS" then the "business_entity", "control_person", "beneficial_owner_individuals", "naics_code", "nature_of_business", and "website_url" attributes will be present.
public final classAccountHolder.AccountHolderVerificationApplicationInformation about the most recent identity verification attempt
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier for the account holder. final OffsetDateTimecreated()Timestamp of when the account holder was created. final Optional<String>accountToken()Globally unique identifier for the account. final Optional<List<AccountHolder.AccountHolderIndividualResponse>>beneficialOwnerIndividuals()Only present when user_type == "BUSINESS". final Optional<String>businessAccountToken()Only applicable for customers using the KYC-Exempt workflow to enroll authorized users of businesses. final Optional<AccountHolder.AccountHolderBusinessResponse>businessEntity()Only present when user_type == "BUSINESS". final Optional<AccountHolder.AccountHolderIndividualResponse>controlPerson()Only present when user_type == "BUSINESS". final Optional<String>email()(Deprecated. final Optional<AccountHolder.ExemptionType>exemptionType()The type of KYC exemption for a KYC-Exempt Account Holder. final Optional<String>externalId()Customer-provided token that indicates a relationship with an object outside of the Lithic ecosystem. final Optional<AccountHolder.AccountHolderIndividualResponse>individual()Only present when user_type == "INDIVIDUAL". final Optional<String>naicsCode()Only present when user_type == "BUSINESS". final Optional<String>natureOfBusiness()Only present when user_type == "BUSINESS". final Optional<String>phoneNumber()(Deprecated. final Optional<List<RequiredDocument>>requiredDocuments()Only present for "KYB_BASIC" workflow. final Optional<AccountHolder.Status>status()(Deprecated. final Optional<List<AccountHolder.StatusReason>>statusReasons()(Deprecated. final Optional<AccountHolder.UserType>userType()The type of Account Holder. final Optional<AccountHolder.AccountHolderVerificationApplication>verificationApplication()Information about the most recent identity verification attempt final Optional<String>websiteUrl()Only present when user_type == "BUSINESS". final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<String>_accountToken()Returns the raw JSON value of accountToken. final JsonField<List<AccountHolder.AccountHolderIndividualResponse>>_beneficialOwnerIndividuals()Returns the raw JSON value of beneficialOwnerIndividuals. final JsonField<String>_businessAccountToken()Returns the raw JSON value of businessAccountToken. final JsonField<AccountHolder.AccountHolderBusinessResponse>_businessEntity()Returns the raw JSON value of businessEntity. final JsonField<AccountHolder.AccountHolderIndividualResponse>_controlPerson()Returns the raw JSON value of controlPerson. final JsonField<String>_email()Returns the raw JSON value of email. final JsonField<AccountHolder.ExemptionType>_exemptionType()Returns the raw JSON value of exemptionType. final JsonField<String>_externalId()Returns the raw JSON value of externalId. final JsonField<AccountHolder.AccountHolderIndividualResponse>_individual()Returns the raw JSON value of individual. final JsonField<String>_naicsCode()Returns the raw JSON value of naicsCode. final JsonField<String>_natureOfBusiness()Returns the raw JSON value of natureOfBusiness. final JsonField<String>_phoneNumber()Returns the raw JSON value of phoneNumber. final JsonField<List<RequiredDocument>>_requiredDocuments()Returns the raw JSON value of requiredDocuments. final JsonField<AccountHolder.Status>_status()Returns the raw JSON value of status. final JsonField<List<AccountHolder.StatusReason>>_statusReasons()Returns the raw JSON value of statusReasons. final JsonField<AccountHolder.UserType>_userType()Returns the raw JSON value of userType. final JsonField<AccountHolder.AccountHolderVerificationApplication>_verificationApplication()Returns the raw JSON value of verificationApplication. final JsonField<String>_websiteUrl()Returns the raw JSON value of websiteUrl. final Map<String, JsonValue>_additionalProperties()final AccountHolder.BuildertoBuilder()final AccountHoldervalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountHolder.Builderbuilder()Returns a mutable builder for constructing an instance of AccountHolder. -
-
Method Detail
-
created
final OffsetDateTime created()
Timestamp of when the account holder was created.
-
accountToken
final Optional<String> accountToken()
Globally unique identifier for the account.
-
beneficialOwnerIndividuals
final Optional<List<AccountHolder.AccountHolderIndividualResponse>> beneficialOwnerIndividuals()
Only present when user_type == "BUSINESS". You must submit a list of all direct and indirect individuals with 25% or more ownership in the company. A maximum of 4 beneficial owners can be submitted. If no individual owns 25% of the company you do not need to send beneficial owner information. See FinCEN requirements (Section I) for more background on individuals that should be included.
-
businessAccountToken
final Optional<String> businessAccountToken()
Only applicable for customers using the KYC-Exempt workflow to enroll authorized users of businesses. Pass the account_token of the enrolled business associated with the AUTHORIZED_USER in this field.
-
businessEntity
final Optional<AccountHolder.AccountHolderBusinessResponse> businessEntity()
Only present when user_type == "BUSINESS". Information about the business for which the account is being opened and KYB is being run.
-
controlPerson
final Optional<AccountHolder.AccountHolderIndividualResponse> controlPerson()
Only present when user_type == "BUSINESS". An individual with significant responsibility for managing the legal entity (e.g., a Chief Executive Officer, Chief Financial Officer, Chief Operating Officer, Managing Member, General Partner, President, Vice President, or Treasurer). This can be an executive, or someone who will have program-wide access to the cards that Lithic will provide. In some cases, this individual could also be a beneficial owner listed above.
-
email
final Optional<String> email()
(Deprecated. Use control_person.email when user_type == "BUSINESS". Use individual.phone_number when user_type == "INDIVIDUAL".) Primary email of Account Holder.
-
exemptionType
final Optional<AccountHolder.ExemptionType> exemptionType()
The type of KYC exemption for a KYC-Exempt Account Holder.
-
externalId
final Optional<String> externalId()
Customer-provided token that indicates a relationship with an object outside of the Lithic ecosystem.
-
individual
final Optional<AccountHolder.AccountHolderIndividualResponse> individual()
Only present when user_type == "INDIVIDUAL". Information about the individual for which the account is being opened and KYC is being run.
-
naicsCode
final Optional<String> naicsCode()
Only present when user_type == "BUSINESS". 6-digit North American Industry Classification System (NAICS) code for the business.
-
natureOfBusiness
final Optional<String> natureOfBusiness()
Only present when user_type == "BUSINESS". User-submitted description of the business.
-
phoneNumber
final Optional<String> phoneNumber()
(Deprecated. Use control_person.phone_number when user_type == "BUSINESS". Use individual.phone_number when user_type == "INDIVIDUAL".) Primary phone of Account Holder, entered in E.164 format.
-
requiredDocuments
final Optional<List<RequiredDocument>> requiredDocuments()
Only present for "KYB_BASIC" workflow. A list of documents required for the account holder to be approved.
-
status
final Optional<AccountHolder.Status> status()
(Deprecated. Use verification_application.status instead)
KYC and KYB evaluation states.
Note:
PENDING_REVIEWis only applicable for theKYB_BASICworkflow.
-
statusReasons
final Optional<List<AccountHolder.StatusReason>> statusReasons()
(Deprecated. Use verification_application.status_reasons)
Reason for the evaluation status.
-
userType
final Optional<AccountHolder.UserType> userType()
The type of Account Holder. If the type is "INDIVIDUAL", the "individual" attribute will be present. If the type is "BUSINESS" then the "business_entity", "control_person", "beneficial_owner_individuals", "naics_code", "nature_of_business", and "website_url" attributes will be present.
-
verificationApplication
final Optional<AccountHolder.AccountHolderVerificationApplication> verificationApplication()
Information about the most recent identity verification attempt
-
websiteUrl
final Optional<String> websiteUrl()
Only present when user_type == "BUSINESS". Business's primary website.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_accountToken
final JsonField<String> _accountToken()
Returns the raw JSON value of accountToken.
Unlike accountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficialOwnerIndividuals
final JsonField<List<AccountHolder.AccountHolderIndividualResponse>> _beneficialOwnerIndividuals()
Returns the raw JSON value of beneficialOwnerIndividuals.
Unlike beneficialOwnerIndividuals, this method doesn't throw if the JSON field has an unexpected type.
-
_businessAccountToken
final JsonField<String> _businessAccountToken()
Returns the raw JSON value of businessAccountToken.
Unlike businessAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_businessEntity
final JsonField<AccountHolder.AccountHolderBusinessResponse> _businessEntity()
Returns the raw JSON value of businessEntity.
Unlike businessEntity, this method doesn't throw if the JSON field has an unexpected type.
-
_controlPerson
final JsonField<AccountHolder.AccountHolderIndividualResponse> _controlPerson()
Returns the raw JSON value of controlPerson.
Unlike controlPerson, this method doesn't throw if the JSON field has an unexpected type.
-
_email
final JsonField<String> _email()
Returns the raw JSON value of email.
Unlike email, this method doesn't throw if the JSON field has an unexpected type.
-
_exemptionType
final JsonField<AccountHolder.ExemptionType> _exemptionType()
Returns the raw JSON value of exemptionType.
Unlike exemptionType, this method doesn't throw if the JSON field has an unexpected type.
-
_externalId
final JsonField<String> _externalId()
Returns the raw JSON value of externalId.
Unlike externalId, this method doesn't throw if the JSON field has an unexpected type.
-
_individual
final JsonField<AccountHolder.AccountHolderIndividualResponse> _individual()
Returns the raw JSON value of individual.
Unlike individual, this method doesn't throw if the JSON field has an unexpected type.
-
_naicsCode
final JsonField<String> _naicsCode()
Returns the raw JSON value of naicsCode.
Unlike naicsCode, this method doesn't throw if the JSON field has an unexpected type.
-
_natureOfBusiness
final JsonField<String> _natureOfBusiness()
Returns the raw JSON value of natureOfBusiness.
Unlike natureOfBusiness, this method doesn't throw if the JSON field has an unexpected type.
-
_phoneNumber
final JsonField<String> _phoneNumber()
Returns the raw JSON value of phoneNumber.
Unlike phoneNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_requiredDocuments
final JsonField<List<RequiredDocument>> _requiredDocuments()
Returns the raw JSON value of requiredDocuments.
Unlike requiredDocuments, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<AccountHolder.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_statusReasons
final JsonField<List<AccountHolder.StatusReason>> _statusReasons()
Returns the raw JSON value of statusReasons.
Unlike statusReasons, this method doesn't throw if the JSON field has an unexpected type.
-
_userType
final JsonField<AccountHolder.UserType> _userType()
Returns the raw JSON value of userType.
Unlike userType, this method doesn't throw if the JSON field has an unexpected type.
-
_verificationApplication
final JsonField<AccountHolder.AccountHolderVerificationApplication> _verificationApplication()
Returns the raw JSON value of verificationApplication.
Unlike verificationApplication, this method doesn't throw if the JSON field has an unexpected type.
-
_websiteUrl
final JsonField<String> _websiteUrl()
Returns the raw JSON value of websiteUrl.
Unlike websiteUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountHolder.Builder toBuilder()
-
validate
final AccountHolder validate()
-
builder
final static AccountHolder.Builder builder()
Returns a mutable builder for constructing an instance of AccountHolder.
The following fields are required:
.token() .created()
-
-
-
-