Class AccountHolderSimulateEnrollmentReviewResponse.VerificationApplication
-
- All Implemented Interfaces:
public final class AccountHolderSimulateEnrollmentReviewResponse.VerificationApplicationInformation about the most recent identity verification attempt
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountHolderSimulateEnrollmentReviewResponse.VerificationApplication.BuilderA builder for VerificationApplication.
public final classAccountHolderSimulateEnrollmentReviewResponse.VerificationApplication.StatusKYC and KYB evaluation states.
Note:
PENDING_RESUBMITandPENDING_DOCUMENTare only applicable for theADVANCEDworkflow.public final classAccountHolderSimulateEnrollmentReviewResponse.VerificationApplication.StatusReasonsStatus Reasons for KYC/KYB enrollment states
-
Method Summary
-
-
Method Detail
-
created
final OffsetDateTime created()
Timestamp of when the application was created.
-
status
final AccountHolderSimulateEnrollmentReviewResponse.VerificationApplication.Status status()
KYC and KYB evaluation states.
Note:
PENDING_RESUBMITandPENDING_DOCUMENTare only applicable for theADVANCEDworkflow.
-
statusReasons
final List<AccountHolderSimulateEnrollmentReviewResponse.VerificationApplication.StatusReasons> statusReasons()
Reason for the evaluation status.
-
updated
final OffsetDateTime updated()
Timestamp of when the application was last updated.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<AccountHolderSimulateEnrollmentReviewResponse.VerificationApplication.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_statusReasons
final JsonField<List<AccountHolderSimulateEnrollmentReviewResponse.VerificationApplication.StatusReasons>> _statusReasons()
Returns the raw JSON value of statusReasons.
Unlike statusReasons, this method doesn't throw if the JSON field has an unexpected type.
-
_updated
final JsonField<OffsetDateTime> _updated()
Returns the raw JSON value of updated.
Unlike updated, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountHolderSimulateEnrollmentReviewResponse.VerificationApplication.Builder toBuilder()
-
builder
final static AccountHolderSimulateEnrollmentReviewResponse.VerificationApplication.Builder builder()
Returns a mutable builder for constructing an instance of VerificationApplication.
The following fields are required:
.created() .status() .statusReasons() .updated()
-
-
-
-