Package com.lithic.api.models
Class AccountListPageAsync
-
- All Implemented Interfaces:
public final class AccountListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountListPageAsync.BuilderA builder for AccountListPageAsync.
public final classAccountListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<Account>data()Delegates to AccountListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to AccountListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<AccountListParams>getNextPageParams()final CompletableFuture<Optional<AccountListPageAsync>>getNextPage()final AccountListPageAsync.AutoPagerautoPager()final AccountListParamsparams()The parameters that were used to request this page. final AccountListPageResponseresponse()The response that this page was parsed from. final AccountListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of AccountListPageAsync. -
-
Method Detail
-
data
final List<Account> data()
Delegates to AccountListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to AccountListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<AccountListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<AccountListPageAsync>> getNextPage()
-
autoPager
final AccountListPageAsync.AutoPager autoPager()
-
params
final AccountListParams params()
The parameters that were used to request this page.
-
response
final AccountListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final AccountListPageAsync.Builder toBuilder()
-
builder
final static AccountListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of AccountListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-