Class AccountSpendLimits.AvailableSpendLimit
-
- All Implemented Interfaces:
public final class AccountSpendLimits.AvailableSpendLimit
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountSpendLimits.AvailableSpendLimit.BuilderA builder for AvailableSpendLimit.
-
Method Summary
Modifier and Type Method Description final Optional<Long>daily()The available spend limit (in cents) relative to the daily limit configured on the Account (e.g. final Optional<Long>lifetime()The available spend limit (in cents) relative to the lifetime limit configured on the Account. final Optional<Long>monthly()The available spend limit (in cents) relative to the monthly limit configured on the Account. final JsonField<Long>_daily()Returns the raw JSON value of daily. final JsonField<Long>_lifetime()Returns the raw JSON value of lifetime. final JsonField<Long>_monthly()Returns the raw JSON value of monthly. final Map<String, JsonValue>_additionalProperties()final AccountSpendLimits.AvailableSpendLimit.BuildertoBuilder()final AccountSpendLimits.AvailableSpendLimitvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountSpendLimits.AvailableSpendLimit.Builderbuilder()Returns a mutable builder for constructing an instance of AvailableSpendLimit. -
-
Method Detail
-
daily
final Optional<Long> daily()
The available spend limit (in cents) relative to the daily limit configured on the Account (e.g. 100000 would be a $1,000 limit).
-
lifetime
final Optional<Long> lifetime()
The available spend limit (in cents) relative to the lifetime limit configured on the Account.
-
monthly
final Optional<Long> monthly()
The available spend limit (in cents) relative to the monthly limit configured on the Account.
-
_daily
final JsonField<Long> _daily()
Returns the raw JSON value of daily.
Unlike daily, this method doesn't throw if the JSON field has an unexpected type.
-
_lifetime
final JsonField<Long> _lifetime()
Returns the raw JSON value of lifetime.
Unlike lifetime, this method doesn't throw if the JSON field has an unexpected type.
-
_monthly
final JsonField<Long> _monthly()
Returns the raw JSON value of monthly.
Unlike monthly, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountSpendLimits.AvailableSpendLimit.Builder toBuilder()
-
validate
final AccountSpendLimits.AvailableSpendLimit validate()
-
builder
final static AccountSpendLimits.AvailableSpendLimit.Builder builder()
Returns a mutable builder for constructing an instance of AvailableSpendLimit.
-
-
-
-