Class Address

  • All Implemented Interfaces:

    
    public final class Address
    
                        
    • Constructor Detail

    • Method Detail

      • address1

         final String address1()

        Valid deliverable address (no PO boxes).

      • country

         final String country()

        Valid country code, entered in uppercase ISO 3166-1 alpha-3 three-character format. Only USA is currently supported for all workflows. KYC_EXEMPT supports CAN additionally.

      • postalCode

         final String postalCode()

        Valid postal code. USA postal codes (ZIP codes) are supported, entered as a five-digit postal code or nine-digit postal code (ZIP+4) using the format 12345-1234. KYC_EXEMPT supports Canadian postal codes.

      • state

         final String state()

        Valid state code. USA state codes are supported, entered in uppercase ISO 3166-2 two-character format. KYC_EXEMPT supports Canadian province codes.

      • _country

         final JsonField<String> _country()

        Valid country code, entered in uppercase ISO 3166-1 alpha-3 three-character format. Only USA is currently supported for all workflows. KYC_EXEMPT supports CAN additionally.

      • _postalCode

         final JsonField<String> _postalCode()

        Valid postal code. USA postal codes (ZIP codes) are supported, entered as a five-digit postal code or nine-digit postal code (ZIP+4) using the format 12345-1234. KYC_EXEMPT supports Canadian postal codes.

      • _state

         final JsonField<String> _state()

        Valid state code. USA state codes are supported, entered in uppercase ISO 3166-2 two-character format. KYC_EXEMPT supports Canadian province codes.

      • builder

         final static Address.Builder builder()

        Returns a mutable builder for constructing an instance of Address.

        The following fields are required:

        .address1()
        .city()
        .country()
        .postalCode()
        .state()