Class AggregateBalance.Builder
-
- All Implemented Interfaces:
public final class AggregateBalance.BuilderA builder for AggregateBalance.
-
-
Method Summary
Modifier and Type Method Description final AggregateBalance.BuilderavailableAmount(Long availableAmount)Funds available for spend in the currency's smallest unit (e.g. final AggregateBalance.BuilderavailableAmount(JsonField<Long> availableAmount)Funds available for spend in the currency's smallest unit (e.g. final AggregateBalance.Buildercreated(OffsetDateTime created)Date and time for when the balance was first created. final AggregateBalance.Buildercreated(JsonField<OffsetDateTime> created)Date and time for when the balance was first created. final AggregateBalance.Buildercurrency(String currency)3-character alphabetic ISO 4217 code for the local currency of the balance. final AggregateBalance.Buildercurrency(JsonField<String> currency)3-character alphabetic ISO 4217 code for the local currency of the balance. final AggregateBalance.BuilderfinancialAccountType(AggregateBalance.FinancialAccountType financialAccountType)Type of financial account final AggregateBalance.BuilderfinancialAccountType(JsonField<AggregateBalance.FinancialAccountType> financialAccountType)Type of financial account final AggregateBalance.BuilderlastFinancialAccountToken(String lastFinancialAccountToken)Globally unique identifier for the financial account that had its balance updated most recently final AggregateBalance.BuilderlastFinancialAccountToken(JsonField<String> lastFinancialAccountToken)Globally unique identifier for the financial account that had its balance updated most recently final AggregateBalance.BuilderlastTransactionEventToken(String lastTransactionEventToken)Globally unique identifier for the last transaction event that impacted this balance final AggregateBalance.BuilderlastTransactionEventToken(JsonField<String> lastTransactionEventToken)Globally unique identifier for the last transaction event that impacted this balance final AggregateBalance.BuilderlastTransactionToken(String lastTransactionToken)Globally unique identifier for the last transaction that impacted this balance final AggregateBalance.BuilderlastTransactionToken(JsonField<String> lastTransactionToken)Globally unique identifier for the last transaction that impacted this balance final AggregateBalance.BuilderpendingAmount(Long pendingAmount)Funds not available for spend due to card authorizations or pending ACH release. final AggregateBalance.BuilderpendingAmount(JsonField<Long> pendingAmount)Funds not available for spend due to card authorizations or pending ACH release. final AggregateBalance.BuildertotalAmount(Long totalAmount)The sum of available and pending balance in the currency's smallest unit (e.g. final AggregateBalance.BuildertotalAmount(JsonField<Long> totalAmount)The sum of available and pending balance in the currency's smallest unit (e.g. final AggregateBalance.Builderupdated(OffsetDateTime updated)Date and time for when the balance was last updated. final AggregateBalance.Builderupdated(JsonField<OffsetDateTime> updated)Date and time for when the balance was last updated. final AggregateBalance.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final AggregateBalance.BuilderputAdditionalProperty(String key, JsonValue value)final AggregateBalance.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final AggregateBalance.BuilderremoveAdditionalProperty(String key)final AggregateBalance.BuilderremoveAllAdditionalProperties(Set<String> keys)final AggregateBalancebuild()-
-
Method Detail
-
availableAmount
final AggregateBalance.Builder availableAmount(Long availableAmount)
Funds available for spend in the currency's smallest unit (e.g., cents for USD)
-
availableAmount
final AggregateBalance.Builder availableAmount(JsonField<Long> availableAmount)
Funds available for spend in the currency's smallest unit (e.g., cents for USD)
-
created
final AggregateBalance.Builder created(OffsetDateTime created)
Date and time for when the balance was first created.
-
created
final AggregateBalance.Builder created(JsonField<OffsetDateTime> created)
Date and time for when the balance was first created.
-
currency
final AggregateBalance.Builder currency(String currency)
3-character alphabetic ISO 4217 code for the local currency of the balance.
-
currency
final AggregateBalance.Builder currency(JsonField<String> currency)
3-character alphabetic ISO 4217 code for the local currency of the balance.
-
financialAccountType
final AggregateBalance.Builder financialAccountType(AggregateBalance.FinancialAccountType financialAccountType)
Type of financial account
-
financialAccountType
final AggregateBalance.Builder financialAccountType(JsonField<AggregateBalance.FinancialAccountType> financialAccountType)
Type of financial account
-
lastFinancialAccountToken
final AggregateBalance.Builder lastFinancialAccountToken(String lastFinancialAccountToken)
Globally unique identifier for the financial account that had its balance updated most recently
-
lastFinancialAccountToken
final AggregateBalance.Builder lastFinancialAccountToken(JsonField<String> lastFinancialAccountToken)
Globally unique identifier for the financial account that had its balance updated most recently
-
lastTransactionEventToken
final AggregateBalance.Builder lastTransactionEventToken(String lastTransactionEventToken)
Globally unique identifier for the last transaction event that impacted this balance
-
lastTransactionEventToken
final AggregateBalance.Builder lastTransactionEventToken(JsonField<String> lastTransactionEventToken)
Globally unique identifier for the last transaction event that impacted this balance
-
lastTransactionToken
final AggregateBalance.Builder lastTransactionToken(String lastTransactionToken)
Globally unique identifier for the last transaction that impacted this balance
-
lastTransactionToken
final AggregateBalance.Builder lastTransactionToken(JsonField<String> lastTransactionToken)
Globally unique identifier for the last transaction that impacted this balance
-
pendingAmount
final AggregateBalance.Builder pendingAmount(Long pendingAmount)
Funds not available for spend due to card authorizations or pending ACH release. Shown in the currency's smallest unit (e.g., cents for USD)
-
pendingAmount
final AggregateBalance.Builder pendingAmount(JsonField<Long> pendingAmount)
Funds not available for spend due to card authorizations or pending ACH release. Shown in the currency's smallest unit (e.g., cents for USD)
-
totalAmount
final AggregateBalance.Builder totalAmount(Long totalAmount)
The sum of available and pending balance in the currency's smallest unit (e.g., cents for USD)
-
totalAmount
final AggregateBalance.Builder totalAmount(JsonField<Long> totalAmount)
The sum of available and pending balance in the currency's smallest unit (e.g., cents for USD)
-
updated
final AggregateBalance.Builder updated(OffsetDateTime updated)
Date and time for when the balance was last updated.
-
updated
final AggregateBalance.Builder updated(JsonField<OffsetDateTime> updated)
Date and time for when the balance was last updated.
-
additionalProperties
final AggregateBalance.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AggregateBalance.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AggregateBalance.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AggregateBalance.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AggregateBalance.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AggregateBalance build()
-
-
-
-