Class AuthRule.DraftVersion.State

  • All Implemented Interfaces:
    com.lithic.api.core.Enum

    
    public final class AuthRule.DraftVersion.State
     implements Enum
                        

    The state of the draft version. Most rules are created synchronously and the state is immediately SHADOWING. Rules backed by TypeScript code are compiled asynchronously — the state starts as PENDING and transitions to SHADOWING on success or ERROR on failure.

    • PENDING: Compilation of the rule is in progress (TypeScript rules only).

    • SHADOWING: The draft version is ready and evaluating in shadow mode alongside the current active version. It can be promoted to the active version.

    • ERROR: Compilation of the rule failed. Check the error field for details.