Class AuthenticationRetrieveResponse.Cardholder.AddressMatchResult
-
- All Implemented Interfaces:
-
com.lithic.api.core.Enum
public final class AuthenticationRetrieveResponse.Cardholder.AddressMatchResult implements EnumLithic's evaluation result comparing the transaction's address data with the cardholder KYC data if it exists. In the event Lithic does not have any Cardholder KYC data, or the transaction does not contain any address data, NOT_PRESENT will be returned
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumAuthenticationRetrieveResponse.Cardholder.AddressMatchResult.KnownAn enum containing AddressMatchResult's known values.
public enumAuthenticationRetrieveResponse.Cardholder.AddressMatchResult.ValueAn enum containing AddressMatchResult's known values, as well as an _UNKNOWN member.
An instance of AddressMatchResult can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static AuthenticationRetrieveResponse.Cardholder.AddressMatchResultMATCHpublic final static AuthenticationRetrieveResponse.Cardholder.AddressMatchResultMATCH_ADDRESS_ONLYpublic final static AuthenticationRetrieveResponse.Cardholder.AddressMatchResultMATCH_ZIP_ONLYpublic final static AuthenticationRetrieveResponse.Cardholder.AddressMatchResultMISMATCHpublic final static AuthenticationRetrieveResponse.Cardholder.AddressMatchResultNOT_PRESENT
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final AuthenticationRetrieveResponse.Cardholder.AddressMatchResult.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final AuthenticationRetrieveResponse.Cardholder.AddressMatchResult.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. final AuthenticationRetrieveResponse.Cardholder.AddressMatchResultvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AuthenticationRetrieveResponse.Cardholder.AddressMatchResultof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final AuthenticationRetrieveResponse.Cardholder.AddressMatchResult.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final AuthenticationRetrieveResponse.Cardholder.AddressMatchResult.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
validate
final AuthenticationRetrieveResponse.Cardholder.AddressMatchResult validate()
-
of
final static AuthenticationRetrieveResponse.Cardholder.AddressMatchResult of(String value)
-
-
-
-