Package com.lithic.api.models
Class BacktestResults.Results.RuleStats.Example
-
- All Implemented Interfaces:
public final class BacktestResults.Results.RuleStats.Example
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBacktestResults.Results.RuleStats.Example.BuilderA builder for Example.
-
Method Summary
Modifier and Type Method Description final Optional<Boolean>approved()Whether the rule would have approved the authorization request. final Optional<String>eventToken()The authorization request event token. final Optional<OffsetDateTime>timestamp()The timestamp of the authorization request event. final JsonField<Boolean>_approved()Whether the rule would have approved the authorization request. final JsonField<String>_eventToken()The authorization request event token. final JsonField<OffsetDateTime>_timestamp()The timestamp of the authorization request event. final Map<String, JsonValue>_additionalProperties()final BacktestResults.Results.RuleStats.Examplevalidate()final BacktestResults.Results.RuleStats.Example.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BacktestResults.Results.RuleStats.Example.Builderbuilder()Returns a mutable builder for constructing an instance of Example. -
-
Method Detail
-
approved
final Optional<Boolean> approved()
Whether the rule would have approved the authorization request.
-
eventToken
final Optional<String> eventToken()
The authorization request event token.
-
timestamp
final Optional<OffsetDateTime> timestamp()
The timestamp of the authorization request event.
-
_approved
final JsonField<Boolean> _approved()
Whether the rule would have approved the authorization request.
-
_eventToken
final JsonField<String> _eventToken()
The authorization request event token.
-
_timestamp
final JsonField<OffsetDateTime> _timestamp()
The timestamp of the authorization request event.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final BacktestResults.Results.RuleStats.Example validate()
-
toBuilder
final BacktestResults.Results.RuleStats.Example.Builder toBuilder()
-
builder
final static BacktestResults.Results.RuleStats.Example.Builder builder()
Returns a mutable builder for constructing an instance of Example.
-
-
-
-