Package com.lithic.api.models
Class BalanceListPage
-
- All Implemented Interfaces:
public final class BalanceListPageGet the balances for a program, business, or a given end-user account
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBalanceListPage.Responsepublic final classBalanceListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final BalanceListPage.Responseresponse()final List<Balance>data()final BooleanhasMore()Booleanequals(Object other)IntegerhashCode()StringtoString()final BooleanhasNextPage()final Optional<BalanceListParams>getNextPageParams()final Optional<BalanceListPage>getNextPage()final BalanceListPage.AutoPagerautoPager()final static BalanceListPageof(BalanceService balancesService, BalanceListParams params, BalanceListPage.Response response)-
-
Method Detail
-
response
final BalanceListPage.Response response()
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<BalanceListParams> getNextPageParams()
-
getNextPage
final Optional<BalanceListPage> getNextPage()
-
autoPager
final BalanceListPage.AutoPager autoPager()
-
of
final static BalanceListPage of(BalanceService balancesService, BalanceListParams params, BalanceListPage.Response response)
-
-
-
-