Package com.lithic.api.models
Class BalanceListPageAsync
-
- All Implemented Interfaces:
public final class BalanceListPageAsyncGet the balances for a program, business, or a given end-user account
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBalanceListPageAsync.Responsepublic final classBalanceListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final BalanceListPageAsync.Responseresponse()final List<Balance>data()final BooleanhasMore()Booleanequals(Object other)IntegerhashCode()StringtoString()final BooleanhasNextPage()final Optional<BalanceListParams>getNextPageParams()final CompletableFuture<Optional<BalanceListPageAsync>>getNextPage()final BalanceListPageAsync.AutoPagerautoPager()final static BalanceListPageAsyncof(BalanceServiceAsync balancesService, BalanceListParams params, BalanceListPageAsync.Response response)-
-
Method Detail
-
response
final BalanceListPageAsync.Response response()
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<BalanceListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<BalanceListPageAsync>> getNextPage()
-
autoPager
final BalanceListPageAsync.AutoPager autoPager()
-
of
final static BalanceListPageAsync of(BalanceServiceAsync balancesService, BalanceListParams params, BalanceListPageAsync.Response response)
-
-
-
-