Class BookTransferResponse
-
- All Implemented Interfaces:
public final class BookTransferResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookTransferResponse.BuilderA builder for BookTransferResponse.
public final classBookTransferResponse.CategoryCategory of the book transfer
public final classBookTransferResponse.BookTransferEventpublic final classBookTransferResponse.ResultAPPROVED transactions were successful while DECLINED transactions were declined by user, Lithic, or the network.
public final classBookTransferResponse.StatusStatus types: _
DECLINED- The transfer was declined. _REVERSED- The transfer was reversed \*SETTLED- The transfer is completed.
-
Method Summary
Modifier and Type Method Description final Stringtoken()Customer-provided token that will serve as an idempotency token. final BookTransferResponse.Categorycategory()Category of the book transfer final OffsetDateTimecreated()Date and time when the transfer occurred. final Stringcurrency()3-character alphabetic ISO 4217 code for the settling currency of the transaction. final List<BookTransferResponse.BookTransferEvent>events()A list of all financial events that have modified this transfer. final StringfromFinancialAccountToken()Globally unique identifier for the financial account or card that will send the funds. final LongpendingAmount()Pending amount of the transaction in the currency's smallest unit (e.g., cents), including any acquirer fees. final BookTransferResponse.Resultresult()APPROVED transactions were successful while DECLINED transactions were declined by user, Lithic, or the network. final LongsettledAmount()Amount of the transaction that has been settled in the currency's smallest unit (e.g., cents). final BookTransferResponse.Statusstatus()Status types: _ DECLINED- The transfer was declined.final JsonValue_toFinancialAccountToken()Globally unique identifier for the financial account or card that will receive the funds. final OffsetDateTimeupdated()Date and time when the financial transaction was last updated. final JsonField<String>_token()Customer-provided token that will serve as an idempotency token. final JsonField<BookTransferResponse.Category>_category()Category of the book transfer final JsonField<OffsetDateTime>_created()Date and time when the transfer occurred. final JsonField<String>_currency()3-character alphabetic ISO 4217 code for the settling currency of the transaction. final JsonField<List<BookTransferResponse.BookTransferEvent>>_events()A list of all financial events that have modified this transfer. final JsonField<String>_fromFinancialAccountToken()Globally unique identifier for the financial account or card that will send the funds. final JsonField<Long>_pendingAmount()Pending amount of the transaction in the currency's smallest unit (e.g., cents), including any acquirer fees. final JsonField<BookTransferResponse.Result>_result()APPROVED transactions were successful while DECLINED transactions were declined by user, Lithic, or the network. final JsonField<Long>_settledAmount()Amount of the transaction that has been settled in the currency's smallest unit (e.g., cents). final JsonField<BookTransferResponse.Status>_status()Status types: _ DECLINED- The transfer was declined.final JsonField<OffsetDateTime>_updated()Date and time when the financial transaction was last updated. final Map<String, JsonValue>_additionalProperties()final BookTransferResponsevalidate()final BookTransferResponse.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookTransferResponse.Builderbuilder()Returns a mutable builder for constructing an instance of BookTransferResponse. -
-
Method Detail
-
token
final String token()
Customer-provided token that will serve as an idempotency token. This token will become the transaction token.
-
category
final BookTransferResponse.Category category()
Category of the book transfer
-
created
final OffsetDateTime created()
Date and time when the transfer occurred. UTC time zone.
-
currency
final String currency()
3-character alphabetic ISO 4217 code for the settling currency of the transaction.
-
events
final List<BookTransferResponse.BookTransferEvent> events()
A list of all financial events that have modified this transfer.
-
fromFinancialAccountToken
final String fromFinancialAccountToken()
Globally unique identifier for the financial account or card that will send the funds. Accepted type dependent on the program's use case.
-
pendingAmount
final Long pendingAmount()
Pending amount of the transaction in the currency's smallest unit (e.g., cents), including any acquirer fees. The value of this field will go to zero over time once the financial transaction is settled.
-
result
final BookTransferResponse.Result result()
APPROVED transactions were successful while DECLINED transactions were declined by user, Lithic, or the network.
-
settledAmount
final Long settledAmount()
Amount of the transaction that has been settled in the currency's smallest unit (e.g., cents).
-
status
final BookTransferResponse.Status status()
Status types: _
DECLINED- The transfer was declined. _REVERSED- The transfer was reversed \*SETTLED- The transfer is completed.
-
_toFinancialAccountToken
final JsonValue _toFinancialAccountToken()
Globally unique identifier for the financial account or card that will receive the funds. Accepted type dependent on the program's use case.
-
updated
final OffsetDateTime updated()
Date and time when the financial transaction was last updated. UTC time zone.
-
_token
final JsonField<String> _token()
Customer-provided token that will serve as an idempotency token. This token will become the transaction token.
-
_category
final JsonField<BookTransferResponse.Category> _category()
Category of the book transfer
-
_created
final JsonField<OffsetDateTime> _created()
Date and time when the transfer occurred. UTC time zone.
-
_currency
final JsonField<String> _currency()
3-character alphabetic ISO 4217 code for the settling currency of the transaction.
-
_events
final JsonField<List<BookTransferResponse.BookTransferEvent>> _events()
A list of all financial events that have modified this transfer.
-
_fromFinancialAccountToken
final JsonField<String> _fromFinancialAccountToken()
Globally unique identifier for the financial account or card that will send the funds. Accepted type dependent on the program's use case.
-
_pendingAmount
final JsonField<Long> _pendingAmount()
Pending amount of the transaction in the currency's smallest unit (e.g., cents), including any acquirer fees. The value of this field will go to zero over time once the financial transaction is settled.
-
_result
final JsonField<BookTransferResponse.Result> _result()
APPROVED transactions were successful while DECLINED transactions were declined by user, Lithic, or the network.
-
_settledAmount
final JsonField<Long> _settledAmount()
Amount of the transaction that has been settled in the currency's smallest unit (e.g., cents).
-
_status
final JsonField<BookTransferResponse.Status> _status()
Status types: _
DECLINED- The transfer was declined. _REVERSED- The transfer was reversed \*SETTLED- The transfer is completed.
-
_updated
final JsonField<OffsetDateTime> _updated()
Date and time when the financial transaction was last updated. UTC time zone.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final BookTransferResponse validate()
-
toBuilder
final BookTransferResponse.Builder toBuilder()
-
builder
final static BookTransferResponse.Builder builder()
Returns a mutable builder for constructing an instance of BookTransferResponse.
The following fields are required:
.token() .category() .created() .currency() .events() .fromFinancialAccountToken() .pendingAmount() .result() .settledAmount() .status() .toFinancialAccountToken() .updated()
-
-
-
-