Class BookTransferResponse.Builder
-
- All Implemented Interfaces:
public final class BookTransferResponse.BuilderA builder for BookTransferResponse.
-
-
Method Summary
Modifier and Type Method Description final BookTransferResponse.Buildertoken(String token)Customer-provided token that will serve as an idempotency token. final BookTransferResponse.Buildertoken(JsonField<String> token)Sets Builder.token to an arbitrary JSON value. final BookTransferResponse.Buildercategory(BookTransferResponse.Category category)Category of the book transfer final BookTransferResponse.Buildercategory(JsonField<BookTransferResponse.Category> category)Sets Builder.category to an arbitrary JSON value. final BookTransferResponse.Buildercreated(OffsetDateTime created)Date and time when the transfer occurred. final BookTransferResponse.Buildercreated(JsonField<OffsetDateTime> created)Sets Builder.created to an arbitrary JSON value. final BookTransferResponse.Buildercurrency(String currency)3-character alphabetic ISO 4217 code for the settling currency of the transaction. final BookTransferResponse.Buildercurrency(JsonField<String> currency)Sets Builder.currency to an arbitrary JSON value. final BookTransferResponse.Builderevents(List<BookTransferResponse.BookTransferEvent> events)A list of all financial events that have modified this transfer. final BookTransferResponse.Builderevents(JsonField<List<BookTransferResponse.BookTransferEvent>> events)Sets Builder.events to an arbitrary JSON value. final BookTransferResponse.BuilderaddEvent(BookTransferResponse.BookTransferEvent event)Adds a single BookTransferEvent to events. final BookTransferResponse.BuilderfromFinancialAccountToken(String fromFinancialAccountToken)Globally unique identifier for the financial account or card that will send the funds. final BookTransferResponse.BuilderfromFinancialAccountToken(JsonField<String> fromFinancialAccountToken)Sets Builder.fromFinancialAccountToken to an arbitrary JSON value. final BookTransferResponse.BuilderpendingAmount(Long pendingAmount)Pending amount of the transaction in the currency's smallest unit (e.g., cents), including any acquirer fees. final BookTransferResponse.BuilderpendingAmount(JsonField<Long> pendingAmount)Sets Builder.pendingAmount to an arbitrary JSON value. final BookTransferResponse.Builderresult(BookTransferResponse.Result result)APPROVED transactions were successful while DECLINED transactions were declined by user, Lithic, or the network. final BookTransferResponse.Builderresult(JsonField<BookTransferResponse.Result> result)Sets Builder.result to an arbitrary JSON value. final BookTransferResponse.BuildersettledAmount(Long settledAmount)Amount of the transaction that has been settled in the currency's smallest unit (e.g., cents). final BookTransferResponse.BuildersettledAmount(JsonField<Long> settledAmount)Sets Builder.settledAmount to an arbitrary JSON value. final BookTransferResponse.Builderstatus(BookTransferResponse.Status status)Status types: _ DECLINED- The transfer was declined.final BookTransferResponse.Builderstatus(JsonField<BookTransferResponse.Status> status)Sets Builder.status to an arbitrary JSON value. final BookTransferResponse.BuildertoFinancialAccountToken(JsonValue toFinancialAccountToken)Globally unique identifier for the financial account or card that will receive the funds. final BookTransferResponse.Builderupdated(OffsetDateTime updated)Date and time when the financial transaction was last updated. final BookTransferResponse.Builderupdated(JsonField<OffsetDateTime> updated)Sets Builder.updated to an arbitrary JSON value. final BookTransferResponse.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final BookTransferResponse.BuilderputAdditionalProperty(String key, JsonValue value)final BookTransferResponse.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final BookTransferResponse.BuilderremoveAdditionalProperty(String key)final BookTransferResponse.BuilderremoveAllAdditionalProperties(Set<String> keys)final BookTransferResponsebuild()Returns an immutable instance of BookTransferResponse. -
-
Method Detail
-
token
final BookTransferResponse.Builder token(String token)
Customer-provided token that will serve as an idempotency token. This token will become the transaction token.
-
token
final BookTransferResponse.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
category
final BookTransferResponse.Builder category(BookTransferResponse.Category category)
Category of the book transfer
-
category
final BookTransferResponse.Builder category(JsonField<BookTransferResponse.Category> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Category value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final BookTransferResponse.Builder created(OffsetDateTime created)
Date and time when the transfer occurred. UTC time zone.
-
created
final BookTransferResponse.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final BookTransferResponse.Builder currency(String currency)
3-character alphabetic ISO 4217 code for the settling currency of the transaction.
-
currency
final BookTransferResponse.Builder currency(JsonField<String> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
events
final BookTransferResponse.Builder events(List<BookTransferResponse.BookTransferEvent> events)
A list of all financial events that have modified this transfer.
-
events
final BookTransferResponse.Builder events(JsonField<List<BookTransferResponse.BookTransferEvent>> events)
Sets Builder.events to an arbitrary JSON value.
You should usually call Builder.events with a well-typed
List<BookTransferEvent>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEvent
final BookTransferResponse.Builder addEvent(BookTransferResponse.BookTransferEvent event)
Adds a single BookTransferEvent to events.
-
fromFinancialAccountToken
final BookTransferResponse.Builder fromFinancialAccountToken(String fromFinancialAccountToken)
Globally unique identifier for the financial account or card that will send the funds. Accepted type dependent on the program's use case.
-
fromFinancialAccountToken
final BookTransferResponse.Builder fromFinancialAccountToken(JsonField<String> fromFinancialAccountToken)
Sets Builder.fromFinancialAccountToken to an arbitrary JSON value.
You should usually call Builder.fromFinancialAccountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pendingAmount
final BookTransferResponse.Builder pendingAmount(Long pendingAmount)
Pending amount of the transaction in the currency's smallest unit (e.g., cents), including any acquirer fees. The value of this field will go to zero over time once the financial transaction is settled.
-
pendingAmount
final BookTransferResponse.Builder pendingAmount(JsonField<Long> pendingAmount)
Sets Builder.pendingAmount to an arbitrary JSON value.
You should usually call Builder.pendingAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
result
final BookTransferResponse.Builder result(BookTransferResponse.Result result)
APPROVED transactions were successful while DECLINED transactions were declined by user, Lithic, or the network.
-
result
final BookTransferResponse.Builder result(JsonField<BookTransferResponse.Result> result)
Sets Builder.result to an arbitrary JSON value.
You should usually call Builder.result with a well-typed Result value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
settledAmount
final BookTransferResponse.Builder settledAmount(Long settledAmount)
Amount of the transaction that has been settled in the currency's smallest unit (e.g., cents).
-
settledAmount
final BookTransferResponse.Builder settledAmount(JsonField<Long> settledAmount)
Sets Builder.settledAmount to an arbitrary JSON value.
You should usually call Builder.settledAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final BookTransferResponse.Builder status(BookTransferResponse.Status status)
Status types: _
DECLINED- The transfer was declined. _REVERSED- The transfer was reversed \*SETTLED- The transfer is completed.
-
status
final BookTransferResponse.Builder status(JsonField<BookTransferResponse.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
toFinancialAccountToken
final BookTransferResponse.Builder toFinancialAccountToken(JsonValue toFinancialAccountToken)
Globally unique identifier for the financial account or card that will receive the funds. Accepted type dependent on the program's use case.
-
updated
final BookTransferResponse.Builder updated(OffsetDateTime updated)
Date and time when the financial transaction was last updated. UTC time zone.
-
updated
final BookTransferResponse.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final BookTransferResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BookTransferResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BookTransferResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BookTransferResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BookTransferResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BookTransferResponse build()
Returns an immutable instance of BookTransferResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .category() .created() .currency() .events() .fromFinancialAccountToken() .pendingAmount() .result() .settledAmount() .status() .toFinancialAccountToken() .updated()
-
-
-
-