Class BookTransferResponse.Builder
-
- All Implemented Interfaces:
public final class BookTransferResponse.BuilderA builder for BookTransferResponse.
-
-
Method Summary
Modifier and Type Method Description final BookTransferResponse.Buildertoken(String token)Customer-provided token that will serve as an idempotency token. final BookTransferResponse.Buildertoken(JsonField<String> token)Customer-provided token that will serve as an idempotency token. final BookTransferResponse.Buildercategory(BookTransferResponse.Category category)Category of the book transfer final BookTransferResponse.Buildercategory(JsonField<BookTransferResponse.Category> category)Category of the book transfer final BookTransferResponse.Buildercreated(OffsetDateTime created)Date and time when the transfer occurred. final BookTransferResponse.Buildercreated(JsonField<OffsetDateTime> created)Date and time when the transfer occurred. final BookTransferResponse.Buildercurrency(String currency)3-character alphabetic ISO 4217 code for the settling currency of the transaction. final BookTransferResponse.Buildercurrency(JsonField<String> currency)3-character alphabetic ISO 4217 code for the settling currency of the transaction. final BookTransferResponse.Builderevents(List<BookTransferResponse.BookTransferEvent> events)A list of all financial events that have modified this transfer. final BookTransferResponse.Builderevents(JsonField<List<BookTransferResponse.BookTransferEvent>> events)A list of all financial events that have modified this transfer. final BookTransferResponse.BuilderaddEvent(BookTransferResponse.BookTransferEvent event)A list of all financial events that have modified this transfer. final BookTransferResponse.BuilderfromFinancialAccountToken(String fromFinancialAccountToken)Globally unique identifier for the financial account or card that will send the funds. final BookTransferResponse.BuilderfromFinancialAccountToken(JsonField<String> fromFinancialAccountToken)Globally unique identifier for the financial account or card that will send the funds. final BookTransferResponse.BuilderpendingAmount(Long pendingAmount)Pending amount of the transaction in the currency's smallest unit (e.g., cents), including any acquirer fees. final BookTransferResponse.BuilderpendingAmount(JsonField<Long> pendingAmount)Pending amount of the transaction in the currency's smallest unit (e.g., cents), including any acquirer fees. final BookTransferResponse.Builderresult(BookTransferResponse.Result result)APPROVED transactions were successful while DECLINED transactions were declined by user, Lithic, or the network. final BookTransferResponse.Builderresult(JsonField<BookTransferResponse.Result> result)APPROVED transactions were successful while DECLINED transactions were declined by user, Lithic, or the network. final BookTransferResponse.BuildersettledAmount(Long settledAmount)Amount of the transaction that has been settled in the currency's smallest unit (e.g., cents). final BookTransferResponse.BuildersettledAmount(JsonField<Long> settledAmount)Amount of the transaction that has been settled in the currency's smallest unit (e.g., cents). final BookTransferResponse.Builderstatus(BookTransferResponse.Status status)Status types: _ DECLINED- The transfer was declined.final BookTransferResponse.Builderstatus(JsonField<BookTransferResponse.Status> status)Status types: _ DECLINED- The transfer was declined.final BookTransferResponse.BuildertoFinancialAccountToken(JsonValue toFinancialAccountToken)Globally unique identifier for the financial account or card that will receive the funds. final BookTransferResponse.Builderupdated(OffsetDateTime updated)Date and time when the financial transaction was last updated. final BookTransferResponse.Builderupdated(JsonField<OffsetDateTime> updated)Date and time when the financial transaction was last updated. final BookTransferResponse.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final BookTransferResponse.BuilderputAdditionalProperty(String key, JsonValue value)final BookTransferResponse.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final BookTransferResponse.BuilderremoveAdditionalProperty(String key)final BookTransferResponse.BuilderremoveAllAdditionalProperties(Set<String> keys)final BookTransferResponsebuild()-
-
Method Detail
-
token
final BookTransferResponse.Builder token(String token)
Customer-provided token that will serve as an idempotency token. This token will become the transaction token.
-
token
final BookTransferResponse.Builder token(JsonField<String> token)
Customer-provided token that will serve as an idempotency token. This token will become the transaction token.
-
category
final BookTransferResponse.Builder category(BookTransferResponse.Category category)
Category of the book transfer
-
category
final BookTransferResponse.Builder category(JsonField<BookTransferResponse.Category> category)
Category of the book transfer
-
created
final BookTransferResponse.Builder created(OffsetDateTime created)
Date and time when the transfer occurred. UTC time zone.
-
created
final BookTransferResponse.Builder created(JsonField<OffsetDateTime> created)
Date and time when the transfer occurred. UTC time zone.
-
currency
final BookTransferResponse.Builder currency(String currency)
3-character alphabetic ISO 4217 code for the settling currency of the transaction.
-
currency
final BookTransferResponse.Builder currency(JsonField<String> currency)
3-character alphabetic ISO 4217 code for the settling currency of the transaction.
-
events
final BookTransferResponse.Builder events(List<BookTransferResponse.BookTransferEvent> events)
A list of all financial events that have modified this transfer.
-
events
final BookTransferResponse.Builder events(JsonField<List<BookTransferResponse.BookTransferEvent>> events)
A list of all financial events that have modified this transfer.
-
addEvent
final BookTransferResponse.Builder addEvent(BookTransferResponse.BookTransferEvent event)
A list of all financial events that have modified this transfer.
-
fromFinancialAccountToken
final BookTransferResponse.Builder fromFinancialAccountToken(String fromFinancialAccountToken)
Globally unique identifier for the financial account or card that will send the funds. Accepted type dependent on the program's use case.
-
fromFinancialAccountToken
final BookTransferResponse.Builder fromFinancialAccountToken(JsonField<String> fromFinancialAccountToken)
Globally unique identifier for the financial account or card that will send the funds. Accepted type dependent on the program's use case.
-
pendingAmount
final BookTransferResponse.Builder pendingAmount(Long pendingAmount)
Pending amount of the transaction in the currency's smallest unit (e.g., cents), including any acquirer fees. The value of this field will go to zero over time once the financial transaction is settled.
-
pendingAmount
final BookTransferResponse.Builder pendingAmount(JsonField<Long> pendingAmount)
Pending amount of the transaction in the currency's smallest unit (e.g., cents), including any acquirer fees. The value of this field will go to zero over time once the financial transaction is settled.
-
result
final BookTransferResponse.Builder result(BookTransferResponse.Result result)
APPROVED transactions were successful while DECLINED transactions were declined by user, Lithic, or the network.
-
result
final BookTransferResponse.Builder result(JsonField<BookTransferResponse.Result> result)
APPROVED transactions were successful while DECLINED transactions were declined by user, Lithic, or the network.
-
settledAmount
final BookTransferResponse.Builder settledAmount(Long settledAmount)
Amount of the transaction that has been settled in the currency's smallest unit (e.g., cents).
-
settledAmount
final BookTransferResponse.Builder settledAmount(JsonField<Long> settledAmount)
Amount of the transaction that has been settled in the currency's smallest unit (e.g., cents).
-
status
final BookTransferResponse.Builder status(BookTransferResponse.Status status)
Status types: _
DECLINED- The transfer was declined. _REVERSED- The transfer was reversed \*SETTLED- The transfer is completed.
-
status
final BookTransferResponse.Builder status(JsonField<BookTransferResponse.Status> status)
Status types: _
DECLINED- The transfer was declined. _REVERSED- The transfer was reversed \*SETTLED- The transfer is completed.
-
toFinancialAccountToken
final BookTransferResponse.Builder toFinancialAccountToken(JsonValue toFinancialAccountToken)
Globally unique identifier for the financial account or card that will receive the funds. Accepted type dependent on the program's use case.
-
updated
final BookTransferResponse.Builder updated(OffsetDateTime updated)
Date and time when the financial transaction was last updated. UTC time zone.
-
updated
final BookTransferResponse.Builder updated(JsonField<OffsetDateTime> updated)
Date and time when the financial transaction was last updated. UTC time zone.
-
additionalProperties
final BookTransferResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BookTransferResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BookTransferResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BookTransferResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BookTransferResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BookTransferResponse build()
-
-
-
-