Class Card
-
- All Implemented Interfaces:
public final class Card
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCard.BuilderA builder for Card.
public final classCard.FundingAccountDeprecated: Funding account for the card.
public final classCard.PinStatusIndicates if a card is blocked due a PIN status issue (e.g. excessive incorrect attempts).
public final classCard.StateCard state values:
CLOSED- Card will no longer approve authorizations. Closing a card cannot be undone.OPEN- Card will approve authorizations (if they match card and account parameters).PAUSED- Card will decline authorizations, but can be resumed at a later time.PENDING_FULFILLMENT- The initial state for cards of typePHYSICAL. The card is provisioned pending manufacturing and fulfillment. Cards in this state can accept authorizations for e-commerce purchases, but not for "Card Present" purchases where the physical card itself is present.PENDING_ACTIVATION- At regular intervals, cards of typePHYSICALin statePENDING_FULFILLMENTare sent to the card production warehouse and updated to statePENDING_ACTIVATION. Similar toPENDING_FULFILLMENT, cards in this state can be used for e-commerce transactions or can be added to mobile wallets. API clients should update the card's state toOPENonly after the cardholder confirms receipt of the card.
In sandbox, the same daily batch fulfillment occurs, but no cards are actually manufactured.
public final classCard.TypeCard types:
VIRTUAL- Card will authorize at any merchant and can be added to a digital wallet like Apple Pay or Google Pay (if the card program is digital wallet-enabled).PHYSICAL- Manufactured and sent to the cardholder. We offer white label branding, credit, ATM, PIN debit, chip/EMV, NFC and magstripe functionality. Reach out at lithic.com/contact for more information.SINGLE_USE- Card is closed upon first successful authorization.MERCHANT_LOCKED- Deprecated Card is locked to the first merchant that successfully authorizes the card.UNLOCKED- Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.DIGITAL_WALLET- Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier. final StringaccountToken()Globally unique identifier for the account to which the card belongs. final StringcardProgramToken()Globally unique identifier for the card program on which the card exists. final OffsetDateTimecreated()An RFC 3339 timestamp for when the card was created. final Card.FundingAccountfunding()Deprecated: Funding account for the card. final StringlastFour()Last four digits of the card number. final Card.PinStatuspinStatus()Indicates if a card is blocked due a PIN status issue (e.g. final LongspendLimit()Amount (in cents) to limit approved authorizations (e.g. final SpendLimitDurationspendLimitDuration()Spend limit duration values: ANNUALLY- Card will authorize transactions up to spend limit for the trailing year.FOREVER- Card will authorize only up to spend limit for the entire lifetime of the card.MONTHLY- Card will authorize transactions up to spend limit for the trailing month. To support recurring monthly payments, which can occur on different day every month, the time window we consider for monthly velocity starts 6 days after the current calendar date one month prior.TRANSACTION- Card will authorize multiple transactions if each individual transaction is under the spend limit.
final Card.Statestate()Card state values: CLOSED- Card will no longer approve authorizations. Closing a card cannot be undone.OPEN- Card will approve authorizations (if they match card and account parameters).PAUSED- Card will decline authorizations, but can be resumed at a later time.PENDING_FULFILLMENT- The initial state for cards of typePHYSICAL. The card is provisioned pending manufacturing and fulfillment. Cards in this state can accept authorizations for e-commerce purchases, but not for "Card Present" purchases where the physical card itself is present.PENDING_ACTIVATION- At regular intervals, cards of typePHYSICALin statePENDING_FULFILLMENTare sent to the card production warehouse and updated to statePENDING_ACTIVATION. Similar toPENDING_FULFILLMENT, cards in this state can be used for e-commerce transactions or can be added to mobile wallets. API clients should update the card's state toOPENonly after the cardholder confirms receipt of the card.
final Card.Typetype()Card types: VIRTUAL- Card will authorize at any merchant and can be added to a digital wallet like Apple Pay or Google Pay (if the card program is digital wallet-enabled).PHYSICAL- Manufactured and sent to the cardholder. We offer white label branding, credit, ATM, PIN debit, chip/EMV, NFC and magstripe functionality. Reach out at lithic.com/contact for more information.SINGLE_USE- Card is closed upon first successful authorization.MERCHANT_LOCKED- Deprecated Card is locked to the first merchant that successfully authorizes the card.UNLOCKED- Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.DIGITAL_WALLET- Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.
final Optional<List<String>>authRuleTokens()List of identifiers for the Auth Rule(s) that are applied on the card. final Optional<String>cardholderCurrency()3-character alphabetic ISO 4217 code for the currency of the cardholder. final Optional<String>cvv()Three digit cvv printed on the back of the card. final Optional<String>digitalCardArtToken()Specifies the digital card art to be displayed in the user’s digital wallet after tokenization. final Optional<String>expMonth()Two digit (MM) expiry month. final Optional<String>expYear()Four digit (yyyy) expiry year. final Optional<String>hostname()Hostname of card’s locked merchant (will be empty if not applicable). final Optional<String>memo()Friendly name to identify the card. final Optional<String>pan()Primary Account Number (PAN) (i.e. final Optional<List<String>>pendingCommands()Indicates if there are offline PIN changes pending card interaction with an offline PIN terminal. final Optional<String>productId()Only applicable to cards of type PHYSICAL.final Optional<String>replacementFor()If the card is a replacement for another card, the globally unique identifier for the card that was replaced. final JsonField<String>_token()Globally unique identifier. final JsonField<String>_accountToken()Globally unique identifier for the account to which the card belongs. final JsonField<String>_cardProgramToken()Globally unique identifier for the card program on which the card exists. final JsonField<OffsetDateTime>_created()An RFC 3339 timestamp for when the card was created. final JsonField<Card.FundingAccount>_funding()Deprecated: Funding account for the card. final JsonField<String>_lastFour()Last four digits of the card number. final JsonField<Card.PinStatus>_pinStatus()Indicates if a card is blocked due a PIN status issue (e.g. final JsonField<Long>_spendLimit()Amount (in cents) to limit approved authorizations (e.g. final JsonField<SpendLimitDuration>_spendLimitDuration()Spend limit duration values: ANNUALLY- Card will authorize transactions up to spend limit for the trailing year.FOREVER- Card will authorize only up to spend limit for the entire lifetime of the card.MONTHLY- Card will authorize transactions up to spend limit for the trailing month. To support recurring monthly payments, which can occur on different day every month, the time window we consider for monthly velocity starts 6 days after the current calendar date one month prior.TRANSACTION- Card will authorize multiple transactions if each individual transaction is under the spend limit.
final JsonField<Card.State>_state()Card state values: CLOSED- Card will no longer approve authorizations. Closing a card cannot be undone.OPEN- Card will approve authorizations (if they match card and account parameters).PAUSED- Card will decline authorizations, but can be resumed at a later time.PENDING_FULFILLMENT- The initial state for cards of typePHYSICAL. The card is provisioned pending manufacturing and fulfillment. Cards in this state can accept authorizations for e-commerce purchases, but not for "Card Present" purchases where the physical card itself is present.PENDING_ACTIVATION- At regular intervals, cards of typePHYSICALin statePENDING_FULFILLMENTare sent to the card production warehouse and updated to statePENDING_ACTIVATION. Similar toPENDING_FULFILLMENT, cards in this state can be used for e-commerce transactions or can be added to mobile wallets. API clients should update the card's state toOPENonly after the cardholder confirms receipt of the card.
final JsonField<Card.Type>_type()Card types: VIRTUAL- Card will authorize at any merchant and can be added to a digital wallet like Apple Pay or Google Pay (if the card program is digital wallet-enabled).PHYSICAL- Manufactured and sent to the cardholder. We offer white label branding, credit, ATM, PIN debit, chip/EMV, NFC and magstripe functionality. Reach out at lithic.com/contact for more information.SINGLE_USE- Card is closed upon first successful authorization.MERCHANT_LOCKED- Deprecated Card is locked to the first merchant that successfully authorizes the card.UNLOCKED- Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.DIGITAL_WALLET- Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.
final JsonField<List<String>>_authRuleTokens()List of identifiers for the Auth Rule(s) that are applied on the card. final JsonField<String>_cardholderCurrency()3-character alphabetic ISO 4217 code for the currency of the cardholder. final JsonField<String>_cvv()Three digit cvv printed on the back of the card. final JsonField<String>_digitalCardArtToken()Specifies the digital card art to be displayed in the user’s digital wallet after tokenization. final JsonField<String>_expMonth()Two digit (MM) expiry month. final JsonField<String>_expYear()Four digit (yyyy) expiry year. final JsonField<String>_hostname()Hostname of card’s locked merchant (will be empty if not applicable). final JsonField<String>_memo()Friendly name to identify the card. final JsonField<String>_pan()Primary Account Number (PAN) (i.e. final JsonField<List<String>>_pendingCommands()Indicates if there are offline PIN changes pending card interaction with an offline PIN terminal. final JsonField<String>_productId()Only applicable to cards of type PHYSICAL.final JsonField<String>_replacementFor()If the card is a replacement for another card, the globally unique identifier for the card that was replaced. final Map<String, JsonValue>_additionalProperties()final Cardvalidate()final Card.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Card.Builderbuilder()Returns a mutable builder for constructing an instance of Card. -
-
Method Detail
-
accountToken
final String accountToken()
Globally unique identifier for the account to which the card belongs.
-
cardProgramToken
final String cardProgramToken()
Globally unique identifier for the card program on which the card exists.
-
created
final OffsetDateTime created()
An RFC 3339 timestamp for when the card was created. UTC time zone.
-
funding
final Card.FundingAccount funding()
Deprecated: Funding account for the card.
-
pinStatus
final Card.PinStatus pinStatus()
Indicates if a card is blocked due a PIN status issue (e.g. excessive incorrect attempts).
-
spendLimit
final Long spendLimit()
Amount (in cents) to limit approved authorizations (e.g. 100000 would be a $1,000 limit). Transaction requests above the spend limit will be declined.
-
spendLimitDuration
final SpendLimitDuration spendLimitDuration()
Spend limit duration values:
ANNUALLY- Card will authorize transactions up to spend limit for the trailing year.FOREVER- Card will authorize only up to spend limit for the entire lifetime of the card.MONTHLY- Card will authorize transactions up to spend limit for the trailing month. To support recurring monthly payments, which can occur on different day every month, the time window we consider for monthly velocity starts 6 days after the current calendar date one month prior.TRANSACTION- Card will authorize multiple transactions if each individual transaction is under the spend limit.
-
state
final Card.State state()
Card state values:
CLOSED- Card will no longer approve authorizations. Closing a card cannot be undone.OPEN- Card will approve authorizations (if they match card and account parameters).PAUSED- Card will decline authorizations, but can be resumed at a later time.PENDING_FULFILLMENT- The initial state for cards of typePHYSICAL. The card is provisioned pending manufacturing and fulfillment. Cards in this state can accept authorizations for e-commerce purchases, but not for "Card Present" purchases where the physical card itself is present.PENDING_ACTIVATION- At regular intervals, cards of typePHYSICALin statePENDING_FULFILLMENTare sent to the card production warehouse and updated to statePENDING_ACTIVATION. Similar toPENDING_FULFILLMENT, cards in this state can be used for e-commerce transactions or can be added to mobile wallets. API clients should update the card's state toOPENonly after the cardholder confirms receipt of the card.
In sandbox, the same daily batch fulfillment occurs, but no cards are actually manufactured.
-
type
final Card.Type type()
Card types:
VIRTUAL- Card will authorize at any merchant and can be added to a digital wallet like Apple Pay or Google Pay (if the card program is digital wallet-enabled).PHYSICAL- Manufactured and sent to the cardholder. We offer white label branding, credit, ATM, PIN debit, chip/EMV, NFC and magstripe functionality. Reach out at lithic.com/contact for more information.SINGLE_USE- Card is closed upon first successful authorization.MERCHANT_LOCKED- Deprecated Card is locked to the first merchant that successfully authorizes the card.UNLOCKED- Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.DIGITAL_WALLET- Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.
-
authRuleTokens
@Deprecated(message = "deprecated") final Optional<List<String>> authRuleTokens()
List of identifiers for the Auth Rule(s) that are applied on the card. This field is deprecated and will no longer be populated in the
Cardobject. The key will be removed from the schema in a future release. Use the/auth_rulesendpoints to fetch Auth Rule information instead.
-
cardholderCurrency
final Optional<String> cardholderCurrency()
3-character alphabetic ISO 4217 code for the currency of the cardholder.
-
digitalCardArtToken
final Optional<String> digitalCardArtToken()
Specifies the digital card art to be displayed in the user’s digital wallet after tokenization. This artwork must be approved by Mastercard and configured by Lithic to use. See Flexible Card Art Guide.
-
hostname
final Optional<String> hostname()
Hostname of card’s locked merchant (will be empty if not applicable).
-
pan
final Optional<String> pan()
Primary Account Number (PAN) (i.e. the card number). Customers must be PCI compliant to have PAN returned as a field in production. Please contact [email protected] for questions.
-
pendingCommands
final Optional<List<String>> pendingCommands()
Indicates if there are offline PIN changes pending card interaction with an offline PIN terminal. Possible commands are: CHANGE_PIN, UNBLOCK_PIN. Applicable only to cards issued in markets supporting offline PINs.
-
productId
final Optional<String> productId()
Only applicable to cards of type
PHYSICAL. This must be configured with Lithic before use. Specifies the configuration (i.e., physical card art) that the card should be manufactured with.
-
replacementFor
final Optional<String> replacementFor()
If the card is a replacement for another card, the globally unique identifier for the card that was replaced.
-
_accountToken
final JsonField<String> _accountToken()
Globally unique identifier for the account to which the card belongs.
-
_cardProgramToken
final JsonField<String> _cardProgramToken()
Globally unique identifier for the card program on which the card exists.
-
_created
final JsonField<OffsetDateTime> _created()
An RFC 3339 timestamp for when the card was created. UTC time zone.
-
_funding
final JsonField<Card.FundingAccount> _funding()
Deprecated: Funding account for the card.
-
_pinStatus
final JsonField<Card.PinStatus> _pinStatus()
Indicates if a card is blocked due a PIN status issue (e.g. excessive incorrect attempts).
-
_spendLimit
final JsonField<Long> _spendLimit()
Amount (in cents) to limit approved authorizations (e.g. 100000 would be a $1,000 limit). Transaction requests above the spend limit will be declined.
-
_spendLimitDuration
final JsonField<SpendLimitDuration> _spendLimitDuration()
Spend limit duration values:
ANNUALLY- Card will authorize transactions up to spend limit for the trailing year.FOREVER- Card will authorize only up to spend limit for the entire lifetime of the card.MONTHLY- Card will authorize transactions up to spend limit for the trailing month. To support recurring monthly payments, which can occur on different day every month, the time window we consider for monthly velocity starts 6 days after the current calendar date one month prior.TRANSACTION- Card will authorize multiple transactions if each individual transaction is under the spend limit.
-
_state
final JsonField<Card.State> _state()
Card state values:
CLOSED- Card will no longer approve authorizations. Closing a card cannot be undone.OPEN- Card will approve authorizations (if they match card and account parameters).PAUSED- Card will decline authorizations, but can be resumed at a later time.PENDING_FULFILLMENT- The initial state for cards of typePHYSICAL. The card is provisioned pending manufacturing and fulfillment. Cards in this state can accept authorizations for e-commerce purchases, but not for "Card Present" purchases where the physical card itself is present.PENDING_ACTIVATION- At regular intervals, cards of typePHYSICALin statePENDING_FULFILLMENTare sent to the card production warehouse and updated to statePENDING_ACTIVATION. Similar toPENDING_FULFILLMENT, cards in this state can be used for e-commerce transactions or can be added to mobile wallets. API clients should update the card's state toOPENonly after the cardholder confirms receipt of the card.
In sandbox, the same daily batch fulfillment occurs, but no cards are actually manufactured.
-
_type
final JsonField<Card.Type> _type()
Card types:
VIRTUAL- Card will authorize at any merchant and can be added to a digital wallet like Apple Pay or Google Pay (if the card program is digital wallet-enabled).PHYSICAL- Manufactured and sent to the cardholder. We offer white label branding, credit, ATM, PIN debit, chip/EMV, NFC and magstripe functionality. Reach out at lithic.com/contact for more information.SINGLE_USE- Card is closed upon first successful authorization.MERCHANT_LOCKED- Deprecated Card is locked to the first merchant that successfully authorizes the card.UNLOCKED- Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.DIGITAL_WALLET- Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.
-
_authRuleTokens
@Deprecated(message = "deprecated") final JsonField<List<String>> _authRuleTokens()
List of identifiers for the Auth Rule(s) that are applied on the card. This field is deprecated and will no longer be populated in the
Cardobject. The key will be removed from the schema in a future release. Use the/auth_rulesendpoints to fetch Auth Rule information instead.
-
_cardholderCurrency
final JsonField<String> _cardholderCurrency()
3-character alphabetic ISO 4217 code for the currency of the cardholder.
-
_digitalCardArtToken
final JsonField<String> _digitalCardArtToken()
Specifies the digital card art to be displayed in the user’s digital wallet after tokenization. This artwork must be approved by Mastercard and configured by Lithic to use. See Flexible Card Art Guide.
-
_hostname
final JsonField<String> _hostname()
Hostname of card’s locked merchant (will be empty if not applicable).
-
_pan
final JsonField<String> _pan()
Primary Account Number (PAN) (i.e. the card number). Customers must be PCI compliant to have PAN returned as a field in production. Please contact [email protected] for questions.
-
_pendingCommands
final JsonField<List<String>> _pendingCommands()
Indicates if there are offline PIN changes pending card interaction with an offline PIN terminal. Possible commands are: CHANGE_PIN, UNBLOCK_PIN. Applicable only to cards issued in markets supporting offline PINs.
-
_productId
final JsonField<String> _productId()
Only applicable to cards of type
PHYSICAL. This must be configured with Lithic before use. Specifies the configuration (i.e., physical card art) that the card should be manufactured with.
-
_replacementFor
final JsonField<String> _replacementFor()
If the card is a replacement for another card, the globally unique identifier for the card that was replaced.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Card.Builder toBuilder()
-
builder
final static Card.Builder builder()
Returns a mutable builder for constructing an instance of Card.
The following fields are required:
.token() .accountToken() .cardProgramToken() .created() .funding() .lastFour() .pinStatus() .spendLimit() .spendLimitDuration() .state() .type()
-
-
-