Class Card.Builder

  • All Implemented Interfaces:

    
    public final class Card.Builder
    
                        

    A builder for Card.

    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
    • Field Summary

      Fields 
      Modifier and Type Field Description
    • Constructor Summary

      Constructors 
      Constructor Description
    • Enum Constant Summary

      Enum Constants 
      Enum Constant Description
    • Method Summary

      Modifier and Type Method Description
      final Card.Builder token(String token) Globally unique identifier.
      final Card.Builder token(JsonField<String> token) Globally unique identifier.
      final Card.Builder accountToken(String accountToken) Globally unique identifier for the account to which the card belongs.
      final Card.Builder accountToken(JsonField<String> accountToken) Globally unique identifier for the account to which the card belongs.
      final Card.Builder cardProgramToken(String cardProgramToken) Globally unique identifier for the card program on which the card exists.
      final Card.Builder cardProgramToken(JsonField<String> cardProgramToken) Globally unique identifier for the card program on which the card exists.
      final Card.Builder created(OffsetDateTime created) An RFC 3339 timestamp for when the card was created.
      final Card.Builder created(JsonField<OffsetDateTime> created) An RFC 3339 timestamp for when the card was created.
      final Card.Builder funding(Card.FundingAccount funding) Deprecated: Funding account for the card.
      final Card.Builder funding(JsonField<Card.FundingAccount> funding) Deprecated: Funding account for the card.
      final Card.Builder lastFour(String lastFour) Last four digits of the card number.
      final Card.Builder lastFour(JsonField<String> lastFour) Last four digits of the card number.
      final Card.Builder pinStatus(Card.PinStatus pinStatus) Indicates if a card is blocked due a PIN status issue (e.g.
      final Card.Builder pinStatus(JsonField<Card.PinStatus> pinStatus) Indicates if a card is blocked due a PIN status issue (e.g.
      final Card.Builder spendLimit(Long spendLimit) Amount (in cents) to limit approved authorizations (e.g.
      final Card.Builder spendLimit(JsonField<Long> spendLimit) Amount (in cents) to limit approved authorizations (e.g.
      final Card.Builder spendLimitDuration(SpendLimitDuration spendLimitDuration) Spend limit duration values:
      • ANNUALLY - Card will authorize transactions up to spend limit for the trailing year.

      • FOREVER - Card will authorize only up to spend limit for the entire lifetime of the card.

      • MONTHLY - Card will authorize transactions up to spend limit for the trailing month. To support recurring monthly payments, which can occur on different day every month, the time window we consider for monthly velocity starts 6 days after the current calendar date one month prior.

      • TRANSACTION - Card will authorize multiple transactions if each individual transaction is under the spend limit.

      final Card.Builder spendLimitDuration(JsonField<SpendLimitDuration> spendLimitDuration) Spend limit duration values:
      • ANNUALLY - Card will authorize transactions up to spend limit for the trailing year.

      • FOREVER - Card will authorize only up to spend limit for the entire lifetime of the card.

      • MONTHLY - Card will authorize transactions up to spend limit for the trailing month. To support recurring monthly payments, which can occur on different day every month, the time window we consider for monthly velocity starts 6 days after the current calendar date one month prior.

      • TRANSACTION - Card will authorize multiple transactions if each individual transaction is under the spend limit.

      final Card.Builder state(Card.State state) Card state values:
      • CLOSED - Card will no longer approve authorizations. Closing a card cannot be undone.

      • OPEN - Card will approve authorizations (if they match card and account parameters).

      • PAUSED - Card will decline authorizations, but can be resumed at a later time.

      • PENDING_FULFILLMENT - The initial state for cards of type PHYSICAL. The card is provisioned pending manufacturing and fulfillment. Cards in this state can accept authorizations for e-commerce purchases, but not for "Card Present" purchases where the physical card itself is present.

      • PENDING_ACTIVATION - At regular intervals, cards of type PHYSICAL in state PENDING_FULFILLMENT are sent to the card production warehouse and updated to state PENDING_ACTIVATION . Similar to PENDING_FULFILLMENT, cards in this state can be used for e-commerce transactions or can be added to mobile wallets. API clients should update the card's state to OPEN only after the cardholder confirms receipt of the card.

      In sandbox, the same daily batch fulfillment occurs, but no cards are actually manufactured.
      final Card.Builder state(JsonField<Card.State> state) Card state values:
      • CLOSED - Card will no longer approve authorizations. Closing a card cannot be undone.

      • OPEN - Card will approve authorizations (if they match card and account parameters).

      • PAUSED - Card will decline authorizations, but can be resumed at a later time.

      • PENDING_FULFILLMENT - The initial state for cards of type PHYSICAL. The card is provisioned pending manufacturing and fulfillment. Cards in this state can accept authorizations for e-commerce purchases, but not for "Card Present" purchases where the physical card itself is present.

      • PENDING_ACTIVATION - At regular intervals, cards of type PHYSICAL in state PENDING_FULFILLMENT are sent to the card production warehouse and updated to state PENDING_ACTIVATION . Similar to PENDING_FULFILLMENT, cards in this state can be used for e-commerce transactions or can be added to mobile wallets. API clients should update the card's state to OPEN only after the cardholder confirms receipt of the card.

      In sandbox, the same daily batch fulfillment occurs, but no cards are actually manufactured.
      final Card.Builder type(Card.Type type) Card types:
      • VIRTUAL - Card will authorize at any merchant and can be added to a digital wallet like Apple Pay or Google Pay (if the card program is digital wallet-enabled).

      • PHYSICAL - Manufactured and sent to the cardholder. We offer white label branding, credit, ATM, PIN debit, chip/EMV, NFC and magstripe functionality. Reach out at lithic.com/contact for more information.

      • SINGLE_USE - Card is closed upon first successful authorization.

      • MERCHANT_LOCKED - Deprecated Card is locked to the first merchant that successfully authorizes the card.

      • UNLOCKED - Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.

      • DIGITAL_WALLET - Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.

      final Card.Builder type(JsonField<Card.Type> type) Card types:
      • VIRTUAL - Card will authorize at any merchant and can be added to a digital wallet like Apple Pay or Google Pay (if the card program is digital wallet-enabled).

      • PHYSICAL - Manufactured and sent to the cardholder. We offer white label branding, credit, ATM, PIN debit, chip/EMV, NFC and magstripe functionality. Reach out at lithic.com/contact for more information.

      • SINGLE_USE - Card is closed upon first successful authorization.

      • MERCHANT_LOCKED - Deprecated Card is locked to the first merchant that successfully authorizes the card.

      • UNLOCKED - Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.

      • DIGITAL_WALLET - Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.

      final Card.Builder authRuleTokens(List<String> authRuleTokens) List of identifiers for the Auth Rule(s) that are applied on the card.
      final Card.Builder authRuleTokens(JsonField<List<String>> authRuleTokens) List of identifiers for the Auth Rule(s) that are applied on the card.
      final Card.Builder addAuthRuleToken(String authRuleToken) List of identifiers for the Auth Rule(s) that are applied on the card.
      final Card.Builder cardholderCurrency(String cardholderCurrency) 3-character alphabetic ISO 4217 code for the currency of the cardholder.
      final Card.Builder cardholderCurrency(JsonField<String> cardholderCurrency) 3-character alphabetic ISO 4217 code for the currency of the cardholder.
      final Card.Builder cvv(String cvv) Three digit cvv printed on the back of the card.
      final Card.Builder cvv(JsonField<String> cvv) Three digit cvv printed on the back of the card.
      final Card.Builder digitalCardArtToken(String digitalCardArtToken) Specifies the digital card art to be displayed in the user’s digital wallet after tokenization.
      final Card.Builder digitalCardArtToken(JsonField<String> digitalCardArtToken) Specifies the digital card art to be displayed in the user’s digital wallet after tokenization.
      final Card.Builder expMonth(String expMonth) Two digit (MM) expiry month.
      final Card.Builder expMonth(JsonField<String> expMonth) Two digit (MM) expiry month.
      final Card.Builder expYear(String expYear) Four digit (yyyy) expiry year.
      final Card.Builder expYear(JsonField<String> expYear) Four digit (yyyy) expiry year.
      final Card.Builder hostname(String hostname) Hostname of card’s locked merchant (will be empty if not applicable).
      final Card.Builder hostname(JsonField<String> hostname) Hostname of card’s locked merchant (will be empty if not applicable).
      final Card.Builder memo(String memo) Friendly name to identify the card.
      final Card.Builder memo(JsonField<String> memo) Friendly name to identify the card.
      final Card.Builder pan(String pan) Primary Account Number (PAN) (i.e.
      final Card.Builder pan(JsonField<String> pan) Primary Account Number (PAN) (i.e.
      final Card.Builder pendingCommands(List<String> pendingCommands) Indicates if there are offline PIN changes pending card interaction with an offline PIN terminal.
      final Card.Builder pendingCommands(JsonField<List<String>> pendingCommands) Indicates if there are offline PIN changes pending card interaction with an offline PIN terminal.
      final Card.Builder addPendingCommand(String pendingCommand) Indicates if there are offline PIN changes pending card interaction with an offline PIN terminal.
      final Card.Builder productId(String productId) Only applicable to cards of type PHYSICAL.
      final Card.Builder productId(JsonField<String> productId) Only applicable to cards of type PHYSICAL.
      final Card.Builder replacementFor(String replacementFor) If the card is a replacement for another card, the globally unique identifier for the card that was replaced.
      final Card.Builder replacementFor(Optional<String> replacementFor) If the card is a replacement for another card, the globally unique identifier for the card that was replaced.
      final Card.Builder replacementFor(JsonField<String> replacementFor) If the card is a replacement for another card, the globally unique identifier for the card that was replaced.
      final Card.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
      final Card.Builder putAdditionalProperty(String key, JsonValue value)
      final Card.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
      final Card.Builder removeAdditionalProperty(String key)
      final Card.Builder removeAllAdditionalProperties(Set<String> keys)
      final Card build()
      • Methods inherited from class java.lang.Object

        clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
    • Constructor Detail

    • Method Detail

      • spendLimit

         final Card.Builder spendLimit(Long spendLimit)

        Amount (in cents) to limit approved authorizations (e.g. 100000 would be a $1,000 limit). Transaction requests above the spend limit will be declined.

      • spendLimit

         final Card.Builder spendLimit(JsonField<Long> spendLimit)

        Amount (in cents) to limit approved authorizations (e.g. 100000 would be a $1,000 limit). Transaction requests above the spend limit will be declined.

      • spendLimitDuration

         final Card.Builder spendLimitDuration(SpendLimitDuration spendLimitDuration)

        Spend limit duration values:

        • ANNUALLY - Card will authorize transactions up to spend limit for the trailing year.

        • FOREVER - Card will authorize only up to spend limit for the entire lifetime of the card.

        • MONTHLY - Card will authorize transactions up to spend limit for the trailing month. To support recurring monthly payments, which can occur on different day every month, the time window we consider for monthly velocity starts 6 days after the current calendar date one month prior.

        • TRANSACTION - Card will authorize multiple transactions if each individual transaction is under the spend limit.

      • spendLimitDuration

         final Card.Builder spendLimitDuration(JsonField<SpendLimitDuration> spendLimitDuration)

        Spend limit duration values:

        • ANNUALLY - Card will authorize transactions up to spend limit for the trailing year.

        • FOREVER - Card will authorize only up to spend limit for the entire lifetime of the card.

        • MONTHLY - Card will authorize transactions up to spend limit for the trailing month. To support recurring monthly payments, which can occur on different day every month, the time window we consider for monthly velocity starts 6 days after the current calendar date one month prior.

        • TRANSACTION - Card will authorize multiple transactions if each individual transaction is under the spend limit.

      • state

         final Card.Builder state(Card.State state)

        Card state values:

        • CLOSED - Card will no longer approve authorizations. Closing a card cannot be undone.

        • OPEN - Card will approve authorizations (if they match card and account parameters).

        • PAUSED - Card will decline authorizations, but can be resumed at a later time.

        • PENDING_FULFILLMENT - The initial state for cards of type PHYSICAL. The card is provisioned pending manufacturing and fulfillment. Cards in this state can accept authorizations for e-commerce purchases, but not for "Card Present" purchases where the physical card itself is present.

        • PENDING_ACTIVATION - At regular intervals, cards of type PHYSICAL in state PENDING_FULFILLMENT are sent to the card production warehouse and updated to state PENDING_ACTIVATION . Similar to PENDING_FULFILLMENT, cards in this state can be used for e-commerce transactions or can be added to mobile wallets. API clients should update the card's state to OPEN only after the cardholder confirms receipt of the card.

        In sandbox, the same daily batch fulfillment occurs, but no cards are actually manufactured.

      • state

         final Card.Builder state(JsonField<Card.State> state)

        Card state values:

        • CLOSED - Card will no longer approve authorizations. Closing a card cannot be undone.

        • OPEN - Card will approve authorizations (if they match card and account parameters).

        • PAUSED - Card will decline authorizations, but can be resumed at a later time.

        • PENDING_FULFILLMENT - The initial state for cards of type PHYSICAL. The card is provisioned pending manufacturing and fulfillment. Cards in this state can accept authorizations for e-commerce purchases, but not for "Card Present" purchases where the physical card itself is present.

        • PENDING_ACTIVATION - At regular intervals, cards of type PHYSICAL in state PENDING_FULFILLMENT are sent to the card production warehouse and updated to state PENDING_ACTIVATION . Similar to PENDING_FULFILLMENT, cards in this state can be used for e-commerce transactions or can be added to mobile wallets. API clients should update the card's state to OPEN only after the cardholder confirms receipt of the card.

        In sandbox, the same daily batch fulfillment occurs, but no cards are actually manufactured.

      • type

         final Card.Builder type(Card.Type type)

        Card types:

        • VIRTUAL - Card will authorize at any merchant and can be added to a digital wallet like Apple Pay or Google Pay (if the card program is digital wallet-enabled).

        • PHYSICAL - Manufactured and sent to the cardholder. We offer white label branding, credit, ATM, PIN debit, chip/EMV, NFC and magstripe functionality. Reach out at lithic.com/contact for more information.

        • SINGLE_USE - Card is closed upon first successful authorization.

        • MERCHANT_LOCKED - Deprecated Card is locked to the first merchant that successfully authorizes the card.

        • UNLOCKED - Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.

        • DIGITAL_WALLET - Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.

      • type

         final Card.Builder type(JsonField<Card.Type> type)

        Card types:

        • VIRTUAL - Card will authorize at any merchant and can be added to a digital wallet like Apple Pay or Google Pay (if the card program is digital wallet-enabled).

        • PHYSICAL - Manufactured and sent to the cardholder. We offer white label branding, credit, ATM, PIN debit, chip/EMV, NFC and magstripe functionality. Reach out at lithic.com/contact for more information.

        • SINGLE_USE - Card is closed upon first successful authorization.

        • MERCHANT_LOCKED - Deprecated Card is locked to the first merchant that successfully authorizes the card.

        • UNLOCKED - Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.

        • DIGITAL_WALLET - Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.

      • authRuleTokens

        @Deprecated(message = "deprecated") final Card.Builder authRuleTokens(List<String> authRuleTokens)

        List of identifiers for the Auth Rule(s) that are applied on the card. This field is deprecated and will no longer be populated in the Card object. The key will be removed from the schema in a future release. Use the /auth_rules endpoints to fetch Auth Rule information instead.

      • authRuleTokens

        @Deprecated(message = "deprecated") final Card.Builder authRuleTokens(JsonField<List<String>> authRuleTokens)

        List of identifiers for the Auth Rule(s) that are applied on the card. This field is deprecated and will no longer be populated in the Card object. The key will be removed from the schema in a future release. Use the /auth_rules endpoints to fetch Auth Rule information instead.

      • addAuthRuleToken

        @Deprecated(message = "deprecated") final Card.Builder addAuthRuleToken(String authRuleToken)

        List of identifiers for the Auth Rule(s) that are applied on the card. This field is deprecated and will no longer be populated in the Card object. The key will be removed from the schema in a future release. Use the /auth_rules endpoints to fetch Auth Rule information instead.

      • pan

         final Card.Builder pan(String pan)

        Primary Account Number (PAN) (i.e. the card number). Customers must be PCI compliant to have PAN returned as a field in production. Please contact [email protected] for questions.

      • pendingCommands

         final Card.Builder pendingCommands(List<String> pendingCommands)

        Indicates if there are offline PIN changes pending card interaction with an offline PIN terminal. Possible commands are: CHANGE_PIN, UNBLOCK_PIN. Applicable only to cards issued in markets supporting offline PINs.

      • pendingCommands

         final Card.Builder pendingCommands(JsonField<List<String>> pendingCommands)

        Indicates if there are offline PIN changes pending card interaction with an offline PIN terminal. Possible commands are: CHANGE_PIN, UNBLOCK_PIN. Applicable only to cards issued in markets supporting offline PINs.

      • addPendingCommand

         final Card.Builder addPendingCommand(String pendingCommand)

        Indicates if there are offline PIN changes pending card interaction with an offline PIN terminal. Possible commands are: CHANGE_PIN, UNBLOCK_PIN. Applicable only to cards issued in markets supporting offline PINs.

      • productId

         final Card.Builder productId(String productId)

        Only applicable to cards of type PHYSICAL. This must be configured with Lithic before use. Specifies the configuration (i.e., physical card art) that the card should be manufactured with.

      • productId

         final Card.Builder productId(JsonField<String> productId)

        Only applicable to cards of type PHYSICAL. This must be configured with Lithic before use. Specifies the configuration (i.e., physical card art) that the card should be manufactured with.

      • replacementFor

         final Card.Builder replacementFor(String replacementFor)

        If the card is a replacement for another card, the globally unique identifier for the card that was replaced.