Class Card.Builder
-
- All Implemented Interfaces:
public final class Card.BuilderA builder for Card.
-
-
Method Summary
Modifier and Type Method Description final Card.Buildertoken(String token)Globally unique identifier. final Card.Buildertoken(JsonField<String> token)Globally unique identifier. final Card.BuilderaccountToken(String accountToken)Globally unique identifier for the account to which the card belongs. final Card.BuilderaccountToken(JsonField<String> accountToken)Globally unique identifier for the account to which the card belongs. final Card.BuildercardProgramToken(String cardProgramToken)Globally unique identifier for the card program on which the card exists. final Card.BuildercardProgramToken(JsonField<String> cardProgramToken)Globally unique identifier for the card program on which the card exists. final Card.Buildercreated(OffsetDateTime created)An RFC 3339 timestamp for when the card was created. final Card.Buildercreated(JsonField<OffsetDateTime> created)An RFC 3339 timestamp for when the card was created. final Card.Builderfunding(Card.FundingAccount funding)Deprecated: Funding account for the card. final Card.Builderfunding(JsonField<Card.FundingAccount> funding)Deprecated: Funding account for the card. final Card.BuilderlastFour(String lastFour)Last four digits of the card number. final Card.BuilderlastFour(JsonField<String> lastFour)Last four digits of the card number. final Card.BuilderpinStatus(Card.PinStatus pinStatus)Indicates if a card is blocked due a PIN status issue (e.g. final Card.BuilderpinStatus(JsonField<Card.PinStatus> pinStatus)Indicates if a card is blocked due a PIN status issue (e.g. final Card.BuilderspendLimit(Long spendLimit)Amount (in cents) to limit approved authorizations (e.g. final Card.BuilderspendLimit(JsonField<Long> spendLimit)Amount (in cents) to limit approved authorizations (e.g. final Card.BuilderspendLimitDuration(SpendLimitDuration spendLimitDuration)Spend limit duration values: ANNUALLY- Card will authorize transactions up to spend limit for the trailing year.FOREVER- Card will authorize only up to spend limit for the entire lifetime of the card.MONTHLY- Card will authorize transactions up to spend limit for the trailing month. To support recurring monthly payments, which can occur on different day every month, the time window we consider for monthly velocity starts 6 days after the current calendar date one month prior.TRANSACTION- Card will authorize multiple transactions if each individual transaction is under the spend limit.
final Card.BuilderspendLimitDuration(JsonField<SpendLimitDuration> spendLimitDuration)Spend limit duration values: ANNUALLY- Card will authorize transactions up to spend limit for the trailing year.FOREVER- Card will authorize only up to spend limit for the entire lifetime of the card.MONTHLY- Card will authorize transactions up to spend limit for the trailing month. To support recurring monthly payments, which can occur on different day every month, the time window we consider for monthly velocity starts 6 days after the current calendar date one month prior.TRANSACTION- Card will authorize multiple transactions if each individual transaction is under the spend limit.
final Card.Builderstate(Card.State state)Card state values: CLOSED- Card will no longer approve authorizations. Closing a card cannot be undone.OPEN- Card will approve authorizations (if they match card and account parameters).PAUSED- Card will decline authorizations, but can be resumed at a later time.PENDING_FULFILLMENT- The initial state for cards of typePHYSICAL. The card is provisioned pending manufacturing and fulfillment. Cards in this state can accept authorizations for e-commerce purchases, but not for "Card Present" purchases where the physical card itself is present.PENDING_ACTIVATION- At regular intervals, cards of typePHYSICALin statePENDING_FULFILLMENTare sent to the card production warehouse and updated to statePENDING_ACTIVATION. Similar toPENDING_FULFILLMENT, cards in this state can be used for e-commerce transactions or can be added to mobile wallets. API clients should update the card's state toOPENonly after the cardholder confirms receipt of the card.
final Card.Builderstate(JsonField<Card.State> state)Card state values: CLOSED- Card will no longer approve authorizations. Closing a card cannot be undone.OPEN- Card will approve authorizations (if they match card and account parameters).PAUSED- Card will decline authorizations, but can be resumed at a later time.PENDING_FULFILLMENT- The initial state for cards of typePHYSICAL. The card is provisioned pending manufacturing and fulfillment. Cards in this state can accept authorizations for e-commerce purchases, but not for "Card Present" purchases where the physical card itself is present.PENDING_ACTIVATION- At regular intervals, cards of typePHYSICALin statePENDING_FULFILLMENTare sent to the card production warehouse and updated to statePENDING_ACTIVATION. Similar toPENDING_FULFILLMENT, cards in this state can be used for e-commerce transactions or can be added to mobile wallets. API clients should update the card's state toOPENonly after the cardholder confirms receipt of the card.
final Card.Buildertype(Card.Type type)Card types: VIRTUAL- Card will authorize at any merchant and can be added to a digital wallet like Apple Pay or Google Pay (if the card program is digital wallet-enabled).PHYSICAL- Manufactured and sent to the cardholder. We offer white label branding, credit, ATM, PIN debit, chip/EMV, NFC and magstripe functionality. Reach out at lithic.com/contact for more information.SINGLE_USE- Card is closed upon first successful authorization.MERCHANT_LOCKED- Deprecated Card is locked to the first merchant that successfully authorizes the card.UNLOCKED- Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.DIGITAL_WALLET- Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.
final Card.Buildertype(JsonField<Card.Type> type)Card types: VIRTUAL- Card will authorize at any merchant and can be added to a digital wallet like Apple Pay or Google Pay (if the card program is digital wallet-enabled).PHYSICAL- Manufactured and sent to the cardholder. We offer white label branding, credit, ATM, PIN debit, chip/EMV, NFC and magstripe functionality. Reach out at lithic.com/contact for more information.SINGLE_USE- Card is closed upon first successful authorization.MERCHANT_LOCKED- Deprecated Card is locked to the first merchant that successfully authorizes the card.UNLOCKED- Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.DIGITAL_WALLET- Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.
final Card.BuilderauthRuleTokens(List<String> authRuleTokens)List of identifiers for the Auth Rule(s) that are applied on the card. final Card.BuilderauthRuleTokens(JsonField<List<String>> authRuleTokens)List of identifiers for the Auth Rule(s) that are applied on the card. final Card.BuilderaddAuthRuleToken(String authRuleToken)List of identifiers for the Auth Rule(s) that are applied on the card. final Card.BuildercardholderCurrency(String cardholderCurrency)3-character alphabetic ISO 4217 code for the currency of the cardholder. final Card.BuildercardholderCurrency(JsonField<String> cardholderCurrency)3-character alphabetic ISO 4217 code for the currency of the cardholder. final Card.Buildercvv(String cvv)Three digit cvv printed on the back of the card. final Card.Buildercvv(JsonField<String> cvv)Three digit cvv printed on the back of the card. final Card.BuilderdigitalCardArtToken(String digitalCardArtToken)Specifies the digital card art to be displayed in the user’s digital wallet after tokenization. final Card.BuilderdigitalCardArtToken(JsonField<String> digitalCardArtToken)Specifies the digital card art to be displayed in the user’s digital wallet after tokenization. final Card.BuilderexpMonth(String expMonth)Two digit (MM) expiry month. final Card.BuilderexpMonth(JsonField<String> expMonth)Two digit (MM) expiry month. final Card.BuilderexpYear(String expYear)Four digit (yyyy) expiry year. final Card.BuilderexpYear(JsonField<String> expYear)Four digit (yyyy) expiry year. final Card.Builderhostname(String hostname)Hostname of card’s locked merchant (will be empty if not applicable). final Card.Builderhostname(JsonField<String> hostname)Hostname of card’s locked merchant (will be empty if not applicable). final Card.Buildermemo(String memo)Friendly name to identify the card. final Card.Buildermemo(JsonField<String> memo)Friendly name to identify the card. final Card.Builderpan(String pan)Primary Account Number (PAN) (i.e. final Card.Builderpan(JsonField<String> pan)Primary Account Number (PAN) (i.e. final Card.BuilderpendingCommands(List<String> pendingCommands)Indicates if there are offline PIN changes pending card interaction with an offline PIN terminal. final Card.BuilderpendingCommands(JsonField<List<String>> pendingCommands)Indicates if there are offline PIN changes pending card interaction with an offline PIN terminal. final Card.BuilderaddPendingCommand(String pendingCommand)Indicates if there are offline PIN changes pending card interaction with an offline PIN terminal. final Card.BuilderproductId(String productId)Only applicable to cards of type PHYSICAL.final Card.BuilderproductId(JsonField<String> productId)Only applicable to cards of type PHYSICAL.final Card.BuilderreplacementFor(String replacementFor)If the card is a replacement for another card, the globally unique identifier for the card that was replaced. final Card.BuilderreplacementFor(Optional<String> replacementFor)If the card is a replacement for another card, the globally unique identifier for the card that was replaced. final Card.BuilderreplacementFor(JsonField<String> replacementFor)If the card is a replacement for another card, the globally unique identifier for the card that was replaced. final Card.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Card.BuilderputAdditionalProperty(String key, JsonValue value)final Card.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Card.BuilderremoveAdditionalProperty(String key)final Card.BuilderremoveAllAdditionalProperties(Set<String> keys)final Cardbuild()-
-
Method Detail
-
token
final Card.Builder token(String token)
Globally unique identifier.
-
token
final Card.Builder token(JsonField<String> token)
Globally unique identifier.
-
accountToken
final Card.Builder accountToken(String accountToken)
Globally unique identifier for the account to which the card belongs.
-
accountToken
final Card.Builder accountToken(JsonField<String> accountToken)
Globally unique identifier for the account to which the card belongs.
-
cardProgramToken
final Card.Builder cardProgramToken(String cardProgramToken)
Globally unique identifier for the card program on which the card exists.
-
cardProgramToken
final Card.Builder cardProgramToken(JsonField<String> cardProgramToken)
Globally unique identifier for the card program on which the card exists.
-
created
final Card.Builder created(OffsetDateTime created)
An RFC 3339 timestamp for when the card was created. UTC time zone.
-
created
final Card.Builder created(JsonField<OffsetDateTime> created)
An RFC 3339 timestamp for when the card was created. UTC time zone.
-
funding
final Card.Builder funding(Card.FundingAccount funding)
Deprecated: Funding account for the card.
-
funding
final Card.Builder funding(JsonField<Card.FundingAccount> funding)
Deprecated: Funding account for the card.
-
lastFour
final Card.Builder lastFour(String lastFour)
Last four digits of the card number.
-
lastFour
final Card.Builder lastFour(JsonField<String> lastFour)
Last four digits of the card number.
-
pinStatus
final Card.Builder pinStatus(Card.PinStatus pinStatus)
Indicates if a card is blocked due a PIN status issue (e.g. excessive incorrect attempts).
-
pinStatus
final Card.Builder pinStatus(JsonField<Card.PinStatus> pinStatus)
Indicates if a card is blocked due a PIN status issue (e.g. excessive incorrect attempts).
-
spendLimit
final Card.Builder spendLimit(Long spendLimit)
Amount (in cents) to limit approved authorizations (e.g. 100000 would be a $1,000 limit). Transaction requests above the spend limit will be declined.
-
spendLimit
final Card.Builder spendLimit(JsonField<Long> spendLimit)
Amount (in cents) to limit approved authorizations (e.g. 100000 would be a $1,000 limit). Transaction requests above the spend limit will be declined.
-
spendLimitDuration
final Card.Builder spendLimitDuration(SpendLimitDuration spendLimitDuration)
Spend limit duration values:
ANNUALLY- Card will authorize transactions up to spend limit for the trailing year.FOREVER- Card will authorize only up to spend limit for the entire lifetime of the card.MONTHLY- Card will authorize transactions up to spend limit for the trailing month. To support recurring monthly payments, which can occur on different day every month, the time window we consider for monthly velocity starts 6 days after the current calendar date one month prior.TRANSACTION- Card will authorize multiple transactions if each individual transaction is under the spend limit.
-
spendLimitDuration
final Card.Builder spendLimitDuration(JsonField<SpendLimitDuration> spendLimitDuration)
Spend limit duration values:
ANNUALLY- Card will authorize transactions up to spend limit for the trailing year.FOREVER- Card will authorize only up to spend limit for the entire lifetime of the card.MONTHLY- Card will authorize transactions up to spend limit for the trailing month. To support recurring monthly payments, which can occur on different day every month, the time window we consider for monthly velocity starts 6 days after the current calendar date one month prior.TRANSACTION- Card will authorize multiple transactions if each individual transaction is under the spend limit.
-
state
final Card.Builder state(Card.State state)
Card state values:
CLOSED- Card will no longer approve authorizations. Closing a card cannot be undone.OPEN- Card will approve authorizations (if they match card and account parameters).PAUSED- Card will decline authorizations, but can be resumed at a later time.PENDING_FULFILLMENT- The initial state for cards of typePHYSICAL. The card is provisioned pending manufacturing and fulfillment. Cards in this state can accept authorizations for e-commerce purchases, but not for "Card Present" purchases where the physical card itself is present.PENDING_ACTIVATION- At regular intervals, cards of typePHYSICALin statePENDING_FULFILLMENTare sent to the card production warehouse and updated to statePENDING_ACTIVATION. Similar toPENDING_FULFILLMENT, cards in this state can be used for e-commerce transactions or can be added to mobile wallets. API clients should update the card's state toOPENonly after the cardholder confirms receipt of the card.
In sandbox, the same daily batch fulfillment occurs, but no cards are actually manufactured.
-
state
final Card.Builder state(JsonField<Card.State> state)
Card state values:
CLOSED- Card will no longer approve authorizations. Closing a card cannot be undone.OPEN- Card will approve authorizations (if they match card and account parameters).PAUSED- Card will decline authorizations, but can be resumed at a later time.PENDING_FULFILLMENT- The initial state for cards of typePHYSICAL. The card is provisioned pending manufacturing and fulfillment. Cards in this state can accept authorizations for e-commerce purchases, but not for "Card Present" purchases where the physical card itself is present.PENDING_ACTIVATION- At regular intervals, cards of typePHYSICALin statePENDING_FULFILLMENTare sent to the card production warehouse and updated to statePENDING_ACTIVATION. Similar toPENDING_FULFILLMENT, cards in this state can be used for e-commerce transactions or can be added to mobile wallets. API clients should update the card's state toOPENonly after the cardholder confirms receipt of the card.
In sandbox, the same daily batch fulfillment occurs, but no cards are actually manufactured.
-
type
final Card.Builder type(Card.Type type)
Card types:
VIRTUAL- Card will authorize at any merchant and can be added to a digital wallet like Apple Pay or Google Pay (if the card program is digital wallet-enabled).PHYSICAL- Manufactured and sent to the cardholder. We offer white label branding, credit, ATM, PIN debit, chip/EMV, NFC and magstripe functionality. Reach out at lithic.com/contact for more information.SINGLE_USE- Card is closed upon first successful authorization.MERCHANT_LOCKED- Deprecated Card is locked to the first merchant that successfully authorizes the card.UNLOCKED- Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.DIGITAL_WALLET- Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.
-
type
final Card.Builder type(JsonField<Card.Type> type)
Card types:
VIRTUAL- Card will authorize at any merchant and can be added to a digital wallet like Apple Pay or Google Pay (if the card program is digital wallet-enabled).PHYSICAL- Manufactured and sent to the cardholder. We offer white label branding, credit, ATM, PIN debit, chip/EMV, NFC and magstripe functionality. Reach out at lithic.com/contact for more information.SINGLE_USE- Card is closed upon first successful authorization.MERCHANT_LOCKED- Deprecated Card is locked to the first merchant that successfully authorizes the card.UNLOCKED- Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.DIGITAL_WALLET- Deprecated Similar behavior to VIRTUAL cards, please use VIRTUAL instead.
-
authRuleTokens
@Deprecated(message = "deprecated") final Card.Builder authRuleTokens(List<String> authRuleTokens)
List of identifiers for the Auth Rule(s) that are applied on the card. This field is deprecated and will no longer be populated in the
Cardobject. The key will be removed from the schema in a future release. Use the/auth_rulesendpoints to fetch Auth Rule information instead.
-
authRuleTokens
@Deprecated(message = "deprecated") final Card.Builder authRuleTokens(JsonField<List<String>> authRuleTokens)
List of identifiers for the Auth Rule(s) that are applied on the card. This field is deprecated and will no longer be populated in the
Cardobject. The key will be removed from the schema in a future release. Use the/auth_rulesendpoints to fetch Auth Rule information instead.
-
addAuthRuleToken
@Deprecated(message = "deprecated") final Card.Builder addAuthRuleToken(String authRuleToken)
List of identifiers for the Auth Rule(s) that are applied on the card. This field is deprecated and will no longer be populated in the
Cardobject. The key will be removed from the schema in a future release. Use the/auth_rulesendpoints to fetch Auth Rule information instead.
-
cardholderCurrency
final Card.Builder cardholderCurrency(String cardholderCurrency)
3-character alphabetic ISO 4217 code for the currency of the cardholder.
-
cardholderCurrency
final Card.Builder cardholderCurrency(JsonField<String> cardholderCurrency)
3-character alphabetic ISO 4217 code for the currency of the cardholder.
-
cvv
final Card.Builder cvv(String cvv)
Three digit cvv printed on the back of the card.
-
cvv
final Card.Builder cvv(JsonField<String> cvv)
Three digit cvv printed on the back of the card.
-
digitalCardArtToken
final Card.Builder digitalCardArtToken(String digitalCardArtToken)
Specifies the digital card art to be displayed in the user’s digital wallet after tokenization. This artwork must be approved by Mastercard and configured by Lithic to use. See Flexible Card Art Guide.
-
digitalCardArtToken
final Card.Builder digitalCardArtToken(JsonField<String> digitalCardArtToken)
Specifies the digital card art to be displayed in the user’s digital wallet after tokenization. This artwork must be approved by Mastercard and configured by Lithic to use. See Flexible Card Art Guide.
-
expMonth
final Card.Builder expMonth(String expMonth)
Two digit (MM) expiry month.
-
expMonth
final Card.Builder expMonth(JsonField<String> expMonth)
Two digit (MM) expiry month.
-
expYear
final Card.Builder expYear(String expYear)
Four digit (yyyy) expiry year.
-
expYear
final Card.Builder expYear(JsonField<String> expYear)
Four digit (yyyy) expiry year.
-
hostname
final Card.Builder hostname(String hostname)
Hostname of card’s locked merchant (will be empty if not applicable).
-
hostname
final Card.Builder hostname(JsonField<String> hostname)
Hostname of card’s locked merchant (will be empty if not applicable).
-
memo
final Card.Builder memo(String memo)
Friendly name to identify the card.
-
memo
final Card.Builder memo(JsonField<String> memo)
Friendly name to identify the card.
-
pan
final Card.Builder pan(String pan)
Primary Account Number (PAN) (i.e. the card number). Customers must be PCI compliant to have PAN returned as a field in production. Please contact [email protected] for questions.
-
pan
final Card.Builder pan(JsonField<String> pan)
Primary Account Number (PAN) (i.e. the card number). Customers must be PCI compliant to have PAN returned as a field in production. Please contact [email protected] for questions.
-
pendingCommands
final Card.Builder pendingCommands(List<String> pendingCommands)
Indicates if there are offline PIN changes pending card interaction with an offline PIN terminal. Possible commands are: CHANGE_PIN, UNBLOCK_PIN. Applicable only to cards issued in markets supporting offline PINs.
-
pendingCommands
final Card.Builder pendingCommands(JsonField<List<String>> pendingCommands)
Indicates if there are offline PIN changes pending card interaction with an offline PIN terminal. Possible commands are: CHANGE_PIN, UNBLOCK_PIN. Applicable only to cards issued in markets supporting offline PINs.
-
addPendingCommand
final Card.Builder addPendingCommand(String pendingCommand)
Indicates if there are offline PIN changes pending card interaction with an offline PIN terminal. Possible commands are: CHANGE_PIN, UNBLOCK_PIN. Applicable only to cards issued in markets supporting offline PINs.
-
productId
final Card.Builder productId(String productId)
Only applicable to cards of type
PHYSICAL. This must be configured with Lithic before use. Specifies the configuration (i.e., physical card art) that the card should be manufactured with.
-
productId
final Card.Builder productId(JsonField<String> productId)
Only applicable to cards of type
PHYSICAL. This must be configured with Lithic before use. Specifies the configuration (i.e., physical card art) that the card should be manufactured with.
-
replacementFor
final Card.Builder replacementFor(String replacementFor)
If the card is a replacement for another card, the globally unique identifier for the card that was replaced.
-
replacementFor
final Card.Builder replacementFor(Optional<String> replacementFor)
If the card is a replacement for another card, the globally unique identifier for the card that was replaced.
-
replacementFor
final Card.Builder replacementFor(JsonField<String> replacementFor)
If the card is a replacement for another card, the globally unique identifier for the card that was replaced.
-
additionalProperties
final Card.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Card.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Card.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Card.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Card.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-