Class CardAuthorizationApprovalRequestWebhookEvent.AsaNetworkSpecificData
-
- All Implemented Interfaces:
public final class CardAuthorizationApprovalRequestWebhookEvent.AsaNetworkSpecificDataContains raw data provided by the card network, including attributes that provide further context about the authorization. If populated by the network, data is organized by Lithic and passed through without further modification. Please consult the official network documentation for more details about these values and how to use them. This object is only available to certain programs- contact your Customer Success Manager to discuss enabling access.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorizationApprovalRequestWebhookEvent.AsaNetworkSpecificData.BuilderA builder for AsaNetworkSpecificData.
public final classCardAuthorizationApprovalRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercardpublic final classCardAuthorizationApprovalRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataVisa
-
Method Summary
-
-
Method Detail
-
mastercard
final Optional<CardAuthorizationApprovalRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard> mastercard()
-
visa
final Optional<CardAuthorizationApprovalRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataVisa> visa()
-
_mastercard
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard> _mastercard()
Returns the raw JSON value of mastercard.
Unlike mastercard, this method doesn't throw if the JSON field has an unexpected type.
-
_visa
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataVisa> _visa()
Returns the raw JSON value of visa.
Unlike visa, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardAuthorizationApprovalRequestWebhookEvent.AsaNetworkSpecificData.Builder toBuilder()
-
builder
final static CardAuthorizationApprovalRequestWebhookEvent.AsaNetworkSpecificData.Builder builder()
Returns a mutable builder for constructing an instance of AsaNetworkSpecificData.
-
-
-
-