Class CardAuthorizationChallengeResponseParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class CardAuthorizationChallengeResponseParams implements Params
Card program's response to Authorization Challenge. Programs that have Authorization Challenges configured as Out of Band receive a card_authorization.challenge webhook when an authorization attempt triggers a challenge. The card program should respond using this endpoint after the cardholder completes the challenge.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorizationChallengeResponseParams.BuilderA builder for CardAuthorizationChallengeResponseParams.
public final classCardAuthorizationChallengeResponseParams.BodyCard program's response to Authorization Challenge
public final classCardAuthorizationChallengeResponseParams.ResponseWhether the cardholder has approved or declined the issued challenge
-
Method Summary
Modifier and Type Method Description final Optional<String>eventToken()final CardAuthorizationChallengeResponseParams.Responseresponse()Whether the cardholder has approved or declined the issued challenge final JsonField<CardAuthorizationChallengeResponseParams.Response>_response()Returns the raw JSON value of response. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final CardAuthorizationChallengeResponseParams.BuildertoBuilder()final CardAuthorizationChallengeResponseParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardAuthorizationChallengeResponseParams.Builderbuilder()Returns a mutable builder for constructing an instance of CardAuthorizationChallengeResponseParams. -
-
Method Detail
-
eventToken
final Optional<String> eventToken()
-
response
final CardAuthorizationChallengeResponseParams.Response response()
Whether the cardholder has approved or declined the issued challenge
-
_response
final JsonField<CardAuthorizationChallengeResponseParams.Response> _response()
Returns the raw JSON value of response.
Unlike response, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final CardAuthorizationChallengeResponseParams.Builder toBuilder()
-
_body
final CardAuthorizationChallengeResponseParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static CardAuthorizationChallengeResponseParams.Builder builder()
Returns a mutable builder for constructing an instance of CardAuthorizationChallengeResponseParams.
The following fields are required:
.response()
-
-
-
-