Class CardRetrieveSignalsParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class CardRetrieveSignalsParams implements Params
Returns behavioral feature state derived from a card's transaction history.
These signals expose the same data used by behavioral rule attributes (e.g.
AMOUNT_Z_SCOREwithscope: CARD,IS_NEW_COUNTRYwithscope: CARD) and custom codeTRANSACTION_HISTORY_SIGNALSfeatures, allowing clients to inspect feature values before writing rules and debug rule behavior.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardRetrieveSignalsParams.BuilderA builder for CardRetrieveSignalsParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>cardToken()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final CardRetrieveSignalsParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardRetrieveSignalsParamsnone()final static CardRetrieveSignalsParams.Builderbuilder()Returns a mutable builder for constructing an instance of CardRetrieveSignalsParams. -
-
Method Detail
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final CardRetrieveSignalsParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static CardRetrieveSignalsParams none()
-
builder
final static CardRetrieveSignalsParams.Builder builder()
Returns a mutable builder for constructing an instance of CardRetrieveSignalsParams.
-
-
-
-