Class CardSearchByPanParams

  • All Implemented Interfaces:
    com.lithic.api.core.Params

    
    public final class CardSearchByPanParams
     implements Params
                        

    Get card configuration such as spend limit and state. Customers must be PCI compliant to use this endpoint. Please contact [email protected] for questions. Note: this is a POST endpoint because it is more secure to send sensitive data in a request body than in a URL.