Class CardSearchByPanParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class CardSearchByPanParams implements Params
Get card configuration such as spend limit and state. Customers must be PCI compliant to use this endpoint. Please contact [email protected] for questions. Note: this is a
POSTendpoint because it is more secure to send sensitive data in a request body than in a URL.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardSearchByPanParams.BuilderA builder for CardSearchByPanParams.
public final classCardSearchByPanParams.Body
-
Method Summary
Modifier and Type Method Description final Stringpan()The PAN for the card being retrieved. final JsonField<String>_pan()Returns the raw JSON value of pan. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final CardSearchByPanParams.BuildertoBuilder()final CardSearchByPanParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardSearchByPanParams.Builderbuilder()Returns a mutable builder for constructing an instance of CardSearchByPanParams. -
-
Method Detail
-
_pan
final JsonField<String> _pan()
Returns the raw JSON value of pan.
Unlike pan, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final CardSearchByPanParams.Builder toBuilder()
-
_body
final CardSearchByPanParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static CardSearchByPanParams.Builder builder()
Returns a mutable builder for constructing an instance of CardSearchByPanParams.
The following fields are required:
.pan()
-
-
-
-