Package com.lithic.api.models
Class ChallengeResponse
-
- All Implemented Interfaces:
public final class ChallengeResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChallengeResponse.BuilderA builder for ChallengeResponse.
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier for the 3DS authentication. final ChallengeResultchallengeResponse()Whether the Cardholder has Approved or Declined the issued Challenge final JsonField<String>_token()Globally unique identifier for the 3DS authentication. final JsonField<ChallengeResult>_challengeResponse()Whether the Cardholder has Approved or Declined the issued Challenge final Map<String, JsonValue>_additionalProperties()final ChallengeResponsevalidate()final ChallengeResponse.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChallengeResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ChallengeResponse. -
-
Method Detail
-
token
final String token()
Globally unique identifier for the 3DS authentication. This token is sent as part of the initial 3DS Decisioning Request and as part of the 3DS Challenge Event in the #/components/schemas/ThreeDSAuthentication object
-
challengeResponse
final ChallengeResult challengeResponse()
Whether the Cardholder has Approved or Declined the issued Challenge
-
_token
final JsonField<String> _token()
Globally unique identifier for the 3DS authentication. This token is sent as part of the initial 3DS Decisioning Request and as part of the 3DS Challenge Event in the #/components/schemas/ThreeDSAuthentication object
-
_challengeResponse
final JsonField<ChallengeResult> _challengeResponse()
Whether the Cardholder has Approved or Declined the issued Challenge
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final ChallengeResponse validate()
-
toBuilder
final ChallengeResponse.Builder toBuilder()
-
builder
final static ChallengeResponse.Builder builder()
Returns a mutable builder for constructing an instance of ChallengeResponse.
The following fields are required:
.token() .challengeResponse()
-
-
-
-