Class Event.Builder

    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
    • Field Summary

      Fields 
      Modifier and Type Field Description
    • Constructor Summary

      Constructors 
      Constructor Description
    • Enum Constant Summary

      Enum Constants 
      Enum Constant Description
    • Constructor Detail

    • Method Detail

      • created

         final Event.Builder created(OffsetDateTime created)

        An RFC 3339 timestamp for when the event was created. UTC time zone.

        If no timezone is specified, UTC will be used.

      • eventType

         final Event.Builder eventType(Event.EventType eventType)

        Event types:

        • account_holder.created - Notification that a new account holder has been created and was not rejected.

        • account_holder.updated - Notification that an account holder was updated.

        • account_holder.verification - Notification than an account holder's identity verification is complete.

        • card.created - Notification that a card has been created.

        • card.renewed - Notification that a card has been renewed.

        • card.reissued - Notification that a card has been reissued.

        • card.shipped - Physical card shipment notification. See https://docs.lithic.com/docs/cards#physical-card-shipped-webhook.

        • card.converted - Notification that a virtual card has been converted to a physical card.

        • card_transaction.updated - Transaction Lifecycle webhook. See https://docs.lithic.com/docs/transaction-webhooks.

        • dispute.updated - A dispute has been updated.

        • digital_wallet.tokenization_approval_request - Card network's request to Lithic to activate a digital wallet token.

        • digital_wallet.tokenization_result - Notification of the end result of a tokenization, whether successful or failed.

        • digital_wallet.tokenization_two_factor_authentication_code - A code to be passed to an end user to complete digital wallet authentication. See https://docs.lithic.com/docs/tokenization-control#digital-wallet-tokenization-auth-code.

        • digital_wallet.tokenization_two_factor_authentication_code_sent - Notification that a two factor authentication code for activating a digital wallet has been sent to the end user.

        • digital_wallet.tokenization_updated - Notification that a digital wallet tokenization's status has changed.

      • build

         final Event build()

        Returns an immutable instance of Event.

        Further updates to this Builder will not mutate the returned instance.

        The following fields are required:

        .token()
        .created()
        .eventType()
        .payload()