Class Event.Builder
-
- All Implemented Interfaces:
public final class Event.BuilderA builder for Event.
-
-
Method Summary
Modifier and Type Method Description final Event.Buildertoken(String token)Globally unique identifier. final Event.Buildertoken(JsonField<String> token)Globally unique identifier. final Event.Buildercreated(OffsetDateTime created)An RFC 3339 timestamp for when the event was created. final Event.Buildercreated(JsonField<OffsetDateTime> created)An RFC 3339 timestamp for when the event was created. final Event.BuildereventType(Event.EventType eventType)Event types: account_holder.created- Notification that a new account holder has been created and was not rejected.account_holder.updated- Notification that an account holder was updated.account_holder.verification- Notification than an account holder's identity verification is complete.card.created- Notification that a card has been created.card.renewed- Notification that a card has been renewed.card.reissued- Notification that a card has been reissued.card.shipped- Physical card shipment notification. See https://docs.lithic.com/docs/cards#physical-card-shipped-webhook.card.converted- Notification that a virtual card has been converted to a physical card.card_transaction.updated- Transaction Lifecycle webhook. See https://docs.lithic.com/docs/transaction-webhooks.dispute.updated- A dispute has been updated.digital_wallet.tokenization_approval_request- Card network's request to Lithic to activate a digital wallet token.digital_wallet.tokenization_result- Notification of the end result of a tokenization, whether successful or failed.digital_wallet.tokenization_two_factor_authentication_code- A code to be passed to an end user to complete digital wallet authentication. See https://docs.lithic.com/docs/tokenization-control#digital-wallet-tokenization-auth-code.digital_wallet.tokenization_two_factor_authentication_code_sent- Notification that a two factor authentication code for activating a digital wallet has been sent to the end user.digital_wallet.tokenization_updated- Notification that a digital wallet tokenization's status has changed.
final Event.BuildereventType(JsonField<Event.EventType> eventType)Event types: account_holder.created- Notification that a new account holder has been created and was not rejected.account_holder.updated- Notification that an account holder was updated.account_holder.verification- Notification than an account holder's identity verification is complete.card.created- Notification that a card has been created.card.renewed- Notification that a card has been renewed.card.reissued- Notification that a card has been reissued.card.shipped- Physical card shipment notification. See https://docs.lithic.com/docs/cards#physical-card-shipped-webhook.card.converted- Notification that a virtual card has been converted to a physical card.card_transaction.updated- Transaction Lifecycle webhook. See https://docs.lithic.com/docs/transaction-webhooks.dispute.updated- A dispute has been updated.digital_wallet.tokenization_approval_request- Card network's request to Lithic to activate a digital wallet token.digital_wallet.tokenization_result- Notification of the end result of a tokenization, whether successful or failed.digital_wallet.tokenization_two_factor_authentication_code- A code to be passed to an end user to complete digital wallet authentication. See https://docs.lithic.com/docs/tokenization-control#digital-wallet-tokenization-auth-code.digital_wallet.tokenization_two_factor_authentication_code_sent- Notification that a two factor authentication code for activating a digital wallet has been sent to the end user.digital_wallet.tokenization_updated- Notification that a digital wallet tokenization's status has changed.
final Event.Builderpayload(Event.Payload payload)final Event.Builderpayload(JsonField<Event.Payload> payload)final Event.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Event.BuilderputAdditionalProperty(String key, JsonValue value)final Event.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Event.BuilderremoveAdditionalProperty(String key)final Event.BuilderremoveAllAdditionalProperties(Set<String> keys)final Eventbuild()-
-
Method Detail
-
token
final Event.Builder token(String token)
Globally unique identifier.
-
token
final Event.Builder token(JsonField<String> token)
Globally unique identifier.
-
created
final Event.Builder created(OffsetDateTime created)
An RFC 3339 timestamp for when the event was created. UTC time zone.
If no timezone is specified, UTC will be used.
-
created
final Event.Builder created(JsonField<OffsetDateTime> created)
An RFC 3339 timestamp for when the event was created. UTC time zone.
If no timezone is specified, UTC will be used.
-
eventType
final Event.Builder eventType(Event.EventType eventType)
Event types:
account_holder.created- Notification that a new account holder has been created and was not rejected.account_holder.updated- Notification that an account holder was updated.account_holder.verification- Notification than an account holder's identity verification is complete.card.created- Notification that a card has been created.card.renewed- Notification that a card has been renewed.card.reissued- Notification that a card has been reissued.card.shipped- Physical card shipment notification. See https://docs.lithic.com/docs/cards#physical-card-shipped-webhook.card.converted- Notification that a virtual card has been converted to a physical card.card_transaction.updated- Transaction Lifecycle webhook. See https://docs.lithic.com/docs/transaction-webhooks.dispute.updated- A dispute has been updated.digital_wallet.tokenization_approval_request- Card network's request to Lithic to activate a digital wallet token.digital_wallet.tokenization_result- Notification of the end result of a tokenization, whether successful or failed.digital_wallet.tokenization_two_factor_authentication_code- A code to be passed to an end user to complete digital wallet authentication. See https://docs.lithic.com/docs/tokenization-control#digital-wallet-tokenization-auth-code.digital_wallet.tokenization_two_factor_authentication_code_sent- Notification that a two factor authentication code for activating a digital wallet has been sent to the end user.digital_wallet.tokenization_updated- Notification that a digital wallet tokenization's status has changed.
-
eventType
final Event.Builder eventType(JsonField<Event.EventType> eventType)
Event types:
account_holder.created- Notification that a new account holder has been created and was not rejected.account_holder.updated- Notification that an account holder was updated.account_holder.verification- Notification than an account holder's identity verification is complete.card.created- Notification that a card has been created.card.renewed- Notification that a card has been renewed.card.reissued- Notification that a card has been reissued.card.shipped- Physical card shipment notification. See https://docs.lithic.com/docs/cards#physical-card-shipped-webhook.card.converted- Notification that a virtual card has been converted to a physical card.card_transaction.updated- Transaction Lifecycle webhook. See https://docs.lithic.com/docs/transaction-webhooks.dispute.updated- A dispute has been updated.digital_wallet.tokenization_approval_request- Card network's request to Lithic to activate a digital wallet token.digital_wallet.tokenization_result- Notification of the end result of a tokenization, whether successful or failed.digital_wallet.tokenization_two_factor_authentication_code- A code to be passed to an end user to complete digital wallet authentication. See https://docs.lithic.com/docs/tokenization-control#digital-wallet-tokenization-auth-code.digital_wallet.tokenization_two_factor_authentication_code_sent- Notification that a two factor authentication code for activating a digital wallet has been sent to the end user.digital_wallet.tokenization_updated- Notification that a digital wallet tokenization's status has changed.
-
payload
final Event.Builder payload(Event.Payload payload)
-
payload
final Event.Builder payload(JsonField<Event.Payload> payload)
-
additionalProperties
final Event.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Event.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Event.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Event.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Event.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-