Package com.lithic.api.models
Class ExternalBankAccountListPageAsync
-
- All Implemented Interfaces:
public final class ExternalBankAccountListPageAsyncList all the external bank accounts for the provided search criteria.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalBankAccountListPageAsync.Responsepublic final classExternalBankAccountListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final ExternalBankAccountListPageAsync.Responseresponse()final List<ExternalBankAccountListResponse>data()final BooleanhasMore()Booleanequals(Object other)IntegerhashCode()StringtoString()final BooleanhasNextPage()final Optional<ExternalBankAccountListParams>getNextPageParams()final CompletableFuture<Optional<ExternalBankAccountListPageAsync>>getNextPage()final ExternalBankAccountListPageAsync.AutoPagerautoPager()final static ExternalBankAccountListPageAsyncof(ExternalBankAccountServiceAsync externalBankAccountsService, ExternalBankAccountListParams params, ExternalBankAccountListPageAsync.Response response)-
-
Method Detail
-
response
final ExternalBankAccountListPageAsync.Response response()
-
data
final List<ExternalBankAccountListResponse> data()
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<ExternalBankAccountListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<ExternalBankAccountListPageAsync>> getNextPage()
-
autoPager
final ExternalBankAccountListPageAsync.AutoPager autoPager()
-
of
final static ExternalBankAccountListPageAsync of(ExternalBankAccountServiceAsync externalBankAccountsService, ExternalBankAccountListParams params, ExternalBankAccountListPageAsync.Response response)
-
-
-
-