Class ExternalBankAccountSetVerificationMethodParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class ExternalBankAccountSetVerificationMethodParams implements Params
Update the verification method for an external bank account. Verification method can only be updated if the
verification_stateisPENDING.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalBankAccountSetVerificationMethodParams.BuilderA builder for ExternalBankAccountSetVerificationMethodParams.
public final classExternalBankAccountSetVerificationMethodParams.SetVerificationMethodRequestpublic final classExternalBankAccountSetVerificationMethodParams.SetVerificationMethodAllowedVerificationMethodsThe verification method to set for the external bank account
-
Method Summary
-
-
Method Detail
-
externalBankAccountToken
final Optional<String> externalBankAccountToken()
-
verificationMethod
final ExternalBankAccountSetVerificationMethodParams.SetVerificationMethodAllowedVerificationMethods verificationMethod()
The verification method to set for the external bank account
-
financialAccountToken
final Optional<String> financialAccountToken()
The financial account token of the operating account to fund the micro deposits. Required when verification_method is MICRO_DEPOSIT or PRENOTE.
-
_verificationMethod
final JsonField<ExternalBankAccountSetVerificationMethodParams.SetVerificationMethodAllowedVerificationMethods> _verificationMethod()
Returns the raw JSON value of verificationMethod.
Unlike verificationMethod, this method doesn't throw if the JSON field has an unexpected type.
-
_financialAccountToken
final JsonField<String> _financialAccountToken()
Returns the raw JSON value of financialAccountToken.
Unlike financialAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ExternalBankAccountSetVerificationMethodParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static ExternalBankAccountSetVerificationMethodParams.Builder builder()
Returns a mutable builder for constructing an instance of ExternalBankAccountSetVerificationMethodParams.
The following fields are required:
.verificationMethod()
-
-
-
-