Package com.lithic.api.models
Class FinancialAccountListPageAsync
-
- All Implemented Interfaces:
public final class FinancialAccountListPageAsyncRetrieve information on your financial accounts including routing and account number.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinancialAccountListPageAsync.Responsepublic final classFinancialAccountListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final FinancialAccountListPageAsync.Responseresponse()final List<FinancialAccount>data()final BooleanhasMore()Booleanequals(Object other)IntegerhashCode()StringtoString()final BooleanhasNextPage()final Optional<FinancialAccountListParams>getNextPageParams()final CompletableFuture<Optional<FinancialAccountListPageAsync>>getNextPage()final FinancialAccountListPageAsync.AutoPagerautoPager()final static FinancialAccountListPageAsyncof(FinancialAccountServiceAsync financialAccountsService, FinancialAccountListParams params, FinancialAccountListPageAsync.Response response)-
-
Method Detail
-
response
final FinancialAccountListPageAsync.Response response()
-
data
final List<FinancialAccount> data()
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<FinancialAccountListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<FinancialAccountListPageAsync>> getNextPage()
-
autoPager
final FinancialAccountListPageAsync.AutoPager autoPager()
-
of
final static FinancialAccountListPageAsync of(FinancialAccountServiceAsync financialAccountsService, FinancialAccountListParams params, FinancialAccountListPageAsync.Response response)
-
-
-
-