Package com.lithic.api.models
Class FinancialTransactionListPageAsync
-
- All Implemented Interfaces:
public final class FinancialTransactionListPageAsyncList the financial transactions for a given financial account.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinancialTransactionListPageAsync.Responsepublic final classFinancialTransactionListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final FinancialTransactionListPageAsync.Responseresponse()final List<FinancialTransaction>data()final BooleanhasMore()Booleanequals(Object other)IntegerhashCode()StringtoString()final BooleanhasNextPage()final Optional<FinancialTransactionListParams>getNextPageParams()final CompletableFuture<Optional<FinancialTransactionListPageAsync>>getNextPage()final FinancialTransactionListPageAsync.AutoPagerautoPager()final static FinancialTransactionListPageAsyncof(FinancialTransactionServiceAsync financialTransactionsService, FinancialTransactionListParams params, FinancialTransactionListPageAsync.Response response)-
-
Method Detail
-
response
final FinancialTransactionListPageAsync.Response response()
-
data
final List<FinancialTransaction> data()
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<FinancialTransactionListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<FinancialTransactionListPageAsync>> getNextPage()
-
autoPager
final FinancialTransactionListPageAsync.AutoPager autoPager()
-
of
final static FinancialTransactionListPageAsync of(FinancialTransactionServiceAsync financialTransactionsService, FinancialTransactionListParams params, FinancialTransactionListPageAsync.Response response)
-
-
-
-