Class Kyb

  • All Implemented Interfaces:

    
    public final class Kyb
    
                        
    • Constructor Detail

    • Method Detail

      • beneficialOwnerEntities

         final List<Kyb.BusinessEntity> beneficialOwnerEntities()

        List of all entities with >25% ownership in the company. If no entity or individual owns >25% of the company, and the largest shareholder is an entity, please identify them in this field. See FinCEN requirements (Section I) for more background. If no business owner is an entity, pass in an empty list. However, either this parameter or beneficial_owner_individuals must be populated. on entities that should be included.

      • beneficialOwnerIndividuals

         final List<Kyb.KybIndividual> beneficialOwnerIndividuals()

        List of all direct and indirect individuals with >25% ownership in the company. If no entity or individual owns >25% of the company, and the largest shareholder is an individual, please identify them in this field. See FinCEN requirements (Section I) for more background on individuals that should be included. If no individual is an entity, pass in an empty list. However, either this parameter or beneficial_owner_entities must be populated.

      • controlPerson

         final Kyb.KybIndividual controlPerson()

        An individual with significant responsibility for managing the legal entity (e.g., a Chief Executive Officer, Chief Financial Officer, Chief Operating Officer, Managing Member, General Partner, President, Vice President, or Treasurer). This can be an executive, or someone who will have program-wide access to the cards that Lithic will provide. In some cases, this individual could also be a beneficial owner listed above. See FinCEN requirements (Section II) for more background.

      • natureOfBusiness

         final String natureOfBusiness()

        Short description of the company's line of business (i.e., what does the company do?).

      • tosTimestamp

         final String tosTimestamp()

        An RFC 3339 timestamp indicating when the account holder accepted the applicable legal agreements (e.g., cardholder terms) as agreed upon during API customer's implementation with Lithic.

      • externalId

         final Optional<String> externalId()

        A user provided id that can be used to link an account holder with an external system

      • kybPassedTimestamp

         final Optional<String> kybPassedTimestamp()

        An RFC 3339 timestamp indicating when precomputed KYC was completed on the business with a pass result.

        This field is required only if workflow type is KYB_BYO.

      • _beneficialOwnerEntities

         final JsonField<List<Kyb.BusinessEntity>> _beneficialOwnerEntities()

        List of all entities with >25% ownership in the company. If no entity or individual owns >25% of the company, and the largest shareholder is an entity, please identify them in this field. See FinCEN requirements (Section I) for more background. If no business owner is an entity, pass in an empty list. However, either this parameter or beneficial_owner_individuals must be populated. on entities that should be included.

      • _beneficialOwnerIndividuals

         final JsonField<List<Kyb.KybIndividual>> _beneficialOwnerIndividuals()

        List of all direct and indirect individuals with >25% ownership in the company. If no entity or individual owns >25% of the company, and the largest shareholder is an individual, please identify them in this field. See FinCEN requirements (Section I) for more background on individuals that should be included. If no individual is an entity, pass in an empty list. However, either this parameter or beneficial_owner_entities must be populated.

      • _controlPerson

         final JsonField<Kyb.KybIndividual> _controlPerson()

        An individual with significant responsibility for managing the legal entity (e.g., a Chief Executive Officer, Chief Financial Officer, Chief Operating Officer, Managing Member, General Partner, President, Vice President, or Treasurer). This can be an executive, or someone who will have program-wide access to the cards that Lithic will provide. In some cases, this individual could also be a beneficial owner listed above. See FinCEN requirements (Section II) for more background.

      • _tosTimestamp

         final JsonField<String> _tosTimestamp()

        An RFC 3339 timestamp indicating when the account holder accepted the applicable legal agreements (e.g., cardholder terms) as agreed upon during API customer's implementation with Lithic.

      • _externalId

         final JsonField<String> _externalId()

        A user provided id that can be used to link an account holder with an external system

      • _kybPassedTimestamp

         final JsonField<String> _kybPassedTimestamp()

        An RFC 3339 timestamp indicating when precomputed KYC was completed on the business with a pass result.

        This field is required only if workflow type is KYB_BYO.

      • builder

         final static Kyb.Builder builder()

        Returns a mutable builder for constructing an instance of Kyb.

        The following fields are required:

        .beneficialOwnerEntities()
        .beneficialOwnerIndividuals()
        .businessEntity()
        .controlPerson()
        .natureOfBusiness()
        .tosTimestamp()
        .workflow()