Class Kyb
-
- All Implemented Interfaces:
public final class Kyb
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classKyb.BuilderA builder for Kyb.
public final classKyb.BusinessEntitypublic final classKyb.KybIndividualIndividuals associated with a KYB application. Phone number is optional.
public final classKyb.WorkflowSpecifies the type of KYB workflow to run.
-
Method Summary
Modifier and Type Method Description final List<Kyb.BusinessEntity>beneficialOwnerEntities()List of all entities with >25% ownership in the company. final List<Kyb.KybIndividual>beneficialOwnerIndividuals()List of all direct and indirect individuals with >25% ownership in the company. final Kyb.BusinessEntitybusinessEntity()Information for business for which the account is being opened and KYB is being run. final Kyb.KybIndividualcontrolPerson()An individual with significant responsibility for managing the legal entity (e.g., a Chief Executive Officer, Chief Financial Officer, Chief Operating Officer, Managing Member, General Partner, President, Vice President, or Treasurer). final StringnatureOfBusiness()Short description of the company's line of business (i.e., what does the company do?). final StringtosTimestamp()An RFC 3339 timestamp indicating when the account holder accepted the applicable legal agreements (e.g., cardholder terms) as agreed upon during API customer's implementation with Lithic. final Kyb.Workflowworkflow()Specifies the type of KYB workflow to run. final Optional<String>externalId()A user provided id that can be used to link an account holder with an external system final Optional<String>kybPassedTimestamp()An RFC 3339 timestamp indicating when precomputed KYC was completed on the business with a pass result. final Optional<String>websiteUrl()Company website URL. final JsonField<List<Kyb.BusinessEntity>>_beneficialOwnerEntities()List of all entities with >25% ownership in the company. final JsonField<List<Kyb.KybIndividual>>_beneficialOwnerIndividuals()List of all direct and indirect individuals with >25% ownership in the company. final JsonField<Kyb.BusinessEntity>_businessEntity()Information for business for which the account is being opened and KYB is being run. final JsonField<Kyb.KybIndividual>_controlPerson()An individual with significant responsibility for managing the legal entity (e.g., a Chief Executive Officer, Chief Financial Officer, Chief Operating Officer, Managing Member, General Partner, President, Vice President, or Treasurer). final JsonField<String>_natureOfBusiness()Short description of the company's line of business (i.e., what does the company do?). final JsonField<String>_tosTimestamp()An RFC 3339 timestamp indicating when the account holder accepted the applicable legal agreements (e.g., cardholder terms) as agreed upon during API customer's implementation with Lithic. final JsonField<Kyb.Workflow>_workflow()Specifies the type of KYB workflow to run. final JsonField<String>_externalId()A user provided id that can be used to link an account holder with an external system final JsonField<String>_kybPassedTimestamp()An RFC 3339 timestamp indicating when precomputed KYC was completed on the business with a pass result. final JsonField<String>_websiteUrl()Company website URL. final Map<String, JsonValue>_additionalProperties()final Kybvalidate()final Kyb.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Kyb.Builderbuilder()Returns a mutable builder for constructing an instance of Kyb. -
-
Method Detail
-
beneficialOwnerEntities
final List<Kyb.BusinessEntity> beneficialOwnerEntities()
List of all entities with >25% ownership in the company. If no entity or individual owns >25% of the company, and the largest shareholder is an entity, please identify them in this field. See FinCEN requirements (Section I) for more background. If no business owner is an entity, pass in an empty list. However, either this parameter or
beneficial_owner_individualsmust be populated. on entities that should be included.
-
beneficialOwnerIndividuals
final List<Kyb.KybIndividual> beneficialOwnerIndividuals()
List of all direct and indirect individuals with >25% ownership in the company. If no entity or individual owns >25% of the company, and the largest shareholder is an individual, please identify them in this field. See FinCEN requirements (Section I) for more background on individuals that should be included. If no individual is an entity, pass in an empty list. However, either this parameter or
beneficial_owner_entitiesmust be populated.
-
businessEntity
final Kyb.BusinessEntity businessEntity()
Information for business for which the account is being opened and KYB is being run.
-
controlPerson
final Kyb.KybIndividual controlPerson()
An individual with significant responsibility for managing the legal entity (e.g., a Chief Executive Officer, Chief Financial Officer, Chief Operating Officer, Managing Member, General Partner, President, Vice President, or Treasurer). This can be an executive, or someone who will have program-wide access to the cards that Lithic will provide. In some cases, this individual could also be a beneficial owner listed above. See FinCEN requirements (Section II) for more background.
-
natureOfBusiness
final String natureOfBusiness()
Short description of the company's line of business (i.e., what does the company do?).
-
tosTimestamp
final String tosTimestamp()
An RFC 3339 timestamp indicating when the account holder accepted the applicable legal agreements (e.g., cardholder terms) as agreed upon during API customer's implementation with Lithic.
-
workflow
final Kyb.Workflow workflow()
Specifies the type of KYB workflow to run.
-
externalId
final Optional<String> externalId()
A user provided id that can be used to link an account holder with an external system
-
kybPassedTimestamp
final Optional<String> kybPassedTimestamp()
An RFC 3339 timestamp indicating when precomputed KYC was completed on the business with a pass result.
This field is required only if workflow type is
KYB_BYO.
-
websiteUrl
final Optional<String> websiteUrl()
Company website URL.
-
_beneficialOwnerEntities
final JsonField<List<Kyb.BusinessEntity>> _beneficialOwnerEntities()
List of all entities with >25% ownership in the company. If no entity or individual owns >25% of the company, and the largest shareholder is an entity, please identify them in this field. See FinCEN requirements (Section I) for more background. If no business owner is an entity, pass in an empty list. However, either this parameter or
beneficial_owner_individualsmust be populated. on entities that should be included.
-
_beneficialOwnerIndividuals
final JsonField<List<Kyb.KybIndividual>> _beneficialOwnerIndividuals()
List of all direct and indirect individuals with >25% ownership in the company. If no entity or individual owns >25% of the company, and the largest shareholder is an individual, please identify them in this field. See FinCEN requirements (Section I) for more background on individuals that should be included. If no individual is an entity, pass in an empty list. However, either this parameter or
beneficial_owner_entitiesmust be populated.
-
_businessEntity
final JsonField<Kyb.BusinessEntity> _businessEntity()
Information for business for which the account is being opened and KYB is being run.
-
_controlPerson
final JsonField<Kyb.KybIndividual> _controlPerson()
An individual with significant responsibility for managing the legal entity (e.g., a Chief Executive Officer, Chief Financial Officer, Chief Operating Officer, Managing Member, General Partner, President, Vice President, or Treasurer). This can be an executive, or someone who will have program-wide access to the cards that Lithic will provide. In some cases, this individual could also be a beneficial owner listed above. See FinCEN requirements (Section II) for more background.
-
_natureOfBusiness
final JsonField<String> _natureOfBusiness()
Short description of the company's line of business (i.e., what does the company do?).
-
_tosTimestamp
final JsonField<String> _tosTimestamp()
An RFC 3339 timestamp indicating when the account holder accepted the applicable legal agreements (e.g., cardholder terms) as agreed upon during API customer's implementation with Lithic.
-
_workflow
final JsonField<Kyb.Workflow> _workflow()
Specifies the type of KYB workflow to run.
-
_externalId
final JsonField<String> _externalId()
A user provided id that can be used to link an account holder with an external system
-
_kybPassedTimestamp
final JsonField<String> _kybPassedTimestamp()
An RFC 3339 timestamp indicating when precomputed KYC was completed on the business with a pass result.
This field is required only if workflow type is
KYB_BYO.
-
_websiteUrl
final JsonField<String> _websiteUrl()
Company website URL.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Kyb.Builder toBuilder()
-
builder
final static Kyb.Builder builder()
Returns a mutable builder for constructing an instance of Kyb.
The following fields are required:
.beneficialOwnerEntities() .beneficialOwnerIndividuals() .businessEntity() .controlPerson() .natureOfBusiness() .tosTimestamp() .workflow()
-
-
-
-