Class Kyc
-
- All Implemented Interfaces:
public final class Kyc
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classKyc.BuilderA builder for Kyc.
public final classKyc.IndividualInformation on individual for whom the account is being opened and KYC is being run.
public final classKyc.WorkflowSpecifies the type of KYC workflow to run.
-
Method Summary
Modifier and Type Method Description final Kyc.Individualindividual()Information on individual for whom the account is being opened and KYC is being run. final StringtosTimestamp()An RFC 3339 timestamp indicating when the account holder accepted the applicable legal agreements (e.g., cardholder terms) as agreed upon during API customer's implementation with Lithic. final Kyc.Workflowworkflow()Specifies the type of KYC workflow to run. final Optional<String>externalId()A user provided id that can be used to link an account holder with an external system final Optional<String>kycPassedTimestamp()An RFC 3339 timestamp indicating when precomputed KYC was completed on the individual with a pass result. final JsonField<Kyc.Individual>_individual()Information on individual for whom the account is being opened and KYC is being run. final JsonField<String>_tosTimestamp()An RFC 3339 timestamp indicating when the account holder accepted the applicable legal agreements (e.g., cardholder terms) as agreed upon during API customer's implementation with Lithic. final JsonField<Kyc.Workflow>_workflow()Specifies the type of KYC workflow to run. final JsonField<String>_externalId()A user provided id that can be used to link an account holder with an external system final JsonField<String>_kycPassedTimestamp()An RFC 3339 timestamp indicating when precomputed KYC was completed on the individual with a pass result. final Map<String, JsonValue>_additionalProperties()final Kycvalidate()final Kyc.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Kyc.Builderbuilder()Returns a mutable builder for constructing an instance of Kyc. -
-
Method Detail
-
individual
final Kyc.Individual individual()
Information on individual for whom the account is being opened and KYC is being run.
-
tosTimestamp
final String tosTimestamp()
An RFC 3339 timestamp indicating when the account holder accepted the applicable legal agreements (e.g., cardholder terms) as agreed upon during API customer's implementation with Lithic.
-
workflow
final Kyc.Workflow workflow()
Specifies the type of KYC workflow to run.
-
externalId
final Optional<String> externalId()
A user provided id that can be used to link an account holder with an external system
-
kycPassedTimestamp
final Optional<String> kycPassedTimestamp()
An RFC 3339 timestamp indicating when precomputed KYC was completed on the individual with a pass result.
This field is required only if workflow type is
KYC_BYO.
-
_individual
final JsonField<Kyc.Individual> _individual()
Information on individual for whom the account is being opened and KYC is being run.
-
_tosTimestamp
final JsonField<String> _tosTimestamp()
An RFC 3339 timestamp indicating when the account holder accepted the applicable legal agreements (e.g., cardholder terms) as agreed upon during API customer's implementation with Lithic.
-
_workflow
final JsonField<Kyc.Workflow> _workflow()
Specifies the type of KYC workflow to run.
-
_externalId
final JsonField<String> _externalId()
A user provided id that can be used to link an account holder with an external system
-
_kycPassedTimestamp
final JsonField<String> _kycPassedTimestamp()
An RFC 3339 timestamp indicating when precomputed KYC was completed on the individual with a pass result.
This field is required only if workflow type is
KYC_BYO.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Kyc.Builder toBuilder()
-
builder
final static Kyc.Builder builder()
Returns a mutable builder for constructing an instance of Kyc.
The following fields are required:
.individual() .tosTimestamp() .workflow()
-
-
-
-