Class KycExempt
-
- All Implemented Interfaces:
public final class KycExempt
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classKycExempt.BuilderA builder for KycExempt.
public final classKycExempt.KycExemptionTypeSpecifies the type of KYC Exempt user
public final classKycExempt.WorkflowSpecifies the workflow type. This must be 'KYC_EXEMPT'
-
Method Summary
Modifier and Type Method Description final Addressaddress()KYC Exempt user's current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable. final Stringemail()The KYC Exempt user's email final StringfirstName()The KYC Exempt user's first name final KycExempt.KycExemptionTypekycExemptionType()Specifies the type of KYC Exempt user final StringlastName()The KYC Exempt user's last name final StringphoneNumber()The KYC Exempt user's phone number, entered in E.164 format. final KycExempt.Workflowworkflow()Specifies the workflow type. final Optional<String>businessAccountToken()Only applicable for customers using the KYC-Exempt workflow to enroll authorized users of businesses. final Optional<String>externalId()A user provided id that can be used to link an account holder with an external system final JsonField<Address>_address()KYC Exempt user's current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable. final JsonField<String>_email()The KYC Exempt user's email final JsonField<String>_firstName()The KYC Exempt user's first name final JsonField<KycExempt.KycExemptionType>_kycExemptionType()Specifies the type of KYC Exempt user final JsonField<String>_lastName()The KYC Exempt user's last name final JsonField<String>_phoneNumber()The KYC Exempt user's phone number, entered in E.164 format. final JsonField<KycExempt.Workflow>_workflow()Specifies the workflow type. final JsonField<String>_businessAccountToken()Only applicable for customers using the KYC-Exempt workflow to enroll authorized users of businesses. final JsonField<String>_externalId()A user provided id that can be used to link an account holder with an external system final Map<String, JsonValue>_additionalProperties()final KycExemptvalidate()final KycExempt.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static KycExempt.Builderbuilder()Returns a mutable builder for constructing an instance of KycExempt. -
-
Method Detail
-
address
final Address address()
KYC Exempt user's current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable.
-
kycExemptionType
final KycExempt.KycExemptionType kycExemptionType()
Specifies the type of KYC Exempt user
-
phoneNumber
final String phoneNumber()
The KYC Exempt user's phone number, entered in E.164 format.
-
workflow
final KycExempt.Workflow workflow()
Specifies the workflow type. This must be 'KYC_EXEMPT'
-
businessAccountToken
final Optional<String> businessAccountToken()
Only applicable for customers using the KYC-Exempt workflow to enroll authorized users of businesses. Pass the account_token of the enrolled business associated with the AUTHORIZED_USER in this field.
-
externalId
final Optional<String> externalId()
A user provided id that can be used to link an account holder with an external system
-
_address
final JsonField<Address> _address()
KYC Exempt user's current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable.
-
_firstName
final JsonField<String> _firstName()
The KYC Exempt user's first name
-
_kycExemptionType
final JsonField<KycExempt.KycExemptionType> _kycExemptionType()
Specifies the type of KYC Exempt user
-
_phoneNumber
final JsonField<String> _phoneNumber()
The KYC Exempt user's phone number, entered in E.164 format.
-
_workflow
final JsonField<KycExempt.Workflow> _workflow()
Specifies the workflow type. This must be 'KYC_EXEMPT'
-
_businessAccountToken
final JsonField<String> _businessAccountToken()
Only applicable for customers using the KYC-Exempt workflow to enroll authorized users of businesses. Pass the account_token of the enrolled business associated with the AUTHORIZED_USER in this field.
-
_externalId
final JsonField<String> _externalId()
A user provided id that can be used to link an account holder with an external system
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final KycExempt.Builder toBuilder()
-
builder
final static KycExempt.Builder builder()
Returns a mutable builder for constructing an instance of KycExempt.
The following fields are required:
.address() .email() .firstName() .kycExemptionType() .lastName() .phoneNumber() .workflow()
-
-
-
-