Package com.lithic.api.models
Class ManagementOperationListPageAsync
-
- All Implemented Interfaces:
public final class ManagementOperationListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classManagementOperationListPageAsync.BuilderA builder for ManagementOperationListPageAsync.
public final classManagementOperationListPageAsync.AutoPager
-
Method Summary
-
-
Method Detail
-
data
final List<ManagementOperationTransaction> data()
Delegates to ManagementOperationListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to ManagementOperationListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<ManagementOperationListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<ManagementOperationListPageAsync>> getNextPage()
-
autoPager
final ManagementOperationListPageAsync.AutoPager autoPager()
-
params
final ManagementOperationListParams params()
The parameters that were used to request this page.
-
response
final ManagementOperationListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final ManagementOperationListPageAsync.Builder toBuilder()
-
builder
final static ManagementOperationListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of ManagementOperationListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-