Class ShippingAddress
-
- All Implemented Interfaces:
public final class ShippingAddress
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classShippingAddress.BuilderA builder for ShippingAddress.
-
Method Summary
Modifier and Type Method Description final Stringaddress1()Valid USPS routable address. final Stringcity()City final Stringcountry()Uppercase ISO 3166-1 alpha-3 three character abbreviation. final StringfirstName()Customer's first name. final StringlastName()Customer's surname (family name). final StringpostalCode()Postal code (formerly zipcode). final Stringstate()Uppercase ISO 3166-2 two character abbreviation for US and CA. final Optional<String>address2()Unit number (if applicable). final Optional<String>email()Email address to be contacted for expedited shipping process purposes. final Optional<String>line2Text()Text to be printed on line two of the physical card. final Optional<String>phoneNumber()Cardholder's phone number in E.164 format to be contacted for expedited shipping process purposes. final JsonField<String>_address1()Valid USPS routable address. final JsonField<String>_city()City final JsonField<String>_country()Uppercase ISO 3166-1 alpha-3 three character abbreviation. final JsonField<String>_firstName()Customer's first name. final JsonField<String>_lastName()Customer's surname (family name). final JsonField<String>_postalCode()Postal code (formerly zipcode). final JsonField<String>_state()Uppercase ISO 3166-2 two character abbreviation for US and CA. final JsonField<String>_address2()Unit number (if applicable). final JsonField<String>_email()Email address to be contacted for expedited shipping process purposes. final JsonField<String>_line2Text()Text to be printed on line two of the physical card. final JsonField<String>_phoneNumber()Cardholder's phone number in E.164 format to be contacted for expedited shipping process purposes. final Map<String, JsonValue>_additionalProperties()final ShippingAddressvalidate()final ShippingAddress.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ShippingAddress.Builderbuilder()Returns a mutable builder for constructing an instance of ShippingAddress. -
-
Method Detail
-
firstName
final String firstName()
Customer's first name. This will be the first name printed on the physical card. The combined length of
first_nameandlast_namemay not exceed 25 characters.
-
lastName
final String lastName()
Customer's surname (family name). This will be the last name printed on the physical card. The combined length of
first_nameandlast_namemay not exceed 25 characters.
-
postalCode
final String postalCode()
Postal code (formerly zipcode). For US addresses, either five-digit postal code or nine-digit postal code (ZIP+4) using the format 12345-1234.
-
state
final String state()
Uppercase ISO 3166-2 two character abbreviation for US and CA. Optional with a limit of 24 characters for other countries.
-
email
final Optional<String> email()
Email address to be contacted for expedited shipping process purposes. Required if
shipping_methodisEXPEDITED.
-
line2Text
final Optional<String> line2Text()
Text to be printed on line two of the physical card. Use of this field requires additional permissions.
-
phoneNumber
final Optional<String> phoneNumber()
Cardholder's phone number in E.164 format to be contacted for expedited shipping process purposes. Required if
shipping_methodisEXPEDITED.
-
_country
final JsonField<String> _country()
Uppercase ISO 3166-1 alpha-3 three character abbreviation.
-
_firstName
final JsonField<String> _firstName()
Customer's first name. This will be the first name printed on the physical card. The combined length of
first_nameandlast_namemay not exceed 25 characters.
-
_lastName
final JsonField<String> _lastName()
Customer's surname (family name). This will be the last name printed on the physical card. The combined length of
first_nameandlast_namemay not exceed 25 characters.
-
_postalCode
final JsonField<String> _postalCode()
Postal code (formerly zipcode). For US addresses, either five-digit postal code or nine-digit postal code (ZIP+4) using the format 12345-1234.
-
_state
final JsonField<String> _state()
Uppercase ISO 3166-2 two character abbreviation for US and CA. Optional with a limit of 24 characters for other countries.
-
_email
final JsonField<String> _email()
Email address to be contacted for expedited shipping process purposes. Required if
shipping_methodisEXPEDITED.
-
_line2Text
final JsonField<String> _line2Text()
Text to be printed on line two of the physical card. Use of this field requires additional permissions.
-
_phoneNumber
final JsonField<String> _phoneNumber()
Cardholder's phone number in E.164 format to be contacted for expedited shipping process purposes. Required if
shipping_methodisEXPEDITED.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final ShippingAddress validate()
-
toBuilder
final ShippingAddress.Builder toBuilder()
-
builder
final static ShippingAddress.Builder builder()
Returns a mutable builder for constructing an instance of ShippingAddress.
The following fields are required:
.address1() .city() .country() .firstName() .lastName() .postalCode() .state()
-
-
-
-