Class TokenMetadata.PaymentAccountInfo
-
- All Implemented Interfaces:
public final class TokenMetadata.PaymentAccountInfoContains the information of the account responsible for the payment.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTokenMetadata.PaymentAccountInfo.BuilderA builder for PaymentAccountInfo.
public final classTokenMetadata.PaymentAccountInfo.AccountHolderDataAdditional information that can be used to identify the account holder, such as name, address, etc
-
Method Summary
Modifier and Type Method Description final TokenMetadata.PaymentAccountInfo.AccountHolderDataaccountHolderData()Additional information that can be used to identify the account holder, such as name, address, etc final Optional<String>panUniqueReference()Reference to the PAN that is unique per Wallet Provider final Optional<String>paymentAccountReference()The unique account reference assigned to the PAN final Optional<String>tokenUniqueReference()A unique reference assigned following the allocation of a token used to identify the token for the duration of its lifetime. final JsonField<TokenMetadata.PaymentAccountInfo.AccountHolderData>_accountHolderData()Returns the raw JSON value of accountHolderData. final JsonField<String>_panUniqueReference()Returns the raw JSON value of panUniqueReference. final JsonField<String>_paymentAccountReference()Returns the raw JSON value of paymentAccountReference. final JsonField<String>_tokenUniqueReference()Returns the raw JSON value of tokenUniqueReference. final Map<String, JsonValue>_additionalProperties()final TokenMetadata.PaymentAccountInfo.BuildertoBuilder()final TokenMetadata.PaymentAccountInfovalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TokenMetadata.PaymentAccountInfo.Builderbuilder()Returns a mutable builder for constructing an instance of PaymentAccountInfo. -
-
Method Detail
-
accountHolderData
final TokenMetadata.PaymentAccountInfo.AccountHolderData accountHolderData()
Additional information that can be used to identify the account holder, such as name, address, etc
-
panUniqueReference
final Optional<String> panUniqueReference()
Reference to the PAN that is unique per Wallet Provider
-
paymentAccountReference
final Optional<String> paymentAccountReference()
The unique account reference assigned to the PAN
-
tokenUniqueReference
final Optional<String> tokenUniqueReference()
A unique reference assigned following the allocation of a token used to identify the token for the duration of its lifetime.
-
_accountHolderData
final JsonField<TokenMetadata.PaymentAccountInfo.AccountHolderData> _accountHolderData()
Returns the raw JSON value of accountHolderData.
Unlike accountHolderData, this method doesn't throw if the JSON field has an unexpected type.
-
_panUniqueReference
final JsonField<String> _panUniqueReference()
Returns the raw JSON value of panUniqueReference.
Unlike panUniqueReference, this method doesn't throw if the JSON field has an unexpected type.
-
_paymentAccountReference
final JsonField<String> _paymentAccountReference()
Returns the raw JSON value of paymentAccountReference.
Unlike paymentAccountReference, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenUniqueReference
final JsonField<String> _tokenUniqueReference()
Returns the raw JSON value of tokenUniqueReference.
Unlike tokenUniqueReference, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TokenMetadata.PaymentAccountInfo.Builder toBuilder()
-
validate
final TokenMetadata.PaymentAccountInfo validate()
-
builder
final static TokenMetadata.PaymentAccountInfo.Builder builder()
Returns a mutable builder for constructing an instance of PaymentAccountInfo.
The following fields are required:
.accountHolderData()
-
-
-
-