Class Transaction.ServiceLocation
-
- All Implemented Interfaces:
public final class Transaction.ServiceLocationWhere the cardholder received the service, when different from the card acceptor location. This is populated from network data elements such as Mastercard DE-122 SE1 SF9-14 and Visa F34 DS02.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.ServiceLocation.BuilderA builder for ServiceLocation.
-
Method Summary
Modifier and Type Method Description final Optional<String>city()City of service location. final Optional<String>country()Country code of service location, ISO 3166-1 alpha-3. final Optional<String>postalCode()Postal code of service location. final Optional<String>state()State/province code of service location, ISO 3166-2. final Optional<String>streetAddress()Street address of service location. final JsonField<String>_city()Returns the raw JSON value of city. final JsonField<String>_country()Returns the raw JSON value of country. final JsonField<String>_postalCode()Returns the raw JSON value of postalCode. final JsonField<String>_state()Returns the raw JSON value of state. final JsonField<String>_streetAddress()Returns the raw JSON value of streetAddress. final Map<String, JsonValue>_additionalProperties()final Transaction.ServiceLocation.BuildertoBuilder()final Transaction.ServiceLocationvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.ServiceLocation.Builderbuilder()Returns a mutable builder for constructing an instance of ServiceLocation. -
-
Method Detail
-
postalCode
final Optional<String> postalCode()
Postal code of service location.
-
streetAddress
final Optional<String> streetAddress()
Street address of service location.
-
_city
final JsonField<String> _city()
Returns the raw JSON value of city.
Unlike city, this method doesn't throw if the JSON field has an unexpected type.
-
_country
final JsonField<String> _country()
Returns the raw JSON value of country.
Unlike country, this method doesn't throw if the JSON field has an unexpected type.
-
_postalCode
final JsonField<String> _postalCode()
Returns the raw JSON value of postalCode.
Unlike postalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<String> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_streetAddress
final JsonField<String> _streetAddress()
Returns the raw JSON value of streetAddress.
Unlike streetAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.ServiceLocation.Builder toBuilder()
-
validate
final Transaction.ServiceLocation validate()
-
builder
final static Transaction.ServiceLocation.Builder builder()
Returns a mutable builder for constructing an instance of ServiceLocation.
The following fields are required:
.city() .country() .postalCode() .state() .streetAddress()
-
-
-
-