Package com.lithic.api.models
Class TransactionListPage
-
- All Implemented Interfaces:
public final class TransactionListPageList card transactions. All amounts are in the smallest unit of their respective currency (e.g., cents for USD) and inclusive of any acquirer fees.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionListPage.Responsepublic final classTransactionListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final TransactionListPage.Responseresponse()final List<Transaction>data()final BooleanhasMore()Booleanequals(Object other)IntegerhashCode()StringtoString()final BooleanhasNextPage()final Optional<TransactionListParams>getNextPageParams()final Optional<TransactionListPage>getNextPage()final TransactionListPage.AutoPagerautoPager()final static TransactionListPageof(TransactionService transactionsService, TransactionListParams params, TransactionListPage.Response response)-
-
Method Detail
-
response
final TransactionListPage.Response response()
-
data
final List<Transaction> data()
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<TransactionListParams> getNextPageParams()
-
getNextPage
final Optional<TransactionListPage> getNextPage()
-
autoPager
final TransactionListPage.AutoPager autoPager()
-
of
final static TransactionListPage of(TransactionService transactionsService, TransactionListParams params, TransactionListPage.Response response)
-
-
-
-