Package com.lithic.api.models
Class TransactionListPageAsync
-
- All Implemented Interfaces:
public final class TransactionListPageAsyncList card transactions. All amounts are in the smallest unit of their respective currency (e.g., cents for USD) and inclusive of any acquirer fees.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionListPageAsync.Responsepublic final classTransactionListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final TransactionListPageAsync.Responseresponse()final List<Transaction>data()final BooleanhasMore()Booleanequals(Object other)IntegerhashCode()StringtoString()final BooleanhasNextPage()final Optional<TransactionListParams>getNextPageParams()final CompletableFuture<Optional<TransactionListPageAsync>>getNextPage()final TransactionListPageAsync.AutoPagerautoPager()final static TransactionListPageAsyncof(TransactionServiceAsync transactionsService, TransactionListParams params, TransactionListPageAsync.Response response)-
-
Method Detail
-
response
final TransactionListPageAsync.Response response()
-
data
final List<Transaction> data()
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<TransactionListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<TransactionListPageAsync>> getNextPage()
-
autoPager
final TransactionListPageAsync.AutoPager autoPager()
-
of
final static TransactionListPageAsync of(TransactionServiceAsync transactionsService, TransactionListParams params, TransactionListPageAsync.Response response)
-
-
-
-