Class V2RetrieveFeaturesResponse.SpendFeatureState
-
- All Implemented Interfaces:
public final class V2RetrieveFeaturesResponse.SpendFeatureState
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV2RetrieveFeaturesResponse.SpendFeatureState.BuilderA builder for SpendFeatureState.
public final classV2RetrieveFeaturesResponse.SpendFeatureState.VelocityLimitFilterspublic final classV2RetrieveFeaturesResponse.SpendFeatureState.VelocityScopeThe scope the velocity is calculated for
public final classV2RetrieveFeaturesResponse.SpendFeatureState.Value
-
Method Summary
-
-
Method Detail
-
period
final VelocityLimitPeriod period()
Velocity over the current day since 00:00 / 12 AM in Eastern Time
-
scope
final V2RetrieveFeaturesResponse.SpendFeatureState.VelocityScope scope()
The scope the velocity is calculated for
-
value
final V2RetrieveFeaturesResponse.SpendFeatureState.Value value()
-
_filters
final JsonField<V2RetrieveFeaturesResponse.SpendFeatureState.VelocityLimitFilters> _filters()
Returns the raw JSON value of filters.
Unlike filters, this method doesn't throw if the JSON field has an unexpected type.
-
_period
final JsonField<VelocityLimitPeriod> _period()
Returns the raw JSON value of period.
Unlike period, this method doesn't throw if the JSON field has an unexpected type.
-
_scope
final JsonField<V2RetrieveFeaturesResponse.SpendFeatureState.VelocityScope> _scope()
Returns the raw JSON value of scope.
Unlike scope, this method doesn't throw if the JSON field has an unexpected type.
-
_value
final JsonField<V2RetrieveFeaturesResponse.SpendFeatureState.Value> _value()
Returns the raw JSON value of value.
Unlike value, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V2RetrieveFeaturesResponse.SpendFeatureState.Builder toBuilder()
-
validate
final V2RetrieveFeaturesResponse.SpendFeatureState validate()
-
builder
final static V2RetrieveFeaturesResponse.SpendFeatureState.Builder builder()
Returns a mutable builder for constructing an instance of SpendFeatureState.
The following fields are required:
.filters() .period() .scope() .value()
-
-
-
-