Class VelocityLimitPeriod.FixedWindowYear
-
- All Implemented Interfaces:
public final class VelocityLimitPeriod.FixedWindowYearVelocity over the current year since 00:00 / 12 AM in Eastern Time on specified
monthandday_of_month. This validates the month and day of the year to start from is a real date. In the event that February 29th is selected, in non-leap years, the window will start from February 28th.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVelocityLimitPeriod.FixedWindowYear.BuilderA builder for FixedWindowYear.
public final classVelocityLimitPeriod.FixedWindowYear.Type
-
Method Summary
Modifier and Type Method Description final VelocityLimitPeriod.FixedWindowYear.Typetype()final Optional<Long>dayOfMonth()The day of the month to start from. final Optional<Long>month()The month to start from. final JsonField<VelocityLimitPeriod.FixedWindowYear.Type>_type()Returns the raw JSON value of type. final JsonField<Long>_dayOfMonth()Returns the raw JSON value of dayOfMonth. final JsonField<Long>_month()Returns the raw JSON value of month. final Map<String, JsonValue>_additionalProperties()final VelocityLimitPeriod.FixedWindowYear.BuildertoBuilder()final VelocityLimitPeriod.FixedWindowYearvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VelocityLimitPeriod.FixedWindowYear.Builderbuilder()Returns a mutable builder for constructing an instance of FixedWindowYear. -
-
Method Detail
-
type
final VelocityLimitPeriod.FixedWindowYear.Type type()
-
dayOfMonth
final Optional<Long> dayOfMonth()
The day of the month to start from. Defaults to the 1st of the month if not specified.
-
month
final Optional<Long> month()
The month to start from. 1 is January and 12 is December. Defaults to January if not specified.
-
_type
final JsonField<VelocityLimitPeriod.FixedWindowYear.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_dayOfMonth
final JsonField<Long> _dayOfMonth()
Returns the raw JSON value of dayOfMonth.
Unlike dayOfMonth, this method doesn't throw if the JSON field has an unexpected type.
-
_month
final JsonField<Long> _month()
Returns the raw JSON value of month.
Unlike month, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VelocityLimitPeriod.FixedWindowYear.Builder toBuilder()
-
validate
final VelocityLimitPeriod.FixedWindowYear validate()
-
builder
final static VelocityLimitPeriod.FixedWindowYear.Builder builder()
Returns a mutable builder for constructing an instance of FixedWindowYear.
The following fields are required:
.type()
-
-
-
-