Interface EventSubscriptionServiceAsync
-
- All Implemented Interfaces:
public interface EventSubscriptionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceEventSubscriptionServiceAsync.WithRawResponseA view of EventSubscriptionServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract EventSubscriptionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<Void>resend(EventEventSubscriptionResendParams params)Resend an event to an event subscription. abstract CompletableFuture<Void>resend(EventEventSubscriptionResendParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract EventSubscriptionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
resend
CompletableFuture<Void> resend(EventEventSubscriptionResendParams params)
Resend an event to an event subscription.
-
resend
abstract CompletableFuture<Void> resend(EventEventSubscriptionResendParams params, RequestOptions requestOptions)
-
-
-
-