Class CreditConfigurationServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.async.financialAccounts.CreditConfigurationServiceAsync
public final class CreditConfigurationServiceAsyncImpl implements CreditConfigurationServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCreditConfigurationServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CreditConfigurationServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<FinancialAccountCreditConfig>retrieve(FinancialAccountCreditConfigurationRetrieveParams params, RequestOptions requestOptions)CompletableFuture<FinancialAccountCreditConfig>update(FinancialAccountCreditConfigurationUpdateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CreditConfigurationServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<FinancialAccountCreditConfig> retrieve(FinancialAccountCreditConfigurationRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<FinancialAccountCreditConfig> update(FinancialAccountCreditConfigurationUpdateParams params, RequestOptions requestOptions)
-
-
-
-