Class FinancialTransactionServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.async.financialAccounts.FinancialTransactionServiceAsync
public final class FinancialTransactionServiceAsyncImpl implements FinancialTransactionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinancialTransactionServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description FinancialTransactionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<FinancialTransaction>retrieve(FinancialTransactionRetrieveParams params, RequestOptions requestOptions)CompletableFuture<FinancialTransactionListPageAsync>list(FinancialTransactionListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
FinancialTransactionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<FinancialTransaction> retrieve(FinancialTransactionRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<FinancialTransactionListPageAsync> list(FinancialTransactionListParams params, RequestOptions requestOptions)
-
-
-
-