Interface SubscriptionService
-
- All Implemented Interfaces:
public interface SubscriptionService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSubscriptionService.WithRawResponseA view of SubscriptionService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract SubscriptionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
EventSubscription create(EventSubscriptionCreateParams params)
Create a new event subscription.
-
create
abstract EventSubscription create(EventSubscriptionCreateParams params, RequestOptions requestOptions)
-
retrieve
EventSubscription retrieve(EventSubscriptionRetrieveParams params)
Get an event subscription.
-
retrieve
abstract EventSubscription retrieve(EventSubscriptionRetrieveParams params, RequestOptions requestOptions)
-
update
EventSubscription update(EventSubscriptionUpdateParams params)
Update an event subscription.
-
update
abstract EventSubscription update(EventSubscriptionUpdateParams params, RequestOptions requestOptions)
-
list
EventSubscriptionListPage list()
List all the event subscriptions.
-
list
abstract EventSubscriptionListPage list(EventSubscriptionListParams params, RequestOptions requestOptions)
-
list
EventSubscriptionListPage list(EventSubscriptionListParams params)
-
list
EventSubscriptionListPage list(RequestOptions requestOptions)
-
delete
Unit delete(EventSubscriptionDeleteParams params)
Delete an event subscription.
-
delete
abstract Unit delete(EventSubscriptionDeleteParams params, RequestOptions requestOptions)
-
listAttempts
EventSubscriptionListAttemptsPage listAttempts(EventSubscriptionListAttemptsParams params)
List all the message attempts for a given event subscription.
-
listAttempts
abstract EventSubscriptionListAttemptsPage listAttempts(EventSubscriptionListAttemptsParams params, RequestOptions requestOptions)
-
recover
Unit recover(EventSubscriptionRecoverParams params)
Resend all failed messages since a given time.
-
recover
abstract Unit recover(EventSubscriptionRecoverParams params, RequestOptions requestOptions)
-
replayMissing
Unit replayMissing(EventSubscriptionReplayMissingParams params)
Replays messages to the endpoint. Only messages that were created after
beginwill be sent. Messages that were previously sent to the endpoint are not resent. Message will be retried if endpoint responds with a non-2xx status code. See Retry Schedule for details.
-
replayMissing
abstract Unit replayMissing(EventSubscriptionReplayMissingParams params, RequestOptions requestOptions)
-
retrieveSecret
SubscriptionRetrieveSecretResponse retrieveSecret(EventSubscriptionRetrieveSecretParams params)
Get the secret for an event subscription.
-
retrieveSecret
abstract SubscriptionRetrieveSecretResponse retrieveSecret(EventSubscriptionRetrieveSecretParams params, RequestOptions requestOptions)
-
rotateSecret
Unit rotateSecret(EventSubscriptionRotateSecretParams params)
Rotate the secret for an event subscription. The previous secret will be valid for the next 24 hours.
-
rotateSecret
abstract Unit rotateSecret(EventSubscriptionRotateSecretParams params, RequestOptions requestOptions)
-
sendSimulatedExample
Unit sendSimulatedExample(EventSubscriptionSendSimulatedExampleParams params)
Send an example message for event.
-
sendSimulatedExample
abstract Unit sendSimulatedExample(EventSubscriptionSendSimulatedExampleParams params, RequestOptions requestOptions)
-
-
-
-