Class MicroDepositServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.externalBankAccounts.MicroDepositService
public final class MicroDepositServiceImpl implements MicroDepositService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMicroDepositServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description MicroDepositService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. MicroDepositCreateResponsecreate(ExternalBankAccountMicroDepositCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
MicroDepositService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
MicroDepositCreateResponse create(ExternalBankAccountMicroDepositCreateParams params, RequestOptions requestOptions)
-
-
-
-